{% load widget_tweaks %}

{% fragment as select_classes %}
form-select {{ classes }}
{% endfragment %}

{% fragment as input_classes %}
form-select {{ classes }}
{% endfragment %}

{% if input %}
    {% form_input data_control="select2" input=input input_classes=input_classes form=form placeholder=placeholder classes=classes hide=hide label_classes=label_classes label=label help_text=help_text errors=errors %}
{% endif %}