<div class="modal fade" tabindex="-1" id="{{ id }}">
    <div class="modal-dialog">
        <div class="modal-content position-absolute">
            <div class="modal-header">
                <h5 class="modal-title">{{ title }}</h5>
                <!--begin::Close-->
                <div class="btn btn-icon btn-sm btn-active-light-primary ms-2"
                     data-bs-dismiss="modal"
                     aria-label="Close">
                    <i class="ki-duotone ki-cross fs-2x"><span class="path1"></span><span class="path2"></span></i>
                </div>
                <!--end::Close-->
            </div>
            <div class="modal-body">{{ children }}</div>
            <div class="modal-footer">
                <button type="button" class="btn btn-light modal-left-button" data-bs-dismiss="modal">{{ close_label|default:"Fechar" }}</button>
                <button type="button"
                        class="btn btn-primary modal-right-button">
                    {{ save_label|default:"Guardar" }}
                </button>
            </div>
        </div>
    </div>
</div>
