<div {% attrs id style %} class="col-md-{{ cols|default:3 }}">
    <a href="javascript:;" class="btn btn-sm btn-flex flex-center btn-light-danger mt-3 mt-md-9 {{ classes }}">
        <i class="ki-duotone ki-trash fs-5"><span class="path1"></span><span class="path2"></span><span class="path3"></span><span class="path4"></span><span class="path5"></span></i>
        Apagar                                        
    </a>
</div>