<div>
    <!-- begin::Menu toggle -->
    <a href="#" class="btn btn-sm btn-flex btn-{{ type|default:'secondary' }} fw-bold menu-dropdown" data-kt-menu-trigger="click" data-kt-menu-placement="bottom-end">
        <i class="{{ icon }} fs-6 me-1"></i>               
        {{ label }}
    </a>
    <!-- end::Menu toggle -->

    <!-- begin::Menu -->
    <div class="menu menu-sub menu-sub-dropdown menu-column menu-rounded menu-gray-600 menu-state-bg-light-primary fw-semibold fs-7 w-{{ width|default:250 }}px py-4" data-kt-menu="true">
        {{ children }}
    </div>
    <!-- end::Menu -->
</div>