<!--begin::Menu item-->
<div class="menu-item">
    <!--begin:Menu link--><a class="menu-link" href="/metronic8/demo1/../demo1/apps/calendar.html"><span class="menu-icon"><i class="ki-duotone ki-calendar-8 fs-2"><span class="path1"></span><span class="path2"></span><span class="path3"></span><span class="path4"></span><span class="path5"></span><span class="path6"></span></i></span><span class="menu-title">Calendar</span></a><!--end:Menu link-->
</div>
<!--end::Menu item-->