<!--begin:Menu item-->
<div class="menu-item pt-5">
    <!--begin:Menu content-->
    <div class="menu-content">
        <span class="menu-heading fw-bold text-uppercase fs-7">Pages</span>
    </div>
    <!--end:Menu content-->
</div>
<!--end:Menu item-->