<!--begin::Menu item-->
<div class="menu-item px-3 my-0">
   <a href="#"
      class="menu-link px-3 py-2 active"
      data-kt-element="mode"
      data-kt-value="light">
       <span class="menu-icon" data-kt-element="icon">
           <i class="ki-duotone ki-night-day fs-2"><span class="path1"></span><span class="path2"></span><span class="path3"></span><span class="path4"></span><span class="path5"></span><span class="path6"></span><span class="path7"></span><span class="path8"></span><span class="path9"></span><span class="path10"></span></i>            </span>
       <span class="menu-title">Light</span>
   </a>
</div>
<!--end::Menu item-->
<!--begin::Menu item-->
<div class="menu-item px-3 my-0">
   <a href="#"
      class="menu-link px-3 py-2"
      data-kt-element="mode"
      data-kt-value="dark">
       <span class="menu-icon" data-kt-element="icon">
           <i class="ki-duotone ki-moon fs-2"><span class="path1"></span><span class="path2"></span></i>            </span>
       <span class="menu-title">
           Dark
       </span>
   </a>
</div>
<!--end::Menu item-->
<!--begin::Menu item-->
<div class="menu-item px-3 my-0">
   <a href="#"
      class="menu-link px-3 py-2"
      data-kt-element="mode"
      data-kt-value="system">
       <span class="menu-icon" data-kt-element="icon">
           <i class="ki-duotone ki-screen fs-2"><span class="path1"></span><span class="path2"></span><span class="path3"></span><span class="path4"></span></i>            </span>
       <span class="menu-title">
           Sistema
       </span>
   </a>
</div>
<!--end::Menu item-->