{% if has_permissions %}
<!--begin::Menu item-->
<div class="menu-item">
    <!--begin:Menu link-->
    <a id="{{ id }}" class="menu-link {{ active|yesno:'active, ' }}" href="{% url url_name %}">
        <span class="menu-icon">
            <i class="{{ icon }} fs-2"></i>
        </span>
        <span class="menu-title">{{ name }}</span>
    </a>
    <!--end:Menu link-->
</div>
<!--end::Menu item-->
{% endif %}