<!--begin::Toolbar button-->
<a href="{{ url|default:'#' }}"
   class="btn btn-sm fw-bold btn-{{ type|default:'primary' }} {{ classes }}">
    {{ label|default:"Criar" }}
</a>
<!--end::Toolbar button-->
