<div id="kt_app_footer" class="app-footer ">
    <!--begin::Footer container-->
    <div class="app-container  container-fluid d-flex flex-column flex-md-row flex-center flex-md-stack py-3 ">
        <!--begin::Copyright-->
        <div class="text-gray-900 order-2 order-md-1">
            <span class="text-muted fw-semibold me-1">{% now 'Y' %}©</span>
            <a href="{{ BASE_URL }}"
               target="_blank"
               class="text-gray-800 text-hover-primary">Empresa Diário de Notícias, Lda.</a>
        </div>
        <!--end::Copyright-->
    </div>
    <!--end::Footer container-->
</div>
