/**
 * vis-timeline and vis-graph2d
 * https://visjs.github.io/vis-timeline/
 *
 * Create a fully customizable, interactive timeline with items and ranges.
 *
 * @version 7.7.3
 * @date    2023-10-27T17:57:57.604Z
 *
 * @copyright (c) 2011-2017 Almende B.V, http://almende.com
 * @copyright (c) 2017-2019 visjs contributors, https://github.com/visjs
 *
 * @license
 * vis.js is dual licensed under both
 *
 *   1. The Apache 2.0 License
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *   and
 *
 *   2. The MIT License
 *      http://opensource.org/licenses/MIT
 *
 * vis.js may be distributed under either license.
 */
!function(t,e){"object"==typeof exports&&"undefined"!=typeof module?e(exports):"function"==typeof define&&define.amd?define(["exports"],e):e((t="undefined"!=typeof globalThis?globalThis:t||self).vis=t.vis||{})}(this,(function(t){var e="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function n(t){return t&&t.__esModule&&Object.prototype.hasOwnProperty.call(t,"default")?t.default:t}var r,o,s={exports:{}};function a(){return r||(r=1,function(t,e){t.exports=function(){var e,i;function n(){return e.apply(null,arguments)}function r(t){return t instanceof Array||"[object Array]"===Object.prototype.toString.call(t)}function o(t){return null!=t&&"[object Object]"===Object.prototype.toString.call(t)}function s(t,e){return Object.prototype.hasOwnProperty.call(t,e)}function a(t){if(Object.getOwnPropertyNames)return 0===Object.getOwnPropertyNames(t).length;var e;for(e in t)if(s(t,e))return!1;return!0}function l(t){return void 0===t}function h(t){return"number"==typeof t||"[object Number]"===Object.prototype.toString.call(t)}function u(t){return t instanceof Date||"[object Date]"===Object.prototype.toString.call(t)}function c(t,e){var i,n=[],r=t.length;for(i=0;i<r;++i)n.push(e(t[i],i));return n}function d(t,e){for(var i in e)s(e,i)&&(t[i]=e[i]);return s(e,"toString")&&(t.toString=e.toString),s(e,"valueOf")&&(t.valueOf=e.valueOf),t}function p(t,e,i,n){return Ne(t,e,i,n,!0).utc()}function f(t){return null==t._pf&&(t._pf={empty:!1,unusedTokens:[],unusedInput:[],overflow:-2,charsLeftOver:0,nullInput:!1,invalidEra:null,invalidMonth:null,invalidFormat:!1,userInvalidated:!1,iso:!1,parsedDateParts:[],era:null,meridiem:null,rfc2822:!1,weekdayMismatch:!1}),t._pf}function m(t){if(null==t._isValid){var e=f(t),n=i.call(e.parsedDateParts,(function(t){return null!=t})),r=!isNaN(t._d.getTime())&&e.overflow<0&&!e.empty&&!e.invalidEra&&!e.invalidMonth&&!e.invalidWeekday&&!e.weekdayMismatch&&!e.nullInput&&!e.invalidFormat&&!e.userInvalidated&&(!e.meridiem||e.meridiem&&n);if(t._strict&&(r=r&&0===e.charsLeftOver&&0===e.unusedTokens.length&&void 0===e.bigHour),null!=Object.isFrozen&&Object.isFrozen(t))return r;t._isValid=r}return t._isValid}function v(t){var e=p(NaN);return null!=t?d(f(e),t):f(e).userInvalidated=!0,e}i=Array.prototype.some?Array.prototype.some:function(t){var e,i=Object(this),n=i.length>>>0;for(e=0;e<n;e++)if(e in i&&t.call(this,i[e],e,i))return!0;return!1};var g=n.momentProperties=[],y=!1;function b(t,e){var i,n,r,o=g.length;if(l(e._isAMomentObject)||(t._isAMomentObject=e._isAMomentObject),l(e._i)||(t._i=e._i),l(e._f)||(t._f=e._f),l(e._l)||(t._l=e._l),l(e._strict)||(t._strict=e._strict),l(e._tzm)||(t._tzm=e._tzm),l(e._isUTC)||(t._isUTC=e._isUTC),l(e._offset)||(t._offset=e._offset),l(e._pf)||(t._pf=f(e)),l(e._locale)||(t._locale=e._locale),o>0)for(i=0;i<o;i++)l(r=e[n=g[i]])||(t[n]=r);return t}function _(t){b(this,t),this._d=new Date(null!=t._d?t._d.getTime():NaN),this.isValid()||(this._d=new Date(NaN)),!1===y&&(y=!0,n.updateOffset(this),y=!1)}function w(t){return t instanceof _||null!=t&&null!=t._isAMomentObject}function k(t){!1===n.suppressDeprecationWarnings&&"undefined"!=typeof console&&console.warn&&console.warn("Deprecation warning: "+t)}function x(t,e){var i=!0;return d((function(){if(null!=n.deprecationHandler&&n.deprecationHandler(null,t),i){var r,o,a,l=[],h=arguments.length;for(o=0;o<h;o++){if(r="","object"==typeof arguments[o]){for(a in r+="\n["+o+"] ",arguments[0])s(arguments[0],a)&&(r+=a+": "+arguments[0][a]+", ");r=r.slice(0,-2)}else r=arguments[o];l.push(r)}k(t+"\nArguments: "+Array.prototype.slice.call(l).join("")+"\n"+(new Error).stack),i=!1}return e.apply(this,arguments)}),e)}var S,D={};function C(t,e){null!=n.deprecationHandler&&n.deprecationHandler(t,e),D[t]||(k(e),D[t]=!0)}function T(t){return"undefined"!=typeof Function&&t instanceof Function||"[object Function]"===Object.prototype.toString.call(t)}function M(t,e){var i,n=d({},t);for(i in e)s(e,i)&&(o(t[i])&&o(e[i])?(n[i]={},d(n[i],t[i]),d(n[i],e[i])):null!=e[i]?n[i]=e[i]:delete n[i]);for(i in t)s(t,i)&&!s(e,i)&&o(t[i])&&(n[i]=d({},n[i]));return n}function O(t){null!=t&&this.set(t)}n.suppressDeprecationWarnings=!1,n.deprecationHandler=null,S=Object.keys?Object.keys:function(t){var e,i=[];for(e in t)s(t,e)&&i.push(e);return i};function P(t,e,i){var n=""+Math.abs(t),r=e-n.length;return(t>=0?i?"+":"":"-")+Math.pow(10,Math.max(0,r)).toString().substr(1)+n}var E=/(\[[^\[]*\])|(\\)?([Hh]mm(ss)?|Mo|MM?M?M?|Do|DDDo|DD?D?D?|ddd?d?|do?|w[o|w]?|W[o|W]?|Qo?|N{1,5}|YYYYYY|YYYYY|YYYY|YY|y{2,4}|yo?|gg(ggg?)?|GG(GGG?)?|e|E|a|A|hh?|HH?|kk?|mm?|ss?|S{1,9}|x|X|zz?|ZZ?|.)/g,I=/(\[[^\[]*\])|(\\)?(LTS|LT|LL?L?L?|l{1,4})/g,L={},A={};function N(t,e,i,n){var r=n;"string"==typeof n&&(r=function(){return this[n]()}),t&&(A[t]=r),e&&(A[e[0]]=function(){return P(r.apply(this,arguments),e[1],e[2])}),i&&(A[i]=function(){return this.localeData().ordinal(r.apply(this,arguments),t)})}function R(t){return t.match(/\[[\s\S]/)?t.replace(/^\[|\]$/g,""):t.replace(/\\/g,"")}function F(t,e){return t.isValid()?(e=j(e,t.localeData()),L[e]=L[e]||function(t){var e,i,n=t.match(E);for(e=0,i=n.length;e<i;e++)A[n[e]]?n[e]=A[n[e]]:n[e]=R(n[e]);return function(e){var r,o="";for(r=0;r<i;r++)o+=T(n[r])?n[r].call(e,t):n[r];return o}}(e),L[e](t)):t.localeData().invalidDate()}function j(t,e){var i=5;function n(t){return e.longDateFormat(t)||t}for(I.lastIndex=0;i>=0&&I.test(t);)t=t.replace(I,n),I.lastIndex=0,i-=1;return t}var Y={};function H(t,e){var i=t.toLowerCase();Y[i]=Y[i+"s"]=Y[e]=t}function B(t){return"string"==typeof t?Y[t]||Y[t.toLowerCase()]:void 0}function z(t){var e,i,n={};for(i in t)s(t,i)&&(e=B(i))&&(n[e]=t[i]);return n}var G={};function W(t,e){G[t]=e}function V(t){return t%4==0&&t%100!=0||t%400==0}function U(t){return t<0?Math.ceil(t)||0:Math.floor(t)}function X(t){var e=+t,i=0;return 0!==e&&isFinite(e)&&(i=U(e)),i}function q(t,e){return function(i){return null!=i?(K(this,t,i),n.updateOffset(this,e),this):$(this,t)}}function $(t,e){return t.isValid()?t._d["get"+(t._isUTC?"UTC":"")+e]():NaN}function K(t,e,i){t.isValid()&&!isNaN(i)&&("FullYear"===e&&V(t.year())&&1===t.month()&&29===t.date()?(i=X(i),t._d["set"+(t._isUTC?"UTC":"")+e](i,t.month(),Et(i,t.month()))):t._d["set"+(t._isUTC?"UTC":"")+e](i))}var Z,J=/\d/,Q=/\d\d/,tt=/\d{3}/,et=/\d{4}/,it=/[+-]?\d{6}/,nt=/\d\d?/,rt=/\d\d\d\d?/,ot=/\d\d\d\d\d\d?/,st=/\d{1,3}/,at=/\d{1,4}/,lt=/[+-]?\d{1,6}/,ht=/\d+/,ut=/[+-]?\d+/,ct=/Z|[+-]\d\d:?\d\d/gi,dt=/Z|[+-]\d\d(?::?\d\d)?/gi,pt=/[0-9]{0,256}['a-z\u00A0-\u05FF\u0700-\uD7FF\uF900-\uFDCF\uFDF0-\uFF07\uFF10-\uFFEF]{1,256}|[\u0600-\u06FF\/]{1,256}(\s*?[\u0600-\u06FF]{1,256}){1,2}/i;function ft(t,e,i){Z[t]=T(e)?e:function(t,n){return t&&i?i:e}}function mt(t,e){return s(Z,t)?Z[t](e._strict,e._locale):new RegExp(function(t){return vt(t.replace("\\","").replace(/\\(\[)|\\(\])|\[([^\]\[]*)\]|\\(.)/g,(function(t,e,i,n,r){return e||i||n||r})))}(t))}function vt(t){return t.replace(/[-\/\\^$*+?.()|[\]{}]/g,"\\$&")}Z={};var gt={};function yt(t,e){var i,n,r=e;for("string"==typeof t&&(t=[t]),h(e)&&(r=function(t,i){i[e]=X(t)}),n=t.length,i=0;i<n;i++)gt[t[i]]=r}function bt(t,e){yt(t,(function(t,i,n,r){n._w=n._w||{},e(t,n._w,n,r)}))}function _t(t,e,i){null!=e&&s(gt,t)&&gt[t](e,i._a,i,t)}var wt,kt=0,xt=1,St=2,Dt=3,Ct=4,Tt=5,Mt=6,Ot=7,Pt=8;function Et(t,e){if(isNaN(t)||isNaN(e))return NaN;var i=function(t,e){return(t%e+e)%e}(e,12);return t+=(e-i)/12,1===i?V(t)?29:28:31-i%7%2}wt=Array.prototype.indexOf?Array.prototype.indexOf:function(t){var e;for(e=0;e<this.length;++e)if(this[e]===t)return e;return-1},N("M",["MM",2],"Mo",(function(){return this.month()+1})),N("MMM",0,0,(function(t){return this.localeData().monthsShort(this,t)})),N("MMMM",0,0,(function(t){return this.localeData().months(this,t)})),H("month","M"),W("month",8),ft("M",nt),ft("MM",nt,Q),ft("MMM",(function(t,e){return e.monthsShortRegex(t)})),ft("MMMM",(function(t,e){return e.monthsRegex(t)})),yt(["M","MM"],(function(t,e){e[xt]=X(t)-1})),yt(["MMM","MMMM"],(function(t,e,i,n){var r=i._locale.monthsParse(t,n,i._strict);null!=r?e[xt]=r:f(i).invalidMonth=t}));var It="January_February_March_April_May_June_July_August_September_October_November_December".split("_"),Lt="Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"),At=/D[oD]?(\[[^\[\]]*\]|\s)+MMMM?/,Nt=pt,Rt=pt;function Ft(t,e,i){var n,r,o,s=t.toLocaleLowerCase();if(!this._monthsParse)for(this._monthsParse=[],this._longMonthsParse=[],this._shortMonthsParse=[],n=0;n<12;++n)o=p([2e3,n]),this._shortMonthsParse[n]=this.monthsShort(o,"").toLocaleLowerCase(),this._longMonthsParse[n]=this.months(o,"").toLocaleLowerCase();return i?"MMM"===e?-1!==(r=wt.call(this._shortMonthsParse,s))?r:null:-1!==(r=wt.call(this._longMonthsParse,s))?r:null:"MMM"===e?-1!==(r=wt.call(this._shortMonthsParse,s))||-1!==(r=wt.call(this._longMonthsParse,s))?r:null:-1!==(r=wt.call(this._longMonthsParse,s))||-1!==(r=wt.call(this._shortMonthsParse,s))?r:null}function jt(t,e){var i;if(!t.isValid())return t;if("string"==typeof e)if(/^\d+$/.test(e))e=X(e);else if(!h(e=t.localeData().monthsParse(e)))return t;return i=Math.min(t.date(),Et(t.year(),e)),t._d["set"+(t._isUTC?"UTC":"")+"Month"](e,i),t}function Yt(t){return null!=t?(jt(this,t),n.updateOffset(this,!0),this):$(this,"Month")}function Ht(){function t(t,e){return e.length-t.length}var e,i,n=[],r=[],o=[];for(e=0;e<12;e++)i=p([2e3,e]),n.push(this.monthsShort(i,"")),r.push(this.months(i,"")),o.push(this.months(i,"")),o.push(this.monthsShort(i,""));for(n.sort(t),r.sort(t),o.sort(t),e=0;e<12;e++)n[e]=vt(n[e]),r[e]=vt(r[e]);for(e=0;e<24;e++)o[e]=vt(o[e]);this._monthsRegex=new RegExp("^("+o.join("|")+")","i"),this._monthsShortRegex=this._monthsRegex,this._monthsStrictRegex=new RegExp("^("+r.join("|")+")","i"),this._monthsShortStrictRegex=new RegExp("^("+n.join("|")+")","i")}function Bt(t){return V(t)?366:365}N("Y",0,0,(function(){var t=this.year();return t<=9999?P(t,4):"+"+t})),N(0,["YY",2],0,(function(){return this.year()%100})),N(0,["YYYY",4],0,"year"),N(0,["YYYYY",5],0,"year"),N(0,["YYYYYY",6,!0],0,"year"),H("year","y"),W("year",1),ft("Y",ut),ft("YY",nt,Q),ft("YYYY",at,et),ft("YYYYY",lt,it),ft("YYYYYY",lt,it),yt(["YYYYY","YYYYYY"],kt),yt("YYYY",(function(t,e){e[kt]=2===t.length?n.parseTwoDigitYear(t):X(t)})),yt("YY",(function(t,e){e[kt]=n.parseTwoDigitYear(t)})),yt("Y",(function(t,e){e[kt]=parseInt(t,10)})),n.parseTwoDigitYear=function(t){return X(t)+(X(t)>68?1900:2e3)};var zt=q("FullYear",!0);function Gt(t,e,i,n,r,o,s){var a;return t<100&&t>=0?(a=new Date(t+400,e,i,n,r,o,s),isFinite(a.getFullYear())&&a.setFullYear(t)):a=new Date(t,e,i,n,r,o,s),a}function Wt(t){var e,i;return t<100&&t>=0?((i=Array.prototype.slice.call(arguments))[0]=t+400,e=new Date(Date.UTC.apply(null,i)),isFinite(e.getUTCFullYear())&&e.setUTCFullYear(t)):e=new Date(Date.UTC.apply(null,arguments)),e}function Vt(t,e,i){var n=7+e-i;return-(7+Wt(t,0,n).getUTCDay()-e)%7+n-1}function Ut(t,e,i,n,r){var o,s,a=1+7*(e-1)+(7+i-n)%7+Vt(t,n,r);return a<=0?s=Bt(o=t-1)+a:a>Bt(t)?(o=t+1,s=a-Bt(t)):(o=t,s=a),{year:o,dayOfYear:s}}function Xt(t,e,i){var n,r,o=Vt(t.year(),e,i),s=Math.floor((t.dayOfYear()-o-1)/7)+1;return s<1?n=s+qt(r=t.year()-1,e,i):s>qt(t.year(),e,i)?(n=s-qt(t.year(),e,i),r=t.year()+1):(r=t.year(),n=s),{week:n,year:r}}function qt(t,e,i){var n=Vt(t,e,i),r=Vt(t+1,e,i);return(Bt(t)-n+r)/7}N("w",["ww",2],"wo","week"),N("W",["WW",2],"Wo","isoWeek"),H("week","w"),H("isoWeek","W"),W("week",5),W("isoWeek",5),ft("w",nt),ft("ww",nt,Q),ft("W",nt),ft("WW",nt,Q),bt(["w","ww","W","WW"],(function(t,e,i,n){e[n.substr(0,1)]=X(t)}));function $t(t,e){return t.slice(e,7).concat(t.slice(0,e))}N("d",0,"do","day"),N("dd",0,0,(function(t){return this.localeData().weekdaysMin(this,t)})),N("ddd",0,0,(function(t){return this.localeData().weekdaysShort(this,t)})),N("dddd",0,0,(function(t){return this.localeData().weekdays(this,t)})),N("e",0,0,"weekday"),N("E",0,0,"isoWeekday"),H("day","d"),H("weekday","e"),H("isoWeekday","E"),W("day",11),W("weekday",11),W("isoWeekday",11),ft("d",nt),ft("e",nt),ft("E",nt),ft("dd",(function(t,e){return e.weekdaysMinRegex(t)})),ft("ddd",(function(t,e){return e.weekdaysShortRegex(t)})),ft("dddd",(function(t,e){return e.weekdaysRegex(t)})),bt(["dd","ddd","dddd"],(function(t,e,i,n){var r=i._locale.weekdaysParse(t,n,i._strict);null!=r?e.d=r:f(i).invalidWeekday=t})),bt(["d","e","E"],(function(t,e,i,n){e[n]=X(t)}));var Kt="Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),Zt="Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"),Jt="Su_Mo_Tu_We_Th_Fr_Sa".split("_"),Qt=pt,te=pt,ee=pt;function ie(t,e,i){var n,r,o,s=t.toLocaleLowerCase();if(!this._weekdaysParse)for(this._weekdaysParse=[],this._shortWeekdaysParse=[],this._minWeekdaysParse=[],n=0;n<7;++n)o=p([2e3,1]).day(n),this._minWeekdaysParse[n]=this.weekdaysMin(o,"").toLocaleLowerCase(),this._shortWeekdaysParse[n]=this.weekdaysShort(o,"").toLocaleLowerCase(),this._weekdaysParse[n]=this.weekdays(o,"").toLocaleLowerCase();return i?"dddd"===e?-1!==(r=wt.call(this._weekdaysParse,s))?r:null:"ddd"===e?-1!==(r=wt.call(this._shortWeekdaysParse,s))?r:null:-1!==(r=wt.call(this._minWeekdaysParse,s))?r:null:"dddd"===e?-1!==(r=wt.call(this._weekdaysParse,s))||-1!==(r=wt.call(this._shortWeekdaysParse,s))||-1!==(r=wt.call(this._minWeekdaysParse,s))?r:null:"ddd"===e?-1!==(r=wt.call(this._shortWeekdaysParse,s))||-1!==(r=wt.call(this._weekdaysParse,s))||-1!==(r=wt.call(this._minWeekdaysParse,s))?r:null:-1!==(r=wt.call(this._minWeekdaysParse,s))||-1!==(r=wt.call(this._weekdaysParse,s))||-1!==(r=wt.call(this._shortWeekdaysParse,s))?r:null}function ne(){function t(t,e){return e.length-t.length}var e,i,n,r,o,s=[],a=[],l=[],h=[];for(e=0;e<7;e++)i=p([2e3,1]).day(e),n=vt(this.weekdaysMin(i,"")),r=vt(this.weekdaysShort(i,"")),o=vt(this.weekdays(i,"")),s.push(n),a.push(r),l.push(o),h.push(n),h.push(r),h.push(o);s.sort(t),a.sort(t),l.sort(t),h.sort(t),this._weekdaysRegex=new RegExp("^("+h.join("|")+")","i"),this._weekdaysShortRegex=this._weekdaysRegex,this._weekdaysMinRegex=this._weekdaysRegex,this._weekdaysStrictRegex=new RegExp("^("+l.join("|")+")","i"),this._weekdaysShortStrictRegex=new RegExp("^("+a.join("|")+")","i"),this._weekdaysMinStrictRegex=new RegExp("^("+s.join("|")+")","i")}function re(){return this.hours()%12||12}function oe(t,e){N(t,0,0,(function(){return this.localeData().meridiem(this.hours(),this.minutes(),e)}))}function se(t,e){return e._meridiemParse}N("H",["HH",2],0,"hour"),N("h",["hh",2],0,re),N("k",["kk",2],0,(function(){return this.hours()||24})),N("hmm",0,0,(function(){return""+re.apply(this)+P(this.minutes(),2)})),N("hmmss",0,0,(function(){return""+re.apply(this)+P(this.minutes(),2)+P(this.seconds(),2)})),N("Hmm",0,0,(function(){return""+this.hours()+P(this.minutes(),2)})),N("Hmmss",0,0,(function(){return""+this.hours()+P(this.minutes(),2)+P(this.seconds(),2)})),oe("a",!0),oe("A",!1),H("hour","h"),W("hour",13),ft("a",se),ft("A",se),ft("H",nt),ft("h",nt),ft("k",nt),ft("HH",nt,Q),ft("hh",nt,Q),ft("kk",nt,Q),ft("hmm",rt),ft("hmmss",ot),ft("Hmm",rt),ft("Hmmss",ot),yt(["H","HH"],Dt),yt(["k","kk"],(function(t,e,i){var n=X(t);e[Dt]=24===n?0:n})),yt(["a","A"],(function(t,e,i){i._isPm=i._locale.isPM(t),i._meridiem=t})),yt(["h","hh"],(function(t,e,i){e[Dt]=X(t),f(i).bigHour=!0})),yt("hmm",(function(t,e,i){var n=t.length-2;e[Dt]=X(t.substr(0,n)),e[Ct]=X(t.substr(n)),f(i).bigHour=!0})),yt("hmmss",(function(t,e,i){var n=t.length-4,r=t.length-2;e[Dt]=X(t.substr(0,n)),e[Ct]=X(t.substr(n,2)),e[Tt]=X(t.substr(r)),f(i).bigHour=!0})),yt("Hmm",(function(t,e,i){var n=t.length-2;e[Dt]=X(t.substr(0,n)),e[Ct]=X(t.substr(n))})),yt("Hmmss",(function(t,e,i){var n=t.length-4,r=t.length-2;e[Dt]=X(t.substr(0,n)),e[Ct]=X(t.substr(n,2)),e[Tt]=X(t.substr(r))}));var ae=q("Hours",!0);var le,he={calendar:{sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"},longDateFormat:{LTS:"h:mm:ss A",LT:"h:mm A",L:"MM/DD/YYYY",LL:"MMMM D, YYYY",LLL:"MMMM D, YYYY h:mm A",LLLL:"dddd, MMMM D, YYYY h:mm A"},invalidDate:"Invalid date",ordinal:"%d",dayOfMonthOrdinalParse:/\d{1,2}/,relativeTime:{future:"in %s",past:"%s ago",s:"a few seconds",ss:"%d seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",w:"a week",ww:"%d weeks",M:"a month",MM:"%d months",y:"a year",yy:"%d years"},months:It,monthsShort:Lt,week:{dow:0,doy:6},weekdays:Kt,weekdaysMin:Jt,weekdaysShort:Zt,meridiemParse:/[ap]\.?m?\.?/i},ue={},ce={};function de(t,e){var i,n=Math.min(t.length,e.length);for(i=0;i<n;i+=1)if(t[i]!==e[i])return i;return n}function pe(t){return t?t.toLowerCase().replace("_","-"):t}function fe(e){var i=null;if(void 0===ue[e]&&t&&t.exports&&function(t){return null!=t.match("^[^/\\\\]*$")}(e))try{i=le._abbr,function(t){throw new Error('Could not dynamically require "'+t+'". Please configure the dynamicRequireTargets or/and ignoreDynamicRequires option of @rollup/plugin-commonjs appropriately for this require call to work.')}("./locale/"+e),me(i)}catch(t){ue[e]=null}return ue[e]}function me(t,e){var i;return t&&((i=l(e)?ge(t):ve(t,e))?le=i:"undefined"!=typeof console&&console.warn&&console.warn("Locale "+t+" not found. Did you forget to load it?")),le._abbr}function ve(t,e){if(null!==e){var i,n=he;if(e.abbr=t,null!=ue[t])C("defineLocaleOverride","use moment.updateLocale(localeName, config) to change an existing locale. moment.defineLocale(localeName, config) should only be used for creating a new locale See http://momentjs.com/guides/#/warnings/define-locale/ for more info."),n=ue[t]._config;else if(null!=e.parentLocale)if(null!=ue[e.parentLocale])n=ue[e.parentLocale]._config;else{if(null==(i=fe(e.parentLocale)))return ce[e.parentLocale]||(ce[e.parentLocale]=[]),ce[e.parentLocale].push({name:t,config:e}),null;n=i._config}return ue[t]=new O(M(n,e)),ce[t]&&ce[t].forEach((function(t){ve(t.name,t.config)})),me(t),ue[t]}return delete ue[t],null}function ge(t){var e;if(t&&t._locale&&t._locale._abbr&&(t=t._locale._abbr),!t)return le;if(!r(t)){if(e=fe(t))return e;t=[t]}return function(t){for(var e,i,n,r,o=0;o<t.length;){for(e=(r=pe(t[o]).split("-")).length,i=(i=pe(t[o+1]))?i.split("-"):null;e>0;){if(n=fe(r.slice(0,e).join("-")))return n;if(i&&i.length>=e&&de(r,i)>=e-1)break;e--}o++}return le}(t)}function ye(t){var e,i=t._a;return i&&-2===f(t).overflow&&(e=i[xt]<0||i[xt]>11?xt:i[St]<1||i[St]>Et(i[kt],i[xt])?St:i[Dt]<0||i[Dt]>24||24===i[Dt]&&(0!==i[Ct]||0!==i[Tt]||0!==i[Mt])?Dt:i[Ct]<0||i[Ct]>59?Ct:i[Tt]<0||i[Tt]>59?Tt:i[Mt]<0||i[Mt]>999?Mt:-1,f(t)._overflowDayOfYear&&(e<kt||e>St)&&(e=St),f(t)._overflowWeeks&&-1===e&&(e=Ot),f(t)._overflowWeekday&&-1===e&&(e=Pt),f(t).overflow=e),t}var be=/^\s*((?:[+-]\d{6}|\d{4})-(?:\d\d-\d\d|W\d\d-\d|W\d\d|\d\d\d|\d\d))(?:(T| )(\d\d(?::\d\d(?::\d\d(?:[.,]\d+)?)?)?)([+-]\d\d(?::?\d\d)?|\s*Z)?)?$/,_e=/^\s*((?:[+-]\d{6}|\d{4})(?:\d\d\d\d|W\d\d\d|W\d\d|\d\d\d|\d\d|))(?:(T| )(\d\d(?:\d\d(?:\d\d(?:[.,]\d+)?)?)?)([+-]\d\d(?::?\d\d)?|\s*Z)?)?$/,we=/Z|[+-]\d\d(?::?\d\d)?/,ke=[["YYYYYY-MM-DD",/[+-]\d{6}-\d\d-\d\d/],["YYYY-MM-DD",/\d{4}-\d\d-\d\d/],["GGGG-[W]WW-E",/\d{4}-W\d\d-\d/],["GGGG-[W]WW",/\d{4}-W\d\d/,!1],["YYYY-DDD",/\d{4}-\d{3}/],["YYYY-MM",/\d{4}-\d\d/,!1],["YYYYYYMMDD",/[+-]\d{10}/],["YYYYMMDD",/\d{8}/],["GGGG[W]WWE",/\d{4}W\d{3}/],["GGGG[W]WW",/\d{4}W\d{2}/,!1],["YYYYDDD",/\d{7}/],["YYYYMM",/\d{6}/,!1],["YYYY",/\d{4}/,!1]],xe=[["HH:mm:ss.SSSS",/\d\d:\d\d:\d\d\.\d+/],["HH:mm:ss,SSSS",/\d\d:\d\d:\d\d,\d+/],["HH:mm:ss",/\d\d:\d\d:\d\d/],["HH:mm",/\d\d:\d\d/],["HHmmss.SSSS",/\d\d\d\d\d\d\.\d+/],["HHmmss,SSSS",/\d\d\d\d\d\d,\d+/],["HHmmss",/\d\d\d\d\d\d/],["HHmm",/\d\d\d\d/],["HH",/\d\d/]],Se=/^\/?Date\((-?\d+)/i,De=/^(?:(Mon|Tue|Wed|Thu|Fri|Sat|Sun),?\s)?(\d{1,2})\s(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)\s(\d{2,4})\s(\d\d):(\d\d)(?::(\d\d))?\s(?:(UT|GMT|[ECMP][SD]T)|([Zz])|([+-]\d{4}))$/,Ce={UT:0,GMT:0,EDT:-240,EST:-300,CDT:-300,CST:-360,MDT:-360,MST:-420,PDT:-420,PST:-480};function Te(t){var e,i,n,r,o,s,a=t._i,l=be.exec(a)||_e.exec(a),h=ke.length,u=xe.length;if(l){for(f(t).iso=!0,e=0,i=h;e<i;e++)if(ke[e][1].exec(l[1])){r=ke[e][0],n=!1!==ke[e][2];break}if(null==r)return void(t._isValid=!1);if(l[3]){for(e=0,i=u;e<i;e++)if(xe[e][1].exec(l[3])){o=(l[2]||" ")+xe[e][0];break}if(null==o)return void(t._isValid=!1)}if(!n&&null!=o)return void(t._isValid=!1);if(l[4]){if(!we.exec(l[4]))return void(t._isValid=!1);s="Z"}t._f=r+(o||"")+(s||""),Le(t)}else t._isValid=!1}function Me(t){var e=parseInt(t,10);return e<=49?2e3+e:e<=999?1900+e:e}function Oe(t){var e,i=De.exec(function(t){return t.replace(/\([^()]*\)|[\n\t]/g," ").replace(/(\s\s+)/g," ").replace(/^\s\s*/,"").replace(/\s\s*$/,"")}(t._i));if(i){if(e=function(t,e,i,n,r,o){var s=[Me(t),Lt.indexOf(e),parseInt(i,10),parseInt(n,10),parseInt(r,10)];return o&&s.push(parseInt(o,10)),s}(i[4],i[3],i[2],i[5],i[6],i[7]),!function(t,e,i){return!t||Zt.indexOf(t)===new Date(e[0],e[1],e[2]).getDay()||(f(i).weekdayMismatch=!0,i._isValid=!1,!1)}(i[1],e,t))return;t._a=e,t._tzm=function(t,e,i){if(t)return Ce[t];if(e)return 0;var n=parseInt(i,10),r=n%100;return(n-r)/100*60+r}(i[8],i[9],i[10]),t._d=Wt.apply(null,t._a),t._d.setUTCMinutes(t._d.getUTCMinutes()-t._tzm),f(t).rfc2822=!0}else t._isValid=!1}function Pe(t,e,i){return null!=t?t:null!=e?e:i}function Ee(t){var e=new Date(n.now());return t._useUTC?[e.getUTCFullYear(),e.getUTCMonth(),e.getUTCDate()]:[e.getFullYear(),e.getMonth(),e.getDate()]}function Ie(t){var e,i,n,r,o,s=[];if(!t._d){for(n=Ee(t),t._w&&null==t._a[St]&&null==t._a[xt]&&function(t){var e,i,n,r,o,s,a,l,h;null!=(e=t._w).GG||null!=e.W||null!=e.E?(o=1,s=4,i=Pe(e.GG,t._a[kt],Xt(Re(),1,4).year),n=Pe(e.W,1),((r=Pe(e.E,1))<1||r>7)&&(l=!0)):(o=t._locale._week.dow,s=t._locale._week.doy,h=Xt(Re(),o,s),i=Pe(e.gg,t._a[kt],h.year),n=Pe(e.w,h.week),null!=e.d?((r=e.d)<0||r>6)&&(l=!0):null!=e.e?(r=e.e+o,(e.e<0||e.e>6)&&(l=!0)):r=o),n<1||n>qt(i,o,s)?f(t)._overflowWeeks=!0:null!=l?f(t)._overflowWeekday=!0:(a=Ut(i,n,r,o,s),t._a[kt]=a.year,t._dayOfYear=a.dayOfYear)}(t),null!=t._dayOfYear&&(o=Pe(t._a[kt],n[kt]),(t._dayOfYear>Bt(o)||0===t._dayOfYear)&&(f(t)._overflowDayOfYear=!0),i=Wt(o,0,t._dayOfYear),t._a[xt]=i.getUTCMonth(),t._a[St]=i.getUTCDate()),e=0;e<3&&null==t._a[e];++e)t._a[e]=s[e]=n[e];for(;e<7;e++)t._a[e]=s[e]=null==t._a[e]?2===e?1:0:t._a[e];24===t._a[Dt]&&0===t._a[Ct]&&0===t._a[Tt]&&0===t._a[Mt]&&(t._nextDay=!0,t._a[Dt]=0),t._d=(t._useUTC?Wt:Gt).apply(null,s),r=t._useUTC?t._d.getUTCDay():t._d.getDay(),null!=t._tzm&&t._d.setUTCMinutes(t._d.getUTCMinutes()-t._tzm),t._nextDay&&(t._a[Dt]=24),t._w&&void 0!==t._w.d&&t._w.d!==r&&(f(t).weekdayMismatch=!0)}}function Le(t){if(t._f!==n.ISO_8601)if(t._f!==n.RFC_2822){t._a=[],f(t).empty=!0;var e,i,r,o,s,a,l,h=""+t._i,u=h.length,c=0;for(l=(r=j(t._f,t._locale).match(E)||[]).length,e=0;e<l;e++)o=r[e],(i=(h.match(mt(o,t))||[])[0])&&((s=h.substr(0,h.indexOf(i))).length>0&&f(t).unusedInput.push(s),h=h.slice(h.indexOf(i)+i.length),c+=i.length),A[o]?(i?f(t).empty=!1:f(t).unusedTokens.push(o),_t(o,i,t)):t._strict&&!i&&f(t).unusedTokens.push(o);f(t).charsLeftOver=u-c,h.length>0&&f(t).unusedInput.push(h),t._a[Dt]<=12&&!0===f(t).bigHour&&t._a[Dt]>0&&(f(t).bigHour=void 0),f(t).parsedDateParts=t._a.slice(0),f(t).meridiem=t._meridiem,t._a[Dt]=function(t,e,i){var n;return null==i?e:null!=t.meridiemHour?t.meridiemHour(e,i):null!=t.isPM?((n=t.isPM(i))&&e<12&&(e+=12),n||12!==e||(e=0),e):e}(t._locale,t._a[Dt],t._meridiem),null!==(a=f(t).era)&&(t._a[kt]=t._locale.erasConvertYear(a,t._a[kt])),Ie(t),ye(t)}else Oe(t);else Te(t)}function Ae(t){var e=t._i,i=t._f;return t._locale=t._locale||ge(t._l),null===e||void 0===i&&""===e?v({nullInput:!0}):("string"==typeof e&&(t._i=e=t._locale.preparse(e)),w(e)?new _(ye(e)):(u(e)?t._d=e:r(i)?function(t){var e,i,n,r,o,s,a=!1,l=t._f.length;if(0===l)return f(t).invalidFormat=!0,void(t._d=new Date(NaN));for(r=0;r<l;r++)o=0,s=!1,e=b({},t),null!=t._useUTC&&(e._useUTC=t._useUTC),e._f=t._f[r],Le(e),m(e)&&(s=!0),o+=f(e).charsLeftOver,o+=10*f(e).unusedTokens.length,f(e).score=o,a?o<n&&(n=o,i=e):(null==n||o<n||s)&&(n=o,i=e,s&&(a=!0));d(t,i||e)}(t):i?Le(t):function(t){var e=t._i;l(e)?t._d=new Date(n.now()):u(e)?t._d=new Date(e.valueOf()):"string"==typeof e?function(t){var e=Se.exec(t._i);null===e?(Te(t),!1===t._isValid&&(delete t._isValid,Oe(t),!1===t._isValid&&(delete t._isValid,t._strict?t._isValid=!1:n.createFromInputFallback(t)))):t._d=new Date(+e[1])}(t):r(e)?(t._a=c(e.slice(0),(function(t){return parseInt(t,10)})),Ie(t)):o(e)?function(t){if(!t._d){var e=z(t._i),i=void 0===e.day?e.date:e.day;t._a=c([e.year,e.month,i,e.hour,e.minute,e.second,e.millisecond],(function(t){return t&&parseInt(t,10)})),Ie(t)}}(t):h(e)?t._d=new Date(e):n.createFromInputFallback(t)}(t),m(t)||(t._d=null),t))}function Ne(t,e,i,n,s){var l={};return!0!==e&&!1!==e||(n=e,e=void 0),!0!==i&&!1!==i||(n=i,i=void 0),(o(t)&&a(t)||r(t)&&0===t.length)&&(t=void 0),l._isAMomentObject=!0,l._useUTC=l._isUTC=s,l._l=i,l._i=t,l._f=e,l._strict=n,function(t){var e=new _(ye(Ae(t)));return e._nextDay&&(e.add(1,"d"),e._nextDay=void 0),e}(l)}function Re(t,e,i,n){return Ne(t,e,i,n,!1)}n.createFromInputFallback=x("value provided is not in a recognized RFC2822 or ISO format. moment construction falls back to js Date(), which is not reliable across all browsers and versions. Non RFC2822/ISO date formats are discouraged. Please refer to http://momentjs.com/guides/#/warnings/js-date/ for more info.",(function(t){t._d=new Date(t._i+(t._useUTC?" UTC":""))})),n.ISO_8601=function(){},n.RFC_2822=function(){};var Fe=x("moment().min is deprecated, use moment.max instead. http://momentjs.com/guides/#/warnings/min-max/",(function(){var t=Re.apply(null,arguments);return this.isValid()&&t.isValid()?t<this?this:t:v()})),je=x("moment().max is deprecated, use moment.min instead. http://momentjs.com/guides/#/warnings/min-max/",(function(){var t=Re.apply(null,arguments);return this.isValid()&&t.isValid()?t>this?this:t:v()}));function Ye(t,e){var i,n;if(1===e.length&&r(e[0])&&(e=e[0]),!e.length)return Re();for(i=e[0],n=1;n<e.length;++n)e[n].isValid()&&!e[n][t](i)||(i=e[n]);return i}var He=["year","quarter","month","week","day","hour","minute","second","millisecond"];function Be(t){var e,i,n=!1,r=He.length;for(e in t)if(s(t,e)&&(-1===wt.call(He,e)||null!=t[e]&&isNaN(t[e])))return!1;for(i=0;i<r;++i)if(t[He[i]]){if(n)return!1;parseFloat(t[He[i]])!==X(t[He[i]])&&(n=!0)}return!0}function ze(t){var e=z(t),i=e.year||0,n=e.quarter||0,r=e.month||0,o=e.week||e.isoWeek||0,s=e.day||0,a=e.hour||0,l=e.minute||0,h=e.second||0,u=e.millisecond||0;this._isValid=Be(e),this._milliseconds=+u+1e3*h+6e4*l+1e3*a*60*60,this._days=+s+7*o,this._months=+r+3*n+12*i,this._data={},this._locale=ge(),this._bubble()}function Ge(t){return t instanceof ze}function We(t){return t<0?-1*Math.round(-1*t):Math.round(t)}function Ve(t,e){N(t,0,0,(function(){var t=this.utcOffset(),i="+";return t<0&&(t=-t,i="-"),i+P(~~(t/60),2)+e+P(~~t%60,2)}))}Ve("Z",":"),Ve("ZZ",""),ft("Z",dt),ft("ZZ",dt),yt(["Z","ZZ"],(function(t,e,i){i._useUTC=!0,i._tzm=Xe(dt,t)}));var Ue=/([\+\-]|\d\d)/gi;function Xe(t,e){var i,n,r=(e||"").match(t);return null===r?null:0===(n=60*(i=((r[r.length-1]||[])+"").match(Ue)||["-",0,0])[1]+X(i[2]))?0:"+"===i[0]?n:-n}function qe(t,e){var i,r;return e._isUTC?(i=e.clone(),r=(w(t)||u(t)?t.valueOf():Re(t).valueOf())-i.valueOf(),i._d.setTime(i._d.valueOf()+r),n.updateOffset(i,!1),i):Re(t).local()}function $e(t){return-Math.round(t._d.getTimezoneOffset())}function Ke(){return!!this.isValid()&&this._isUTC&&0===this._offset}n.updateOffset=function(){};var Ze=/^(-|\+)?(?:(\d*)[. ])?(\d+):(\d+)(?::(\d+)(\.\d*)?)?$/,Je=/^(-|\+)?P(?:([-+]?[0-9,.]*)Y)?(?:([-+]?[0-9,.]*)M)?(?:([-+]?[0-9,.]*)W)?(?:([-+]?[0-9,.]*)D)?(?:T(?:([-+]?[0-9,.]*)H)?(?:([-+]?[0-9,.]*)M)?(?:([-+]?[0-9,.]*)S)?)?$/;function Qe(t,e){var i,n,r,o=t,a=null;return Ge(t)?o={ms:t._milliseconds,d:t._days,M:t._months}:h(t)||!isNaN(+t)?(o={},e?o[e]=+t:o.milliseconds=+t):(a=Ze.exec(t))?(i="-"===a[1]?-1:1,o={y:0,d:X(a[St])*i,h:X(a[Dt])*i,m:X(a[Ct])*i,s:X(a[Tt])*i,ms:X(We(1e3*a[Mt]))*i}):(a=Je.exec(t))?(i="-"===a[1]?-1:1,o={y:ti(a[2],i),M:ti(a[3],i),w:ti(a[4],i),d:ti(a[5],i),h:ti(a[6],i),m:ti(a[7],i),s:ti(a[8],i)}):null==o?o={}:"object"==typeof o&&("from"in o||"to"in o)&&(r=function(t,e){var i;return t.isValid()&&e.isValid()?(e=qe(e,t),t.isBefore(e)?i=ei(t,e):((i=ei(e,t)).milliseconds=-i.milliseconds,i.months=-i.months),i):{milliseconds:0,months:0}}(Re(o.from),Re(o.to)),(o={}).ms=r.milliseconds,o.M=r.months),n=new ze(o),Ge(t)&&s(t,"_locale")&&(n._locale=t._locale),Ge(t)&&s(t,"_isValid")&&(n._isValid=t._isValid),n}function ti(t,e){var i=t&&parseFloat(t.replace(",","."));return(isNaN(i)?0:i)*e}function ei(t,e){var i={};return i.months=e.month()-t.month()+12*(e.year()-t.year()),t.clone().add(i.months,"M").isAfter(e)&&--i.months,i.milliseconds=+e-+t.clone().add(i.months,"M"),i}function ii(t,e){return function(i,n){var r;return null===n||isNaN(+n)||(C(e,"moment()."+e+"(period, number) is deprecated. Please use moment()."+e+"(number, period). See http://momentjs.com/guides/#/warnings/add-inverted-param/ for more info."),r=i,i=n,n=r),ni(this,Qe(i,n),t),this}}function ni(t,e,i,r){var o=e._milliseconds,s=We(e._days),a=We(e._months);t.isValid()&&(r=null==r||r,a&&jt(t,$(t,"Month")+a*i),s&&K(t,"Date",$(t,"Date")+s*i),o&&t._d.setTime(t._d.valueOf()+o*i),r&&n.updateOffset(t,s||a))}Qe.fn=ze.prototype,Qe.invalid=function(){return Qe(NaN)};var ri=ii(1,"add"),oi=ii(-1,"subtract");function si(t){return"string"==typeof t||t instanceof String}function ai(t){return w(t)||u(t)||si(t)||h(t)||function(t){var e=r(t),i=!1;return e&&(i=0===t.filter((function(e){return!h(e)&&si(t)})).length),e&&i}(t)||function(t){var e,i,n=o(t)&&!a(t),r=!1,l=["years","year","y","months","month","M","days","day","d","dates","date","D","hours","hour","h","minutes","minute","m","seconds","second","s","milliseconds","millisecond","ms"],h=l.length;for(e=0;e<h;e+=1)i=l[e],r=r||s(t,i);return n&&r}(t)||null==t}function li(t,e){if(t.date()<e.date())return-li(e,t);var i=12*(e.year()-t.year())+(e.month()-t.month()),n=t.clone().add(i,"months");return-(i+(e-n<0?(e-n)/(n-t.clone().add(i-1,"months")):(e-n)/(t.clone().add(i+1,"months")-n)))||0}function hi(t){var e;return void 0===t?this._locale._abbr:(null!=(e=ge(t))&&(this._locale=e),this)}n.defaultFormat="YYYY-MM-DDTHH:mm:ssZ",n.defaultFormatUtc="YYYY-MM-DDTHH:mm:ss[Z]";var ui=x("moment().lang() is deprecated. Instead, use moment().localeData() to get the language configuration. Use moment().locale() to change languages.",(function(t){return void 0===t?this.localeData():this.locale(t)}));function ci(){return this._locale}var di=1e3,pi=6e4,fi=60*pi,mi=3506328*fi;function vi(t,e){return(t%e+e)%e}function gi(t,e,i){return t<100&&t>=0?new Date(t+400,e,i)-mi:new Date(t,e,i).valueOf()}function yi(t,e,i){return t<100&&t>=0?Date.UTC(t+400,e,i)-mi:Date.UTC(t,e,i)}function bi(t,e){return e.erasAbbrRegex(t)}function _i(){var t,e,i=[],n=[],r=[],o=[],s=this.eras();for(t=0,e=s.length;t<e;++t)n.push(vt(s[t].name)),i.push(vt(s[t].abbr)),r.push(vt(s[t].narrow)),o.push(vt(s[t].name)),o.push(vt(s[t].abbr)),o.push(vt(s[t].narrow));this._erasRegex=new RegExp("^("+o.join("|")+")","i"),this._erasNameRegex=new RegExp("^("+n.join("|")+")","i"),this._erasAbbrRegex=new RegExp("^("+i.join("|")+")","i"),this._erasNarrowRegex=new RegExp("^("+r.join("|")+")","i")}function wi(t,e){N(0,[t,t.length],0,e)}function ki(t,e,i,n,r){var o;return null==t?Xt(this,n,r).year:(e>(o=qt(t,n,r))&&(e=o),xi.call(this,t,e,i,n,r))}function xi(t,e,i,n,r){var o=Ut(t,e,i,n,r),s=Wt(o.year,0,o.dayOfYear);return this.year(s.getUTCFullYear()),this.month(s.getUTCMonth()),this.date(s.getUTCDate()),this}N("N",0,0,"eraAbbr"),N("NN",0,0,"eraAbbr"),N("NNN",0,0,"eraAbbr"),N("NNNN",0,0,"eraName"),N("NNNNN",0,0,"eraNarrow"),N("y",["y",1],"yo","eraYear"),N("y",["yy",2],0,"eraYear"),N("y",["yyy",3],0,"eraYear"),N("y",["yyyy",4],0,"eraYear"),ft("N",bi),ft("NN",bi),ft("NNN",bi),ft("NNNN",(function(t,e){return e.erasNameRegex(t)})),ft("NNNNN",(function(t,e){return e.erasNarrowRegex(t)})),yt(["N","NN","NNN","NNNN","NNNNN"],(function(t,e,i,n){var r=i._locale.erasParse(t,n,i._strict);r?f(i).era=r:f(i).invalidEra=t})),ft("y",ht),ft("yy",ht),ft("yyy",ht),ft("yyyy",ht),ft("yo",(function(t,e){return e._eraYearOrdinalRegex||ht})),yt(["y","yy","yyy","yyyy"],kt),yt(["yo"],(function(t,e,i,n){var r;i._locale._eraYearOrdinalRegex&&(r=t.match(i._locale._eraYearOrdinalRegex)),i._locale.eraYearOrdinalParse?e[kt]=i._locale.eraYearOrdinalParse(t,r):e[kt]=parseInt(t,10)})),N(0,["gg",2],0,(function(){return this.weekYear()%100})),N(0,["GG",2],0,(function(){return this.isoWeekYear()%100})),wi("gggg","weekYear"),wi("ggggg","weekYear"),wi("GGGG","isoWeekYear"),wi("GGGGG","isoWeekYear"),H("weekYear","gg"),H("isoWeekYear","GG"),W("weekYear",1),W("isoWeekYear",1),ft("G",ut),ft("g",ut),ft("GG",nt,Q),ft("gg",nt,Q),ft("GGGG",at,et),ft("gggg",at,et),ft("GGGGG",lt,it),ft("ggggg",lt,it),bt(["gggg","ggggg","GGGG","GGGGG"],(function(t,e,i,n){e[n.substr(0,2)]=X(t)})),bt(["gg","GG"],(function(t,e,i,r){e[r]=n.parseTwoDigitYear(t)})),N("Q",0,"Qo","quarter"),H("quarter","Q"),W("quarter",7),ft("Q",J),yt("Q",(function(t,e){e[xt]=3*(X(t)-1)})),N("D",["DD",2],"Do","date"),H("date","D"),W("date",9),ft("D",nt),ft("DD",nt,Q),ft("Do",(function(t,e){return t?e._dayOfMonthOrdinalParse||e._ordinalParse:e._dayOfMonthOrdinalParseLenient})),yt(["D","DD"],St),yt("Do",(function(t,e){e[St]=X(t.match(nt)[0])}));var Si=q("Date",!0);N("DDD",["DDDD",3],"DDDo","dayOfYear"),H("dayOfYear","DDD"),W("dayOfYear",4),ft("DDD",st),ft("DDDD",tt),yt(["DDD","DDDD"],(function(t,e,i){i._dayOfYear=X(t)})),N("m",["mm",2],0,"minute"),H("minute","m"),W("minute",14),ft("m",nt),ft("mm",nt,Q),yt(["m","mm"],Ct);var Di=q("Minutes",!1);N("s",["ss",2],0,"second"),H("second","s"),W("second",15),ft("s",nt),ft("ss",nt,Q),yt(["s","ss"],Tt);var Ci,Ti,Mi=q("Seconds",!1);for(N("S",0,0,(function(){return~~(this.millisecond()/100)})),N(0,["SS",2],0,(function(){return~~(this.millisecond()/10)})),N(0,["SSS",3],0,"millisecond"),N(0,["SSSS",4],0,(function(){return 10*this.millisecond()})),N(0,["SSSSS",5],0,(function(){return 100*this.millisecond()})),N(0,["SSSSSS",6],0,(function(){return 1e3*this.millisecond()})),N(0,["SSSSSSS",7],0,(function(){return 1e4*this.millisecond()})),N(0,["SSSSSSSS",8],0,(function(){return 1e5*this.millisecond()})),N(0,["SSSSSSSSS",9],0,(function(){return 1e6*this.millisecond()})),H("millisecond","ms"),W("millisecond",16),ft("S",st,J),ft("SS",st,Q),ft("SSS",st,tt),Ci="SSSS";Ci.length<=9;Ci+="S")ft(Ci,ht);function Oi(t,e){e[Mt]=X(1e3*("0."+t))}for(Ci="S";Ci.length<=9;Ci+="S")yt(Ci,Oi);Ti=q("Milliseconds",!1),N("z",0,0,"zoneAbbr"),N("zz",0,0,"zoneName");var Pi=_.prototype;function Ei(t){return t}Pi.add=ri,Pi.calendar=function(t,e){1===arguments.length&&(arguments[0]?ai(arguments[0])?(t=arguments[0],e=void 0):function(t){var e,i=o(t)&&!a(t),n=!1,r=["sameDay","nextDay","lastDay","nextWeek","lastWeek","sameElse"];for(e=0;e<r.length;e+=1)n=n||s(t,r[e]);return i&&n}(arguments[0])&&(e=arguments[0],t=void 0):(t=void 0,e=void 0));var i=t||Re(),r=qe(i,this).startOf("day"),l=n.calendarFormat(this,r)||"sameElse",h=e&&(T(e[l])?e[l].call(this,i):e[l]);return this.format(h||this.localeData().calendar(l,this,Re(i)))},Pi.clone=function(){return new _(this)},Pi.diff=function(t,e,i){var n,r,o;if(!this.isValid())return NaN;if(!(n=qe(t,this)).isValid())return NaN;switch(r=6e4*(n.utcOffset()-this.utcOffset()),e=B(e)){case"year":o=li(this,n)/12;break;case"month":o=li(this,n);break;case"quarter":o=li(this,n)/3;break;case"second":o=(this-n)/1e3;break;case"minute":o=(this-n)/6e4;break;case"hour":o=(this-n)/36e5;break;case"day":o=(this-n-r)/864e5;break;case"week":o=(this-n-r)/6048e5;break;default:o=this-n}return i?o:U(o)},Pi.endOf=function(t){var e,i;if(void 0===(t=B(t))||"millisecond"===t||!this.isValid())return this;switch(i=this._isUTC?yi:gi,t){case"year":e=i(this.year()+1,0,1)-1;break;case"quarter":e=i(this.year(),this.month()-this.month()%3+3,1)-1;break;case"month":e=i(this.year(),this.month()+1,1)-1;break;case"week":e=i(this.year(),this.month(),this.date()-this.weekday()+7)-1;break;case"isoWeek":e=i(this.year(),this.month(),this.date()-(this.isoWeekday()-1)+7)-1;break;case"day":case"date":e=i(this.year(),this.month(),this.date()+1)-1;break;case"hour":e=this._d.valueOf(),e+=fi-vi(e+(this._isUTC?0:this.utcOffset()*pi),fi)-1;break;case"minute":e=this._d.valueOf(),e+=pi-vi(e,pi)-1;break;case"second":e=this._d.valueOf(),e+=di-vi(e,di)-1}return this._d.setTime(e),n.updateOffset(this,!0),this},Pi.format=function(t){t||(t=this.isUtc()?n.defaultFormatUtc:n.defaultFormat);var e=F(this,t);return this.localeData().postformat(e)},Pi.from=function(t,e){return this.isValid()&&(w(t)&&t.isValid()||Re(t).isValid())?Qe({to:this,from:t}).locale(this.locale()).humanize(!e):this.localeData().invalidDate()},Pi.fromNow=function(t){return this.from(Re(),t)},Pi.to=function(t,e){return this.isValid()&&(w(t)&&t.isValid()||Re(t).isValid())?Qe({from:this,to:t}).locale(this.locale()).humanize(!e):this.localeData().invalidDate()},Pi.toNow=function(t){return this.to(Re(),t)},Pi.get=function(t){return T(this[t=B(t)])?this[t]():this},Pi.invalidAt=function(){return f(this).overflow},Pi.isAfter=function(t,e){var i=w(t)?t:Re(t);return!(!this.isValid()||!i.isValid())&&("millisecond"===(e=B(e)||"millisecond")?this.valueOf()>i.valueOf():i.valueOf()<this.clone().startOf(e).valueOf())},Pi.isBefore=function(t,e){var i=w(t)?t:Re(t);return!(!this.isValid()||!i.isValid())&&("millisecond"===(e=B(e)||"millisecond")?this.valueOf()<i.valueOf():this.clone().endOf(e).valueOf()<i.valueOf())},Pi.isBetween=function(t,e,i,n){var r=w(t)?t:Re(t),o=w(e)?e:Re(e);return!!(this.isValid()&&r.isValid()&&o.isValid())&&("("===(n=n||"()")[0]?this.isAfter(r,i):!this.isBefore(r,i))&&(")"===n[1]?this.isBefore(o,i):!this.isAfter(o,i))},Pi.isSame=function(t,e){var i,n=w(t)?t:Re(t);return!(!this.isValid()||!n.isValid())&&("millisecond"===(e=B(e)||"millisecond")?this.valueOf()===n.valueOf():(i=n.valueOf(),this.clone().startOf(e).valueOf()<=i&&i<=this.clone().endOf(e).valueOf()))},Pi.isSameOrAfter=function(t,e){return this.isSame(t,e)||this.isAfter(t,e)},Pi.isSameOrBefore=function(t,e){return this.isSame(t,e)||this.isBefore(t,e)},Pi.isValid=function(){return m(this)},Pi.lang=ui,Pi.locale=hi,Pi.localeData=ci,Pi.max=je,Pi.min=Fe,Pi.parsingFlags=function(){return d({},f(this))},Pi.set=function(t,e){if("object"==typeof t){var i,n=function(t){var e,i=[];for(e in t)s(t,e)&&i.push({unit:e,priority:G[e]});return i.sort((function(t,e){return t.priority-e.priority})),i}(t=z(t)),r=n.length;for(i=0;i<r;i++)this[n[i].unit](t[n[i].unit])}else if(T(this[t=B(t)]))return this[t](e);return this},Pi.startOf=function(t){var e,i;if(void 0===(t=B(t))||"millisecond"===t||!this.isValid())return this;switch(i=this._isUTC?yi:gi,t){case"year":e=i(this.year(),0,1);break;case"quarter":e=i(this.year(),this.month()-this.month()%3,1);break;case"month":e=i(this.year(),this.month(),1);break;case"week":e=i(this.year(),this.month(),this.date()-this.weekday());break;case"isoWeek":e=i(this.year(),this.month(),this.date()-(this.isoWeekday()-1));break;case"day":case"date":e=i(this.year(),this.month(),this.date());break;case"hour":e=this._d.valueOf(),e-=vi(e+(this._isUTC?0:this.utcOffset()*pi),fi);break;case"minute":e=this._d.valueOf(),e-=vi(e,pi);break;case"second":e=this._d.valueOf(),e-=vi(e,di)}return this._d.setTime(e),n.updateOffset(this,!0),this},Pi.subtract=oi,Pi.toArray=function(){var t=this;return[t.year(),t.month(),t.date(),t.hour(),t.minute(),t.second(),t.millisecond()]},Pi.toObject=function(){var t=this;return{years:t.year(),months:t.month(),date:t.date(),hours:t.hours(),minutes:t.minutes(),seconds:t.seconds(),milliseconds:t.milliseconds()}},Pi.toDate=function(){return new Date(this.valueOf())},Pi.toISOString=function(t){if(!this.isValid())return null;var e=!0!==t,i=e?this.clone().utc():this;return i.year()<0||i.year()>9999?F(i,e?"YYYYYY-MM-DD[T]HH:mm:ss.SSS[Z]":"YYYYYY-MM-DD[T]HH:mm:ss.SSSZ"):T(Date.prototype.toISOString)?e?this.toDate().toISOString():new Date(this.valueOf()+60*this.utcOffset()*1e3).toISOString().replace("Z",F(i,"Z")):F(i,e?"YYYY-MM-DD[T]HH:mm:ss.SSS[Z]":"YYYY-MM-DD[T]HH:mm:ss.SSSZ")},Pi.inspect=function(){if(!this.isValid())return"moment.invalid(/* "+this._i+" */)";var t,e,i,n="moment",r="";return this.isLocal()||(n=0===this.utcOffset()?"moment.utc":"moment.parseZone",r="Z"),t="["+n+'("]',e=0<=this.year()&&this.year()<=9999?"YYYY":"YYYYYY","-MM-DD[T]HH:mm:ss.SSS",i=r+'[")]',this.format(t+e+"-MM-DD[T]HH:mm:ss.SSS"+i)},"undefined"!=typeof Symbol&&null!=Symbol.for&&(Pi[Symbol.for("nodejs.util.inspect.custom")]=function(){return"Moment<"+this.format()+">"}),Pi.toJSON=function(){return this.isValid()?this.toISOString():null},Pi.toString=function(){return this.clone().locale("en").format("ddd MMM DD YYYY HH:mm:ss [GMT]ZZ")},Pi.unix=function(){return Math.floor(this.valueOf()/1e3)},Pi.valueOf=function(){return this._d.valueOf()-6e4*(this._offset||0)},Pi.creationData=function(){return{input:this._i,format:this._f,locale:this._locale,isUTC:this._isUTC,strict:this._strict}},Pi.eraName=function(){var t,e,i,n=this.localeData().eras();for(t=0,e=n.length;t<e;++t){if(i=this.clone().startOf("day").valueOf(),n[t].since<=i&&i<=n[t].until)return n[t].name;if(n[t].until<=i&&i<=n[t].since)return n[t].name}return""},Pi.eraNarrow=function(){var t,e,i,n=this.localeData().eras();for(t=0,e=n.length;t<e;++t){if(i=this.clone().startOf("day").valueOf(),n[t].since<=i&&i<=n[t].until)return n[t].narrow;if(n[t].until<=i&&i<=n[t].since)return n[t].narrow}return""},Pi.eraAbbr=function(){var t,e,i,n=this.localeData().eras();for(t=0,e=n.length;t<e;++t){if(i=this.clone().startOf("day").valueOf(),n[t].since<=i&&i<=n[t].until)return n[t].abbr;if(n[t].until<=i&&i<=n[t].since)return n[t].abbr}return""},Pi.eraYear=function(){var t,e,i,r,o=this.localeData().eras();for(t=0,e=o.length;t<e;++t)if(i=o[t].since<=o[t].until?1:-1,r=this.clone().startOf("day").valueOf(),o[t].since<=r&&r<=o[t].until||o[t].until<=r&&r<=o[t].since)return(this.year()-n(o[t].since).year())*i+o[t].offset;return this.year()},Pi.year=zt,Pi.isLeapYear=function(){return V(this.year())},Pi.weekYear=function(t){return ki.call(this,t,this.week(),this.weekday(),this.localeData()._week.dow,this.localeData()._week.doy)},Pi.isoWeekYear=function(t){return ki.call(this,t,this.isoWeek(),this.isoWeekday(),1,4)},Pi.quarter=Pi.quarters=function(t){return null==t?Math.ceil((this.month()+1)/3):this.month(3*(t-1)+this.month()%3)},Pi.month=Yt,Pi.daysInMonth=function(){return Et(this.year(),this.month())},Pi.week=Pi.weeks=function(t){var e=this.localeData().week(this);return null==t?e:this.add(7*(t-e),"d")},Pi.isoWeek=Pi.isoWeeks=function(t){var e=Xt(this,1,4).week;return null==t?e:this.add(7*(t-e),"d")},Pi.weeksInYear=function(){var t=this.localeData()._week;return qt(this.year(),t.dow,t.doy)},Pi.weeksInWeekYear=function(){var t=this.localeData()._week;return qt(this.weekYear(),t.dow,t.doy)},Pi.isoWeeksInYear=function(){return qt(this.year(),1,4)},Pi.isoWeeksInISOWeekYear=function(){return qt(this.isoWeekYear(),1,4)},Pi.date=Si,Pi.day=Pi.days=function(t){if(!this.isValid())return null!=t?this:NaN;var e=this._isUTC?this._d.getUTCDay():this._d.getDay();return null!=t?(t=function(t,e){return"string"!=typeof t?t:isNaN(t)?"number"==typeof(t=e.weekdaysParse(t))?t:null:parseInt(t,10)}(t,this.localeData()),this.add(t-e,"d")):e},Pi.weekday=function(t){if(!this.isValid())return null!=t?this:NaN;var e=(this.day()+7-this.localeData()._week.dow)%7;return null==t?e:this.add(t-e,"d")},Pi.isoWeekday=function(t){if(!this.isValid())return null!=t?this:NaN;if(null!=t){var e=function(t,e){return"string"==typeof t?e.weekdaysParse(t)%7||7:isNaN(t)?null:t}(t,this.localeData());return this.day(this.day()%7?e:e-7)}return this.day()||7},Pi.dayOfYear=function(t){var e=Math.round((this.clone().startOf("day")-this.clone().startOf("year"))/864e5)+1;return null==t?e:this.add(t-e,"d")},Pi.hour=Pi.hours=ae,Pi.minute=Pi.minutes=Di,Pi.second=Pi.seconds=Mi,Pi.millisecond=Pi.milliseconds=Ti,Pi.utcOffset=function(t,e,i){var r,o=this._offset||0;if(!this.isValid())return null!=t?this:NaN;if(null!=t){if("string"==typeof t){if(null===(t=Xe(dt,t)))return this}else Math.abs(t)<16&&!i&&(t*=60);return!this._isUTC&&e&&(r=$e(this)),this._offset=t,this._isUTC=!0,null!=r&&this.add(r,"m"),o!==t&&(!e||this._changeInProgress?ni(this,Qe(t-o,"m"),1,!1):this._changeInProgress||(this._changeInProgress=!0,n.updateOffset(this,!0),this._changeInProgress=null)),this}return this._isUTC?o:$e(this)},Pi.utc=function(t){return this.utcOffset(0,t)},Pi.local=function(t){return this._isUTC&&(this.utcOffset(0,t),this._isUTC=!1,t&&this.subtract($e(this),"m")),this},Pi.parseZone=function(){if(null!=this._tzm)this.utcOffset(this._tzm,!1,!0);else if("string"==typeof this._i){var t=Xe(ct,this._i);null!=t?this.utcOffset(t):this.utcOffset(0,!0)}return this},Pi.hasAlignedHourOffset=function(t){return!!this.isValid()&&(t=t?Re(t).utcOffset():0,(this.utcOffset()-t)%60==0)},Pi.isDST=function(){return this.utcOffset()>this.clone().month(0).utcOffset()||this.utcOffset()>this.clone().month(5).utcOffset()},Pi.isLocal=function(){return!!this.isValid()&&!this._isUTC},Pi.isUtcOffset=function(){return!!this.isValid()&&this._isUTC},Pi.isUtc=Ke,Pi.isUTC=Ke,Pi.zoneAbbr=function(){return this._isUTC?"UTC":""},Pi.zoneName=function(){return this._isUTC?"Coordinated Universal Time":""},Pi.dates=x("dates accessor is deprecated. Use date instead.",Si),Pi.months=x("months accessor is deprecated. Use month instead",Yt),Pi.years=x("years accessor is deprecated. Use year instead",zt),Pi.zone=x("moment().zone is deprecated, use moment().utcOffset instead. http://momentjs.com/guides/#/warnings/zone/",(function(t,e){return null!=t?("string"!=typeof t&&(t=-t),this.utcOffset(t,e),this):-this.utcOffset()})),Pi.isDSTShifted=x("isDSTShifted is deprecated. See http://momentjs.com/guides/#/warnings/dst-shifted/ for more information",(function(){if(!l(this._isDSTShifted))return this._isDSTShifted;var t,e={};return b(e,this),(e=Ae(e))._a?(t=e._isUTC?p(e._a):Re(e._a),this._isDSTShifted=this.isValid()&&function(t,e,i){var n,r=Math.min(t.length,e.length),o=Math.abs(t.length-e.length),s=0;for(n=0;n<r;n++)(i&&t[n]!==e[n]||!i&&X(t[n])!==X(e[n]))&&s++;return s+o}(e._a,t.toArray())>0):this._isDSTShifted=!1,this._isDSTShifted}));var Ii=O.prototype;function Li(t,e,i,n){var r=ge(),o=p().set(n,e);return r[i](o,t)}function Ai(t,e,i){if(h(t)&&(e=t,t=void 0),t=t||"",null!=e)return Li(t,e,i,"month");var n,r=[];for(n=0;n<12;n++)r[n]=Li(t,n,i,"month");return r}function Ni(t,e,i,n){"boolean"==typeof t?(h(e)&&(i=e,e=void 0),e=e||""):(i=e=t,t=!1,h(e)&&(i=e,e=void 0),e=e||"");var r,o=ge(),s=t?o._week.dow:0,a=[];if(null!=i)return Li(e,(i+s)%7,n,"day");for(r=0;r<7;r++)a[r]=Li(e,(r+s)%7,n,"day");return a}Ii.calendar=function(t,e,i){var n=this._calendar[t]||this._calendar.sameElse;return T(n)?n.call(e,i):n},Ii.longDateFormat=function(t){var e=this._longDateFormat[t],i=this._longDateFormat[t.toUpperCase()];return e||!i?e:(this._longDateFormat[t]=i.match(E).map((function(t){return"MMMM"===t||"MM"===t||"DD"===t||"dddd"===t?t.slice(1):t})).join(""),this._longDateFormat[t])},Ii.invalidDate=function(){return this._invalidDate},Ii.ordinal=function(t){return this._ordinal.replace("%d",t)},Ii.preparse=Ei,Ii.postformat=Ei,Ii.relativeTime=function(t,e,i,n){var r=this._relativeTime[i];return T(r)?r(t,e,i,n):r.replace(/%d/i,t)},Ii.pastFuture=function(t,e){var i=this._relativeTime[t>0?"future":"past"];return T(i)?i(e):i.replace(/%s/i,e)},Ii.set=function(t){var e,i;for(i in t)s(t,i)&&(T(e=t[i])?this[i]=e:this["_"+i]=e);this._config=t,this._dayOfMonthOrdinalParseLenient=new RegExp((this._dayOfMonthOrdinalParse.source||this._ordinalParse.source)+"|"+/\d{1,2}/.source)},Ii.eras=function(t,e){var i,r,o,s=this._eras||ge("en")._eras;for(i=0,r=s.length;i<r;++i)switch("string"==typeof s[i].since&&(o=n(s[i].since).startOf("day"),s[i].since=o.valueOf()),typeof s[i].until){case"undefined":s[i].until=1/0;break;case"string":o=n(s[i].until).startOf("day").valueOf(),s[i].until=o.valueOf()}return s},Ii.erasParse=function(t,e,i){var n,r,o,s,a,l=this.eras();for(t=t.toUpperCase(),n=0,r=l.length;n<r;++n)if(o=l[n].name.toUpperCase(),s=l[n].abbr.toUpperCase(),a=l[n].narrow.toUpperCase(),i)switch(e){case"N":case"NN":case"NNN":if(s===t)return l[n];break;case"NNNN":if(o===t)return l[n];break;case"NNNNN":if(a===t)return l[n]}else if([o,s,a].indexOf(t)>=0)return l[n]},Ii.erasConvertYear=function(t,e){var i=t.since<=t.until?1:-1;return void 0===e?n(t.since).year():n(t.since).year()+(e-t.offset)*i},Ii.erasAbbrRegex=function(t){return s(this,"_erasAbbrRegex")||_i.call(this),t?this._erasAbbrRegex:this._erasRegex},Ii.erasNameRegex=function(t){return s(this,"_erasNameRegex")||_i.call(this),t?this._erasNameRegex:this._erasRegex},Ii.erasNarrowRegex=function(t){return s(this,"_erasNarrowRegex")||_i.call(this),t?this._erasNarrowRegex:this._erasRegex},Ii.months=function(t,e){return t?r(this._months)?this._months[t.month()]:this._months[(this._months.isFormat||At).test(e)?"format":"standalone"][t.month()]:r(this._months)?this._months:this._months.standalone},Ii.monthsShort=function(t,e){return t?r(this._monthsShort)?this._monthsShort[t.month()]:this._monthsShort[At.test(e)?"format":"standalone"][t.month()]:r(this._monthsShort)?this._monthsShort:this._monthsShort.standalone},Ii.monthsParse=function(t,e,i){var n,r,o;if(this._monthsParseExact)return Ft.call(this,t,e,i);for(this._monthsParse||(this._monthsParse=[],this._longMonthsParse=[],this._shortMonthsParse=[]),n=0;n<12;n++){if(r=p([2e3,n]),i&&!this._longMonthsParse[n]&&(this._longMonthsParse[n]=new RegExp("^"+this.months(r,"").replace(".","")+"$","i"),this._shortMonthsParse[n]=new RegExp("^"+this.monthsShort(r,"").replace(".","")+"$","i")),i||this._monthsParse[n]||(o="^"+this.months(r,"")+"|^"+this.monthsShort(r,""),this._monthsParse[n]=new RegExp(o.replace(".",""),"i")),i&&"MMMM"===e&&this._longMonthsParse[n].test(t))return n;if(i&&"MMM"===e&&this._shortMonthsParse[n].test(t))return n;if(!i&&this._monthsParse[n].test(t))return n}},Ii.monthsRegex=function(t){return this._monthsParseExact?(s(this,"_monthsRegex")||Ht.call(this),t?this._monthsStrictRegex:this._monthsRegex):(s(this,"_monthsRegex")||(this._monthsRegex=Rt),this._monthsStrictRegex&&t?this._monthsStrictRegex:this._monthsRegex)},Ii.monthsShortRegex=function(t){return this._monthsParseExact?(s(this,"_monthsRegex")||Ht.call(this),t?this._monthsShortStrictRegex:this._monthsShortRegex):(s(this,"_monthsShortRegex")||(this._monthsShortRegex=Nt),this._monthsShortStrictRegex&&t?this._monthsShortStrictRegex:this._monthsShortRegex)},Ii.week=function(t){return Xt(t,this._week.dow,this._week.doy).week},Ii.firstDayOfYear=function(){return this._week.doy},Ii.firstDayOfWeek=function(){return this._week.dow},Ii.weekdays=function(t,e){var i=r(this._weekdays)?this._weekdays:this._weekdays[t&&!0!==t&&this._weekdays.isFormat.test(e)?"format":"standalone"];return!0===t?$t(i,this._week.dow):t?i[t.day()]:i},Ii.weekdaysMin=function(t){return!0===t?$t(this._weekdaysMin,this._week.dow):t?this._weekdaysMin[t.day()]:this._weekdaysMin},Ii.weekdaysShort=function(t){return!0===t?$t(this._weekdaysShort,this._week.dow):t?this._weekdaysShort[t.day()]:this._weekdaysShort},Ii.weekdaysParse=function(t,e,i){var n,r,o;if(this._weekdaysParseExact)return ie.call(this,t,e,i);for(this._weekdaysParse||(this._weekdaysParse=[],this._minWeekdaysParse=[],this._shortWeekdaysParse=[],this._fullWeekdaysParse=[]),n=0;n<7;n++){if(r=p([2e3,1]).day(n),i&&!this._fullWeekdaysParse[n]&&(this._fullWeekdaysParse[n]=new RegExp("^"+this.weekdays(r,"").replace(".","\\.?")+"$","i"),this._shortWeekdaysParse[n]=new RegExp("^"+this.weekdaysShort(r,"").replace(".","\\.?")+"$","i"),this._minWeekdaysParse[n]=new RegExp("^"+this.weekdaysMin(r,"").replace(".","\\.?")+"$","i")),this._weekdaysParse[n]||(o="^"+this.weekdays(r,"")+"|^"+this.weekdaysShort(r,"")+"|^"+this.weekdaysMin(r,""),this._weekdaysParse[n]=new RegExp(o.replace(".",""),"i")),i&&"dddd"===e&&this._fullWeekdaysParse[n].test(t))return n;if(i&&"ddd"===e&&this._shortWeekdaysParse[n].test(t))return n;if(i&&"dd"===e&&this._minWeekdaysParse[n].test(t))return n;if(!i&&this._weekdaysParse[n].test(t))return n}},Ii.weekdaysRegex=function(t){return this._weekdaysParseExact?(s(this,"_weekdaysRegex")||ne.call(this),t?this._weekdaysStrictRegex:this._weekdaysRegex):(s(this,"_weekdaysRegex")||(this._weekdaysRegex=Qt),this._weekdaysStrictRegex&&t?this._weekdaysStrictRegex:this._weekdaysRegex)},Ii.weekdaysShortRegex=function(t){return this._weekdaysParseExact?(s(this,"_weekdaysRegex")||ne.call(this),t?this._weekdaysShortStrictRegex:this._weekdaysShortRegex):(s(this,"_weekdaysShortRegex")||(this._weekdaysShortRegex=te),this._weekdaysShortStrictRegex&&t?this._weekdaysShortStrictRegex:this._weekdaysShortRegex)},Ii.weekdaysMinRegex=function(t){return this._weekdaysParseExact?(s(this,"_weekdaysRegex")||ne.call(this),t?this._weekdaysMinStrictRegex:this._weekdaysMinRegex):(s(this,"_weekdaysMinRegex")||(this._weekdaysMinRegex=ee),this._weekdaysMinStrictRegex&&t?this._weekdaysMinStrictRegex:this._weekdaysMinRegex)},Ii.isPM=function(t){return"p"===(t+"").toLowerCase().charAt(0)},Ii.meridiem=function(t,e,i){return t>11?i?"pm":"PM":i?"am":"AM"},me("en",{eras:[{since:"0001-01-01",until:1/0,offset:1,name:"Anno Domini",narrow:"AD",abbr:"AD"},{since:"0000-12-31",until:-1/0,offset:1,name:"Before Christ",narrow:"BC",abbr:"BC"}],dayOfMonthOrdinalParse:/\d{1,2}(th|st|nd|rd)/,ordinal:function(t){var e=t%10;return t+(1===X(t%100/10)?"th":1===e?"st":2===e?"nd":3===e?"rd":"th")}}),n.lang=x("moment.lang is deprecated. Use moment.locale instead.",me),n.langData=x("moment.langData is deprecated. Use moment.localeData instead.",ge);var Ri=Math.abs;function Fi(t,e,i,n){var r=Qe(e,i);return t._milliseconds+=n*r._milliseconds,t._days+=n*r._days,t._months+=n*r._months,t._bubble()}function ji(t){return t<0?Math.floor(t):Math.ceil(t)}function Yi(t){return 4800*t/146097}function Hi(t){return 146097*t/4800}function Bi(t){return function(){return this.as(t)}}var zi=Bi("ms"),Gi=Bi("s"),Wi=Bi("m"),Vi=Bi("h"),Ui=Bi("d"),Xi=Bi("w"),qi=Bi("M"),$i=Bi("Q"),Ki=Bi("y");function Zi(t){return function(){return this.isValid()?this._data[t]:NaN}}var Ji=Zi("milliseconds"),Qi=Zi("seconds"),tn=Zi("minutes"),en=Zi("hours"),nn=Zi("days"),rn=Zi("months"),on=Zi("years");var sn=Math.round,an={ss:44,s:45,m:45,h:22,d:26,w:null,M:11};function ln(t,e,i,n,r){return r.relativeTime(e||1,!!i,t,n)}var hn=Math.abs;function un(t){return(t>0)-(t<0)||+t}function cn(){if(!this.isValid())return this.localeData().invalidDate();var t,e,i,n,r,o,s,a,l=hn(this._milliseconds)/1e3,h=hn(this._days),u=hn(this._months),c=this.asSeconds();return c?(t=U(l/60),e=U(t/60),l%=60,t%=60,i=U(u/12),u%=12,n=l?l.toFixed(3).replace(/\.?0+$/,""):"",r=c<0?"-":"",o=un(this._months)!==un(c)?"-":"",s=un(this._days)!==un(c)?"-":"",a=un(this._milliseconds)!==un(c)?"-":"",r+"P"+(i?o+i+"Y":"")+(u?o+u+"M":"")+(h?s+h+"D":"")+(e||t||l?"T":"")+(e?a+e+"H":"")+(t?a+t+"M":"")+(l?a+n+"S":"")):"P0D"}var dn=ze.prototype;return dn.isValid=function(){return this._isValid},dn.abs=function(){var t=this._data;return this._milliseconds=Ri(this._milliseconds),this._days=Ri(this._days),this._months=Ri(this._months),t.milliseconds=Ri(t.milliseconds),t.seconds=Ri(t.seconds),t.minutes=Ri(t.minutes),t.hours=Ri(t.hours),t.months=Ri(t.months),t.years=Ri(t.years),this},dn.add=function(t,e){return Fi(this,t,e,1)},dn.subtract=function(t,e){return Fi(this,t,e,-1)},dn.as=function(t){if(!this.isValid())return NaN;var e,i,n=this._milliseconds;if("month"===(t=B(t))||"quarter"===t||"year"===t)switch(e=this._days+n/864e5,i=this._months+Yi(e),t){case"month":return i;case"quarter":return i/3;case"year":return i/12}else switch(e=this._days+Math.round(Hi(this._months)),t){case"week":return e/7+n/6048e5;case"day":return e+n/864e5;case"hour":return 24*e+n/36e5;case"minute":return 1440*e+n/6e4;case"second":return 86400*e+n/1e3;case"millisecond":return Math.floor(864e5*e)+n;default:throw new Error("Unknown unit "+t)}},dn.asMilliseconds=zi,dn.asSeconds=Gi,dn.asMinutes=Wi,dn.asHours=Vi,dn.asDays=Ui,dn.asWeeks=Xi,dn.asMonths=qi,dn.asQuarters=$i,dn.asYears=Ki,dn.valueOf=function(){return this.isValid()?this._milliseconds+864e5*this._days+this._months%12*2592e6+31536e6*X(this._months/12):NaN},dn._bubble=function(){var t,e,i,n,r,o=this._milliseconds,s=this._days,a=this._months,l=this._data;return o>=0&&s>=0&&a>=0||o<=0&&s<=0&&a<=0||(o+=864e5*ji(Hi(a)+s),s=0,a=0),l.milliseconds=o%1e3,t=U(o/1e3),l.seconds=t%60,e=U(t/60),l.minutes=e%60,i=U(e/60),l.hours=i%24,s+=U(i/24),a+=r=U(Yi(s)),s-=ji(Hi(r)),n=U(a/12),a%=12,l.days=s,l.months=a,l.years=n,this},dn.clone=function(){return Qe(this)},dn.get=function(t){return t=B(t),this.isValid()?this[t+"s"]():NaN},dn.milliseconds=Ji,dn.seconds=Qi,dn.minutes=tn,dn.hours=en,dn.days=nn,dn.weeks=function(){return U(this.days()/7)},dn.months=rn,dn.years=on,dn.humanize=function(t,e){if(!this.isValid())return this.localeData().invalidDate();var i,n,r=!1,o=an;return"object"==typeof t&&(e=t,t=!1),"boolean"==typeof t&&(r=t),"object"==typeof e&&(o=Object.assign({},an,e),null!=e.s&&null==e.ss&&(o.ss=e.s-1)),n=function(t,e,i,n){var r=Qe(t).abs(),o=sn(r.as("s")),s=sn(r.as("m")),a=sn(r.as("h")),l=sn(r.as("d")),h=sn(r.as("M")),u=sn(r.as("w")),c=sn(r.as("y")),d=o<=i.ss&&["s",o]||o<i.s&&["ss",o]||s<=1&&["m"]||s<i.m&&["mm",s]||a<=1&&["h"]||a<i.h&&["hh",a]||l<=1&&["d"]||l<i.d&&["dd",l];return null!=i.w&&(d=d||u<=1&&["w"]||u<i.w&&["ww",u]),(d=d||h<=1&&["M"]||h<i.M&&["MM",h]||c<=1&&["y"]||["yy",c])[2]=e,d[3]=+t>0,d[4]=n,ln.apply(null,d)}(this,!r,o,i=this.localeData()),r&&(n=i.pastFuture(+this,n)),i.postformat(n)},dn.toISOString=cn,dn.toString=cn,dn.toJSON=cn,dn.locale=hi,dn.localeData=ci,dn.toIsoString=x("toIsoString() is deprecated. Please use toISOString() instead (notice the capitals)",cn),dn.lang=ui,N("X",0,0,"unix"),N("x",0,0,"valueOf"),ft("x",ut),ft("X",/[+-]?\d+(\.\d{1,3})?/),yt("X",(function(t,e,i){i._d=new Date(1e3*parseFloat(t))})),yt("x",(function(t,e,i){i._d=new Date(X(t))})),
//! moment.js
n.version="2.29.4",function(t){e=t}(Re),n.fn=Pi,n.min=function(){return Ye("isBefore",[].slice.call(arguments,0))},n.max=function(){return Ye("isAfter",[].slice.call(arguments,0))},n.now=function(){return Date.now?Date.now():+new Date},n.utc=p,n.unix=function(t){return Re(1e3*t)},n.months=function(t,e){return Ai(t,e,"months")},n.isDate=u,n.locale=me,n.invalid=v,n.duration=Qe,n.isMoment=w,n.weekdays=function(t,e,i){return Ni(t,e,i,"weekdays")},n.parseZone=function(){return Re.apply(null,arguments).parseZone()},n.localeData=ge,n.isDuration=Ge,n.monthsShort=function(t,e){return Ai(t,e,"monthsShort")},n.weekdaysMin=function(t,e,i){return Ni(t,e,i,"weekdaysMin")},n.defineLocale=ve,n.updateLocale=function(t,e){if(null!=e){var i,n,r=he;null!=ue[t]&&null!=ue[t].parentLocale?ue[t].set(M(ue[t]._config,e)):(null!=(n=fe(t))&&(r=n._config),e=M(r,e),null==n&&(e.abbr=t),(i=new O(e)).parentLocale=ue[t],ue[t]=i),me(t)}else null!=ue[t]&&(null!=ue[t].parentLocale?(ue[t]=ue[t].parentLocale,t===me()&&me(t)):null!=ue[t]&&delete ue[t]);return ue[t]},n.locales=function(){return S(ue)},n.weekdaysShort=function(t,e,i){return Ni(t,e,i,"weekdaysShort")},n.normalizeUnits=B,n.relativeTimeRounding=function(t){return void 0===t?sn:"function"==typeof t&&(sn=t,!0)},n.relativeTimeThreshold=function(t,e){return void 0!==an[t]&&(void 0===e?an[t]:(an[t]=e,"s"===t&&(an.ss=e-1),!0))},n.calendarFormat=function(t,e){var i=t.diff(e,"days",!0);return i<-6?"sameElse":i<-1?"lastWeek":i<0?"lastDay":i<1?"sameDay":i<2?"nextDay":i<7?"nextWeek":"sameElse"},n.prototype=Pi,n.HTML5_FMT={DATETIME_LOCAL:"YYYY-MM-DDTHH:mm",DATETIME_LOCAL_SECONDS:"YYYY-MM-DDTHH:mm:ss",DATETIME_LOCAL_MS:"YYYY-MM-DDTHH:mm:ss.SSS",DATE:"YYYY-MM-DD",TIME:"HH:mm",TIME_SECONDS:"HH:mm:ss",TIME_MS:"HH:mm:ss.SSS",WEEK:"GGGG-[W]WW",MONTH:"YYYY-MM"},n}()}(s)),s.exports}o=function(t){
//! moment.js locale configuration
function e(t,e,i,n){var r={m:["eine Minute","einer Minute"],h:["eine Stunde","einer Stunde"],d:["ein Tag","einem Tag"],dd:[t+" Tage",t+" Tagen"],w:["eine Woche","einer Woche"],M:["ein Monat","einem Monat"],MM:[t+" Monate",t+" Monaten"],y:["ein Jahr","einem Jahr"],yy:[t+" Jahre",t+" Jahren"]};return e?r[i][0]:r[i][1]}return t.defineLocale("de",{months:"Januar_Februar_März_April_Mai_Juni_Juli_August_September_Oktober_November_Dezember".split("_"),monthsShort:"Jan._Feb._März_Apr._Mai_Juni_Juli_Aug._Sep._Okt._Nov._Dez.".split("_"),monthsParseExact:!0,weekdays:"Sonntag_Montag_Dienstag_Mittwoch_Donnerstag_Freitag_Samstag".split("_"),weekdaysShort:"So._Mo._Di._Mi._Do._Fr._Sa.".split("_"),weekdaysMin:"So_Mo_Di_Mi_Do_Fr_Sa".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D. MMMM YYYY",LLL:"D. MMMM YYYY HH:mm",LLLL:"dddd, D. MMMM YYYY HH:mm"},calendar:{sameDay:"[heute um] LT [Uhr]",sameElse:"L",nextDay:"[morgen um] LT [Uhr]",nextWeek:"dddd [um] LT [Uhr]",lastDay:"[gestern um] LT [Uhr]",lastWeek:"[letzten] dddd [um] LT [Uhr]"},relativeTime:{future:"in %s",past:"vor %s",s:"ein paar Sekunden",ss:"%d Sekunden",m:e,mm:"%d Minuten",h:e,hh:"%d Stunden",d:e,dd:e,w:e,ww:"%d Wochen",M:e,MM:e,y:e,yy:e},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})},o(a()),function(t){
//! moment.js locale configuration
var e="ene._feb._mar._abr._may._jun._jul._ago._sep._oct._nov._dic.".split("_"),i="ene_feb_mar_abr_may_jun_jul_ago_sep_oct_nov_dic".split("_"),n=[/^ene/i,/^feb/i,/^mar/i,/^abr/i,/^may/i,/^jun/i,/^jul/i,/^ago/i,/^sep/i,/^oct/i,/^nov/i,/^dic/i],r=/^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre|ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i;t.defineLocale("es",{months:"enero_febrero_marzo_abril_mayo_junio_julio_agosto_septiembre_octubre_noviembre_diciembre".split("_"),monthsShort:function(t,n){return t?/-MMM-/.test(n)?i[t.month()]:e[t.month()]:e},monthsRegex:r,monthsShortRegex:r,monthsStrictRegex:/^(enero|febrero|marzo|abril|mayo|junio|julio|agosto|septiembre|octubre|noviembre|diciembre)/i,monthsShortStrictRegex:/^(ene\.?|feb\.?|mar\.?|abr\.?|may\.?|jun\.?|jul\.?|ago\.?|sep\.?|oct\.?|nov\.?|dic\.?)/i,monthsParse:n,longMonthsParse:n,shortMonthsParse:n,weekdays:"domingo_lunes_martes_miércoles_jueves_viernes_sábado".split("_"),weekdaysShort:"dom._lun._mar._mié._jue._vie._sáb.".split("_"),weekdaysMin:"do_lu_ma_mi_ju_vi_sá".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD/MM/YYYY",LL:"D [de] MMMM [de] YYYY",LLL:"D [de] MMMM [de] YYYY H:mm",LLLL:"dddd, D [de] MMMM [de] YYYY H:mm"},calendar:{sameDay:function(){return"[hoy a la"+(1!==this.hours()?"s":"")+"] LT"},nextDay:function(){return"[mañana a la"+(1!==this.hours()?"s":"")+"] LT"},nextWeek:function(){return"dddd [a la"+(1!==this.hours()?"s":"")+"] LT"},lastDay:function(){return"[ayer a la"+(1!==this.hours()?"s":"")+"] LT"},lastWeek:function(){return"[el] dddd [pasado a la"+(1!==this.hours()?"s":"")+"] LT"},sameElse:"L"},relativeTime:{future:"en %s",past:"hace %s",s:"unos segundos",ss:"%d segundos",m:"un minuto",mm:"%d minutos",h:"una hora",hh:"%d horas",d:"un día",dd:"%d días",w:"una semana",ww:"%d semanas",M:"un mes",MM:"%d meses",y:"un año",yy:"%d años"},dayOfMonthOrdinalParse:/\d{1,2}º/,ordinal:"%dº",week:{dow:1,doy:4},invalidDate:"Fecha inválida"})}(a()),function(t){
//! moment.js locale configuration
var e=/(janv\.?|févr\.?|mars|avr\.?|mai|juin|juil\.?|août|sept\.?|oct\.?|nov\.?|déc\.?|janvier|février|mars|avril|mai|juin|juillet|août|septembre|octobre|novembre|décembre)/i,i=[/^janv/i,/^févr/i,/^mars/i,/^avr/i,/^mai/i,/^juin/i,/^juil/i,/^août/i,/^sept/i,/^oct/i,/^nov/i,/^déc/i];t.defineLocale("fr",{months:"janvier_février_mars_avril_mai_juin_juillet_août_septembre_octobre_novembre_décembre".split("_"),monthsShort:"janv._févr._mars_avr._mai_juin_juil._août_sept._oct._nov._déc.".split("_"),monthsRegex:e,monthsShortRegex:e,monthsStrictRegex:/^(janvier|février|mars|avril|mai|juin|juillet|août|septembre|octobre|novembre|décembre)/i,monthsShortStrictRegex:/(janv\.?|févr\.?|mars|avr\.?|mai|juin|juil\.?|août|sept\.?|oct\.?|nov\.?|déc\.?)/i,monthsParse:i,longMonthsParse:i,shortMonthsParse:i,weekdays:"dimanche_lundi_mardi_mercredi_jeudi_vendredi_samedi".split("_"),weekdaysShort:"dim._lun._mar._mer._jeu._ven._sam.".split("_"),weekdaysMin:"di_lu_ma_me_je_ve_sa".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[Aujourd’hui à] LT",nextDay:"[Demain à] LT",nextWeek:"dddd [à] LT",lastDay:"[Hier à] LT",lastWeek:"dddd [dernier à] LT",sameElse:"L"},relativeTime:{future:"dans %s",past:"il y a %s",s:"quelques secondes",ss:"%d secondes",m:"une minute",mm:"%d minutes",h:"une heure",hh:"%d heures",d:"un jour",dd:"%d jours",w:"une semaine",ww:"%d semaines",M:"un mois",MM:"%d mois",y:"un an",yy:"%d ans"},dayOfMonthOrdinalParse:/\d{1,2}(er|)/,ordinal:function(t,e){switch(e){case"D":return t+(1===t?"er":"");default:case"M":case"Q":case"DDD":case"d":return t+(1===t?"er":"e");case"w":case"W":return t+(1===t?"re":"e")}},week:{dow:1,doy:4}})}(a()),function(t){t.defineLocale("it",{months:"gennaio_febbraio_marzo_aprile_maggio_giugno_luglio_agosto_settembre_ottobre_novembre_dicembre".split("_"),monthsShort:"gen_feb_mar_apr_mag_giu_lug_ago_set_ott_nov_dic".split("_"),weekdays:"domenica_lunedì_martedì_mercoledì_giovedì_venerdì_sabato".split("_"),weekdaysShort:"dom_lun_mar_mer_gio_ven_sab".split("_"),weekdaysMin:"do_lu_ma_me_gi_ve_sa".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD/MM/YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:function(){return"[Oggi a"+(this.hours()>1?"lle ":0===this.hours()?" ":"ll'")+"]LT"},nextDay:function(){return"[Domani a"+(this.hours()>1?"lle ":0===this.hours()?" ":"ll'")+"]LT"},nextWeek:function(){return"dddd [a"+(this.hours()>1?"lle ":0===this.hours()?" ":"ll'")+"]LT"},lastDay:function(){return"[Ieri a"+(this.hours()>1?"lle ":0===this.hours()?" ":"ll'")+"]LT"},lastWeek:function(){return 0===this.day()?"[La scorsa] dddd [a"+(this.hours()>1?"lle ":0===this.hours()?" ":"ll'")+"]LT":"[Lo scorso] dddd [a"+(this.hours()>1?"lle ":0===this.hours()?" ":"ll'")+"]LT"},sameElse:"L"},relativeTime:{future:"tra %s",past:"%s fa",s:"alcuni secondi",ss:"%d secondi",m:"un minuto",mm:"%d minuti",h:"un'ora",hh:"%d ore",d:"un giorno",dd:"%d giorni",w:"una settimana",ww:"%d settimane",M:"un mese",MM:"%d mesi",y:"un anno",yy:"%d anni"},dayOfMonthOrdinalParse:/\d{1,2}º/,ordinal:"%dº",week:{dow:1,doy:4}})}(a()),function(t){
//! moment.js locale configuration
t.defineLocale("ja",{eras:[{since:"2019-05-01",offset:1,name:"令和",narrow:"㋿",abbr:"R"},{since:"1989-01-08",until:"2019-04-30",offset:1,name:"平成",narrow:"㍻",abbr:"H"},{since:"1926-12-25",until:"1989-01-07",offset:1,name:"昭和",narrow:"㍼",abbr:"S"},{since:"1912-07-30",until:"1926-12-24",offset:1,name:"大正",narrow:"㍽",abbr:"T"},{since:"1873-01-01",until:"1912-07-29",offset:6,name:"明治",narrow:"㍾",abbr:"M"},{since:"0001-01-01",until:"1873-12-31",offset:1,name:"西暦",narrow:"AD",abbr:"AD"},{since:"0000-12-31",until:-1/0,offset:1,name:"紀元前",narrow:"BC",abbr:"BC"}],eraYearOrdinalRegex:/(元|\d+)年/,eraYearOrdinalParse:function(t,e){return"元"===e[1]?1:parseInt(e[1]||t,10)},months:"1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月".split("_"),monthsShort:"1月_2月_3月_4月_5月_6月_7月_8月_9月_10月_11月_12月".split("_"),weekdays:"日曜日_月曜日_火曜日_水曜日_木曜日_金曜日_土曜日".split("_"),weekdaysShort:"日_月_火_水_木_金_土".split("_"),weekdaysMin:"日_月_火_水_木_金_土".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"YYYY/MM/DD",LL:"YYYY年M月D日",LLL:"YYYY年M月D日 HH:mm",LLLL:"YYYY年M月D日 dddd HH:mm",l:"YYYY/MM/DD",ll:"YYYY年M月D日",lll:"YYYY年M月D日 HH:mm",llll:"YYYY年M月D日(ddd) HH:mm"},meridiemParse:/午前|午後/i,isPM:function(t){return"午後"===t},meridiem:function(t,e,i){return t<12?"午前":"午後"},calendar:{sameDay:"[今日] LT",nextDay:"[明日] LT",nextWeek:function(t){return t.week()!==this.week()?"[来週]dddd LT":"dddd LT"},lastDay:"[昨日] LT",lastWeek:function(t){return this.week()!==t.week()?"[先週]dddd LT":"dddd LT"},sameElse:"L"},dayOfMonthOrdinalParse:/\d{1,2}日/,ordinal:function(t,e){switch(e){case"y":return 1===t?"元年":t+"年";case"d":case"D":case"DDD":return t+"日";default:return t}},relativeTime:{future:"%s後",past:"%s前",s:"数秒",ss:"%d秒",m:"1分",mm:"%d分",h:"1時間",hh:"%d時間",d:"1日",dd:"%d日",M:"1ヶ月",MM:"%dヶ月",y:"1年",yy:"%d年"}})}(a()),function(t){
//! moment.js locale configuration
var e="jan._feb._mrt._apr._mei_jun._jul._aug._sep._okt._nov._dec.".split("_"),i="jan_feb_mrt_apr_mei_jun_jul_aug_sep_okt_nov_dec".split("_"),n=[/^jan/i,/^feb/i,/^maart|mrt.?$/i,/^apr/i,/^mei$/i,/^jun[i.]?$/i,/^jul[i.]?$/i,/^aug/i,/^sep/i,/^okt/i,/^nov/i,/^dec/i],r=/^(januari|februari|maart|april|mei|ju[nl]i|augustus|september|oktober|november|december|jan\.?|feb\.?|mrt\.?|apr\.?|ju[nl]\.?|aug\.?|sep\.?|okt\.?|nov\.?|dec\.?)/i;t.defineLocale("nl",{months:"januari_februari_maart_april_mei_juni_juli_augustus_september_oktober_november_december".split("_"),monthsShort:function(t,n){return t?/-MMM-/.test(n)?i[t.month()]:e[t.month()]:e},monthsRegex:r,monthsShortRegex:r,monthsStrictRegex:/^(januari|februari|maart|april|mei|ju[nl]i|augustus|september|oktober|november|december)/i,monthsShortStrictRegex:/^(jan\.?|feb\.?|mrt\.?|apr\.?|mei|ju[nl]\.?|aug\.?|sep\.?|okt\.?|nov\.?|dec\.?)/i,monthsParse:n,longMonthsParse:n,shortMonthsParse:n,weekdays:"zondag_maandag_dinsdag_woensdag_donderdag_vrijdag_zaterdag".split("_"),weekdaysShort:"zo._ma._di._wo._do._vr._za.".split("_"),weekdaysMin:"zo_ma_di_wo_do_vr_za".split("_"),weekdaysParseExact:!0,longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD-MM-YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd D MMMM YYYY HH:mm"},calendar:{sameDay:"[vandaag om] LT",nextDay:"[morgen om] LT",nextWeek:"dddd [om] LT",lastDay:"[gisteren om] LT",lastWeek:"[afgelopen] dddd [om] LT",sameElse:"L"},relativeTime:{future:"over %s",past:"%s geleden",s:"een paar seconden",ss:"%d seconden",m:"één minuut",mm:"%d minuten",h:"één uur",hh:"%d uur",d:"één dag",dd:"%d dagen",w:"één week",ww:"%d weken",M:"één maand",MM:"%d maanden",y:"één jaar",yy:"%d jaar"},dayOfMonthOrdinalParse:/\d{1,2}(ste|de)/,ordinal:function(t){return t+(1===t||8===t||t>=20?"ste":"de")},week:{dow:1,doy:4}})}(a()),function(t){
//! moment.js locale configuration
var e="styczeń_luty_marzec_kwiecień_maj_czerwiec_lipiec_sierpień_wrzesień_październik_listopad_grudzień".split("_"),i="stycznia_lutego_marca_kwietnia_maja_czerwca_lipca_sierpnia_września_października_listopada_grudnia".split("_"),n=[/^sty/i,/^lut/i,/^mar/i,/^kwi/i,/^maj/i,/^cze/i,/^lip/i,/^sie/i,/^wrz/i,/^paź/i,/^lis/i,/^gru/i];function r(t){return t%10<5&&t%10>1&&~~(t/10)%10!=1}function o(t,e,i){var n=t+" ";switch(i){case"ss":return n+(r(t)?"sekundy":"sekund");case"m":return e?"minuta":"minutę";case"mm":return n+(r(t)?"minuty":"minut");case"h":return e?"godzina":"godzinę";case"hh":return n+(r(t)?"godziny":"godzin");case"ww":return n+(r(t)?"tygodnie":"tygodni");case"MM":return n+(r(t)?"miesiące":"miesięcy");case"yy":return n+(r(t)?"lata":"lat")}}t.defineLocale("pl",{months:function(t,n){return t?/D MMMM/.test(n)?i[t.month()]:e[t.month()]:e},monthsShort:"sty_lut_mar_kwi_maj_cze_lip_sie_wrz_paź_lis_gru".split("_"),monthsParse:n,longMonthsParse:n,shortMonthsParse:n,weekdays:"niedziela_poniedziałek_wtorek_środa_czwartek_piątek_sobota".split("_"),weekdaysShort:"ndz_pon_wt_śr_czw_pt_sob".split("_"),weekdaysMin:"Nd_Pn_Wt_Śr_Cz_Pt_So".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY",LLL:"D MMMM YYYY HH:mm",LLLL:"dddd, D MMMM YYYY HH:mm"},calendar:{sameDay:"[Dziś o] LT",nextDay:"[Jutro o] LT",nextWeek:function(){switch(this.day()){case 0:return"[W niedzielę o] LT";case 2:return"[We wtorek o] LT";case 3:return"[W środę o] LT";case 6:return"[W sobotę o] LT";default:return"[W] dddd [o] LT"}},lastDay:"[Wczoraj o] LT",lastWeek:function(){switch(this.day()){case 0:return"[W zeszłą niedzielę o] LT";case 3:return"[W zeszłą środę o] LT";case 6:return"[W zeszłą sobotę o] LT";default:return"[W zeszły] dddd [o] LT"}},sameElse:"L"},relativeTime:{future:"za %s",past:"%s temu",s:"kilka sekund",ss:o,m:o,mm:o,h:o,hh:o,d:"1 dzień",dd:"%d dni",w:"tydzień",ww:o,M:"miesiąc",MM:o,y:"rok",yy:o},dayOfMonthOrdinalParse:/\d{1,2}\./,ordinal:"%d.",week:{dow:1,doy:4}})}(a()),function(t){function e(t,e,i){var n,r;return"m"===i?e?"минута":"минуту":t+" "+(n=+t,r={ss:e?"секунда_секунды_секунд":"секунду_секунды_секунд",mm:e?"минута_минуты_минут":"минуту_минуты_минут",hh:"час_часа_часов",dd:"день_дня_дней",ww:"неделя_недели_недель",MM:"месяц_месяца_месяцев",yy:"год_года_лет"}[i].split("_"),n%10==1&&n%100!=11?r[0]:n%10>=2&&n%10<=4&&(n%100<10||n%100>=20)?r[1]:r[2])}var i=[/^янв/i,/^фев/i,/^мар/i,/^апр/i,/^ма[йя]/i,/^июн/i,/^июл/i,/^авг/i,/^сен/i,/^окт/i,/^ноя/i,/^дек/i];t.defineLocale("ru",{months:{format:"января_февраля_марта_апреля_мая_июня_июля_августа_сентября_октября_ноября_декабря".split("_"),standalone:"январь_февраль_март_апрель_май_июнь_июль_август_сентябрь_октябрь_ноябрь_декабрь".split("_")},monthsShort:{format:"янв._февр._мар._апр._мая_июня_июля_авг._сент._окт._нояб._дек.".split("_"),standalone:"янв._февр._март_апр._май_июнь_июль_авг._сент._окт._нояб._дек.".split("_")},weekdays:{standalone:"воскресенье_понедельник_вторник_среда_четверг_пятница_суббота".split("_"),format:"воскресенье_понедельник_вторник_среду_четверг_пятницу_субботу".split("_"),isFormat:/\[ ?[Вв] ?(?:прошлую|следующую|эту)? ?] ?dddd/},weekdaysShort:"вс_пн_вт_ср_чт_пт_сб".split("_"),weekdaysMin:"вс_пн_вт_ср_чт_пт_сб".split("_"),monthsParse:i,longMonthsParse:i,shortMonthsParse:i,monthsRegex:/^(январ[ья]|янв\.?|феврал[ья]|февр?\.?|марта?|мар\.?|апрел[ья]|апр\.?|ма[йя]|июн[ья]|июн\.?|июл[ья]|июл\.?|августа?|авг\.?|сентябр[ья]|сент?\.?|октябр[ья]|окт\.?|ноябр[ья]|нояб?\.?|декабр[ья]|дек\.?)/i,monthsShortRegex:/^(январ[ья]|янв\.?|феврал[ья]|февр?\.?|марта?|мар\.?|апрел[ья]|апр\.?|ма[йя]|июн[ья]|июн\.?|июл[ья]|июл\.?|августа?|авг\.?|сентябр[ья]|сент?\.?|октябр[ья]|окт\.?|ноябр[ья]|нояб?\.?|декабр[ья]|дек\.?)/i,monthsStrictRegex:/^(январ[яь]|феврал[яь]|марта?|апрел[яь]|ма[яй]|июн[яь]|июл[яь]|августа?|сентябр[яь]|октябр[яь]|ноябр[яь]|декабр[яь])/i,monthsShortStrictRegex:/^(янв\.|февр?\.|мар[т.]|апр\.|ма[яй]|июн[ья.]|июл[ья.]|авг\.|сент?\.|окт\.|нояб?\.|дек\.)/i,longDateFormat:{LT:"H:mm",LTS:"H:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY г.",LLL:"D MMMM YYYY г., H:mm",LLLL:"dddd, D MMMM YYYY г., H:mm"},calendar:{sameDay:"[Сегодня, в] LT",nextDay:"[Завтра, в] LT",lastDay:"[Вчера, в] LT",nextWeek:function(t){if(t.week()===this.week())return 2===this.day()?"[Во] dddd, [в] LT":"[В] dddd, [в] LT";switch(this.day()){case 0:return"[В следующее] dddd, [в] LT";case 1:case 2:case 4:return"[В следующий] dddd, [в] LT";case 3:case 5:case 6:return"[В следующую] dddd, [в] LT"}},lastWeek:function(t){if(t.week()===this.week())return 2===this.day()?"[Во] dddd, [в] LT":"[В] dddd, [в] LT";switch(this.day()){case 0:return"[В прошлое] dddd, [в] LT";case 1:case 2:case 4:return"[В прошлый] dddd, [в] LT";case 3:case 5:case 6:return"[В прошлую] dddd, [в] LT"}},sameElse:"L"},relativeTime:{future:"через %s",past:"%s назад",s:"несколько секунд",ss:e,m:e,mm:e,h:"час",hh:e,d:"день",dd:e,w:"неделя",ww:e,M:"месяц",MM:e,y:"год",yy:e},meridiemParse:/ночи|утра|дня|вечера/i,isPM:function(t){return/^(дня|вечера)$/.test(t)},meridiem:function(t,e,i){return t<4?"ночи":t<12?"утра":t<17?"дня":"вечера"},dayOfMonthOrdinalParse:/\d{1,2}-(й|го|я)/,ordinal:function(t,e){switch(e){case"M":case"d":case"DDD":return t+"-й";case"D":return t+"-го";case"w":case"W":return t+"-я";default:return t}},week:{dow:1,doy:4}})}(a()),function(t){function e(t,e,i){var n,r;return"m"===i?e?"хвилина":"хвилину":"h"===i?e?"година":"годину":t+" "+(n=+t,r={ss:e?"секунда_секунди_секунд":"секунду_секунди_секунд",mm:e?"хвилина_хвилини_хвилин":"хвилину_хвилини_хвилин",hh:e?"година_години_годин":"годину_години_годин",dd:"день_дні_днів",MM:"місяць_місяці_місяців",yy:"рік_роки_років"}[i].split("_"),n%10==1&&n%100!=11?r[0]:n%10>=2&&n%10<=4&&(n%100<10||n%100>=20)?r[1]:r[2])}function i(t){return function(){return t+"о"+(11===this.hours()?"б":"")+"] LT"}}t.defineLocale("uk",{months:{format:"січня_лютого_березня_квітня_травня_червня_липня_серпня_вересня_жовтня_листопада_грудня".split("_"),standalone:"січень_лютий_березень_квітень_травень_червень_липень_серпень_вересень_жовтень_листопад_грудень".split("_")},monthsShort:"січ_лют_бер_квіт_трав_черв_лип_серп_вер_жовт_лист_груд".split("_"),weekdays:function(t,e){var i={nominative:"неділя_понеділок_вівторок_середа_четвер_п’ятниця_субота".split("_"),accusative:"неділю_понеділок_вівторок_середу_четвер_п’ятницю_суботу".split("_"),genitive:"неділі_понеділка_вівторка_середи_четверга_п’ятниці_суботи".split("_")};return!0===t?i.nominative.slice(1,7).concat(i.nominative.slice(0,1)):t?i[/(\[[ВвУу]\]) ?dddd/.test(e)?"accusative":/\[?(?:минулої|наступної)? ?\] ?dddd/.test(e)?"genitive":"nominative"][t.day()]:i.nominative},weekdaysShort:"нд_пн_вт_ср_чт_пт_сб".split("_"),weekdaysMin:"нд_пн_вт_ср_чт_пт_сб".split("_"),longDateFormat:{LT:"HH:mm",LTS:"HH:mm:ss",L:"DD.MM.YYYY",LL:"D MMMM YYYY р.",LLL:"D MMMM YYYY р., HH:mm",LLLL:"dddd, D MMMM YYYY р., HH:mm"},calendar:{sameDay:i("[Сьогодні "),nextDay:i("[Завтра "),lastDay:i("[Вчора "),nextWeek:i("[У] dddd ["),lastWeek:function(){switch(this.day()){case 0:case 3:case 5:case 6:return i("[Минулої] dddd [").call(this);case 1:case 2:case 4:return i("[Минулого] dddd [").call(this)}},sameElse:"L"},relativeTime:{future:"за %s",past:"%s тому",s:"декілька секунд",ss:e,m:e,mm:e,h:"годину",hh:e,d:"день",dd:e,M:"місяць",MM:e,y:"рік",yy:e},meridiemParse:/ночі|ранку|дня|вечора/,isPM:function(t){return/^(дня|вечора)$/.test(t)},meridiem:function(t,e,i){return t<4?"ночі":t<12?"ранку":t<17?"дня":"вечора"},dayOfMonthOrdinalParse:/\d{1,2}-(й|го)/,ordinal:function(t,e){switch(e){case"M":case"d":case"DDD":case"w":case"W":return t+"-й";case"D":return t+"-го";default:return t}},week:{dow:1,doy:7}})}(a());var l=function(t){try{return!!t()}catch(t){return!0}},h=!l((function(){var t=function(){}.bind();return"function"!=typeof t||t.hasOwnProperty("prototype")})),u=h,c=Function.prototype,d=c.call,p=u&&c.bind.bind(d,d),f=u?p:function(t){return function(){return d.apply(t,arguments)}},m=Math.ceil,v=Math.floor,g=Math.trunc||function(t){var e=+t;return(e>0?v:m)(e)},y=function(t){var e=+t;return e!=e||0===e?0:g(e)},b=function(t){return t&&t.Math===Math&&t},_=b("object"==typeof globalThis&&globalThis)||b("object"==typeof window&&window)||b("object"==typeof self&&self)||b("object"==typeof e&&e)||function(){return this}()||e||Function("return this")(),w={exports:{}},k=_,x=Object.defineProperty,S="__core-js_shared__",D=_[S]||function(t,e){try{x(k,t,{value:e,configurable:!0,writable:!0})}catch(i){k[t]=e}return e}(S,{}),C=D;(w.exports=function(t,e){return C[t]||(C[t]=void 0!==e?e:{})})("versions",[]).push({version:"3.33.0",mode:"pure",copyright:"© 2014-2023 Denis Pushkarev (zloirock.ru)",license:"https://github.com/zloirock/core-js/blob/v3.33.0/LICENSE",source:"https://github.com/zloirock/core-js"});var T,M,O=w.exports,P=function(t){return null==t},E=P,I=TypeError,L=function(t){if(E(t))throw new I("Can't call method on "+t);return t},A=L,N=Object,R=function(t){return N(A(t))},F=R,j=f({}.hasOwnProperty),Y=Object.hasOwn||function(t,e){return j(F(t),e)},H=f,B=0,z=Math.random(),G=H(1..toString),W=function(t){return"Symbol("+(void 0===t?"":t)+")_"+G(++B+z,36)},V="undefined"!=typeof navigator&&String(navigator.userAgent)||"",U=_,X=V,q=U.process,$=U.Deno,K=q&&q.versions||$&&$.version,Z=K&&K.v8;Z&&(M=(T=Z.split("."))[0]>0&&T[0]<4?1:+(T[0]+T[1])),!M&&X&&(!(T=X.match(/Edge\/(\d+)/))||T[1]>=74)&&(T=X.match(/Chrome\/(\d+)/))&&(M=+T[1]);var J=M,Q=J,tt=l,et=_.String,it=!!Object.getOwnPropertySymbols&&!tt((function(){var t=Symbol("symbol detection");return!et(t)||!(Object(t)instanceof Symbol)||!Symbol.sham&&Q&&Q<41})),nt=it&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,rt=O,ot=Y,st=W,at=it,lt=nt,ht=_.Symbol,ut=rt("wks"),ct=lt?ht.for||ht:ht&&ht.withoutSetter||st,dt=function(t){return ot(ut,t)||(ut[t]=at&&ot(ht,t)?ht[t]:ct("Symbol."+t)),ut[t]},pt={};pt[dt("toStringTag")]="z";var ft="[object z]"===String(pt),mt="object"==typeof document&&document.all,vt={all:mt,IS_HTMLDDA:void 0===mt&&void 0!==mt},gt=vt.all,yt=vt.IS_HTMLDDA?function(t){return"function"==typeof t||t===gt}:function(t){return"function"==typeof t},bt=f,_t=bt({}.toString),wt=bt("".slice),kt=function(t){return wt(_t(t),8,-1)},xt=ft,St=yt,Dt=kt,Ct=dt("toStringTag"),Tt=Object,Mt="Arguments"===Dt(function(){return arguments}()),Ot=xt?Dt:function(t){var e,i,n;return void 0===t?"Undefined":null===t?"Null":"string"==typeof(i=function(t,e){try{return t[e]}catch(t){}}(e=Tt(t),Ct))?i:Mt?Dt(e):"Object"===(n=Dt(e))&&St(e.callee)?"Arguments":n},Pt=Ot,Et=String,It=function(t){if("Symbol"===Pt(t))throw new TypeError("Cannot convert a Symbol value to a string");return Et(t)},Lt=f,At=y,Nt=It,Rt=L,Ft=Lt("".charAt),jt=Lt("".charCodeAt),Yt=Lt("".slice),Ht=function(t){return function(e,i){var n,r,o=Nt(Rt(e)),s=At(i),a=o.length;return s<0||s>=a?t?"":void 0:(n=jt(o,s))<55296||n>56319||s+1===a||(r=jt(o,s+1))<56320||r>57343?t?Ft(o,s):n:t?Yt(o,s,s+2):r-56320+(n-55296<<10)+65536}},Bt={codeAt:Ht(!1),charAt:Ht(!0)},zt=yt,Gt=_.WeakMap,Wt=zt(Gt)&&/native code/.test(String(Gt)),Vt=yt,Ut=vt.all,Xt=vt.IS_HTMLDDA?function(t){return"object"==typeof t?null!==t:Vt(t)||t===Ut}:function(t){return"object"==typeof t?null!==t:Vt(t)},qt=!l((function(){return 7!==Object.defineProperty({},1,{get:function(){return 7}})[1]})),$t={},Kt=Xt,Zt=_.document,Jt=Kt(Zt)&&Kt(Zt.createElement),Qt=function(t){return Jt?Zt.createElement(t):{}},te=Qt,ee=!qt&&!l((function(){return 7!==Object.defineProperty(te("div"),"a",{get:function(){return 7}}).a})),ie=qt&&l((function(){return 42!==Object.defineProperty((function(){}),"prototype",{value:42,writable:!1}).prototype})),ne=Xt,re=String,oe=TypeError,se=function(t){if(ne(t))return t;throw new oe(re(t)+" is not an object")},ae=h,le=Function.prototype.call,he=ae?le.bind(le):function(){return le.apply(le,arguments)},ue={},ce=ue,de=_,pe=yt,fe=function(t){return pe(t)?t:void 0},me=function(t,e){return arguments.length<2?fe(ce[t])||fe(de[t]):ce[t]&&ce[t][e]||de[t]&&de[t][e]},ve=f({}.isPrototypeOf),ge=me,ye=yt,be=ve,_e=Object,we=nt?function(t){return"symbol"==typeof t}:function(t){var e=ge("Symbol");return ye(e)&&be(e.prototype,_e(t))},ke=String,xe=function(t){try{return ke(t)}catch(t){return"Object"}},Se=yt,De=xe,Ce=TypeError,Te=function(t){if(Se(t))return t;throw new Ce(De(t)+" is not a function")},Me=Te,Oe=P,Pe=function(t,e){var i=t[e];return Oe(i)?void 0:Me(i)},Ee=he,Ie=yt,Le=Xt,Ae=TypeError,Ne=he,Re=Xt,Fe=we,je=Pe,Ye=TypeError,He=dt("toPrimitive"),Be=function(t,e){if(!Re(t)||Fe(t))return t;var i,n=je(t,He);if(n){if(void 0===e&&(e="default"),i=Ne(n,t,e),!Re(i)||Fe(i))return i;throw new Ye("Can't convert object to primitive value")}return void 0===e&&(e="number"),function(t,e){var i,n;if("string"===e&&Ie(i=t.toString)&&!Le(n=Ee(i,t)))return n;if(Ie(i=t.valueOf)&&!Le(n=Ee(i,t)))return n;if("string"!==e&&Ie(i=t.toString)&&!Le(n=Ee(i,t)))return n;throw new Ae("Can't convert object to primitive value")}(t,e)},ze=we,Ge=function(t){var e=Be(t,"string");return ze(e)?e:e+""},We=qt,Ve=ee,Ue=ie,Xe=se,qe=Ge,$e=TypeError,Ke=Object.defineProperty,Ze=Object.getOwnPropertyDescriptor,Je="enumerable",Qe="configurable",ti="writable";$t.f=We?Ue?function(t,e,i){if(Xe(t),e=qe(e),Xe(i),"function"==typeof t&&"prototype"===e&&"value"in i&&ti in i&&!i[ti]){var n=Ze(t,e);n&&n[ti]&&(t[e]=i.value,i={configurable:Qe in i?i[Qe]:n[Qe],enumerable:Je in i?i[Je]:n[Je],writable:!1})}return Ke(t,e,i)}:Ke:function(t,e,i){if(Xe(t),e=qe(e),Xe(i),Ve)try{return Ke(t,e,i)}catch(t){}if("get"in i||"set"in i)throw new $e("Accessors not supported");return"value"in i&&(t[e]=i.value),t};var ei,ii,ni,ri=function(t,e){return{enumerable:!(1&t),configurable:!(2&t),writable:!(4&t),value:e}},oi=$t,si=ri,ai=qt?function(t,e,i){return oi.f(t,e,si(1,i))}:function(t,e,i){return t[e]=i,t},li=W,hi=O("keys"),ui=function(t){return hi[t]||(hi[t]=li(t))},ci={},di=Wt,pi=_,fi=Xt,mi=ai,vi=Y,gi=D,yi=ui,bi=ci,_i="Object already initialized",wi=pi.TypeError,ki=pi.WeakMap;if(di||gi.state){var xi=gi.state||(gi.state=new ki);xi.get=xi.get,xi.has=xi.has,xi.set=xi.set,ei=function(t,e){if(xi.has(t))throw new wi(_i);return e.facade=t,xi.set(t,e),e},ii=function(t){return xi.get(t)||{}},ni=function(t){return xi.has(t)}}else{var Si=yi("state");bi[Si]=!0,ei=function(t,e){if(vi(t,Si))throw new wi(_i);return e.facade=t,mi(t,Si,e),e},ii=function(t){return vi(t,Si)?t[Si]:{}},ni=function(t){return vi(t,Si)}}var Di={set:ei,get:ii,has:ni,enforce:function(t){return ni(t)?ii(t):ei(t,{})},getterFor:function(t){return function(e){var i;if(!fi(e)||(i=ii(e)).type!==t)throw new wi("Incompatible receiver, "+t+" required");return i}}},Ci=h,Ti=Function.prototype,Mi=Ti.apply,Oi=Ti.call,Pi="object"==typeof Reflect&&Reflect.apply||(Ci?Oi.bind(Mi):function(){return Oi.apply(Mi,arguments)}),Ei=kt,Ii=f,Li=function(t){if("Function"===Ei(t))return Ii(t)},Ai={},Ni={},Ri={}.propertyIsEnumerable,Fi=Object.getOwnPropertyDescriptor,ji=Fi&&!Ri.call({1:2},1);Ni.f=ji?function(t){var e=Fi(this,t);return!!e&&e.enumerable}:Ri;var Yi=l,Hi=kt,Bi=Object,zi=f("".split),Gi=Yi((function(){return!Bi("z").propertyIsEnumerable(0)}))?function(t){return"String"===Hi(t)?zi(t,""):Bi(t)}:Bi,Wi=Gi,Vi=L,Ui=function(t){return Wi(Vi(t))},Xi=qt,qi=he,$i=Ni,Ki=ri,Zi=Ui,Ji=Ge,Qi=Y,tn=ee,en=Object.getOwnPropertyDescriptor;Ai.f=Xi?en:function(t,e){if(t=Zi(t),e=Ji(e),tn)try{return en(t,e)}catch(t){}if(Qi(t,e))return Ki(!qi($i.f,t,e),t[e])};var nn=l,rn=yt,on=/#|\.prototype\./,sn=function(t,e){var i=ln[an(t)];return i===un||i!==hn&&(rn(e)?nn(e):!!e)},an=sn.normalize=function(t){return String(t).replace(on,".").toLowerCase()},ln=sn.data={},hn=sn.NATIVE="N",un=sn.POLYFILL="P",cn=sn,dn=Te,pn=h,fn=Li(Li.bind),mn=function(t,e){return dn(t),void 0===e?t:pn?fn(t,e):function(){return t.apply(e,arguments)}},vn=_,gn=Pi,yn=Li,bn=yt,_n=Ai.f,wn=cn,kn=ue,xn=mn,Sn=ai,Dn=Y,Cn=function(t){var e=function(i,n,r){if(this instanceof e){switch(arguments.length){case 0:return new t;case 1:return new t(i);case 2:return new t(i,n)}return new t(i,n,r)}return gn(t,this,arguments)};return e.prototype=t.prototype,e},Tn=function(t,e){var i,n,r,o,s,a,l,h,u,c=t.target,d=t.global,p=t.stat,f=t.proto,m=d?vn:p?vn[c]:(vn[c]||{}).prototype,v=d?kn:kn[c]||Sn(kn,c,{})[c],g=v.prototype;for(o in e)n=!(i=wn(d?o:c+(p?".":"#")+o,t.forced))&&m&&Dn(m,o),a=v[o],n&&(l=t.dontCallGetSet?(u=_n(m,o))&&u.value:m[o]),s=n&&l?l:e[o],n&&typeof a==typeof s||(h=t.bind&&n?xn(s,vn):t.wrap&&n?Cn(s):f&&bn(s)?yn(s):s,(t.sham||s&&s.sham||a&&a.sham)&&Sn(h,"sham",!0),Sn(v,o,h),f&&(Dn(kn,r=c+"Prototype")||Sn(kn,r,{}),Sn(kn[r],o,s),t.real&&g&&(i||!g[o])&&Sn(g,o,s)))},Mn=qt,On=Y,Pn=Function.prototype,En=Mn&&Object.getOwnPropertyDescriptor,In=On(Pn,"name"),Ln={EXISTS:In,PROPER:In&&"something"===function(){}.name,CONFIGURABLE:In&&(!Mn||Mn&&En(Pn,"name").configurable)},An={},Nn=y,Rn=Math.max,Fn=Math.min,jn=function(t,e){var i=Nn(t);return i<0?Rn(i+e,0):Fn(i,e)},Yn=y,Hn=Math.min,Bn=function(t){return function(t){return t>0?Hn(Yn(t),9007199254740991):0}(t.length)},zn=Ui,Gn=jn,Wn=Bn,Vn=function(t){return function(e,i,n){var r,o=zn(e),s=Wn(o),a=Gn(n,s);if(t&&i!=i){for(;s>a;)if((r=o[a++])!=r)return!0}else for(;s>a;a++)if((t||a in o)&&o[a]===i)return t||a||0;return!t&&-1}},Un={includes:Vn(!0),indexOf:Vn(!1)},Xn=Y,qn=Ui,$n=Un.indexOf,Kn=ci,Zn=f([].push),Jn=function(t,e){var i,n=qn(t),r=0,o=[];for(i in n)!Xn(Kn,i)&&Xn(n,i)&&Zn(o,i);for(;e.length>r;)Xn(n,i=e[r++])&&(~$n(o,i)||Zn(o,i));return o},Qn=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],tr=Jn,er=Qn,ir=Object.keys||function(t){return tr(t,er)},nr=qt,rr=ie,or=$t,sr=se,ar=Ui,lr=ir;An.f=nr&&!rr?Object.defineProperties:function(t,e){sr(t);for(var i,n=ar(e),r=lr(e),o=r.length,s=0;o>s;)or.f(t,i=r[s++],n[i]);return t};var hr,ur=me("document","documentElement"),cr=se,dr=An,pr=Qn,fr=ci,mr=ur,vr=Qt,gr="prototype",yr="script",br=ui("IE_PROTO"),_r=function(){},wr=function(t){return"<"+yr+">"+t+"</"+yr+">"},kr=function(t){t.write(wr("")),t.close();var e=t.parentWindow.Object;return t=null,e},xr=function(){try{hr=new ActiveXObject("htmlfile")}catch(t){}var t,e,i;xr="undefined"!=typeof document?document.domain&&hr?kr(hr):(e=vr("iframe"),i="java"+yr+":",e.style.display="none",mr.appendChild(e),e.src=String(i),(t=e.contentWindow.document).open(),t.write(wr("document.F=Object")),t.close(),t.F):kr(hr);for(var n=pr.length;n--;)delete xr[gr][pr[n]];return xr()};fr[br]=!0;var Sr,Dr,Cr,Tr=Object.create||function(t,e){var i;return null!==t?(_r[gr]=cr(t),i=new _r,_r[gr]=null,i[br]=t):i=xr(),void 0===e?i:dr.f(i,e)},Mr=!l((function(){function t(){}return t.prototype.constructor=null,Object.getPrototypeOf(new t)!==t.prototype})),Or=Y,Pr=yt,Er=R,Ir=Mr,Lr=ui("IE_PROTO"),Ar=Object,Nr=Ar.prototype,Rr=Ir?Ar.getPrototypeOf:function(t){var e=Er(t);if(Or(e,Lr))return e[Lr];var i=e.constructor;return Pr(i)&&e instanceof i?i.prototype:e instanceof Ar?Nr:null},Fr=ai,jr=function(t,e,i,n){return n&&n.enumerable?t[e]=i:Fr(t,e,i),t},Yr=l,Hr=yt,Br=Xt,zr=Tr,Gr=Rr,Wr=jr,Vr=dt("iterator"),Ur=!1;[].keys&&("next"in(Cr=[].keys())?(Dr=Gr(Gr(Cr)))!==Object.prototype&&(Sr=Dr):Ur=!0);var Xr=!Br(Sr)||Yr((function(){var t={};return Sr[Vr].call(t)!==t}));Hr((Sr=Xr?{}:zr(Sr))[Vr])||Wr(Sr,Vr,(function(){return this}));var qr={IteratorPrototype:Sr,BUGGY_SAFARI_ITERATORS:Ur},$r=Ot,Kr=ft?{}.toString:function(){return"[object "+$r(this)+"]"},Zr=ft,Jr=$t.f,Qr=ai,to=Y,eo=Kr,io=dt("toStringTag"),no=function(t,e,i,n){if(t){var r=i?t:t.prototype;to(r,io)||Jr(r,io,{configurable:!0,value:e}),n&&!Zr&&Qr(r,"toString",eo)}},ro={},oo=qr.IteratorPrototype,so=Tr,ao=ri,lo=no,ho=ro,uo=function(){return this},co=f,po=Te,fo=yt,mo=String,vo=TypeError,go=se,yo=Object.setPrototypeOf||("__proto__"in{}?function(){var t,e=!1,i={};try{(t=function(t,e,i){try{return co(po(Object.getOwnPropertyDescriptor(t,e)[i]))}catch(t){}}(Object.prototype,"__proto__","set"))(i,[]),e=i instanceof Array}catch(t){}return function(i,n){return go(i),function(t){if("object"==typeof t||fo(t))return t;throw new vo("Can't set "+mo(t)+" as a prototype")}(n),e?t(i,n):i.__proto__=n,i}}():void 0),bo=Tn,_o=he,wo=Rr,ko=no,xo=jr,So=ro,Do=Ln.PROPER,Co=qr.BUGGY_SAFARI_ITERATORS,To=dt("iterator"),Mo="keys",Oo="values",Po="entries",Eo=function(){return this},Io=function(t,e,i,n,r,o,s){!function(t,e,i,n){var r=e+" Iterator";t.prototype=so(oo,{next:ao(+!n,i)}),lo(t,r,!1,!0),ho[r]=uo}(i,e,n);var a,l,h,u=function(t){if(t===r&&m)return m;if(!Co&&t&&t in p)return p[t];switch(t){case Mo:case Oo:case Po:return function(){return new i(this,t)}}return function(){return new i(this)}},c=e+" Iterator",d=!1,p=t.prototype,f=p[To]||p["@@iterator"]||r&&p[r],m=!Co&&f||u(r),v="Array"===e&&p.entries||f;if(v&&(a=wo(v.call(new t)))!==Object.prototype&&a.next&&(ko(a,c,!0,!0),So[c]=Eo),Do&&r===Oo&&f&&f.name!==Oo&&(d=!0,m=function(){return _o(f,this)}),r)if(l={values:u(Oo),keys:o?m:u(Mo),entries:u(Po)},s)for(h in l)(Co||d||!(h in p))&&xo(p,h,l[h]);else bo({target:e,proto:!0,forced:Co||d},l);return s&&p[To]!==m&&xo(p,To,m,{name:r}),So[e]=m,l},Lo=function(t,e){return{value:t,done:e}},Ao=Bt.charAt,No=It,Ro=Di,Fo=Io,jo=Lo,Yo="String Iterator",Ho=Ro.set,Bo=Ro.getterFor(Yo);Fo(String,"String",(function(t){Ho(this,{type:Yo,string:No(t),index:0})}),(function(){var t,e=Bo(this),i=e.string,n=e.index;return n>=i.length?jo(void 0,!0):(t=Ao(i,n),e.index+=t.length,jo(t,!1))}));var zo=he,Go=se,Wo=Pe,Vo=function(t,e,i){var n,r;Go(t);try{if(!(n=Wo(t,"return"))){if("throw"===e)throw i;return i}n=zo(n,t)}catch(t){r=!0,n=t}if("throw"===e)throw i;if(r)throw n;return Go(n),i},Uo=se,Xo=Vo,qo=ro,$o=dt("iterator"),Ko=Array.prototype,Zo=function(t){return void 0!==t&&(qo.Array===t||Ko[$o]===t)},Jo=yt,Qo=D,ts=f(Function.toString);Jo(Qo.inspectSource)||(Qo.inspectSource=function(t){return ts(t)});var es=Qo.inspectSource,is=f,ns=l,rs=yt,os=Ot,ss=es,as=function(){},ls=[],hs=me("Reflect","construct"),us=/^\s*(?:class|function)\b/,cs=is(us.exec),ds=!us.test(as),ps=function(t){if(!rs(t))return!1;try{return hs(as,ls,t),!0}catch(t){return!1}},fs=function(t){if(!rs(t))return!1;switch(os(t)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}try{return ds||!!cs(us,ss(t))}catch(t){return!0}};fs.sham=!0;var ms=!hs||ns((function(){var t;return ps(ps.call)||!ps(Object)||!ps((function(){t=!0}))||t}))?fs:ps,vs=Ge,gs=$t,ys=ri,bs=function(t,e,i){var n=vs(e);n in t?gs.f(t,n,ys(0,i)):t[n]=i},_s=Ot,ws=Pe,ks=P,xs=ro,Ss=dt("iterator"),Ds=function(t){if(!ks(t))return ws(t,Ss)||ws(t,"@@iterator")||xs[_s(t)]},Cs=he,Ts=Te,Ms=se,Os=xe,Ps=Ds,Es=TypeError,Is=function(t,e){var i=arguments.length<2?Ps(t):e;if(Ts(i))return Ms(Cs(i,t));throw new Es(Os(t)+" is not iterable")},Ls=mn,As=he,Ns=R,Rs=function(t,e,i,n){try{return n?e(Uo(i)[0],i[1]):e(i)}catch(e){Xo(t,"throw",e)}},Fs=Zo,js=ms,Ys=Bn,Hs=bs,Bs=Is,zs=Ds,Gs=Array,Ws=dt("iterator"),Vs=!1;try{var Us=0,Xs={next:function(){return{done:!!Us++}},return:function(){Vs=!0}};Xs[Ws]=function(){return this},Array.from(Xs,(function(){throw 2}))}catch(t){}var qs=function(t,e){try{if(!e&&!Vs)return!1}catch(t){return!1}var i=!1;try{var n={};n[Ws]=function(){return{next:function(){return{done:i=!0}}}},t(n)}catch(t){}return i};Tn({target:"Array",stat:!0,forced:!qs((function(t){Array.from(t)}))},{from:function(t){var e=Ns(t),i=js(this),n=arguments.length,r=n>1?arguments[1]:void 0,o=void 0!==r;o&&(r=Ls(r,n>2?arguments[2]:void 0));var s,a,l,h,u,c,d=zs(e),p=0;if(!d||this===Gs&&Fs(d))for(s=Ys(e),a=i?new this(s):Gs(s);s>p;p++)c=o?r(e[p],p):e[p],Hs(a,p,c);else for(u=(h=Bs(e,d)).next,a=i?new this:[];!(l=As(u,h)).done;p++)c=o?Rs(h,r,[l.value,p],!0):l.value,Hs(a,p,c);return a.length=p,a}});var $s=ue.Array.from,Ks=n($s),Zs=Ui,Js=ro,Qs=Di;$t.f;var ta=Io,ea=Lo,ia="Array Iterator",na=Qs.set,ra=Qs.getterFor(ia);ta(Array,"Array",(function(t,e){na(this,{type:ia,target:Zs(t),index:0,kind:e})}),(function(){var t=ra(this),e=t.target,i=t.kind,n=t.index++;if(!e||n>=e.length)return t.target=void 0,ea(void 0,!0);switch(i){case"keys":return ea(n,!1);case"values":return ea(e[n],!1)}return ea([n,e[n]],!1)}),"values"),Js.Arguments=Js.Array;var oa=Ds,sa=_,aa=Ot,la=ai,ha=ro,ua=dt("toStringTag");for(var ca in{CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0}){var da=sa[ca],pa=da&&da.prototype;pa&&aa(pa)!==ua&&la(pa,ua,ca),ha[ca]=ha.Array}var fa=oa,ma=n(fa),va=n(fa);function ga(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}var ya={exports:{}},ba=Tn,_a=qt,wa=$t.f;ba({target:"Object",stat:!0,forced:Object.defineProperty!==wa,sham:!_a},{defineProperty:wa});var ka=ue.Object,xa=ya.exports=function(t,e,i){return ka.defineProperty(t,e,i)};ka.defineProperty.sham&&(xa.sham=!0);var Sa=ya.exports,Da=Sa,Ca=n(Da),Ta=kt,Ma=Array.isArray||function(t){return"Array"===Ta(t)},Oa=TypeError,Pa=function(t){if(t>9007199254740991)throw Oa("Maximum allowed index exceeded");return t},Ea=Ma,Ia=ms,La=Xt,Aa=dt("species"),Na=Array,Ra=function(t,e){return new(function(t){var e;return Ea(t)&&(e=t.constructor,(Ia(e)&&(e===Na||Ea(e.prototype))||La(e)&&null===(e=e[Aa]))&&(e=void 0)),void 0===e?Na:e}(t))(0===e?0:e)},Fa=l,ja=J,Ya=dt("species"),Ha=function(t){return ja>=51||!Fa((function(){var e=[];return(e.constructor={})[Ya]=function(){return{foo:1}},1!==e[t](Boolean).foo}))},Ba=Tn,za=l,Ga=Ma,Wa=Xt,Va=R,Ua=Bn,Xa=Pa,qa=bs,$a=Ra,Ka=Ha,Za=J,Ja=dt("isConcatSpreadable"),Qa=Za>=51||!za((function(){var t=[];return t[Ja]=!1,t.concat()[0]!==t})),tl=function(t){if(!Wa(t))return!1;var e=t[Ja];return void 0!==e?!!e:Ga(t)};Ba({target:"Array",proto:!0,arity:1,forced:!Qa||!Ka("concat")},{concat:function(t){var e,i,n,r,o,s=Va(this),a=$a(s,0),l=0;for(e=-1,n=arguments.length;e<n;e++)if(tl(o=-1===e?s:arguments[e]))for(r=Ua(o),Xa(l+r),i=0;i<r;i++,l++)i in o&&qa(a,l,o[i]);else Xa(l+1),qa(a,l++,o);return a.length=l,a}});var el={},il=Jn,nl=Qn.concat("length","prototype");el.f=Object.getOwnPropertyNames||function(t){return il(t,nl)};var rl={},ol=jn,sl=Bn,al=bs,ll=Array,hl=Math.max,ul=function(t,e,i){for(var n=sl(t),r=ol(e,n),o=ol(void 0===i?n:i,n),s=ll(hl(o-r,0)),a=0;r<o;r++,a++)al(s,a,t[r]);return s.length=a,s},cl=kt,dl=Ui,pl=el.f,fl=ul,ml="object"==typeof window&&window&&Object.getOwnPropertyNames?Object.getOwnPropertyNames(window):[];rl.f=function(t){return ml&&"Window"===cl(t)?function(t){try{return pl(t)}catch(t){return fl(ml)}}(t):pl(dl(t))};var vl={};vl.f=Object.getOwnPropertySymbols;var gl=$t,yl=function(t,e,i){return gl.f(t,e,i)},bl={},_l=dt;bl.f=_l;var wl=ue,kl=Y,xl=bl,Sl=$t.f,Dl=function(t){var e=wl.Symbol||(wl.Symbol={});kl(e,t)||Sl(e,t,{value:xl.f(t)})},Cl=he,Tl=me,Ml=dt,Ol=jr,Pl=function(){var t=Tl("Symbol"),e=t&&t.prototype,i=e&&e.valueOf,n=Ml("toPrimitive");e&&!e[n]&&Ol(e,n,(function(t){return Cl(i,this)}),{arity:1})},El=mn,Il=Gi,Ll=R,Al=Bn,Nl=Ra,Rl=f([].push),Fl=function(t){var e=1===t,i=2===t,n=3===t,r=4===t,o=6===t,s=7===t,a=5===t||o;return function(l,h,u,c){for(var d,p,f=Ll(l),m=Il(f),v=El(h,u),g=Al(m),y=0,b=c||Nl,_=e?b(l,g):i||s?b(l,0):void 0;g>y;y++)if((a||y in m)&&(p=v(d=m[y],y,f),t))if(e)_[y]=p;else if(p)switch(t){case 3:return!0;case 5:return d;case 6:return y;case 2:Rl(_,d)}else switch(t){case 4:return!1;case 7:Rl(_,d)}return o?-1:n||r?r:_}},jl={forEach:Fl(0),map:Fl(1),filter:Fl(2),some:Fl(3),every:Fl(4),find:Fl(5),findIndex:Fl(6),filterReject:Fl(7)},Yl=Tn,Hl=_,Bl=he,zl=f,Gl=qt,Wl=it,Vl=l,Ul=Y,Xl=ve,ql=se,$l=Ui,Kl=Ge,Zl=It,Jl=ri,Ql=Tr,th=ir,eh=el,ih=rl,nh=vl,rh=Ai,oh=$t,sh=An,ah=Ni,lh=jr,hh=yl,uh=O,ch=ci,dh=W,ph=dt,fh=bl,mh=Dl,vh=Pl,gh=no,yh=Di,bh=jl.forEach,_h=ui("hidden"),wh="Symbol",kh="prototype",xh=yh.set,Sh=yh.getterFor(wh),Dh=Object[kh],Ch=Hl.Symbol,Th=Ch&&Ch[kh],Mh=Hl.RangeError,Oh=Hl.TypeError,Ph=Hl.QObject,Eh=rh.f,Ih=oh.f,Lh=ih.f,Ah=ah.f,Nh=zl([].push),Rh=uh("symbols"),Fh=uh("op-symbols"),jh=uh("wks"),Yh=!Ph||!Ph[kh]||!Ph[kh].findChild,Hh=function(t,e,i){var n=Eh(Dh,e);n&&delete Dh[e],Ih(t,e,i),n&&t!==Dh&&Ih(Dh,e,n)},Bh=Gl&&Vl((function(){return 7!==Ql(Ih({},"a",{get:function(){return Ih(this,"a",{value:7}).a}})).a}))?Hh:Ih,zh=function(t,e){var i=Rh[t]=Ql(Th);return xh(i,{type:wh,tag:t,description:e}),Gl||(i.description=e),i},Gh=function(t,e,i){t===Dh&&Gh(Fh,e,i),ql(t);var n=Kl(e);return ql(i),Ul(Rh,n)?(i.enumerable?(Ul(t,_h)&&t[_h][n]&&(t[_h][n]=!1),i=Ql(i,{enumerable:Jl(0,!1)})):(Ul(t,_h)||Ih(t,_h,Jl(1,{})),t[_h][n]=!0),Bh(t,n,i)):Ih(t,n,i)},Wh=function(t,e){ql(t);var i=$l(e),n=th(i).concat(qh(i));return bh(n,(function(e){Gl&&!Bl(Vh,i,e)||Gh(t,e,i[e])})),t},Vh=function(t){var e=Kl(t),i=Bl(Ah,this,e);return!(this===Dh&&Ul(Rh,e)&&!Ul(Fh,e))&&(!(i||!Ul(this,e)||!Ul(Rh,e)||Ul(this,_h)&&this[_h][e])||i)},Uh=function(t,e){var i=$l(t),n=Kl(e);if(i!==Dh||!Ul(Rh,n)||Ul(Fh,n)){var r=Eh(i,n);return!r||!Ul(Rh,n)||Ul(i,_h)&&i[_h][n]||(r.enumerable=!0),r}},Xh=function(t){var e=Lh($l(t)),i=[];return bh(e,(function(t){Ul(Rh,t)||Ul(ch,t)||Nh(i,t)})),i},qh=function(t){var e=t===Dh,i=Lh(e?Fh:$l(t)),n=[];return bh(i,(function(t){!Ul(Rh,t)||e&&!Ul(Dh,t)||Nh(n,Rh[t])})),n};Wl||(Ch=function(){if(Xl(Th,this))throw new Oh("Symbol is not a constructor");var t=arguments.length&&void 0!==arguments[0]?Zl(arguments[0]):void 0,e=dh(t),i=function(t){this===Dh&&Bl(i,Fh,t),Ul(this,_h)&&Ul(this[_h],e)&&(this[_h][e]=!1);var n=Jl(1,t);try{Bh(this,e,n)}catch(t){if(!(t instanceof Mh))throw t;Hh(this,e,n)}};return Gl&&Yh&&Bh(Dh,e,{configurable:!0,set:i}),zh(e,t)},lh(Th=Ch[kh],"toString",(function(){return Sh(this).tag})),lh(Ch,"withoutSetter",(function(t){return zh(dh(t),t)})),ah.f=Vh,oh.f=Gh,sh.f=Wh,rh.f=Uh,eh.f=ih.f=Xh,nh.f=qh,fh.f=function(t){return zh(ph(t),t)},Gl&&hh(Th,"description",{configurable:!0,get:function(){return Sh(this).description}})),Yl({global:!0,constructor:!0,wrap:!0,forced:!Wl,sham:!Wl},{Symbol:Ch}),bh(th(jh),(function(t){mh(t)})),Yl({target:wh,stat:!0,forced:!Wl},{useSetter:function(){Yh=!0},useSimple:function(){Yh=!1}}),Yl({target:"Object",stat:!0,forced:!Wl,sham:!Gl},{create:function(t,e){return void 0===e?Ql(t):Wh(Ql(t),e)},defineProperty:Gh,defineProperties:Wh,getOwnPropertyDescriptor:Uh}),Yl({target:"Object",stat:!0,forced:!Wl},{getOwnPropertyNames:Xh}),vh(),gh(Ch,wh),ch[_h]=!0;var $h=it&&!!Symbol.for&&!!Symbol.keyFor,Kh=Tn,Zh=me,Jh=Y,Qh=It,tu=O,eu=$h,iu=tu("string-to-symbol-registry"),nu=tu("symbol-to-string-registry");Kh({target:"Symbol",stat:!0,forced:!eu},{for:function(t){var e=Qh(t);if(Jh(iu,e))return iu[e];var i=Zh("Symbol")(e);return iu[e]=i,nu[i]=e,i}});var ru=Tn,ou=Y,su=we,au=xe,lu=$h,hu=O("symbol-to-string-registry");ru({target:"Symbol",stat:!0,forced:!lu},{keyFor:function(t){if(!su(t))throw new TypeError(au(t)+" is not a symbol");if(ou(hu,t))return hu[t]}});var uu=f([].slice),cu=Ma,du=yt,pu=kt,fu=It,mu=f([].push),vu=Tn,gu=me,yu=Pi,bu=he,_u=f,wu=l,ku=yt,xu=we,Su=uu,Du=it,Cu=String,Tu=gu("JSON","stringify"),Mu=_u(/./.exec),Ou=_u("".charAt),Pu=_u("".charCodeAt),Eu=_u("".replace),Iu=_u(1..toString),Lu=/[\uD800-\uDFFF]/g,Au=/^[\uD800-\uDBFF]$/,Nu=/^[\uDC00-\uDFFF]$/,Ru=!Du||wu((function(){var t=gu("Symbol")("stringify detection");return"[null]"!==Tu([t])||"{}"!==Tu({a:t})||"{}"!==Tu(Object(t))})),Fu=wu((function(){return'"\\udf06\\ud834"'!==Tu("\udf06\ud834")||'"\\udead"'!==Tu("\udead")})),ju=function(t,e){var i=Su(arguments),n=function(t){if(du(t))return t;if(cu(t)){for(var e=t.length,i=[],n=0;n<e;n++){var r=t[n];"string"==typeof r?mu(i,r):"number"!=typeof r&&"Number"!==pu(r)&&"String"!==pu(r)||mu(i,fu(r))}var o=i.length,s=!0;return function(t,e){if(s)return s=!1,e;if(cu(this))return e;for(var n=0;n<o;n++)if(i[n]===t)return e}}}(e);if(ku(n)||void 0!==t&&!xu(t))return i[1]=function(t,e){if(ku(n)&&(e=bu(n,this,Cu(t),e)),!xu(e))return e},yu(Tu,null,i)},Yu=function(t,e,i){var n=Ou(i,e-1),r=Ou(i,e+1);return Mu(Au,t)&&!Mu(Nu,r)||Mu(Nu,t)&&!Mu(Au,n)?"\\u"+Iu(Pu(t,0),16):t};Tu&&vu({target:"JSON",stat:!0,arity:3,forced:Ru||Fu},{stringify:function(t,e,i){var n=Su(arguments),r=yu(Ru?ju:Tu,null,n);return Fu&&"string"==typeof r?Eu(r,Lu,Yu):r}});var Hu=vl,Bu=R;Tn({target:"Object",stat:!0,forced:!it||l((function(){Hu.f(1)}))},{getOwnPropertySymbols:function(t){var e=Hu.f;return e?e(Bu(t)):[]}}),Dl("asyncIterator"),Dl("hasInstance"),Dl("isConcatSpreadable"),Dl("iterator"),Dl("match"),Dl("matchAll"),Dl("replace"),Dl("search"),Dl("species"),Dl("split");var zu=Pl;Dl("toPrimitive"),zu();var Gu=me,Wu=no;Dl("toStringTag"),Wu(Gu("Symbol"),"Symbol"),Dl("unscopables"),no(_.JSON,"JSON",!0);var Vu=ue.Symbol,Uu=dt,Xu=$t.f,qu=Uu("metadata"),$u=Function.prototype;void 0===$u[qu]&&Xu($u,qu,{value:null}),Dl("asyncDispose"),Dl("dispose"),Dl("metadata");var Ku=Vu,Zu=f,Ju=me("Symbol"),Qu=Ju.keyFor,tc=Zu(Ju.prototype.valueOf),ec=Ju.isRegisteredSymbol||function(t){try{return void 0!==Qu(tc(t))}catch(t){return!1}};Tn({target:"Symbol",stat:!0},{isRegisteredSymbol:ec});for(var ic=O,nc=me,rc=f,oc=we,sc=dt,ac=nc("Symbol"),lc=ac.isWellKnownSymbol,hc=nc("Object","getOwnPropertyNames"),uc=rc(ac.prototype.valueOf),cc=ic("wks"),dc=0,pc=hc(ac),fc=pc.length;dc<fc;dc++)try{var mc=pc[dc];oc(ac[mc])&&sc(mc)}catch(t){}var vc=function(t){if(lc&&lc(t))return!0;try{for(var e=uc(t),i=0,n=hc(cc),r=n.length;i<r;i++)if(cc[n[i]]==e)return!0}catch(t){}return!1};Tn({target:"Symbol",stat:!0,forced:!0},{isWellKnownSymbol:vc}),Dl("matcher"),Dl("observable"),Tn({target:"Symbol",stat:!0,name:"isRegisteredSymbol"},{isRegistered:ec}),Tn({target:"Symbol",stat:!0,name:"isWellKnownSymbol",forced:!0},{isWellKnown:vc}),Dl("metadataKey"),Dl("patternMatch"),Dl("replaceAll");var gc=Ku,yc=n(gc),bc=bl.f("iterator"),_c=bc,wc=n(_c);function kc(t){return kc="function"==typeof yc&&"symbol"==typeof wc?function(t){return typeof t}:function(t){return t&&"function"==typeof yc&&t.constructor===yc&&t!==yc.prototype?"symbol":typeof t},kc(t)}var xc=n(bl.f("toPrimitive"));function Sc(t){var e=function(t,e){if("object"!==kc(t)||null===t)return t;var i=t[xc];if(void 0!==i){var n=i.call(t,"string");if("object"!==kc(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(t)}(t);return"symbol"===kc(e)?e:String(e)}function Dc(t,e){for(var i=0;i<e.length;i++){var n=e[i];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Ca(t,Sc(n.key),n)}}function Cc(t,e,i){return e&&Dc(t.prototype,e),i&&Dc(t,i),Ca(t,"prototype",{writable:!1}),t}Tn({target:"Array",stat:!0},{isArray:Ma});var Tc=ue.Array.isArray,Mc=n(Tc),Oc=qt,Pc=Ma,Ec=TypeError,Ic=Object.getOwnPropertyDescriptor,Lc=Oc&&!function(){if(void 0!==this)return!0;try{Object.defineProperty([],"length",{writable:!1}).length=1}catch(t){return t instanceof TypeError}}()?function(t,e){if(Pc(t)&&!Ic(t,"length").writable)throw new Ec("Cannot set read only .length");return t.length=e}:function(t,e){return t.length=e},Ac=R,Nc=Bn,Rc=Lc,Fc=Pa;Tn({target:"Array",proto:!0,arity:1,forced:l((function(){return 4294967297!==[].push.call({length:4294967296},1)}))||!function(){try{Object.defineProperty([],"length",{writable:!1}).push()}catch(t){return t instanceof TypeError}}()},{push:function(t){var e=Ac(this),i=Nc(e),n=arguments.length;Fc(i+n);for(var r=0;r<n;r++)e[i]=arguments[r],i++;return Rc(e,i),i}});var jc=ue,Yc=function(t){return jc[t+"Prototype"]},Hc=Yc("Array").push,Bc=ve,zc=Hc,Gc=Array.prototype,Wc=function(t){var e=t.push;return t===Gc||Bc(Gc,t)&&e===Gc.push?zc:e},Vc=n(Wc),Uc=Tn,Xc=Ma,qc=ms,$c=Xt,Kc=jn,Zc=Bn,Jc=Ui,Qc=bs,td=dt,ed=uu,id=Ha("slice"),nd=td("species"),rd=Array,od=Math.max;Uc({target:"Array",proto:!0,forced:!id},{slice:function(t,e){var i,n,r,o=Jc(this),s=Zc(o),a=Kc(t,s),l=Kc(void 0===e?s:e,s);if(Xc(o)&&(i=o.constructor,(qc(i)&&(i===rd||Xc(i.prototype))||$c(i)&&null===(i=i[nd]))&&(i=void 0),i===rd||void 0===i))return ed(o,a,l);for(n=new(void 0===i?rd:i)(od(l-a,0)),r=0;a<l;a++,r++)a in o&&Qc(n,r,o[a]);return n.length=r,n}});var sd=Yc("Array").slice,ad=ve,ld=sd,hd=Array.prototype,ud=function(t){var e=t.slice;return t===hd||ad(hd,t)&&e===hd.slice?ld:e},cd=ud,dd=n(cd),pd=n($s);function fd(t,e){(null==e||e>t.length)&&(e=t.length);for(var i=0,n=new Array(e);i<e;i++)n[i]=t[i];return n}function md(t,e){var i;if(t){if("string"==typeof t)return fd(t,e);var n=dd(i=Object.prototype.toString.call(t)).call(i,8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?pd(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?fd(t,e):void 0}}function vd(t,e){return function(t){if(Mc(t))return t}(t)||function(t,e){var i=null==t?null:void 0!==yc&&ma(t)||t["@@iterator"];if(null!=i){var n,r,o,s,a=[],l=!0,h=!1;try{if(o=(i=i.call(t)).next,0===e){if(Object(i)!==i)return;l=!1}else for(;!(l=(n=o.call(i)).done)&&(Vc(a).call(a,n.value),a.length!==e);l=!0);}catch(t){h=!0,r=t}finally{try{if(!l&&null!=i.return&&(s=i.return(),Object(s)!==s))return}finally{if(h)throw r}}return a}}(t,e)||md(t,e)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function gd(t){return function(t){if(Mc(t))return fd(t)}(t)||function(t){if(void 0!==yc&&null!=ma(t)||null!=t["@@iterator"])return pd(t)}(t)||md(t)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}var yd=n(Vu),bd=Yc("Array").concat,_d=ve,wd=bd,kd=Array.prototype,xd=n((function(t){var e=t.concat;return t===kd||_d(kd,t)&&e===kd.concat?wd:e})),Sd=n(ud),Dd=me,Cd=el,Td=vl,Md=se,Od=f([].concat),Pd=Dd("Reflect","ownKeys")||function(t){var e=Cd.f(Md(t)),i=Td.f;return i?Od(e,i(t)):e};Tn({target:"Reflect",stat:!0},{ownKeys:Pd});var Ed=n(ue.Reflect.ownKeys),Id=n(Tc),Ld=jl.map;Tn({target:"Array",proto:!0,forced:!Ha("map")},{map:function(t){return Ld(this,t,arguments.length>1?arguments[1]:void 0)}});var Ad=Yc("Array").map,Nd=ve,Rd=Ad,Fd=Array.prototype,jd=n((function(t){var e=t.map;return t===Fd||Nd(Fd,t)&&e===Fd.map?Rd:e})),Yd=R,Hd=ir;Tn({target:"Object",stat:!0,forced:l((function(){Hd(1)}))},{keys:function(t){return Hd(Yd(t))}});var Bd=n(ue.Object.keys),zd=Tn,Gd=Date,Wd=f(Gd.prototype.getTime);zd({target:"Date",stat:!0},{now:function(){return Wd(new Gd)}});var Vd=n(ue.Date.now),Ud=f,Xd=Te,qd=Xt,$d=Y,Kd=uu,Zd=h,Jd=Function,Qd=Ud([].concat),tp=Ud([].join),ep={},ip=Zd?Jd.bind:function(t){var e=Xd(this),i=e.prototype,n=Kd(arguments,1),r=function(){var i=Qd(n,Kd(arguments));return this instanceof r?function(t,e,i){if(!$d(ep,e)){for(var n=[],r=0;r<e;r++)n[r]="a["+r+"]";ep[e]=Jd("C,a","return new C("+tp(n,",")+")")}return ep[e](t,i)}(e,i.length,i):e.apply(t,i)};return qd(i)&&(r.prototype=i),r},np=ip;Tn({target:"Function",proto:!0,forced:Function.bind!==np},{bind:np});var rp=Yc("Function").bind,op=ve,sp=rp,ap=Function.prototype,lp=function(t){var e=t.bind;return t===ap||op(ap,t)&&e===ap.bind?sp:e},hp=n(lp),up=l,cp=function(t,e){var i=[][t];return!!i&&up((function(){i.call(null,e||function(){return 1},1)}))},dp=jl.forEach,pp=cp("forEach")?[].forEach:function(t){return dp(this,t,arguments.length>1?arguments[1]:void 0)};Tn({target:"Array",proto:!0,forced:[].forEach!==pp},{forEach:pp});var fp=Yc("Array").forEach,mp=Ot,vp=Y,gp=ve,yp=fp,bp=Array.prototype,_p={DOMTokenList:!0,NodeList:!0},wp=function(t){var e=t.forEach;return t===bp||gp(bp,t)&&e===bp.forEach||vp(_p,mp(t))?yp:e},kp=n(wp),xp=Tn,Sp=Ma,Dp=f([].reverse),Cp=[1,2];xp({target:"Array",proto:!0,forced:String(Cp)===String(Cp.reverse())},{reverse:function(){return Sp(this)&&(this.length=this.length),Dp(this)}});var Tp=Yc("Array").reverse,Mp=ve,Op=Tp,Pp=Array.prototype,Ep=function(t){var e=t.reverse;return t===Pp||Mp(Pp,t)&&e===Pp.reverse?Op:e},Ip=n(Ep),Lp=xe,Ap=TypeError,Np=function(t,e){if(!delete t[e])throw new Ap("Cannot delete property "+Lp(e)+" of "+Lp(t))},Rp=Tn,Fp=R,jp=jn,Yp=y,Hp=Bn,Bp=Lc,zp=Pa,Gp=Ra,Wp=bs,Vp=Np,Up=Ha("splice"),Xp=Math.max,qp=Math.min;Rp({target:"Array",proto:!0,forced:!Up},{splice:function(t,e){var i,n,r,o,s,a,l=Fp(this),h=Hp(l),u=jp(t,h),c=arguments.length;for(0===c?i=n=0:1===c?(i=0,n=h-u):(i=c-2,n=qp(Xp(Yp(e),0),h-u)),zp(h+i-n),r=Gp(l,n),o=0;o<n;o++)(s=u+o)in l&&Wp(r,o,l[s]);if(r.length=n,i<n){for(o=u;o<h-n;o++)a=o+i,(s=o+n)in l?l[a]=l[s]:Vp(l,a);for(o=h;o>h-n+i;o--)Vp(l,o-1)}else if(i>n)for(o=h-n;o>u;o--)a=o+i-1,(s=o+n-1)in l?l[a]=l[s]:Vp(l,a);for(o=0;o<i;o++)l[o+u]=arguments[o+2];return Bp(l,h-n+i),r}});var $p=Yc("Array").splice,Kp=ve,Zp=$p,Jp=Array.prototype,Qp=n((function(t){var e=t.splice;return t===Jp||Kp(Jp,t)&&e===Jp.splice?Zp:e})),tf=qt,ef=f,nf=he,rf=l,of=ir,sf=vl,af=Ni,lf=R,hf=Gi,uf=Object.assign,cf=Object.defineProperty,df=ef([].concat),pf=!uf||rf((function(){if(tf&&1!==uf({b:1},uf(cf({},"a",{enumerable:!0,get:function(){cf(this,"b",{value:3,enumerable:!1})}}),{b:2})).b)return!0;var t={},e={},i=Symbol("assign detection"),n="abcdefghijklmnopqrst";return t[i]=7,n.split("").forEach((function(t){e[t]=t})),7!==uf({},t)[i]||of(uf({},e)).join("")!==n}))?function(t,e){for(var i=lf(t),n=arguments.length,r=1,o=sf.f,s=af.f;n>r;)for(var a,l=hf(arguments[r++]),h=o?df(of(l),o(l)):of(l),u=h.length,c=0;u>c;)a=h[c++],tf&&!nf(s,l,a)||(i[a]=l[a]);return i}:uf,ff=pf;Tn({target:"Object",stat:!0,arity:2,forced:Object.assign!==ff},{assign:ff});var mf=n(ue.Object.assign),vf=Un.includes;Tn({target:"Array",proto:!0,forced:l((function(){return!Array(1).includes()}))},{includes:function(t){return vf(this,t,arguments.length>1?arguments[1]:void 0)}});var gf=Yc("Array").includes,yf=Xt,bf=kt,_f=dt("match"),wf=TypeError,kf=dt("match"),xf=Tn,Sf=function(t){if(function(t){var e;return yf(t)&&(void 0!==(e=t[_f])?!!e:"RegExp"===bf(t))}(t))throw new wf("The method doesn't accept regular expressions");return t},Df=L,Cf=It,Tf=f("".indexOf);xf({target:"String",proto:!0,forced:!function(t){var e=/./;try{"/./"[t](e)}catch(i){try{return e[kf]=!1,"/./"[t](e)}catch(t){}}return!1}("includes")},{includes:function(t){return!!~Tf(Cf(Df(this)),Cf(Sf(t)),arguments.length>1?arguments[1]:void 0)}});var Mf=Yc("String").includes,Of=ve,Pf=gf,Ef=Mf,If=Array.prototype,Lf=String.prototype,Af=n((function(t){var e=t.includes;return t===If||Of(If,t)&&e===If.includes?Pf:"string"==typeof t||t===Lf||Of(Lf,t)&&e===Lf.includes?Ef:e})),Nf=R,Rf=Rr,Ff=Mr;Tn({target:"Object",stat:!0,forced:l((function(){Rf(1)})),sham:!Ff},{getPrototypeOf:function(t){return Rf(Nf(t))}});var jf=ue.Object.getPrototypeOf,Yf=n(jf),Hf=jl.filter;Tn({target:"Array",proto:!0,forced:!Ha("filter")},{filter:function(t){return Hf(this,t,arguments.length>1?arguments[1]:void 0)}});var Bf=Yc("Array").filter,zf=ve,Gf=Bf,Wf=Array.prototype,Vf=n((function(t){var e=t.filter;return t===Wf||zf(Wf,t)&&e===Wf.filter?Gf:e})),Uf=qt,Xf=l,qf=f,$f=Rr,Kf=ir,Zf=Ui,Jf=qf(Ni.f),Qf=qf([].push),tm=Uf&&Xf((function(){var t=Object.create(null);return t[2]=2,!Jf(t,2)})),em=function(t){return function(e){for(var i,n=Zf(e),r=Kf(n),o=tm&&null===$f(n),s=r.length,a=0,l=[];s>a;)i=r[a++],Uf&&!(o?i in n:Jf(n,i))||Qf(l,t?[i,n[i]]:n[i]);return l}},im={entries:em(!0),values:em(!1)},nm=im.values;Tn({target:"Object",stat:!0},{values:function(t){return nm(t)}});var rm=n(ue.Object.values),om="\t\n\v\f\r                　\u2028\u2029\ufeff",sm=L,am=It,lm=om,hm=f("".replace),um=RegExp("^["+lm+"]+"),cm=RegExp("(^|[^"+lm+"])["+lm+"]+$"),dm=function(t){return function(e){var i=am(sm(e));return 1&t&&(i=hm(i,um,"")),2&t&&(i=hm(i,cm,"$1")),i}},pm={start:dm(1),end:dm(2),trim:dm(3)},fm=_,mm=l,vm=f,gm=It,ym=pm.trim,bm=om,_m=fm.parseInt,wm=fm.Symbol,km=wm&&wm.iterator,xm=/^[+-]?0x/i,Sm=vm(xm.exec),Dm=8!==_m(bm+"08")||22!==_m(bm+"0x16")||km&&!mm((function(){_m(Object(km))}))?function(t,e){var i=ym(gm(t));return _m(i,e>>>0||(Sm(xm,i)?16:10))}:_m;Tn({global:!0,forced:parseInt!==Dm},{parseInt:Dm});var Cm=n(ue.parseInt),Tm=Tn,Mm=Un.indexOf,Om=cp,Pm=Li([].indexOf),Em=!!Pm&&1/Pm([1],1,-0)<0;Tm({target:"Array",proto:!0,forced:Em||!Om("indexOf")},{indexOf:function(t){var e=arguments.length>1?arguments[1]:void 0;return Em?Pm(this,t,e)||0:Mm(this,t,e)}});var Im=Yc("Array").indexOf,Lm=ve,Am=Im,Nm=Array.prototype,Rm=n((function(t){var e=t.indexOf;return t===Nm||Lm(Nm,t)&&e===Nm.indexOf?Am:e})),Fm=im.entries;Tn({target:"Object",stat:!0},{entries:function(t){return Fm(t)}});var jm=n(ue.Object.entries);Tn({target:"Object",stat:!0,sham:!qt},{create:Tr});var Ym=ue.Object,Hm=function(t,e){return Ym.create(t,e)},Bm=n(Hm),zm=ue,Gm=Pi;zm.JSON||(zm.JSON={stringify:JSON.stringify});var Wm=n((function(t,e,i){return Gm(zm.JSON.stringify,null,arguments)})),Vm="function"==typeof Bun&&Bun&&"string"==typeof Bun.version,Um=TypeError,Xm=function(t,e){if(t<e)throw new Um("Not enough arguments");return t},qm=_,$m=Pi,Km=yt,Zm=Vm,Jm=V,Qm=uu,tv=Xm,ev=qm.Function,iv=/MSIE .\./.test(Jm)||Zm&&function(){var t=qm.Bun.version.split(".");return t.length<3||"0"===t[0]&&(t[1]<3||"3"===t[1]&&"0"===t[2])}(),nv=function(t,e){var i=e?2:1;return iv?function(n,r){var o=tv(arguments.length,1)>i,s=Km(n)?n:ev(n),a=o?Qm(arguments,i):[],l=o?function(){$m(s,this,a)}:s;return e?t(l,r):t(l)}:t},rv=Tn,ov=_,sv=nv(ov.setInterval,!0);rv({global:!0,bind:!0,forced:ov.setInterval!==sv},{setInterval:sv});var av=Tn,lv=_,hv=nv(lv.setTimeout,!0);av({global:!0,bind:!0,forced:lv.setTimeout!==hv},{setTimeout:hv});var uv=n(ue.setTimeout),cv=R,dv=jn,pv=Bn;Tn({target:"Array",proto:!0},{fill:function(t){for(var e=cv(this),i=pv(e),n=arguments.length,r=dv(n>1?arguments[1]:void 0,i),o=n>2?arguments[2]:void 0,s=void 0===o?i:dv(o,i);s>r;)e[r++]=t;return e}});var fv=Yc("Array").fill,mv=ve,vv=fv,gv=Array.prototype,yv=n((function(t){var e=t.fill;return t===gv||mv(gv,t)&&e===gv.fill?vv:e})),bv={exports:{}};!function(t){function e(t){if(t)return function(t){for(var i in e.prototype)t[i]=e.prototype[i];return t}(t)}t.exports=e,e.prototype.on=e.prototype.addEventListener=function(t,e){return this._callbacks=this._callbacks||{},(this._callbacks["$"+t]=this._callbacks["$"+t]||[]).push(e),this},e.prototype.once=function(t,e){function i(){this.off(t,i),e.apply(this,arguments)}return i.fn=e,this.on(t,i),this},e.prototype.off=e.prototype.removeListener=e.prototype.removeAllListeners=e.prototype.removeEventListener=function(t,e){if(this._callbacks=this._callbacks||{},0==arguments.length)return this._callbacks={},this;var i,n=this._callbacks["$"+t];if(!n)return this;if(1==arguments.length)return delete this._callbacks["$"+t],this;for(var r=0;r<n.length;r++)if((i=n[r])===e||i.fn===e){n.splice(r,1);break}return 0===n.length&&delete this._callbacks["$"+t],this},e.prototype.emit=function(t){this._callbacks=this._callbacks||{};for(var e=new Array(arguments.length-1),i=this._callbacks["$"+t],n=1;n<arguments.length;n++)e[n-1]=arguments[n];if(i){n=0;for(var r=(i=i.slice(0)).length;n<r;++n)i[n].apply(this,e)}return this},e.prototype.listeners=function(t){return this._callbacks=this._callbacks||{},this._callbacks["$"+t]||[]},e.prototype.hasListeners=function(t){return!!this.listeners(t).length}}(bv);var _v,wv=n(bv.exports);
/*! Hammer.JS - v2.0.17-rc - 2019-12-16
	 * http://naver.github.io/egjs
	 *
	 * Forked By Naver egjs
	 * Copyright (c) hammerjs
	 * Licensed under the MIT license */function kv(){return kv=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var i=arguments[e];for(var n in i)Object.prototype.hasOwnProperty.call(i,n)&&(t[n]=i[n])}return t},kv.apply(this,arguments)}function xv(t,e){t.prototype=Object.create(e.prototype),t.prototype.constructor=t,t.__proto__=e}function Sv(t){if(void 0===t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return t}_v="function"!=typeof Object.assign?function(t){if(null==t)throw new TypeError("Cannot convert undefined or null to object");for(var e=Object(t),i=1;i<arguments.length;i++){var n=arguments[i];if(null!=n)for(var r in n)n.hasOwnProperty(r)&&(e[r]=n[r])}return e}:Object.assign;var Dv,Cv=_v,Tv=["","webkit","Moz","MS","ms","o"],Mv="undefined"==typeof document?{style:{}}:document.createElement("div"),Ov=Math.round,Pv=Math.abs,Ev=Date.now;function Iv(t,e){for(var i,n,r=e[0].toUpperCase()+e.slice(1),o=0;o<Tv.length;){if((n=(i=Tv[o])?i+r:e)in t)return n;o++}}Dv="undefined"==typeof window?{}:window;var Lv=Iv(Mv.style,"touchAction"),Av=void 0!==Lv,Nv="compute",Rv="auto",Fv="manipulation",jv="none",Yv="pan-x",Hv="pan-y",Bv=function(){if(!Av)return!1;var t={},e=Dv.CSS&&Dv.CSS.supports;return["auto","manipulation","pan-y","pan-x","pan-x pan-y","none"].forEach((function(i){return t[i]=!e||Dv.CSS.supports("touch-action",i)})),t}(),zv="ontouchstart"in Dv,Gv=void 0!==Iv(Dv,"PointerEvent"),Wv=zv&&/mobile|tablet|ip(ad|hone|od)|android/i.test(navigator.userAgent),Vv="touch",Uv="mouse",Xv=25,qv=1,$v=4,Kv=8,Zv=1,Jv=2,Qv=4,tg=8,eg=16,ig=Jv|Qv,ng=tg|eg,rg=ig|ng,og=["x","y"],sg=["clientX","clientY"];function ag(t,e,i){var n;if(t)if(t.forEach)t.forEach(e,i);else if(void 0!==t.length)for(n=0;n<t.length;)e.call(i,t[n],n,t),n++;else for(n in t)t.hasOwnProperty(n)&&e.call(i,t[n],n,t)}function lg(t,e){return"function"==typeof t?t.apply(e&&e[0]||void 0,e):t}function hg(t,e){return t.indexOf(e)>-1}var ug=function(){function t(t,e){this.manager=t,this.set(e)}var e=t.prototype;return e.set=function(t){t===Nv&&(t=this.compute()),Av&&this.manager.element.style&&Bv[t]&&(this.manager.element.style[Lv]=t),this.actions=t.toLowerCase().trim()},e.update=function(){this.set(this.manager.options.touchAction)},e.compute=function(){var t=[];return ag(this.manager.recognizers,(function(e){lg(e.options.enable,[e])&&(t=t.concat(e.getTouchAction()))})),function(t){if(hg(t,jv))return jv;var e=hg(t,Yv),i=hg(t,Hv);return e&&i?jv:e||i?e?Yv:Hv:hg(t,Fv)?Fv:Rv}(t.join(" "))},e.preventDefaults=function(t){var e=t.srcEvent,i=t.offsetDirection;if(this.manager.session.prevented)e.preventDefault();else{var n=this.actions,r=hg(n,jv)&&!Bv[jv],o=hg(n,Hv)&&!Bv[Hv],s=hg(n,Yv)&&!Bv[Yv];if(r){var a=1===t.pointers.length,l=t.distance<2,h=t.deltaTime<250;if(a&&l&&h)return}if(!s||!o)return r||o&&i&ig||s&&i&ng?this.preventSrc(e):void 0}},e.preventSrc=function(t){this.manager.session.prevented=!0,t.preventDefault()},t}();function cg(t,e){for(;t;){if(t===e)return!0;t=t.parentNode}return!1}function dg(t){var e=t.length;if(1===e)return{x:Ov(t[0].clientX),y:Ov(t[0].clientY)};for(var i=0,n=0,r=0;r<e;)i+=t[r].clientX,n+=t[r].clientY,r++;return{x:Ov(i/e),y:Ov(n/e)}}function pg(t){for(var e=[],i=0;i<t.pointers.length;)e[i]={clientX:Ov(t.pointers[i].clientX),clientY:Ov(t.pointers[i].clientY)},i++;return{timeStamp:Ev(),pointers:e,center:dg(e),deltaX:t.deltaX,deltaY:t.deltaY}}function fg(t,e,i){i||(i=og);var n=e[i[0]]-t[i[0]],r=e[i[1]]-t[i[1]];return Math.sqrt(n*n+r*r)}function mg(t,e,i){i||(i=og);var n=e[i[0]]-t[i[0]],r=e[i[1]]-t[i[1]];return 180*Math.atan2(r,n)/Math.PI}function vg(t,e){return t===e?Zv:Pv(t)>=Pv(e)?t<0?Jv:Qv:e<0?tg:eg}function gg(t,e,i){return{x:e/t||0,y:i/t||0}}function yg(t,e,i){var n=i.pointers.length,r=i.changedPointers.length,o=e&qv&&n-r==0,s=e&($v|Kv)&&n-r==0;i.isFirst=!!o,i.isFinal=!!s,o&&(t.session={}),i.eventType=e,function(t,e){var i=t.session,n=e.pointers,r=n.length;i.firstInput||(i.firstInput=pg(e)),r>1&&!i.firstMultiple?i.firstMultiple=pg(e):1===r&&(i.firstMultiple=!1);var o=i.firstInput,s=i.firstMultiple,a=s?s.center:o.center,l=e.center=dg(n);e.timeStamp=Ev(),e.deltaTime=e.timeStamp-o.timeStamp,e.angle=mg(a,l),e.distance=fg(a,l),function(t,e){var i=e.center,n=t.offsetDelta||{},r=t.prevDelta||{},o=t.prevInput||{};e.eventType!==qv&&o.eventType!==$v||(r=t.prevDelta={x:o.deltaX||0,y:o.deltaY||0},n=t.offsetDelta={x:i.x,y:i.y}),e.deltaX=r.x+(i.x-n.x),e.deltaY=r.y+(i.y-n.y)}(i,e),e.offsetDirection=vg(e.deltaX,e.deltaY);var h,u,c=gg(e.deltaTime,e.deltaX,e.deltaY);e.overallVelocityX=c.x,e.overallVelocityY=c.y,e.overallVelocity=Pv(c.x)>Pv(c.y)?c.x:c.y,e.scale=s?(h=s.pointers,fg((u=n)[0],u[1],sg)/fg(h[0],h[1],sg)):1,e.rotation=s?function(t,e){return mg(e[1],e[0],sg)+mg(t[1],t[0],sg)}(s.pointers,n):0,e.maxPointers=i.prevInput?e.pointers.length>i.prevInput.maxPointers?e.pointers.length:i.prevInput.maxPointers:e.pointers.length,function(t,e){var i,n,r,o,s=t.lastInterval||e,a=e.timeStamp-s.timeStamp;if(e.eventType!==Kv&&(a>Xv||void 0===s.velocity)){var l=e.deltaX-s.deltaX,h=e.deltaY-s.deltaY,u=gg(a,l,h);n=u.x,r=u.y,i=Pv(u.x)>Pv(u.y)?u.x:u.y,o=vg(l,h),t.lastInterval=e}else i=s.velocity,n=s.velocityX,r=s.velocityY,o=s.direction;e.velocity=i,e.velocityX=n,e.velocityY=r,e.direction=o}(i,e);var d,p=t.element,f=e.srcEvent;cg(d=f.composedPath?f.composedPath()[0]:f.path?f.path[0]:f.target,p)&&(p=d),e.target=p}(t,i),t.emit("hammer.input",i),t.recognize(i),t.session.prevInput=i}function bg(t){return t.trim().split(/\s+/g)}function _g(t,e,i){ag(bg(e),(function(e){t.addEventListener(e,i,!1)}))}function wg(t,e,i){ag(bg(e),(function(e){t.removeEventListener(e,i,!1)}))}function kg(t){var e=t.ownerDocument||t;return e.defaultView||e.parentWindow||window}var xg=function(){function t(t,e){var i=this;this.manager=t,this.callback=e,this.element=t.element,this.target=t.options.inputTarget,this.domHandler=function(e){lg(t.options.enable,[t])&&i.handler(e)},this.init()}var e=t.prototype;return e.handler=function(){},e.init=function(){this.evEl&&_g(this.element,this.evEl,this.domHandler),this.evTarget&&_g(this.target,this.evTarget,this.domHandler),this.evWin&&_g(kg(this.element),this.evWin,this.domHandler)},e.destroy=function(){this.evEl&&wg(this.element,this.evEl,this.domHandler),this.evTarget&&wg(this.target,this.evTarget,this.domHandler),this.evWin&&wg(kg(this.element),this.evWin,this.domHandler)},t}();function Sg(t,e,i){if(t.indexOf&&!i)return t.indexOf(e);for(var n=0;n<t.length;){if(i&&t[n][i]==e||!i&&t[n]===e)return n;n++}return-1}var Dg={pointerdown:qv,pointermove:2,pointerup:$v,pointercancel:Kv,pointerout:Kv},Cg={2:Vv,3:"pen",4:Uv,5:"kinect"},Tg="pointerdown",Mg="pointermove pointerup pointercancel";Dv.MSPointerEvent&&!Dv.PointerEvent&&(Tg="MSPointerDown",Mg="MSPointerMove MSPointerUp MSPointerCancel");var Og=function(t){function e(){var i,n=e.prototype;return n.evEl=Tg,n.evWin=Mg,(i=t.apply(this,arguments)||this).store=i.manager.session.pointerEvents=[],i}return xv(e,t),e.prototype.handler=function(t){var e=this.store,i=!1,n=t.type.toLowerCase().replace("ms",""),r=Dg[n],o=Cg[t.pointerType]||t.pointerType,s=o===Vv,a=Sg(e,t.pointerId,"pointerId");r&qv&&(0===t.button||s)?a<0&&(e.push(t),a=e.length-1):r&($v|Kv)&&(i=!0),a<0||(e[a]=t,this.callback(this.manager,r,{pointers:e,changedPointers:[t],pointerType:o,srcEvent:t}),i&&e.splice(a,1))},e}(xg);function Pg(t){return Array.prototype.slice.call(t,0)}function Eg(t,e,i){for(var n=[],r=[],o=0;o<t.length;){var s=e?t[o][e]:t[o];Sg(r,s)<0&&n.push(t[o]),r[o]=s,o++}return i&&(n=e?n.sort((function(t,i){return t[e]>i[e]})):n.sort()),n}var Ig={touchstart:qv,touchmove:2,touchend:$v,touchcancel:Kv},Lg=function(t){function e(){var i;return e.prototype.evTarget="touchstart touchmove touchend touchcancel",(i=t.apply(this,arguments)||this).targetIds={},i}return xv(e,t),e.prototype.handler=function(t){var e=Ig[t.type],i=Ag.call(this,t,e);i&&this.callback(this.manager,e,{pointers:i[0],changedPointers:i[1],pointerType:Vv,srcEvent:t})},e}(xg);function Ag(t,e){var i,n,r=Pg(t.touches),o=this.targetIds;if(e&(2|qv)&&1===r.length)return o[r[0].identifier]=!0,[r,r];var s=Pg(t.changedTouches),a=[],l=this.target;if(n=r.filter((function(t){return cg(t.target,l)})),e===qv)for(i=0;i<n.length;)o[n[i].identifier]=!0,i++;for(i=0;i<s.length;)o[s[i].identifier]&&a.push(s[i]),e&($v|Kv)&&delete o[s[i].identifier],i++;return a.length?[Eg(n.concat(a),"identifier",!0),a]:void 0}var Ng={mousedown:qv,mousemove:2,mouseup:$v},Rg=function(t){function e(){var i,n=e.prototype;return n.evEl="mousedown",n.evWin="mousemove mouseup",(i=t.apply(this,arguments)||this).pressed=!1,i}return xv(e,t),e.prototype.handler=function(t){var e=Ng[t.type];e&qv&&0===t.button&&(this.pressed=!0),2&e&&1!==t.which&&(e=$v),this.pressed&&(e&$v&&(this.pressed=!1),this.callback(this.manager,e,{pointers:[t],changedPointers:[t],pointerType:Uv,srcEvent:t}))},e}(xg),Fg=2500;function jg(t){var e=t.changedPointers[0];if(e.identifier===this.primaryTouch){var i={x:e.clientX,y:e.clientY},n=this.lastTouches;this.lastTouches.push(i),setTimeout((function(){var t=n.indexOf(i);t>-1&&n.splice(t,1)}),Fg)}}function Yg(t,e){t&qv?(this.primaryTouch=e.changedPointers[0].identifier,jg.call(this,e)):t&($v|Kv)&&jg.call(this,e)}function Hg(t){for(var e=t.srcEvent.clientX,i=t.srcEvent.clientY,n=0;n<this.lastTouches.length;n++){var r=this.lastTouches[n],o=Math.abs(e-r.x),s=Math.abs(i-r.y);if(o<=25&&s<=25)return!0}return!1}var Bg=function(t){function e(e,i){var n;return(n=t.call(this,e,i)||this).handler=function(t,e,i){var r=i.pointerType===Vv,o=i.pointerType===Uv;if(!(o&&i.sourceCapabilities&&i.sourceCapabilities.firesTouchEvents)){if(r)Yg.call(Sv(Sv(n)),e,i);else if(o&&Hg.call(Sv(Sv(n)),i))return;n.callback(t,e,i)}},n.touch=new Lg(n.manager,n.handler),n.mouse=new Rg(n.manager,n.handler),n.primaryTouch=null,n.lastTouches=[],n}return xv(e,t),e.prototype.destroy=function(){this.touch.destroy(),this.mouse.destroy()},e}(xg);function zg(t,e,i){return!!Array.isArray(t)&&(ag(t,i[e],i),!0)}var Gg=32,Wg=1;function Vg(t,e){var i=e.manager;return i?i.get(t):t}function Ug(t){return 16&t?"cancel":8&t?"end":4&t?"move":2&t?"start":""}var Xg=function(){function t(t){void 0===t&&(t={}),this.options=kv({enable:!0},t),this.id=Wg++,this.manager=null,this.state=1,this.simultaneous={},this.requireFail=[]}var e=t.prototype;return e.set=function(t){return Cv(this.options,t),this.manager&&this.manager.touchAction.update(),this},e.recognizeWith=function(t){if(zg(t,"recognizeWith",this))return this;var e=this.simultaneous;return e[(t=Vg(t,this)).id]||(e[t.id]=t,t.recognizeWith(this)),this},e.dropRecognizeWith=function(t){return zg(t,"dropRecognizeWith",this)||(t=Vg(t,this),delete this.simultaneous[t.id]),this},e.requireFailure=function(t){if(zg(t,"requireFailure",this))return this;var e=this.requireFail;return-1===Sg(e,t=Vg(t,this))&&(e.push(t),t.requireFailure(this)),this},e.dropRequireFailure=function(t){if(zg(t,"dropRequireFailure",this))return this;t=Vg(t,this);var e=Sg(this.requireFail,t);return e>-1&&this.requireFail.splice(e,1),this},e.hasRequireFailures=function(){return this.requireFail.length>0},e.canRecognizeWith=function(t){return!!this.simultaneous[t.id]},e.emit=function(t){var e=this,i=this.state;function n(i){e.manager.emit(i,t)}i<8&&n(e.options.event+Ug(i)),n(e.options.event),t.additionalEvent&&n(t.additionalEvent),i>=8&&n(e.options.event+Ug(i))},e.tryEmit=function(t){if(this.canEmit())return this.emit(t);this.state=Gg},e.canEmit=function(){for(var t=0;t<this.requireFail.length;){if(!(33&this.requireFail[t].state))return!1;t++}return!0},e.recognize=function(t){var e=Cv({},t);if(!lg(this.options.enable,[this,e]))return this.reset(),void(this.state=Gg);56&this.state&&(this.state=1),this.state=this.process(e),30&this.state&&this.tryEmit(e)},e.process=function(t){},e.getTouchAction=function(){},e.reset=function(){},t}(),qg=function(t){function e(e){var i;return void 0===e&&(e={}),(i=t.call(this,kv({event:"tap",pointers:1,taps:1,interval:300,time:250,threshold:9,posThreshold:10},e))||this).pTime=!1,i.pCenter=!1,i._timer=null,i._input=null,i.count=0,i}xv(e,t);var i=e.prototype;return i.getTouchAction=function(){return[Fv]},i.process=function(t){var e=this,i=this.options,n=t.pointers.length===i.pointers,r=t.distance<i.threshold,o=t.deltaTime<i.time;if(this.reset(),t.eventType&qv&&0===this.count)return this.failTimeout();if(r&&o&&n){if(t.eventType!==$v)return this.failTimeout();var s=!this.pTime||t.timeStamp-this.pTime<i.interval,a=!this.pCenter||fg(this.pCenter,t.center)<i.posThreshold;if(this.pTime=t.timeStamp,this.pCenter=t.center,a&&s?this.count+=1:this.count=1,this._input=t,0==this.count%i.taps)return this.hasRequireFailures()?(this._timer=setTimeout((function(){e.state=8,e.tryEmit()}),i.interval),2):8}return Gg},i.failTimeout=function(){var t=this;return this._timer=setTimeout((function(){t.state=Gg}),this.options.interval),Gg},i.reset=function(){clearTimeout(this._timer)},i.emit=function(){8===this.state&&(this._input.tapCount=this.count,this.manager.emit(this.options.event,this._input))},e}(Xg),$g=function(t){function e(e){return void 0===e&&(e={}),t.call(this,kv({pointers:1},e))||this}xv(e,t);var i=e.prototype;return i.attrTest=function(t){var e=this.options.pointers;return 0===e||t.pointers.length===e},i.process=function(t){var e=this.state,i=t.eventType,n=6&e,r=this.attrTest(t);return n&&(i&Kv||!r)?16|e:n||r?i&$v?8|e:2&e?4|e:2:Gg},e}(Xg);function Kg(t){return t===eg?"down":t===tg?"up":t===Jv?"left":t===Qv?"right":""}var Zg=function(t){function e(e){var i;return void 0===e&&(e={}),(i=t.call(this,kv({event:"pan",threshold:10,pointers:1,direction:rg},e))||this).pX=null,i.pY=null,i}xv(e,t);var i=e.prototype;return i.getTouchAction=function(){var t=this.options.direction,e=[];return t&ig&&e.push(Hv),t&ng&&e.push(Yv),e},i.directionTest=function(t){var e=this.options,i=!0,n=t.distance,r=t.direction,o=t.deltaX,s=t.deltaY;return r&e.direction||(e.direction&ig?(r=0===o?Zv:o<0?Jv:Qv,i=o!==this.pX,n=Math.abs(t.deltaX)):(r=0===s?Zv:s<0?tg:eg,i=s!==this.pY,n=Math.abs(t.deltaY))),t.direction=r,i&&n>e.threshold&&r&e.direction},i.attrTest=function(t){return $g.prototype.attrTest.call(this,t)&&(2&this.state||!(2&this.state)&&this.directionTest(t))},i.emit=function(e){this.pX=e.deltaX,this.pY=e.deltaY;var i=Kg(e.direction);i&&(e.additionalEvent=this.options.event+i),t.prototype.emit.call(this,e)},e}($g),Jg=function(t){function e(e){return void 0===e&&(e={}),t.call(this,kv({event:"swipe",threshold:10,velocity:.3,direction:ig|ng,pointers:1},e))||this}xv(e,t);var i=e.prototype;return i.getTouchAction=function(){return Zg.prototype.getTouchAction.call(this)},i.attrTest=function(e){var i,n=this.options.direction;return n&(ig|ng)?i=e.overallVelocity:n&ig?i=e.overallVelocityX:n&ng&&(i=e.overallVelocityY),t.prototype.attrTest.call(this,e)&&n&e.offsetDirection&&e.distance>this.options.threshold&&e.maxPointers===this.options.pointers&&Pv(i)>this.options.velocity&&e.eventType&$v},i.emit=function(t){var e=Kg(t.offsetDirection);e&&this.manager.emit(this.options.event+e,t),this.manager.emit(this.options.event,t)},e}($g),Qg=function(t){function e(e){return void 0===e&&(e={}),t.call(this,kv({event:"pinch",threshold:0,pointers:2},e))||this}xv(e,t);var i=e.prototype;return i.getTouchAction=function(){return[jv]},i.attrTest=function(e){return t.prototype.attrTest.call(this,e)&&(Math.abs(e.scale-1)>this.options.threshold||2&this.state)},i.emit=function(e){if(1!==e.scale){var i=e.scale<1?"in":"out";e.additionalEvent=this.options.event+i}t.prototype.emit.call(this,e)},e}($g),ty=function(t){function e(e){return void 0===e&&(e={}),t.call(this,kv({event:"rotate",threshold:0,pointers:2},e))||this}xv(e,t);var i=e.prototype;return i.getTouchAction=function(){return[jv]},i.attrTest=function(e){return t.prototype.attrTest.call(this,e)&&(Math.abs(e.rotation)>this.options.threshold||2&this.state)},e}($g),ey=function(t){function e(e){var i;return void 0===e&&(e={}),(i=t.call(this,kv({event:"press",pointers:1,time:251,threshold:9},e))||this)._timer=null,i._input=null,i}xv(e,t);var i=e.prototype;return i.getTouchAction=function(){return[Rv]},i.process=function(t){var e=this,i=this.options,n=t.pointers.length===i.pointers,r=t.distance<i.threshold,o=t.deltaTime>i.time;if(this._input=t,!r||!n||t.eventType&($v|Kv)&&!o)this.reset();else if(t.eventType&qv)this.reset(),this._timer=setTimeout((function(){e.state=8,e.tryEmit()}),i.time);else if(t.eventType&$v)return 8;return Gg},i.reset=function(){clearTimeout(this._timer)},i.emit=function(t){8===this.state&&(t&&t.eventType&$v?this.manager.emit(this.options.event+"up",t):(this._input.timeStamp=Ev(),this.manager.emit(this.options.event,this._input)))},e}(Xg),iy={domEvents:!1,touchAction:Nv,enable:!0,inputTarget:null,inputClass:null,cssProps:{userSelect:"none",touchSelect:"none",touchCallout:"none",contentZooming:"none",userDrag:"none",tapHighlightColor:"rgba(0,0,0,0)"}},ny=[[ty,{enable:!1}],[Qg,{enable:!1},["rotate"]],[Jg,{direction:ig}],[Zg,{direction:ig},["swipe"]],[qg],[qg,{event:"doubletap",taps:2},["tap"]],[ey]];function ry(t,e){var i,n=t.element;n.style&&(ag(t.options.cssProps,(function(r,o){i=Iv(n.style,o),e?(t.oldCssProps[i]=n.style[i],n.style[i]=r):n.style[i]=t.oldCssProps[i]||""})),e||(t.oldCssProps={}))}var oy=function(){function t(t,e){var i=this;this.options=Cv({},iy,e||{}),this.options.inputTarget=this.options.inputTarget||t,this.handlers={},this.session={},this.recognizers=[],this.oldCssProps={},this.element=t,this.input=new(this.options.inputClass||(Gv?Og:Wv?Lg:zv?Bg:Rg))(this,yg),this.touchAction=new ug(this,this.options.touchAction),ry(this,!0),ag(this.options.recognizers,(function(t){var e=i.add(new t[0](t[1]));t[2]&&e.recognizeWith(t[2]),t[3]&&e.requireFailure(t[3])}),this)}var e=t.prototype;return e.set=function(t){return Cv(this.options,t),t.touchAction&&this.touchAction.update(),t.inputTarget&&(this.input.destroy(),this.input.target=t.inputTarget,this.input.init()),this},e.stop=function(t){this.session.stopped=t?2:1},e.recognize=function(t){var e=this.session;if(!e.stopped){var i;this.touchAction.preventDefaults(t);var n=this.recognizers,r=e.curRecognizer;(!r||r&&8&r.state)&&(e.curRecognizer=null,r=null);for(var o=0;o<n.length;)i=n[o],2===e.stopped||r&&i!==r&&!i.canRecognizeWith(r)?i.reset():i.recognize(t),!r&&14&i.state&&(e.curRecognizer=i,r=i),o++}},e.get=function(t){if(t instanceof Xg)return t;for(var e=this.recognizers,i=0;i<e.length;i++)if(e[i].options.event===t)return e[i];return null},e.add=function(t){if(zg(t,"add",this))return this;var e=this.get(t.options.event);return e&&this.remove(e),this.recognizers.push(t),t.manager=this,this.touchAction.update(),t},e.remove=function(t){if(zg(t,"remove",this))return this;var e=this.get(t);if(t){var i=this.recognizers,n=Sg(i,e);-1!==n&&(i.splice(n,1),this.touchAction.update())}return this},e.on=function(t,e){if(void 0===t||void 0===e)return this;var i=this.handlers;return ag(bg(t),(function(t){i[t]=i[t]||[],i[t].push(e)})),this},e.off=function(t,e){if(void 0===t)return this;var i=this.handlers;return ag(bg(t),(function(t){e?i[t]&&i[t].splice(Sg(i[t],e),1):delete i[t]})),this},e.emit=function(t,e){this.options.domEvents&&function(t,e){var i=document.createEvent("Event");i.initEvent(t,!0,!0),i.gesture=e,e.target.dispatchEvent(i)}(t,e);var i=this.handlers[t]&&this.handlers[t].slice();if(i&&i.length){e.type=t,e.preventDefault=function(){e.srcEvent.preventDefault()};for(var n=0;n<i.length;)i[n](e),n++}},e.destroy=function(){this.element&&ry(this,!1),this.handlers={},this.session={},this.input.destroy(),this.element=null},t}(),sy={touchstart:qv,touchmove:2,touchend:$v,touchcancel:Kv},ay=function(t){function e(){var i,n=e.prototype;return n.evTarget="touchstart",n.evWin="touchstart touchmove touchend touchcancel",(i=t.apply(this,arguments)||this).started=!1,i}return xv(e,t),e.prototype.handler=function(t){var e=sy[t.type];if(e===qv&&(this.started=!0),this.started){var i=ly.call(this,t,e);e&($v|Kv)&&i[0].length-i[1].length==0&&(this.started=!1),this.callback(this.manager,e,{pointers:i[0],changedPointers:i[1],pointerType:Vv,srcEvent:t})}},e}(xg);function ly(t,e){var i=Pg(t.touches),n=Pg(t.changedTouches);return e&($v|Kv)&&(i=Eg(i.concat(n),"identifier",!0)),[i,n]}function hy(t,e,i){var n="DEPRECATED METHOD: "+e+"\n"+i+" AT \n";return function(){var e=new Error("get-stack-trace"),i=e&&e.stack?e.stack.replace(/^[^\(]+?[\n$]/gm,"").replace(/^\s+at\s+/gm,"").replace(/^Object.<anonymous>\s*\(/gm,"{anonymous}()@"):"Unknown Stack Trace",r=window.console&&(window.console.warn||window.console.log);return r&&r.call(window.console,n,i),t.apply(this,arguments)}}var uy=hy((function(t,e,i){for(var n=Object.keys(e),r=0;r<n.length;)(!i||i&&void 0===t[n[r]])&&(t[n[r]]=e[n[r]]),r++;return t}),"extend","Use `assign`."),cy=hy((function(t,e){return uy(t,e,!0)}),"merge","Use `assign`.");function dy(t,e,i){var n,r=e.prototype;(n=t.prototype=Object.create(r)).constructor=t,n._super=r,i&&Cv(n,i)}function py(t,e){return function(){return t.apply(e,arguments)}}var fy=function(){var t=function(t,e){return void 0===e&&(e={}),new oy(t,kv({recognizers:ny.concat()},e))};return t.VERSION="2.0.17-rc",t.DIRECTION_ALL=rg,t.DIRECTION_DOWN=eg,t.DIRECTION_LEFT=Jv,t.DIRECTION_RIGHT=Qv,t.DIRECTION_UP=tg,t.DIRECTION_HORIZONTAL=ig,t.DIRECTION_VERTICAL=ng,t.DIRECTION_NONE=Zv,t.DIRECTION_DOWN=eg,t.INPUT_START=qv,t.INPUT_MOVE=2,t.INPUT_END=$v,t.INPUT_CANCEL=Kv,t.STATE_POSSIBLE=1,t.STATE_BEGAN=2,t.STATE_CHANGED=4,t.STATE_ENDED=8,t.STATE_RECOGNIZED=8,t.STATE_CANCELLED=16,t.STATE_FAILED=Gg,t.Manager=oy,t.Input=xg,t.TouchAction=ug,t.TouchInput=Lg,t.MouseInput=Rg,t.PointerEventInput=Og,t.TouchMouseInput=Bg,t.SingleTouchInput=ay,t.Recognizer=Xg,t.AttrRecognizer=$g,t.Tap=qg,t.Pan=Zg,t.Swipe=Jg,t.Pinch=Qg,t.Rotate=ty,t.Press=ey,t.on=_g,t.off=wg,t.each=ag,t.merge=cy,t.extend=uy,t.bindFn=py,t.assign=Cv,t.inherit=dy,t.bindFn=py,t.prefixed=Iv,t.toArray=Pg,t.inArray=Sg,t.uniqueArray=Eg,t.splitStr=bg,t.boolOrFn=lg,t.hasParent=cg,t.addEventListeners=_g,t.removeEventListeners=wg,t.defaults=Cv({},iy,{preset:ny}),t}();fy.defaults;var my=fy;function vy(t,e){var i=void 0!==yd&&va(t)||t["@@iterator"];if(!i){if(Id(t)||(i=function(t,e){var i;if(t){if("string"==typeof t)return gy(t,e);var n=Sd(i=Object.prototype.toString.call(t)).call(i,8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Ks(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?gy(t,e):void 0}}(t))||e&&t&&"number"==typeof t.length){i&&(t=i);var n=0,r=function(){};return{s:r,n:function(){return n>=t.length?{done:!0}:{done:!1,value:t[n++]}},e:function(t){throw t},f:r}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var o,s=!0,a=!1;return{s:function(){i=i.call(t)},n:function(){var t=i.next();return s=t.done,t},e:function(t){a=!0,o=t},f:function(){try{s||null==i.return||i.return()}finally{if(a)throw o}}}}function gy(t,e){(null==e||e>t.length)&&(e=t.length);for(var i=0,n=new Array(e);i<e;i++)n[i]=t[i];return n}var yy=yd("DELETE");function by(t){for(var e,i=arguments.length,n=new Array(i>1?i-1:0),r=1;r<i;r++)n[r-1]=arguments[r];return _y.apply(void 0,xd(e=[{},t]).call(e,n))}function _y(){var t=wy.apply(void 0,arguments);return xy(t),t}function wy(){for(var t=arguments.length,e=new Array(t),i=0;i<t;i++)e[i]=arguments[i];if(e.length<2)return e[0];var n;if(e.length>2)return wy.apply(void 0,xd(n=[_y(e[0],e[1])]).call(n,gd(Sd(e).call(e,2))));var r=e[0],o=e[1];if(r instanceof Date&&o instanceof Date)return r.setTime(o.getTime()),r;var s,a=vy(Ed(o));try{for(a.s();!(s=a.n()).done;){var l=s.value;Object.prototype.propertyIsEnumerable.call(o,l)&&(o[l]===yy?delete r[l]:null===r[l]||null===o[l]||"object"!==kc(r[l])||"object"!==kc(o[l])||Id(r[l])||Id(o[l])?r[l]=ky(o[l]):r[l]=wy(r[l],o[l]))}}catch(t){a.e(t)}finally{a.f()}return r}function ky(t){return Id(t)?jd(t).call(t,(function(t){return ky(t)})):"object"===kc(t)&&null!==t?t instanceof Date?new Date(t.getTime()):wy({},t):t}function xy(t){for(var e=0,i=Bd(t);e<i.length;e++){var n=i[e];t[n]===yy?delete t[n]:"object"===kc(t[n])&&null!==t[n]&&xy(t[n])}}var Sy="undefined"!=typeof window?window.Hammer||my:function(){return function(){var t=function(){};return{on:t,off:t,destroy:t,emit:t,get:function(){return{set:t}}}}()};function Dy(t){var e,i=this;this._cleanupQueue=[],this.active=!1,this._dom={container:t,overlay:document.createElement("div")},this._dom.overlay.classList.add("vis-overlay"),this._dom.container.appendChild(this._dom.overlay),this._cleanupQueue.push((function(){i._dom.overlay.parentNode.removeChild(i._dom.overlay)}));var n=Sy(this._dom.overlay);n.on("tap",hp(e=this._onTapOverlay).call(e,this)),this._cleanupQueue.push((function(){n.destroy()}));var r=["tap","doubletap","press","pinch","pan","panstart","panmove","panend"];kp(r).call(r,(function(t){n.on(t,(function(t){t.srcEvent.stopPropagation()}))})),document&&document.body&&(this._onClick=function(e){(function(t,e){for(;t;){if(t===e)return!0;t=t.parentNode}return!1})(e.target,t)||i.deactivate()},document.body.addEventListener("click",this._onClick),this._cleanupQueue.push((function(){document.body.removeEventListener("click",i._onClick)}))),this._escListener=function(t){("key"in t?"Escape"===t.key:27===t.keyCode)&&i.deactivate()}}wv(Dy.prototype),Dy.current=null,Dy.prototype.destroy=function(){var t,e;this.deactivate();var i,n=vy(Ip(t=Qp(e=this._cleanupQueue).call(e,0)).call(t));try{for(n.s();!(i=n.n()).done;)(0,i.value)()}catch(t){n.e(t)}finally{n.f()}},Dy.prototype.activate=function(){Dy.current&&Dy.current.deactivate(),Dy.current=this,this.active=!0,this._dom.overlay.style.display="none",this._dom.container.classList.add("vis-active"),this.emit("change"),this.emit("activate"),document.body.addEventListener("keydown",this._escListener)},Dy.prototype.deactivate=function(){this.active=!1,this._dom.overlay.style.display="block",this._dom.container.classList.remove("vis-active"),document.body.removeEventListener("keydown",this._escListener),this.emit("change"),this.emit("deactivate")},Dy.prototype._onTapOverlay=function(t){this.activate(),t.srcEvent.stopPropagation()};var Cy=/^\/?Date\((-?\d+)/i,Ty=/^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i,My=/^#?([a-f\d])([a-f\d])([a-f\d])$/i,Oy=/^rgb\( *(1?\d{1,2}|2[0-4]\d|25[0-5]) *, *(1?\d{1,2}|2[0-4]\d|25[0-5]) *, *(1?\d{1,2}|2[0-4]\d|25[0-5]) *\)$/i,Py=/^rgba\( *(1?\d{1,2}|2[0-4]\d|25[0-5]) *, *(1?\d{1,2}|2[0-4]\d|25[0-5]) *, *(1?\d{1,2}|2[0-4]\d|25[0-5]) *, *([01]|0?\.\d+) *\)$/i;function Ey(t){return t instanceof Number||"number"==typeof t}function Iy(t){return t instanceof String||"string"==typeof t}function Ly(t){return"object"===kc(t)&&null!==t}function Ay(t,e,i,n){var r=!1;!0===n&&(r=null===e[i]&&void 0!==t[i]),r?delete t[i]:t[i]=e[i]}var Ny=mf;function Ry(t,e){var i=arguments.length>2&&void 0!==arguments[2]&&arguments[2],n=arguments.length>3&&void 0!==arguments[3]&&arguments[3];for(var r in e)if(Object.prototype.hasOwnProperty.call(e,r)||!0===i)if("object"===kc(e[r])&&null!==e[r]&&Yf(e[r])===Object.prototype)void 0===t[r]?t[r]=Ry({},e[r],i):"object"===kc(t[r])&&null!==t[r]&&Yf(t[r])===Object.prototype?Ry(t[r],e[r],i):Ay(t,e,r,n);else if(Id(e[r])){var o;t[r]=Sd(o=e[r]).call(o)}else Ay(t,e,r,n);return t}function Fy(t){var e=kc(t);return"object"===e?null===t?"null":t instanceof Boolean?"Boolean":t instanceof Number?"Number":t instanceof String?"String":Id(t)?"Array":t instanceof Date?"Date":"Object":"number"===e?"Number":"boolean"===e?"Boolean":"string"===e?"String":void 0===e?"undefined":e}function jy(t,e){var i;return xd(i=[]).call(i,gd(t),[e])}function Yy(t){return Sd(t).call(t)}var Hy=rm,By={asBoolean:function(t,e){return"function"==typeof t&&(t=t()),null!=t?0!=t:e||null},asNumber:function(t,e){return"function"==typeof t&&(t=t()),null!=t?Number(t)||e||null:e||null},asString:function(t,e){return"function"==typeof t&&(t=t()),null!=t?String(t):e||null},asSize:function(t,e){return"function"==typeof t&&(t=t()),Iy(t)?t:Ey(t)?t+"px":e||null},asElement:function(t,e){return"function"==typeof t&&(t=t()),t||e||null}};function zy(t){var e;switch(t.length){case 3:case 4:return(e=My.exec(t))?{r:Cm(e[1]+e[1],16),g:Cm(e[2]+e[2],16),b:Cm(e[3]+e[3],16)}:null;case 6:case 7:return(e=Ty.exec(t))?{r:Cm(e[1],16),g:Cm(e[2],16),b:Cm(e[3],16)}:null;default:return null}}function Gy(t,e,i){var n;return"#"+Sd(n=((1<<24)+(t<<16)+(e<<8)+i).toString(16)).call(n,1)}function Wy(t,e,i){t/=255,e/=255,i/=255;var n=Math.min(t,Math.min(e,i)),r=Math.max(t,Math.max(e,i));return n===r?{h:0,s:0,v:n}:{h:60*((t===n?3:i===n?1:5)-(t===n?e-i:i===n?t-e:i-t)/(r-n))/360,s:(r-n)/r,v:r}}function Vy(t){var e=document.createElement("div"),i={};e.style.cssText=t;for(var n=0;n<e.style.length;++n)i[e.style[n]]=e.style.getPropertyValue(e.style[n]);return i}function Uy(t,e,i){var n,r,o,s=Math.floor(6*t),a=6*t-s,l=i*(1-e),h=i*(1-a*e),u=i*(1-(1-a)*e);switch(s%6){case 0:n=i,r=u,o=l;break;case 1:n=h,r=i,o=l;break;case 2:n=l,r=i,o=u;break;case 3:n=l,r=h,o=i;break;case 4:n=u,r=l,o=i;break;case 5:n=i,r=l,o=h}return{r:Math.floor(255*n),g:Math.floor(255*r),b:Math.floor(255*o)}}function Xy(t,e,i){var n=Uy(t,e,i);return Gy(n.r,n.g,n.b)}function qy(t){var e=zy(t);if(!e)throw new TypeError("'".concat(t,"' is not a valid color."));return Wy(e.r,e.g,e.b)}function $y(t){return/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i.test(t)}function Ky(t){return Oy.test(t)}function Zy(t){return Py.test(t)}function Jy(t){if(null===t||"object"!==kc(t))return null;if(t instanceof Element)return t;var e=Bm(t);for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&"object"==kc(t[i])&&(e[i]=Jy(t[i]));return e}var Qy={black:"#000000",navy:"#000080",darkblue:"#00008B",mediumblue:"#0000CD",blue:"#0000FF",darkgreen:"#006400",green:"#008000",teal:"#008080",darkcyan:"#008B8B",deepskyblue:"#00BFFF",darkturquoise:"#00CED1",mediumspringgreen:"#00FA9A",lime:"#00FF00",springgreen:"#00FF7F",aqua:"#00FFFF",cyan:"#00FFFF",midnightblue:"#191970",dodgerblue:"#1E90FF",lightseagreen:"#20B2AA",forestgreen:"#228B22",seagreen:"#2E8B57",darkslategray:"#2F4F4F",limegreen:"#32CD32",mediumseagreen:"#3CB371",turquoise:"#40E0D0",royalblue:"#4169E1",steelblue:"#4682B4",darkslateblue:"#483D8B",mediumturquoise:"#48D1CC",indigo:"#4B0082",darkolivegreen:"#556B2F",cadetblue:"#5F9EA0",cornflowerblue:"#6495ED",mediumaquamarine:"#66CDAA",dimgray:"#696969",slateblue:"#6A5ACD",olivedrab:"#6B8E23",slategray:"#708090",lightslategray:"#778899",mediumslateblue:"#7B68EE",lawngreen:"#7CFC00",chartreuse:"#7FFF00",aquamarine:"#7FFFD4",maroon:"#800000",purple:"#800080",olive:"#808000",gray:"#808080",skyblue:"#87CEEB",lightskyblue:"#87CEFA",blueviolet:"#8A2BE2",darkred:"#8B0000",darkmagenta:"#8B008B",saddlebrown:"#8B4513",darkseagreen:"#8FBC8F",lightgreen:"#90EE90",mediumpurple:"#9370D8",darkviolet:"#9400D3",palegreen:"#98FB98",darkorchid:"#9932CC",yellowgreen:"#9ACD32",sienna:"#A0522D",brown:"#A52A2A",darkgray:"#A9A9A9",lightblue:"#ADD8E6",greenyellow:"#ADFF2F",paleturquoise:"#AFEEEE",lightsteelblue:"#B0C4DE",powderblue:"#B0E0E6",firebrick:"#B22222",darkgoldenrod:"#B8860B",mediumorchid:"#BA55D3",rosybrown:"#BC8F8F",darkkhaki:"#BDB76B",silver:"#C0C0C0",mediumvioletred:"#C71585",indianred:"#CD5C5C",peru:"#CD853F",chocolate:"#D2691E",tan:"#D2B48C",lightgrey:"#D3D3D3",palevioletred:"#D87093",thistle:"#D8BFD8",orchid:"#DA70D6",goldenrod:"#DAA520",crimson:"#DC143C",gainsboro:"#DCDCDC",plum:"#DDA0DD",burlywood:"#DEB887",lightcyan:"#E0FFFF",lavender:"#E6E6FA",darksalmon:"#E9967A",violet:"#EE82EE",palegoldenrod:"#EEE8AA",lightcoral:"#F08080",khaki:"#F0E68C",aliceblue:"#F0F8FF",honeydew:"#F0FFF0",azure:"#F0FFFF",sandybrown:"#F4A460",wheat:"#F5DEB3",beige:"#F5F5DC",whitesmoke:"#F5F5F5",mintcream:"#F5FFFA",ghostwhite:"#F8F8FF",salmon:"#FA8072",antiquewhite:"#FAEBD7",linen:"#FAF0E6",lightgoldenrodyellow:"#FAFAD2",oldlace:"#FDF5E6",red:"#FF0000",fuchsia:"#FF00FF",magenta:"#FF00FF",deeppink:"#FF1493",orangered:"#FF4500",tomato:"#FF6347",hotpink:"#FF69B4",coral:"#FF7F50",darkorange:"#FF8C00",lightsalmon:"#FFA07A",orange:"#FFA500",lightpink:"#FFB6C1",pink:"#FFC0CB",gold:"#FFD700",peachpuff:"#FFDAB9",navajowhite:"#FFDEAD",moccasin:"#FFE4B5",bisque:"#FFE4C4",mistyrose:"#FFE4E1",blanchedalmond:"#FFEBCD",papayawhip:"#FFEFD5",lavenderblush:"#FFF0F5",seashell:"#FFF5EE",cornsilk:"#FFF8DC",lemonchiffon:"#FFFACD",floralwhite:"#FFFAF0",snow:"#FFFAFA",yellow:"#FFFF00",lightyellow:"#FFFFE0",ivory:"#FFFFF0",white:"#FFFFFF"},tb=function(){function t(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:1;ga(this,t),this.pixelRatio=e,this.generated=!1,this.centerCoordinates={x:144.5,y:144.5},this.r=289*.49,this.color={r:255,g:255,b:255,a:1},this.hueCircle=void 0,this.initialColor={r:255,g:255,b:255,a:1},this.previousColor=void 0,this.applied=!1,this.updateCallback=function(){},this.closeCallback=function(){},this._create()}return Cc(t,[{key:"insertTo",value:function(t){void 0!==this.hammer&&(this.hammer.destroy(),this.hammer=void 0),this.container=t,this.container.appendChild(this.frame),this._bindHammer(),this._setSize()}},{key:"setUpdateCallback",value:function(t){if("function"!=typeof t)throw new Error("Function attempted to set as colorPicker update callback is not a function.");this.updateCallback=t}},{key:"setCloseCallback",value:function(t){if("function"!=typeof t)throw new Error("Function attempted to set as colorPicker closing callback is not a function.");this.closeCallback=t}},{key:"_isColorString",value:function(t){if("string"==typeof t)return Qy[t]}},{key:"setColor",value:function(t){var e=!(arguments.length>1&&void 0!==arguments[1])||arguments[1];if("none"!==t){var i,n=this._isColorString(t);if(void 0!==n&&(t=n),!0===Iy(t)){if(!0===Ky(t)){var r=t.substr(4).substr(0,t.length-5).split(",");i={r:r[0],g:r[1],b:r[2],a:1}}else if(!0===Zy(t)){var o=t.substr(5).substr(0,t.length-6).split(",");i={r:o[0],g:o[1],b:o[2],a:o[3]}}else if(!0===$y(t)){var s=zy(t);i={r:s.r,g:s.g,b:s.b,a:1}}}else if(t instanceof Object&&void 0!==t.r&&void 0!==t.g&&void 0!==t.b){var a=void 0!==t.a?t.a:"1.0";i={r:t.r,g:t.g,b:t.b,a:a}}if(void 0===i)throw new Error("Unknown color passed to the colorPicker. Supported are strings: rgb, hex, rgba. Object: rgb ({r:r,g:g,b:b,[a:a]}). Supplied: "+Wm(t));this._setColor(i,e)}}},{key:"show",value:function(){void 0!==this.closeCallback&&(this.closeCallback(),this.closeCallback=void 0),this.applied=!1,this.frame.style.display="block",this._generateHueCircle()}},{key:"_hide",value:function(){var t=this;!0===(!(arguments.length>0&&void 0!==arguments[0])||arguments[0])&&(this.previousColor=mf({},this.color)),!0===this.applied&&this.updateCallback(this.initialColor),this.frame.style.display="none",uv((function(){void 0!==t.closeCallback&&(t.closeCallback(),t.closeCallback=void 0)}),0)}},{key:"_save",value:function(){this.updateCallback(this.color),this.applied=!1,this._hide()}},{key:"_apply",value:function(){this.applied=!0,this.updateCallback(this.color),this._updatePicker(this.color)}},{key:"_loadLast",value:function(){void 0!==this.previousColor?this.setColor(this.previousColor,!1):alert("There is no last color to load...")}},{key:"_setColor",value:function(t){!0===(!(arguments.length>1&&void 0!==arguments[1])||arguments[1])&&(this.initialColor=mf({},t)),this.color=t;var e=Wy(t.r,t.g,t.b),i=2*Math.PI,n=this.r*e.s,r=this.centerCoordinates.x+n*Math.sin(i*e.h),o=this.centerCoordinates.y+n*Math.cos(i*e.h);this.colorPickerSelector.style.left=r-.5*this.colorPickerSelector.clientWidth+"px",this.colorPickerSelector.style.top=o-.5*this.colorPickerSelector.clientHeight+"px",this._updatePicker(t)}},{key:"_setOpacity",value:function(t){this.color.a=t/100,this._updatePicker(this.color)}},{key:"_setBrightness",value:function(t){var e=Wy(this.color.r,this.color.g,this.color.b);e.v=t/100;var i=Uy(e.h,e.s,e.v);i.a=this.color.a,this.color=i,this._updatePicker()}},{key:"_updatePicker",value:function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:this.color,e=Wy(t.r,t.g,t.b),i=this.colorPickerCanvas.getContext("2d");void 0===this.pixelRation&&(this.pixelRatio=(window.devicePixelRatio||1)/(i.webkitBackingStorePixelRatio||i.mozBackingStorePixelRatio||i.msBackingStorePixelRatio||i.oBackingStorePixelRatio||i.backingStorePixelRatio||1)),i.setTransform(this.pixelRatio,0,0,this.pixelRatio,0,0);var n=this.colorPickerCanvas.clientWidth,r=this.colorPickerCanvas.clientHeight;i.clearRect(0,0,n,r),i.putImageData(this.hueCircle,0,0),i.fillStyle="rgba(0,0,0,"+(1-e.v)+")",i.circle(this.centerCoordinates.x,this.centerCoordinates.y,this.r),yv(i).call(i),this.brightnessRange.value=100*e.v,this.opacityRange.value=100*t.a,this.initialColorDiv.style.backgroundColor="rgba("+this.initialColor.r+","+this.initialColor.g+","+this.initialColor.b+","+this.initialColor.a+")",this.newColorDiv.style.backgroundColor="rgba("+this.color.r+","+this.color.g+","+this.color.b+","+this.color.a+")"}},{key:"_setSize",value:function(){this.colorPickerCanvas.style.width="100%",this.colorPickerCanvas.style.height="100%",this.colorPickerCanvas.width=289*this.pixelRatio,this.colorPickerCanvas.height=289*this.pixelRatio}},{key:"_create",value:function(){var t,e,i,n;if(this.frame=document.createElement("div"),this.frame.className="vis-color-picker",this.colorPickerDiv=document.createElement("div"),this.colorPickerSelector=document.createElement("div"),this.colorPickerSelector.className="vis-selector",this.colorPickerDiv.appendChild(this.colorPickerSelector),this.colorPickerCanvas=document.createElement("canvas"),this.colorPickerDiv.appendChild(this.colorPickerCanvas),this.colorPickerCanvas.getContext){var r=this.colorPickerCanvas.getContext("2d");this.pixelRatio=(window.devicePixelRatio||1)/(r.webkitBackingStorePixelRatio||r.mozBackingStorePixelRatio||r.msBackingStorePixelRatio||r.oBackingStorePixelRatio||r.backingStorePixelRatio||1),this.colorPickerCanvas.getContext("2d").setTransform(this.pixelRatio,0,0,this.pixelRatio,0,0)}else{var o=document.createElement("DIV");o.style.color="red",o.style.fontWeight="bold",o.style.padding="10px",o.innerText="Error: your browser does not support HTML canvas",this.colorPickerCanvas.appendChild(o)}this.colorPickerDiv.className="vis-color",this.opacityDiv=document.createElement("div"),this.opacityDiv.className="vis-opacity",this.brightnessDiv=document.createElement("div"),this.brightnessDiv.className="vis-brightness",this.arrowDiv=document.createElement("div"),this.arrowDiv.className="vis-arrow",this.opacityRange=document.createElement("input");try{this.opacityRange.type="range",this.opacityRange.min="0",this.opacityRange.max="100"}catch(t){}this.opacityRange.value="100",this.opacityRange.className="vis-range",this.brightnessRange=document.createElement("input");try{this.brightnessRange.type="range",this.brightnessRange.min="0",this.brightnessRange.max="100"}catch(t){}this.brightnessRange.value="100",this.brightnessRange.className="vis-range",this.opacityDiv.appendChild(this.opacityRange),this.brightnessDiv.appendChild(this.brightnessRange);var s=this;this.opacityRange.onchange=function(){s._setOpacity(this.value)},this.opacityRange.oninput=function(){s._setOpacity(this.value)},this.brightnessRange.onchange=function(){s._setBrightness(this.value)},this.brightnessRange.oninput=function(){s._setBrightness(this.value)},this.brightnessLabel=document.createElement("div"),this.brightnessLabel.className="vis-label vis-brightness",this.brightnessLabel.innerText="brightness:",this.opacityLabel=document.createElement("div"),this.opacityLabel.className="vis-label vis-opacity",this.opacityLabel.innerText="opacity:",this.newColorDiv=document.createElement("div"),this.newColorDiv.className="vis-new-color",this.newColorDiv.innerText="new",this.initialColorDiv=document.createElement("div"),this.initialColorDiv.className="vis-initial-color",this.initialColorDiv.innerText="initial",this.cancelButton=document.createElement("div"),this.cancelButton.className="vis-button vis-cancel",this.cancelButton.innerText="cancel",this.cancelButton.onclick=hp(t=this._hide).call(t,this,!1),this.applyButton=document.createElement("div"),this.applyButton.className="vis-button vis-apply",this.applyButton.innerText="apply",this.applyButton.onclick=hp(e=this._apply).call(e,this),this.saveButton=document.createElement("div"),this.saveButton.className="vis-button vis-save",this.saveButton.innerText="save",this.saveButton.onclick=hp(i=this._save).call(i,this),this.loadButton=document.createElement("div"),this.loadButton.className="vis-button vis-load",this.loadButton.innerText="load last",this.loadButton.onclick=hp(n=this._loadLast).call(n,this),this.frame.appendChild(this.colorPickerDiv),this.frame.appendChild(this.arrowDiv),this.frame.appendChild(this.brightnessLabel),this.frame.appendChild(this.brightnessDiv),this.frame.appendChild(this.opacityLabel),this.frame.appendChild(this.opacityDiv),this.frame.appendChild(this.newColorDiv),this.frame.appendChild(this.initialColorDiv),this.frame.appendChild(this.cancelButton),this.frame.appendChild(this.applyButton),this.frame.appendChild(this.saveButton),this.frame.appendChild(this.loadButton)}},{key:"_bindHammer",value:function(){var t=this;this.drag={},this.pinch={},this.hammer=new Sy(this.colorPickerCanvas),this.hammer.get("pinch").set({enable:!0}),this.hammer.on("hammer.input",(function(e){e.isFirst&&t._moveSelector(e)})),this.hammer.on("tap",(function(e){t._moveSelector(e)})),this.hammer.on("panstart",(function(e){t._moveSelector(e)})),this.hammer.on("panmove",(function(e){t._moveSelector(e)})),this.hammer.on("panend",(function(e){t._moveSelector(e)}))}},{key:"_generateHueCircle",value:function(){if(!1===this.generated){var t=this.colorPickerCanvas.getContext("2d");void 0===this.pixelRation&&(this.pixelRatio=(window.devicePixelRatio||1)/(t.webkitBackingStorePixelRatio||t.mozBackingStorePixelRatio||t.msBackingStorePixelRatio||t.oBackingStorePixelRatio||t.backingStorePixelRatio||1)),t.setTransform(this.pixelRatio,0,0,this.pixelRatio,0,0);var e,i,n,r,o=this.colorPickerCanvas.clientWidth,s=this.colorPickerCanvas.clientHeight;t.clearRect(0,0,o,s),this.centerCoordinates={x:.5*o,y:.5*s},this.r=.49*o;var a,l=2*Math.PI/360,h=1/this.r;for(n=0;n<360;n++)for(r=0;r<this.r;r++)e=this.centerCoordinates.x+r*Math.sin(l*n),i=this.centerCoordinates.y+r*Math.cos(l*n),a=Uy(.002777777777777778*n,r*h,1),t.fillStyle="rgb("+a.r+","+a.g+","+a.b+")",t.fillRect(e-.5,i-.5,2,2);t.strokeStyle="rgba(0,0,0,1)",t.circle(this.centerCoordinates.x,this.centerCoordinates.y,this.r),t.stroke(),this.hueCircle=t.getImageData(0,0,o,s)}this.generated=!0}},{key:"_moveSelector",value:function(t){var e=this.colorPickerDiv.getBoundingClientRect(),i=t.center.x-e.left,n=t.center.y-e.top,r=.5*this.colorPickerDiv.clientHeight,o=.5*this.colorPickerDiv.clientWidth,s=i-o,a=n-r,l=Math.atan2(s,a),h=.98*Math.min(Math.sqrt(s*s+a*a),o),u=Math.cos(l)*h+r,c=Math.sin(l)*h+o;this.colorPickerSelector.style.top=u-.5*this.colorPickerSelector.clientHeight+"px",this.colorPickerSelector.style.left=c-.5*this.colorPickerSelector.clientWidth+"px";var d=l/(2*Math.PI);d=d<0?d+1:d;var p=h/this.r,f=Wy(this.color.r,this.color.g,this.color.b);f.h=d,f.s=p;var m=Uy(f.h,f.s,f.v);m.a=this.color.a,this.color=m,this.initialColorDiv.style.backgroundColor="rgba("+this.initialColor.r+","+this.initialColor.g+","+this.initialColor.b+","+this.initialColor.a+")",this.newColorDiv.style.backgroundColor="rgba("+this.color.r+","+this.color.g+","+this.color.b+","+this.color.a+")"}}]),t}();function eb(){for(var t=arguments.length,e=new Array(t),i=0;i<t;i++)e[i]=arguments[i];if(e.length<1)throw new TypeError("Invalid arguments.");if(1===e.length)return document.createTextNode(e[0]);var n=document.createElement(e[0]);return n.appendChild(eb.apply(void 0,gd(Sd(e).call(e,1)))),n}var ib,nb=function(){function t(e,i,n){var r=arguments.length>3&&void 0!==arguments[3]?arguments[3]:1,o=arguments.length>4&&void 0!==arguments[4]?arguments[4]:function(){return!1};ga(this,t),this.parent=e,this.changedOptions=[],this.container=i,this.allowCreation=!1,this.hideOption=o,this.options={},this.initialized=!1,this.popupCounter=0,this.defaultOptions={enabled:!1,filter:!0,container:void 0,showButton:!0},mf(this.options,this.defaultOptions),this.configureOptions=n,this.moduleOptions={},this.domElements=[],this.popupDiv={},this.popupLimit=5,this.popupHistory={},this.colorPicker=new tb(r),this.wrapper=void 0}return Cc(t,[{key:"setOptions",value:function(t){if(void 0!==t){this.popupHistory={},this._removePopup();var e=!0;if("string"==typeof t)this.options.filter=t;else if(Id(t))this.options.filter=t.join();else if("object"===kc(t)){if(null==t)throw new TypeError("options cannot be null");void 0!==t.container&&(this.options.container=t.container),void 0!==Vf(t)&&(this.options.filter=Vf(t)),void 0!==t.showButton&&(this.options.showButton=t.showButton),void 0!==t.enabled&&(e=t.enabled)}else"boolean"==typeof t?(this.options.filter=!0,e=t):"function"==typeof t&&(this.options.filter=t,e=!0);!1===Vf(this.options)&&(e=!1),this.options.enabled=e}this._clean()}},{key:"setModuleOptions",value:function(t){this.moduleOptions=t,!0===this.options.enabled&&(this._clean(),void 0!==this.options.container&&(this.container=this.options.container),this._create())}},{key:"_create",value:function(){this._clean(),this.changedOptions=[];var t=Vf(this.options),e=0,i=!1;for(var n in this.configureOptions)Object.prototype.hasOwnProperty.call(this.configureOptions,n)&&(this.allowCreation=!1,i=!1,"function"==typeof t?i=(i=t(n,[]))||this._handleObject(this.configureOptions[n],[n],!0):!0!==t&&-1===Rm(t).call(t,n)||(i=!0),!1!==i&&(this.allowCreation=!0,e>0&&this._makeItem([]),this._makeHeader(n),this._handleObject(this.configureOptions[n],[n])),e++);this._makeButton(),this._push()}},{key:"_push",value:function(){this.wrapper=document.createElement("div"),this.wrapper.className="vis-configuration-wrapper",this.container.appendChild(this.wrapper);for(var t=0;t<this.domElements.length;t++)this.wrapper.appendChild(this.domElements[t]);this._showPopupIfNeeded()}},{key:"_clean",value:function(){for(var t=0;t<this.domElements.length;t++)this.wrapper.removeChild(this.domElements[t]);void 0!==this.wrapper&&(this.container.removeChild(this.wrapper),this.wrapper=void 0),this.domElements=[],this._removePopup()}},{key:"_getValue",value:function(t){for(var e=this.moduleOptions,i=0;i<t.length;i++){if(void 0===e[t[i]]){e=void 0;break}e=e[t[i]]}return e}},{key:"_makeItem",value:function(t){if(!0===this.allowCreation){var e=document.createElement("div");e.className="vis-configuration vis-config-item vis-config-s"+t.length;for(var i=arguments.length,n=new Array(i>1?i-1:0),r=1;r<i;r++)n[r-1]=arguments[r];return kp(n).call(n,(function(t){e.appendChild(t)})),this.domElements.push(e),this.domElements.length}return 0}},{key:"_makeHeader",value:function(t){var e=document.createElement("div");e.className="vis-configuration vis-config-header",e.innerText=t,this._makeItem([],e)}},{key:"_makeLabel",value:function(t,e){var i=arguments.length>2&&void 0!==arguments[2]&&arguments[2],n=document.createElement("div");if(n.className="vis-configuration vis-config-label vis-config-s"+e.length,!0===i){for(;n.firstChild;)n.removeChild(n.firstChild);n.appendChild(eb("i","b",t))}else n.innerText=t+":";return n}},{key:"_makeDropdown",value:function(t,e,i){var n=document.createElement("select");n.className="vis-configuration vis-config-select";var r=0;void 0!==e&&-1!==Rm(t).call(t,e)&&(r=Rm(t).call(t,e));for(var o=0;o<t.length;o++){var s=document.createElement("option");s.value=t[o],o===r&&(s.selected="selected"),s.innerText=t[o],n.appendChild(s)}var a=this;n.onchange=function(){a._update(this.value,i)};var l=this._makeLabel(i[i.length-1],i);this._makeItem(i,l,n)}},{key:"_makeRange",value:function(t,e,i){var n=t[0],r=t[1],o=t[2],s=t[3],a=document.createElement("input");a.className="vis-configuration vis-config-range";try{a.type="range",a.min=r,a.max=o}catch(t){}a.step=s;var l="",h=0;if(void 0!==e){var u=1.2;e<0&&e*u<r?(a.min=Math.ceil(e*u),h=a.min,l="range increased"):e/u<r&&(a.min=Math.ceil(e/u),h=a.min,l="range increased"),e*u>o&&1!==o&&(a.max=Math.ceil(e*u),h=a.max,l="range increased"),a.value=e}else a.value=n;var c=document.createElement("input");c.className="vis-configuration vis-config-rangeinput",c.value=a.value;var d=this;a.onchange=function(){c.value=this.value,d._update(Number(this.value),i)},a.oninput=function(){c.value=this.value};var p=this._makeLabel(i[i.length-1],i),f=this._makeItem(i,p,a,c);""!==l&&this.popupHistory[f]!==h&&(this.popupHistory[f]=h,this._setupPopup(l,f))}},{key:"_makeButton",value:function(){var t=this;if(!0===this.options.showButton){var e=document.createElement("div");e.className="vis-configuration vis-config-button",e.innerText="generate options",e.onclick=function(){t._printOptions()},e.onmouseover=function(){e.className="vis-configuration vis-config-button hover"},e.onmouseout=function(){e.className="vis-configuration vis-config-button"},this.optionsContainer=document.createElement("div"),this.optionsContainer.className="vis-configuration vis-config-option-container",this.domElements.push(this.optionsContainer),this.domElements.push(e)}}},{key:"_setupPopup",value:function(t,e){var i=this;if(!0===this.initialized&&!0===this.allowCreation&&this.popupCounter<this.popupLimit){var n=document.createElement("div");n.id="vis-configuration-popup",n.className="vis-configuration-popup",n.innerText=t,n.onclick=function(){i._removePopup()},this.popupCounter+=1,this.popupDiv={html:n,index:e}}}},{key:"_removePopup",value:function(){void 0!==this.popupDiv.html&&(this.popupDiv.html.parentNode.removeChild(this.popupDiv.html),clearTimeout(this.popupDiv.hideTimeout),clearTimeout(this.popupDiv.deleteTimeout),this.popupDiv={})}},{key:"_showPopupIfNeeded",value:function(){var t=this;if(void 0!==this.popupDiv.html){var e=this.domElements[this.popupDiv.index].getBoundingClientRect();this.popupDiv.html.style.left=e.left+"px",this.popupDiv.html.style.top=e.top-30+"px",document.body.appendChild(this.popupDiv.html),this.popupDiv.hideTimeout=uv((function(){t.popupDiv.html.style.opacity=0}),1500),this.popupDiv.deleteTimeout=uv((function(){t._removePopup()}),1800)}}},{key:"_makeCheckbox",value:function(t,e,i){var n=document.createElement("input");n.type="checkbox",n.className="vis-configuration vis-config-checkbox",n.checked=t,void 0!==e&&(n.checked=e,e!==t&&("object"===kc(t)?e!==t.enabled&&this.changedOptions.push({path:i,value:e}):this.changedOptions.push({path:i,value:e})));var r=this;n.onchange=function(){r._update(this.checked,i)};var o=this._makeLabel(i[i.length-1],i);this._makeItem(i,o,n)}},{key:"_makeTextInput",value:function(t,e,i){var n=document.createElement("input");n.type="text",n.className="vis-configuration vis-config-text",n.value=e,e!==t&&this.changedOptions.push({path:i,value:e});var r=this;n.onchange=function(){r._update(this.value,i)};var o=this._makeLabel(i[i.length-1],i);this._makeItem(i,o,n)}},{key:"_makeColorField",value:function(t,e,i){var n=this,r=t[1],o=document.createElement("div");"none"!==(e=void 0===e?r:e)?(o.className="vis-configuration vis-config-colorBlock",o.style.backgroundColor=e):o.className="vis-configuration vis-config-colorBlock none",e=void 0===e?r:e,o.onclick=function(){n._showColorPicker(e,o,i)};var s=this._makeLabel(i[i.length-1],i);this._makeItem(i,s,o)}},{key:"_showColorPicker",value:function(t,e,i){var n=this;e.onclick=function(){},this.colorPicker.insertTo(e),this.colorPicker.show(),this.colorPicker.setColor(t),this.colorPicker.setUpdateCallback((function(t){var r="rgba("+t.r+","+t.g+","+t.b+","+t.a+")";e.style.backgroundColor=r,n._update(r,i)})),this.colorPicker.setCloseCallback((function(){e.onclick=function(){n._showColorPicker(t,e,i)}}))}},{key:"_handleObject",value:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:[],i=arguments.length>2&&void 0!==arguments[2]&&arguments[2],n=!1,r=Vf(this.options),o=!1;for(var s in t)if(Object.prototype.hasOwnProperty.call(t,s)){n=!0;var a=t[s],l=jy(e,s);if("function"==typeof r&&!1===(n=r(s,e))&&!Id(a)&&"string"!=typeof a&&"boolean"!=typeof a&&a instanceof Object&&(this.allowCreation=!1,n=this._handleObject(a,l,!0),this.allowCreation=!1===i),!1!==n){o=!0;var h=this._getValue(l);if(Id(a))this._handleArray(a,h,l);else if("string"==typeof a)this._makeTextInput(a,h,l);else if("boolean"==typeof a)this._makeCheckbox(a,h,l);else if(a instanceof Object){if(!this.hideOption(e,s,this.moduleOptions))if(void 0!==a.enabled){var u=jy(l,"enabled"),c=this._getValue(u);if(!0===c){var d=this._makeLabel(s,l,!0);this._makeItem(l,d),o=this._handleObject(a,l)||o}else this._makeCheckbox(a,c,l)}else{var p=this._makeLabel(s,l,!0);this._makeItem(l,p),o=this._handleObject(a,l)||o}}else console.error("dont know how to handle",a,s,l)}}return o}},{key:"_handleArray",value:function(t,e,i){"string"==typeof t[0]&&"color"===t[0]?(this._makeColorField(t,e,i),t[1]!==e&&this.changedOptions.push({path:i,value:e})):"string"==typeof t[0]?(this._makeDropdown(t,e,i),t[0]!==e&&this.changedOptions.push({path:i,value:e})):"number"==typeof t[0]&&(this._makeRange(t,e,i),t[0]!==e&&this.changedOptions.push({path:i,value:Number(e)}))}},{key:"_update",value:function(t,e){var i=this._constructOptions(t,e);this.parent.body&&this.parent.body.emitter&&this.parent.body.emitter.emit&&this.parent.body.emitter.emit("configChange",i),this.initialized=!0,this.parent.setOptions(i)}},{key:"_constructOptions",value:function(t,e){var i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},n=i;t="false"!==(t="true"===t||t)&&t;for(var r=0;r<e.length;r++)"global"!==e[r]&&(void 0===n[e[r]]&&(n[e[r]]={}),r!==e.length-1?n=n[e[r]]:n[e[r]]=t);return i}},{key:"_printOptions",value:function(){for(var t=this.getOptions();this.optionsContainer.firstChild;)this.optionsContainer.removeChild(this.optionsContainer.firstChild);this.optionsContainer.appendChild(eb("pre","const options = "+Wm(t,null,2)))}},{key:"getOptions",value:function(){for(var t={},e=0;e<this.changedOptions.length;e++)this._constructOptions(this.changedOptions[e].value,this.changedOptions[e].path,t);return t}}]),t}(),rb=function(){function t(e,i){ga(this,t),this.container=e,this.overflowMethod=i||"cap",this.x=0,this.y=0,this.padding=5,this.hidden=!1,this.frame=document.createElement("div"),this.frame.className="vis-tooltip",this.container.appendChild(this.frame)}return Cc(t,[{key:"setPosition",value:function(t,e){this.x=Cm(t),this.y=Cm(e)}},{key:"setText",value:function(t){if(t instanceof Element){for(;this.frame.firstChild;)this.frame.removeChild(this.frame.firstChild);this.frame.appendChild(t)}else this.frame.innerText=t}},{key:"show",value:function(t){if(void 0===t&&(t=!0),!0===t){var e=this.frame.clientHeight,i=this.frame.clientWidth,n=this.frame.parentNode.clientHeight,r=this.frame.parentNode.clientWidth,o=0,s=0;if("flip"==this.overflowMethod){var a=!1,l=!0;this.y-e<this.padding&&(l=!1),this.x+i>r-this.padding&&(a=!0),o=a?this.x-i:this.x,s=l?this.y-e:this.y}else(s=this.y-e)+e+this.padding>n&&(s=n-e-this.padding),s<this.padding&&(s=this.padding),(o=this.x)+i+this.padding>r&&(o=r-i-this.padding),o<this.padding&&(o=this.padding);this.frame.style.left=o+"px",this.frame.style.top=s+"px",this.frame.style.visibility="visible",this.hidden=!1}else this.hide()}},{key:"hide",value:function(){this.hidden=!0,this.frame.style.left="0",this.frame.style.top="0",this.frame.style.visibility="hidden"}},{key:"destroy",value:function(){this.frame.parentNode.removeChild(this.frame)}}]),t}(),ob=!1,sb="background: #FFeeee; color: #dd0000",ab=function(){function t(){ga(this,t)}return Cc(t,null,[{key:"validate",value:function(e,i,n){ob=!1,ib=i;var r=i;return void 0!==n&&(r=i[n]),t.parse(e,r,[]),ob}},{key:"parse",value:function(e,i,n){for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.check(r,e,i,n)}},{key:"check",value:function(e,i,n,r){if(void 0!==n[e]||void 0!==n.__any__){var o=e,s=!0;void 0===n[e]&&void 0!==n.__any__&&(o="__any__",s="object"===t.getType(i[e]));var a=n[o];s&&void 0!==a.__type__&&(a=a.__type__),t.checkFields(e,i,n,o,a,r)}else t.getSuggestion(e,n,r)}},{key:"checkFields",value:function(e,i,n,r,o,s){var a=function(i){console.error("%c"+i+t.printLocation(s,e),sb)},l=t.getType(i[e]),h=o[l];void 0!==h?"array"===t.getType(h)&&-1===Rm(h).call(h,i[e])?(a('Invalid option detected in "'+e+'". Allowed values are:'+t.print(h)+' not "'+i[e]+'". '),ob=!0):"object"===l&&"__any__"!==r&&(s=jy(s,e),t.parse(i[e],n[r],s)):void 0===o.any&&(a('Invalid type received for "'+e+'". Expected: '+t.print(Bd(o))+". Received ["+l+'] "'+i[e]+'"'),ob=!0)}},{key:"getType",value:function(t){var e=kc(t);return"object"===e?null===t?"null":t instanceof Boolean?"boolean":t instanceof Number?"number":t instanceof String?"string":Id(t)?"array":t instanceof Date?"date":void 0!==t.nodeType?"dom":!0===t._isAMomentObject?"moment":"object":"number"===e?"number":"boolean"===e?"boolean":"string"===e?"string":void 0===e?"undefined":e}},{key:"getSuggestion",value:function(e,i,n){var r,o=t.findInOptions(e,i,n,!1),s=t.findInOptions(e,ib,[],!0);r=void 0!==o.indexMatch?" in "+t.printLocation(o.path,e,"")+'Perhaps it was incomplete? Did you mean: "'+o.indexMatch+'"?\n\n':s.distance<=4&&o.distance>s.distance?" in "+t.printLocation(o.path,e,"")+"Perhaps it was misplaced? Matching option found at: "+t.printLocation(s.path,s.closestMatch,""):o.distance<=8?'. Did you mean "'+o.closestMatch+'"?'+t.printLocation(o.path,e):". Did you mean one of these: "+t.print(Bd(i))+t.printLocation(n,e),console.error('%cUnknown option detected: "'+e+'"'+r,sb),ob=!0}},{key:"findInOptions",value:function(e,i,n){var r=arguments.length>3&&void 0!==arguments[3]&&arguments[3],o=1e9,s="",a=[],l=e.toLowerCase(),h=void 0;for(var u in i){var c=void 0;if(void 0!==i[u].__type__&&!0===r){var d=t.findInOptions(e,i[u],jy(n,u));o>d.distance&&(s=d.closestMatch,a=d.path,o=d.distance,h=d.indexMatch)}else{var p;-1!==Rm(p=u.toLowerCase()).call(p,l)&&(h=u),o>(c=t.levenshteinDistance(e,u))&&(s=u,a=Yy(n),o=c)}}return{closestMatch:s,path:a,distance:o,indexMatch:h}}},{key:"printLocation",value:function(t,e){for(var i="\n\n"+(arguments.length>2&&void 0!==arguments[2]?arguments[2]:"Problem value found at: \n")+"options = {\n",n=0;n<t.length;n++){for(var r=0;r<n+1;r++)i+="  ";i+=t[n]+": {\n"}for(var o=0;o<t.length+1;o++)i+="  ";i+=e+"\n";for(var s=0;s<t.length+1;s++){for(var a=0;a<t.length-s;a++)i+="  ";i+="}\n"}return i+"\n\n"}},{key:"print",value:function(t){return Wm(t).replace(/(")|(\[)|(\])|(,"__type__")/g,"").replace(/(,)/g,", ")}},{key:"levenshteinDistance",value:function(t,e){if(0===t.length)return e.length;if(0===e.length)return t.length;var i,n,r=[];for(i=0;i<=e.length;i++)r[i]=[i];for(n=0;n<=t.length;n++)r[0][n]=n;for(i=1;i<=e.length;i++)for(n=1;n<=t.length;n++)e.charAt(i-1)==t.charAt(n-1)?r[i][n]=r[i-1][n-1]:r[i][n]=Math.min(r[i-1][n-1]+1,Math.min(r[i][n-1]+1,r[i-1][n]+1));return r[e.length][t.length]}}]),t}(),lb=Dy,hb=tb,ub=nb,cb=Sy,db=rb,pb=sb,fb=ab,mb=Object.freeze({__proto__:null,Activator:lb,Alea:function(){for(var t=arguments.length,e=new Array(t),i=0;i<t;i++)e[i]=arguments[i];return function(t){var e=function(){for(var t=function(){var t=4022871197;return function(e){for(var i=e.toString(),n=0;n<i.length;n++){var r=.02519603282416938*(t+=i.charCodeAt(n));r-=t=r>>>0,t=(r*=t)>>>0,t+=4294967296*(r-=t)}return 2.3283064365386963e-10*(t>>>0)}}(),e=t(" "),i=t(" "),n=t(" "),r=0;r<arguments.length;r++)(e-=t(r<0||arguments.length<=r?void 0:arguments[r]))<0&&(e+=1),(i-=t(r<0||arguments.length<=r?void 0:arguments[r]))<0&&(i+=1),(n-=t(r<0||arguments.length<=r?void 0:arguments[r]))<0&&(n+=1);return[e,i,n]}(t),i=vd(e,3),n=i[0],r=i[1],o=i[2],s=1,a=function(){var t=2091639*n+2.3283064365386963e-10*s;return n=r,r=o,o=t-(s=0|t)};return a.uint32=function(){return 4294967296*a()},a.fract53=function(){return a()+11102230246251565e-32*(2097152*a()|0)},a.algorithm="Alea",a.seed=t,a.version="0.9",a}(e.length?e:[Vd()])},ColorPicker:hb,Configurator:ub,DELETE:yy,HSVToHex:Xy,HSVToRGB:Uy,Hammer:cb,Popup:db,RGBToHSV:Wy,RGBToHex:Gy,VALIDATOR_PRINT_STYLE:pb,Validator:fb,addClassName:function(t,e){var i=t.className.split(" "),n=e.split(" ");i=xd(i).call(i,Vf(n).call(n,(function(t){return!Af(i).call(i,t)}))),t.className=i.join(" ")},addCssText:function(t,e){for(var i=Vy(e),n=0,r=jm(i);n<r.length;n++){var o=vd(r[n],2),s=o[0],a=o[1];t.style.setProperty(s,a)}},addEventListener:function(t,e,i,n){var r;t.addEventListener?(void 0===n&&(n=!1),"mousewheel"===e&&Af(r=navigator.userAgent).call(r,"Firefox")&&(e="DOMMouseScroll"),t.addEventListener(e,i,n)):t.attachEvent("on"+e,i)},binarySearchCustom:function(t,e,i,n){for(var r=0,o=0,s=t.length-1;o<=s&&r<1e4;){var a=Math.floor((o+s)/2),l=t[a],h=e(void 0===n?l[i]:l[i][n]);if(0==h)return a;-1==h?o=a+1:s=a-1,r++}return-1},binarySearchValue:function(t,e,i,n,r){var o,s,a,l,h=0,u=0,c=t.length-1;for(r=null!=r?r:function(t,e){return t==e?0:t<e?-1:1};u<=c&&h<1e4;){if(l=Math.floor(.5*(c+u)),o=t[Math.max(0,l-1)][i],s=t[l][i],a=t[Math.min(t.length-1,l+1)][i],0==r(s,e))return l;if(r(o,e)<0&&r(s,e)>0)return"before"==n?Math.max(0,l-1):l;if(r(s,e)<0&&r(a,e)>0)return"before"==n?l:Math.min(t.length-1,l+1);r(s,e)<0?u=l+1:c=l-1,h++}return-1},bridgeObject:Jy,copyAndExtendArray:jy,copyArray:Yy,deepExtend:Ry,deepObjectAssign:_y,easingFunctions:{linear:function(t){return t},easeInQuad:function(t){return t*t},easeOutQuad:function(t){return t*(2-t)},easeInOutQuad:function(t){return t<.5?2*t*t:(4-2*t)*t-1},easeInCubic:function(t){return t*t*t},easeOutCubic:function(t){return--t*t*t+1},easeInOutCubic:function(t){return t<.5?4*t*t*t:(t-1)*(2*t-2)*(2*t-2)+1},easeInQuart:function(t){return t*t*t*t},easeOutQuart:function(t){return 1- --t*t*t*t},easeInOutQuart:function(t){return t<.5?8*t*t*t*t:1-8*--t*t*t*t},easeInQuint:function(t){return t*t*t*t*t},easeOutQuint:function(t){return 1+--t*t*t*t*t},easeInOutQuint:function(t){return t<.5?16*t*t*t*t*t:1+16*--t*t*t*t*t}},equalArray:function(t,e){if(t.length!==e.length)return!1;for(var i=0,n=t.length;i<n;i++)if(t[i]!=e[i])return!1;return!0},extend:Ny,fillIfDefined:function t(e,i){var n=arguments.length>2&&void 0!==arguments[2]&&arguments[2];for(var r in e)if(void 0!==i[r])if(null===i[r]||"object"!==kc(i[r]))Ay(e,i,r,n);else{var o=e[r],s=i[r];Ly(o)&&Ly(s)&&t(o,s,n)}},forEach:function(t,e){if(Id(t))for(var i=t.length,n=0;n<i;n++)e(t[n],n,t);else for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&e(t[r],r,t)},getAbsoluteLeft:function(t){return t.getBoundingClientRect().left},getAbsoluteRight:function(t){return t.getBoundingClientRect().right},getAbsoluteTop:function(t){return t.getBoundingClientRect().top},getScrollBarWidth:function(){var t=document.createElement("p");t.style.width="100%",t.style.height="200px";var e=document.createElement("div");e.style.position="absolute",e.style.top="0px",e.style.left="0px",e.style.visibility="hidden",e.style.width="200px",e.style.height="150px",e.style.overflow="hidden",e.appendChild(t),document.body.appendChild(e);var i=t.offsetWidth;e.style.overflow="scroll";var n=t.offsetWidth;return i==n&&(n=e.clientWidth),document.body.removeChild(e),i-n},getTarget:function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:window.event,e=null;return t&&(t.target?e=t.target:t.srcElement&&(e=t.srcElement)),e instanceof Element&&(null==e.nodeType||3!=e.nodeType||(e=e.parentNode)instanceof Element)?e:null},getType:Fy,hasParent:function(t,e){for(var i=t;i;){if(i===e)return!0;if(!i.parentNode)return!1;i=i.parentNode}return!1},hexToHSV:qy,hexToRGB:zy,insertSort:function(t,e){for(var i=0;i<t.length;i++){var n=t[i],r=void 0;for(r=i;r>0&&e(n,t[r-1])<0;r--)t[r]=t[r-1];t[r]=n}return t},isDate:function(t){if(t instanceof Date)return!0;if(Iy(t)){if(Cy.exec(t))return!0;if(!isNaN(Date.parse(t)))return!0}return!1},isNumber:Ey,isObject:Ly,isString:Iy,isValidHex:$y,isValidRGB:Ky,isValidRGBA:Zy,mergeOptions:function(t,e,i){var n=arguments.length>3&&void 0!==arguments[3]?arguments[3]:{},r=function(t){return null!=t},o=function(t){return null!==t&&"object"===kc(t)};if(!o(t))throw new Error("Parameter mergeTarget must be an object");if(!o(e))throw new Error("Parameter options must be an object");if(!r(i))throw new Error("Parameter option must have a value");if(!o(n))throw new Error("Parameter globalOptions must be an object");var s=e[i],a=o(n)&&!function(t){for(var e in t)if(Object.prototype.hasOwnProperty.call(t,e))return!1;return!0}(n)?n[i]:void 0,l=a?a.enabled:void 0;if(void 0!==s){if("boolean"==typeof s)return o(t[i])||(t[i]={}),void(t[i].enabled=s);if(null===s&&!o(t[i])){if(!r(a))return;t[i]=Bm(a)}if(o(s)){var h=!0;void 0!==s.enabled?h=s.enabled:void 0!==l&&(h=a.enabled),function(t,e,i){o(t[i])||(t[i]={});var n=e[i],r=t[i];for(var s in n)Object.prototype.hasOwnProperty.call(n,s)&&(r[s]=n[s])}(t,e,i),t[i].enabled=h}}},option:By,overrideOpacity:function(t,e){if(Af(t).call(t,"rgba"))return t;if(Af(t).call(t,"rgb")){var i=t.substr(Rm(t).call(t,"(")+1).replace(")","").split(",");return"rgba("+i[0]+","+i[1]+","+i[2]+","+e+")"}var n=zy(t);return null==n?t:"rgba("+n.r+","+n.g+","+n.b+","+e+")"},parseColor:function(t,e){if(Iy(t)){var i=t;if(Ky(i)){var n,r=jd(n=i.substr(4).substr(0,i.length-5).split(",")).call(n,(function(t){return Cm(t)}));i=Gy(r[0],r[1],r[2])}if(!0===$y(i)){var o=qy(i),s={h:o.h,s:.8*o.s,v:Math.min(1,1.02*o.v)},a={h:o.h,s:Math.min(1,1.25*o.s),v:.8*o.v},l=Xy(a.h,a.s,a.v),h=Xy(s.h,s.s,s.v);return{background:i,border:l,highlight:{background:h,border:l},hover:{background:h,border:l}}}return{background:i,border:i,highlight:{background:i,border:i},hover:{background:i,border:i}}}return e?{background:t.background||e.background,border:t.border||e.border,highlight:Iy(t.highlight)?{border:t.highlight,background:t.highlight}:{background:t.highlight&&t.highlight.background||e.highlight.background,border:t.highlight&&t.highlight.border||e.highlight.border},hover:Iy(t.hover)?{border:t.hover,background:t.hover}:{border:t.hover&&t.hover.border||e.hover.border,background:t.hover&&t.hover.background||e.hover.background}}:{background:t.background||void 0,border:t.border||void 0,highlight:Iy(t.highlight)?{border:t.highlight,background:t.highlight}:{background:t.highlight&&t.highlight.background||void 0,border:t.highlight&&t.highlight.border||void 0},hover:Iy(t.hover)?{border:t.hover,background:t.hover}:{border:t.hover&&t.hover.border||void 0,background:t.hover&&t.hover.background||void 0}}},preventDefault:function(t){t||(t=window.event),t&&(t.preventDefault?t.preventDefault():t.returnValue=!1)},pureDeepObjectAssign:by,recursiveDOMDelete:function t(e){if(e)for(;!0===e.hasChildNodes();){var i=e.firstChild;i&&(t(i),e.removeChild(i))}},removeClassName:function(t,e){var i=t.className.split(" "),n=e.split(" ");i=Vf(i).call(i,(function(t){return!Af(n).call(n,t)})),t.className=i.join(" ")},removeCssText:function(t,e){for(var i=Vy(e),n=0,r=Bd(i);n<r.length;n++){var o=r[n];t.style.removeProperty(o)}},removeEventListener:function(t,e,i,n){var r;t.removeEventListener?(void 0===n&&(n=!1),"mousewheel"===e&&Af(r=navigator.userAgent).call(r,"Firefox")&&(e="DOMMouseScroll"),t.removeEventListener(e,i,n)):t.detachEvent("on"+e,i)},selectiveBridgeObject:function(t,e){if(null!==e&&"object"===kc(e)){for(var i=Bm(e),n=0;n<t.length;n++)Object.prototype.hasOwnProperty.call(e,t[n])&&"object"==kc(e[t[n]])&&(i[t[n]]=Jy(e[t[n]]));return i}return null},selectiveDeepExtend:function(t,e,i){var n=arguments.length>3&&void 0!==arguments[3]&&arguments[3];if(Id(i))throw new TypeError("Arrays are not supported by deepExtend");for(var r=0;r<t.length;r++){var o=t[r];if(Object.prototype.hasOwnProperty.call(i,o))if(i[o]&&i[o].constructor===Object)void 0===e[o]&&(e[o]={}),e[o].constructor===Object?Ry(e[o],i[o],!1,n):Ay(e,i,o,n);else{if(Id(i[o]))throw new TypeError("Arrays are not supported by deepExtend");Ay(e,i,o,n)}}return e},selectiveExtend:function(t,e){if(!Id(t))throw new Error("Array with property names expected as first argument");for(var i=arguments.length,n=new Array(i>2?i-2:0),r=2;r<i;r++)n[r-2]=arguments[r];for(var o=0,s=n;o<s.length;o++)for(var a=s[o],l=0;l<t.length;l++){var h=t[l];a&&Object.prototype.hasOwnProperty.call(a,h)&&(e[h]=a[h])}return e},selectiveNotDeepExtend:function(t,e,i){var n=arguments.length>3&&void 0!==arguments[3]&&arguments[3];if(Id(i))throw new TypeError("Arrays are not supported by deepExtend");for(var r in i)if(Object.prototype.hasOwnProperty.call(i,r)&&!Af(t).call(t,r))if(i[r]&&i[r].constructor===Object)void 0===e[r]&&(e[r]={}),e[r].constructor===Object?Ry(e[r],i[r]):Ay(e,i,r,n);else if(Id(i[r])){e[r]=[];for(var o=0;o<i[r].length;o++)e[r].push(i[r][o])}else Ay(e,i,r,n);return e},throttle:function(t){var e=!1;return function(){e||(e=!0,requestAnimationFrame((function(){e=!1,t()})))}},toArray:Hy,topMost:function(t,e){var i;Id(e)||(e=[e]);var n,r=vy(t);try{for(r.s();!(n=r.n()).done;){var o=n.value;if(o){i=o[e[0]];for(var s=1;s<e.length;s++)i&&(i=i[e[s]]);if(void 0!==i)break}}}catch(t){r.e(t)}finally{r.f()}return i},updateProperty:function(t,e,i){return t[e]!==i&&(t[e]=i,!0)}});function vb(t){for(var e in t)t.hasOwnProperty(e)&&(t[e].redundant=t[e].used,t[e].used=[])}function gb(t){for(var e in t)if(t.hasOwnProperty(e)&&t[e].redundant){for(var i=0;i<t[e].redundant.length;i++)t[e].redundant[i].parentNode.removeChild(t[e].redundant[i]);t[e].redundant=[]}}function yb(t){vb(t),gb(t),vb(t)}function bb(t,e,i){var n;return e.hasOwnProperty(t)?e[t].redundant.length>0?(n=e[t].redundant[0],e[t].redundant.shift()):(n=document.createElementNS("http://www.w3.org/2000/svg",t),i.appendChild(n)):(n=document.createElementNS("http://www.w3.org/2000/svg",t),e[t]={used:[],redundant:[]},i.appendChild(n)),e[t].used.push(n),n}function _b(t,e,i,n){var r;return e.hasOwnProperty(t)?e[t].redundant.length>0?(r=e[t].redundant[0],e[t].redundant.shift()):(r=document.createElement(t),void 0!==n?i.insertBefore(r,n):i.appendChild(r)):(r=document.createElement(t),e[t]={used:[],redundant:[]},void 0!==n?i.insertBefore(r,n):i.appendChild(r)),e[t].used.push(r),r}function wb(t,e,i,n,r,o){var s;if("circle"==i.style?((s=bb("circle",n,r)).setAttributeNS(null,"cx",t),s.setAttributeNS(null,"cy",e),s.setAttributeNS(null,"r",.5*i.size)):((s=bb("rect",n,r)).setAttributeNS(null,"x",t-.5*i.size),s.setAttributeNS(null,"y",e-.5*i.size),s.setAttributeNS(null,"width",i.size),s.setAttributeNS(null,"height",i.size)),void 0!==i.styles&&s.setAttributeNS(null,"style",i.styles),s.setAttributeNS(null,"class",i.className+" vis-point"),o){var a=bb("text",n,r);o.xOffset&&(t+=o.xOffset),o.yOffset&&(e+=o.yOffset),o.content&&(a.textContent=o.content),o.className&&a.setAttributeNS(null,"class",o.className+" vis-label"),a.setAttributeNS(null,"x",t),a.setAttributeNS(null,"y",e)}return s}function kb(t,e,i,n,r,o,s,a){if(0!=n){n<0&&(e-=n*=-1);var l=bb("rect",o,s);l.setAttributeNS(null,"x",t-.5*i),l.setAttributeNS(null,"y",e),l.setAttributeNS(null,"width",i),l.setAttributeNS(null,"height",n),l.setAttributeNS(null,"class",r),a&&l.setAttributeNS(null,"style",a)}}function xb(){try{return navigator?navigator.languages&&navigator.languages.length?navigator.languages:navigator.userLanguage||navigator.language||navigator.browserLanguage||"en":"en"}catch(t){return"en"}}var Sb=Object.freeze({__proto__:null,cleanupElements:gb,drawBar:kb,drawPoint:wb,getDOMElement:_b,getNavigatorLanguage:xb,getSVGElement:bb,prepareElements:vb,resetElements:yb});function Db(t){if(void 0===t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return t}var Cb=Hm,Tb=n(Cb);Tn({target:"Object",stat:!0},{setPrototypeOf:yo});var Mb=ue.Object.setPrototypeOf,Ob=n(Mb),Pb=n(lp);function Eb(t,e){var i;return Eb=Ob?Pb(i=Ob).call(i):function(t,e){return t.__proto__=e,t},Eb(t,e)}function Ib(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function");t.prototype=Tb(e&&e.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),Ca(t,"prototype",{writable:!1}),e&&Eb(t,e)}function Lb(t,e){if(e&&("object"===kc(e)||"function"==typeof e))return e;if(void 0!==e)throw new TypeError("Derived constructors may only return object or undefined");return Db(t)}var Ab=jf,Nb=n(Ab);function Rb(t){var e;return Rb=Ob?Pb(e=Nb).call(e):function(t){return t.__proto__||Nb(t)},Rb(t)}function Fb(t,e,i){return(e=Sc(e))in t?Ca(t,e,{value:i,enumerable:!0,configurable:!0,writable:!0}):t[e]=i,t}var jb={exports:{}},Yb={exports:{}};!function(t){var e=gc,i=_c;function n(r){return t.exports=n="function"==typeof e&&"symbol"==typeof i?function(t){return typeof t}:function(t){return t&&"function"==typeof e&&t.constructor===e&&t!==e.prototype?"symbol":typeof t},t.exports.__esModule=!0,t.exports.default=t.exports,n(r)}t.exports=n,t.exports.__esModule=!0,t.exports.default=t.exports}(Yb);var Hb=Yb.exports,Bb=wp,zb=Y,Gb=Pd,Wb=Ai,Vb=$t,Ub=Xt,Xb=ai,qb=Error,$b=f("".replace),Kb=String(new qb("zxcasd").stack),Zb=/\n\s*at [^:]*:[^\n]*/,Jb=Zb.test(Kb),Qb=ri,t_=!l((function(){var t=new Error("a");return!("stack"in t)||(Object.defineProperty(t,"stack",Qb(1,7)),7!==t.stack)})),e_=ai,i_=t_,n_=Error.captureStackTrace,r_=mn,o_=he,s_=se,a_=xe,l_=Zo,h_=Bn,u_=ve,c_=Is,d_=Ds,p_=Vo,f_=TypeError,m_=function(t,e){this.stopped=t,this.result=e},v_=m_.prototype,g_=function(t,e,i){var n,r,o,s,a,l,h,u=i&&i.that,c=!(!i||!i.AS_ENTRIES),d=!(!i||!i.IS_RECORD),p=!(!i||!i.IS_ITERATOR),f=!(!i||!i.INTERRUPTED),m=r_(e,u),v=function(t){return n&&p_(n,"normal",t),new m_(!0,t)},g=function(t){return c?(s_(t),f?m(t[0],t[1],v):m(t[0],t[1])):f?m(t,v):m(t)};if(d)n=t.iterator;else if(p)n=t;else{if(!(r=d_(t)))throw new f_(a_(t)+" is not iterable");if(l_(r)){for(o=0,s=h_(t);s>o;o++)if((a=g(t[o]))&&u_(v_,a))return a;return new m_(!1)}n=c_(t,r)}for(l=d?t.next:n.next;!(h=o_(l,n)).done;){try{a=g(h.value)}catch(t){p_(n,"throw",t)}if("object"==typeof a&&a&&u_(v_,a))return a}return new m_(!1)},y_=It,b_=Tn,__=ve,w_=Rr,k_=yo,x_=Tr,S_=ai,D_=ri,C_=function(t,e,i,n){i_&&(n_?n_(t,e):e_(t,"stack",function(t,e){if(Jb&&"string"==typeof t&&!qb.prepareStackTrace)for(;e--;)t=$b(t,Zb,"");return t}(i,n)))},T_=g_,M_=dt("toStringTag"),O_=Error,P_=[].push,E_=function(t,e){var i,n=__(I_,this);k_?i=k_(new O_,n?w_(this):I_):(i=n?this:x_(I_),S_(i,M_,"Error")),void 0!==e&&S_(i,"message",function(t,e){return void 0===t?arguments.length<2?"":e:y_(t)}(e)),C_(i,E_,i.stack,1),arguments.length>2&&function(t,e){Ub(e)&&"cause"in e&&Xb(t,"cause",e.cause)}(i,arguments[2]);var r=[];return T_(t,P_,{that:r}),S_(i,"errors",r),i};k_?k_(E_,O_):function(t,e,i){for(var n=Gb(e),r=Vb.f,o=Wb.f,s=0;s<n.length;s++){var a=n[s];zb(t,a)||i&&zb(i,a)||r(t,a,o(e,a))}}(E_,O_,{name:!0});var I_=E_.prototype=x_(O_.prototype,{constructor:D_(1,E_),message:D_(1,""),name:D_(1,"AggregateError")});b_({global:!0,constructor:!0,arity:2},{AggregateError:E_});var L_,A_,N_,R_,F_="process"===kt(_.process),j_=me,Y_=yl,H_=qt,B_=dt("species"),z_=function(t){var e=j_(t);H_&&e&&!e[B_]&&Y_(e,B_,{configurable:!0,get:function(){return this}})},G_=ve,W_=TypeError,V_=function(t,e){if(G_(e,t))return t;throw new W_("Incorrect invocation")},U_=ms,X_=xe,q_=TypeError,$_=function(t){if(U_(t))return t;throw new q_(X_(t)+" is not a constructor")},K_=se,Z_=$_,J_=P,Q_=dt("species"),tw=function(t,e){var i,n=K_(t).constructor;return void 0===n||J_(i=K_(n)[Q_])?e:Z_(i)},ew=/(?:ipad|iphone|ipod).*applewebkit/i.test(V),iw=_,nw=Pi,rw=mn,ow=yt,sw=Y,aw=l,lw=ur,hw=uu,uw=Qt,cw=Xm,dw=ew,pw=F_,fw=iw.setImmediate,mw=iw.clearImmediate,vw=iw.process,gw=iw.Dispatch,yw=iw.Function,bw=iw.MessageChannel,_w=iw.String,ww=0,kw={},xw="onreadystatechange";aw((function(){L_=iw.location}));var Sw=function(t){if(sw(kw,t)){var e=kw[t];delete kw[t],e()}},Dw=function(t){return function(){Sw(t)}},Cw=function(t){Sw(t.data)},Tw=function(t){iw.postMessage(_w(t),L_.protocol+"//"+L_.host)};fw&&mw||(fw=function(t){cw(arguments.length,1);var e=ow(t)?t:yw(t),i=hw(arguments,1);return kw[++ww]=function(){nw(e,void 0,i)},A_(ww),ww},mw=function(t){delete kw[t]},pw?A_=function(t){vw.nextTick(Dw(t))}:gw&&gw.now?A_=function(t){gw.now(Dw(t))}:bw&&!dw?(R_=(N_=new bw).port2,N_.port1.onmessage=Cw,A_=rw(R_.postMessage,R_)):iw.addEventListener&&ow(iw.postMessage)&&!iw.importScripts&&L_&&"file:"!==L_.protocol&&!aw(Tw)?(A_=Tw,iw.addEventListener("message",Cw,!1)):A_=xw in uw("script")?function(t){lw.appendChild(uw("script"))[xw]=function(){lw.removeChild(this),Sw(t)}}:function(t){setTimeout(Dw(t),0)});var Mw={set:fw,clear:mw},Ow=function(){this.head=null,this.tail=null};Ow.prototype={add:function(t){var e={item:t,next:null},i=this.tail;i?i.next=e:this.head=e,this.tail=e},get:function(){var t=this.head;if(t)return null===(this.head=t.next)&&(this.tail=null),t.item}};var Pw,Ew,Iw,Lw,Aw,Nw=Ow,Rw=/ipad|iphone|ipod/i.test(V)&&"undefined"!=typeof Pebble,Fw=/web0s(?!.*chrome)/i.test(V),jw=_,Yw=mn,Hw=Ai.f,Bw=Mw.set,zw=Nw,Gw=ew,Ww=Rw,Vw=Fw,Uw=F_,Xw=jw.MutationObserver||jw.WebKitMutationObserver,qw=jw.document,$w=jw.process,Kw=jw.Promise,Zw=Hw(jw,"queueMicrotask"),Jw=Zw&&Zw.value;if(!Jw){var Qw=new zw,tk=function(){var t,e;for(Uw&&(t=$w.domain)&&t.exit();e=Qw.get();)try{e()}catch(t){throw Qw.head&&Pw(),t}t&&t.enter()};Gw||Uw||Vw||!Xw||!qw?!Ww&&Kw&&Kw.resolve?((Lw=Kw.resolve(void 0)).constructor=Kw,Aw=Yw(Lw.then,Lw),Pw=function(){Aw(tk)}):Uw?Pw=function(){$w.nextTick(tk)}:(Bw=Yw(Bw,jw),Pw=function(){Bw(tk)}):(Ew=!0,Iw=qw.createTextNode(""),new Xw(tk).observe(Iw,{characterData:!0}),Pw=function(){Iw.data=Ew=!Ew}),Jw=function(t){Qw.head||Pw(),Qw.add(t)}}var ek=Jw,ik=function(t){try{return{error:!1,value:t()}}catch(t){return{error:!0,value:t}}},nk=_.Promise,rk="object"==typeof Deno&&Deno&&"object"==typeof Deno.version,ok=!rk&&!F_&&"object"==typeof window&&"object"==typeof document,sk=_,ak=nk,lk=yt,hk=cn,uk=es,ck=dt,dk=ok,pk=rk,fk=J,mk=ak&&ak.prototype,vk=ck("species"),gk=!1,yk=lk(sk.PromiseRejectionEvent),bk=hk("Promise",(function(){var t=uk(ak),e=t!==String(ak);if(!e&&66===fk)return!0;if(!mk.catch||!mk.finally)return!0;if(!fk||fk<51||!/native code/.test(t)){var i=new ak((function(t){t(1)})),n=function(t){t((function(){}),(function(){}))};if((i.constructor={})[vk]=n,!(gk=i.then((function(){}))instanceof n))return!0}return!e&&(dk||pk)&&!yk})),_k={CONSTRUCTOR:bk,REJECTION_EVENT:yk,SUBCLASSING:gk},wk={},kk=Te,xk=TypeError,Sk=function(t){var e,i;this.promise=new t((function(t,n){if(void 0!==e||void 0!==i)throw new xk("Bad Promise constructor");e=t,i=n})),this.resolve=kk(e),this.reject=kk(i)};wk.f=function(t){return new Sk(t)};var Dk,Ck,Tk=Tn,Mk=F_,Ok=_,Pk=he,Ek=jr,Ik=no,Lk=z_,Ak=Te,Nk=yt,Rk=Xt,Fk=V_,jk=tw,Yk=Mw.set,Hk=ek,Bk=ik,zk=Nw,Gk=Di,Wk=nk,Vk=wk,Uk="Promise",Xk=_k.CONSTRUCTOR,qk=_k.REJECTION_EVENT,$k=Gk.getterFor(Uk),Kk=Gk.set,Zk=Wk&&Wk.prototype,Jk=Wk,Qk=Zk,tx=Ok.TypeError,ex=Ok.document,ix=Ok.process,nx=Vk.f,rx=nx,ox=!!(ex&&ex.createEvent&&Ok.dispatchEvent),sx="unhandledrejection",ax=function(t){var e;return!(!Rk(t)||!Nk(e=t.then))&&e},lx=function(t,e){var i,n,r,o=e.value,s=1===e.state,a=s?t.ok:t.fail,l=t.resolve,h=t.reject,u=t.domain;try{a?(s||(2===e.rejection&&px(e),e.rejection=1),!0===a?i=o:(u&&u.enter(),i=a(o),u&&(u.exit(),r=!0)),i===t.promise?h(new tx("Promise-chain cycle")):(n=ax(i))?Pk(n,i,l,h):l(i)):h(o)}catch(t){u&&!r&&u.exit(),h(t)}},hx=function(t,e){t.notified||(t.notified=!0,Hk((function(){for(var i,n=t.reactions;i=n.get();)lx(i,t);t.notified=!1,e&&!t.rejection&&cx(t)})))},ux=function(t,e,i){var n,r;ox?((n=ex.createEvent("Event")).promise=e,n.reason=i,n.initEvent(t,!1,!0),Ok.dispatchEvent(n)):n={promise:e,reason:i},!qk&&(r=Ok["on"+t])?r(n):t===sx&&function(t,e){try{1===arguments.length?console.error(t):console.error(t,e)}catch(t){}}("Unhandled promise rejection",i)},cx=function(t){Pk(Yk,Ok,(function(){var e,i=t.facade,n=t.value;if(dx(t)&&(e=Bk((function(){Mk?ix.emit("unhandledRejection",n,i):ux(sx,i,n)})),t.rejection=Mk||dx(t)?2:1,e.error))throw e.value}))},dx=function(t){return 1!==t.rejection&&!t.parent},px=function(t){Pk(Yk,Ok,(function(){var e=t.facade;Mk?ix.emit("rejectionHandled",e):ux("rejectionhandled",e,t.value)}))},fx=function(t,e,i){return function(n){t(e,n,i)}},mx=function(t,e,i){t.done||(t.done=!0,i&&(t=i),t.value=e,t.state=2,hx(t,!0))},vx=function(t,e,i){if(!t.done){t.done=!0,i&&(t=i);try{if(t.facade===e)throw new tx("Promise can't be resolved itself");var n=ax(e);n?Hk((function(){var i={done:!1};try{Pk(n,e,fx(vx,i,t),fx(mx,i,t))}catch(e){mx(i,e,t)}})):(t.value=e,t.state=1,hx(t,!1))}catch(e){mx({done:!1},e,t)}}};Xk&&(Qk=(Jk=function(t){Fk(this,Qk),Ak(t),Pk(Dk,this);var e=$k(this);try{t(fx(vx,e),fx(mx,e))}catch(t){mx(e,t)}}).prototype,(Dk=function(t){Kk(this,{type:Uk,done:!1,notified:!1,parent:!1,reactions:new zk,rejection:!1,state:0,value:void 0})}).prototype=Ek(Qk,"then",(function(t,e){var i=$k(this),n=nx(jk(this,Jk));return i.parent=!0,n.ok=!Nk(t)||t,n.fail=Nk(e)&&e,n.domain=Mk?ix.domain:void 0,0===i.state?i.reactions.add(n):Hk((function(){lx(n,i)})),n.promise})),Ck=function(){var t=new Dk,e=$k(t);this.promise=t,this.resolve=fx(vx,e),this.reject=fx(mx,e)},Vk.f=nx=function(t){return t===Jk||void 0===t?new Ck(t):rx(t)}),Tk({global:!0,constructor:!0,wrap:!0,forced:Xk},{Promise:Jk}),Ik(Jk,Uk,!1,!0),Lk(Uk);var gx=nk,yx=_k.CONSTRUCTOR||!qs((function(t){gx.all(t).then(void 0,(function(){}))})),bx=he,_x=Te,wx=wk,kx=ik,xx=g_;Tn({target:"Promise",stat:!0,forced:yx},{all:function(t){var e=this,i=wx.f(e),n=i.resolve,r=i.reject,o=kx((function(){var i=_x(e.resolve),o=[],s=0,a=1;xx(t,(function(t){var l=s++,h=!1;a++,bx(i,e,t).then((function(t){h||(h=!0,o[l]=t,--a||n(o))}),r)})),--a||n(o)}));return o.error&&r(o.value),i.promise}});var Sx=Tn,Dx=_k.CONSTRUCTOR;nk&&nk.prototype,Sx({target:"Promise",proto:!0,forced:Dx,real:!0},{catch:function(t){return this.then(void 0,t)}});var Cx=he,Tx=Te,Mx=wk,Ox=ik,Px=g_;Tn({target:"Promise",stat:!0,forced:yx},{race:function(t){var e=this,i=Mx.f(e),n=i.reject,r=Ox((function(){var r=Tx(e.resolve);Px(t,(function(t){Cx(r,e,t).then(i.resolve,n)}))}));return r.error&&n(r.value),i.promise}});var Ex=he,Ix=wk;Tn({target:"Promise",stat:!0,forced:_k.CONSTRUCTOR},{reject:function(t){var e=Ix.f(this);return Ex(e.reject,void 0,t),e.promise}});var Lx=se,Ax=Xt,Nx=wk,Rx=function(t,e){if(Lx(t),Ax(e)&&e.constructor===t)return e;var i=Nx.f(t);return(0,i.resolve)(e),i.promise},Fx=Tn,jx=nk,Yx=_k.CONSTRUCTOR,Hx=Rx,Bx=me("Promise"),zx=!Yx;Fx({target:"Promise",stat:!0,forced:!0},{resolve:function(t){return Hx(zx&&this===Bx?jx:this,t)}});var Gx=he,Wx=Te,Vx=wk,Ux=ik,Xx=g_;Tn({target:"Promise",stat:!0,forced:yx},{allSettled:function(t){var e=this,i=Vx.f(e),n=i.resolve,r=i.reject,o=Ux((function(){var i=Wx(e.resolve),r=[],o=0,s=1;Xx(t,(function(t){var a=o++,l=!1;s++,Gx(i,e,t).then((function(t){l||(l=!0,r[a]={status:"fulfilled",value:t},--s||n(r))}),(function(t){l||(l=!0,r[a]={status:"rejected",reason:t},--s||n(r))}))})),--s||n(r)}));return o.error&&r(o.value),i.promise}});var qx=he,$x=Te,Kx=me,Zx=wk,Jx=ik,Qx=g_,tS="No one promise resolved";Tn({target:"Promise",stat:!0,forced:yx},{any:function(t){var e=this,i=Kx("AggregateError"),n=Zx.f(e),r=n.resolve,o=n.reject,s=Jx((function(){var n=$x(e.resolve),s=[],a=0,l=1,h=!1;Qx(t,(function(t){var u=a++,c=!1;l++,qx(n,e,t).then((function(t){c||h||(h=!0,r(t))}),(function(t){c||h||(c=!0,s[u]=t,--l||o(new i(s,tS)))}))})),--l||o(new i(s,tS))}));return s.error&&o(s.value),n.promise}});var eS=Tn,iS=nk,nS=l,rS=me,oS=yt,sS=tw,aS=Rx,lS=iS&&iS.prototype;eS({target:"Promise",proto:!0,real:!0,forced:!!iS&&nS((function(){lS.finally.call({then:function(){}},(function(){}))}))},{finally:function(t){var e=sS(this,rS("Promise")),i=oS(t);return this.then(i?function(i){return aS(e,t()).then((function(){return i}))}:t,i?function(i){return aS(e,t()).then((function(){throw i}))}:t)}});var hS=ue.Promise,uS=wk;Tn({target:"Promise",stat:!0},{withResolvers:function(){var t=uS.f(this);return{promise:t.promise,resolve:t.resolve,reject:t.reject}}});var cS=hS,dS=wk,pS=ik;Tn({target:"Promise",stat:!0,forced:!0},{try:function(t){var e=dS.f(this),i=pS(t);return(i.error?e.reject:e.resolve)(i.value),e.promise}});var fS=cS,mS=Ep;!function(t){var e=Hb.default,i=Da,n=gc,r=Cb,o=Ab,s=Bb,a=Wc,l=Mb,h=fS,u=mS,c=cd;function d(){t.exports=d=function(){return f},t.exports.__esModule=!0,t.exports.default=t.exports;var p,f={},m=Object.prototype,v=m.hasOwnProperty,g=i||function(t,e,i){t[e]=i.value},y="function"==typeof n?n:{},b=y.iterator||"@@iterator",_=y.asyncIterator||"@@asyncIterator",w=y.toStringTag||"@@toStringTag";function k(t,e,n){return i(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}),t[e]}try{k({},"")}catch(p){k=function(t,e,i){return t[e]=i}}function x(t,e,i,n){var o=e&&e.prototype instanceof P?e:P,s=r(o.prototype),a=new z(n||[]);return g(s,"_invoke",{value:j(t,i,a)}),s}function S(t,e,i){try{return{type:"normal",arg:t.call(e,i)}}catch(t){return{type:"throw",arg:t}}}f.wrap=x;var D="suspendedStart",C="suspendedYield",T="executing",M="completed",O={};function P(){}function E(){}function I(){}var L={};k(L,b,(function(){return this}));var A=o&&o(o(G([])));A&&A!==m&&v.call(A,b)&&(L=A);var N=I.prototype=P.prototype=r(L);function R(t){var e;s(e=["next","throw","return"]).call(e,(function(e){k(t,e,(function(t){return this._invoke(e,t)}))}))}function F(t,i){function n(r,o,s,a){var l=S(t[r],t,o);if("throw"!==l.type){var h=l.arg,u=h.value;return u&&"object"==e(u)&&v.call(u,"__await")?i.resolve(u.__await).then((function(t){n("next",t,s,a)}),(function(t){n("throw",t,s,a)})):i.resolve(u).then((function(t){h.value=t,s(h)}),(function(t){return n("throw",t,s,a)}))}a(l.arg)}var r;g(this,"_invoke",{value:function(t,e){function o(){return new i((function(i,r){n(t,e,i,r)}))}return r=r?r.then(o,o):o()}})}function j(t,e,i){var n=D;return function(r,o){if(n===T)throw new Error("Generator is already running");if(n===M){if("throw"===r)throw o;return{value:p,done:!0}}for(i.method=r,i.arg=o;;){var s=i.delegate;if(s){var a=Y(s,i);if(a){if(a===O)continue;return a}}if("next"===i.method)i.sent=i._sent=i.arg;else if("throw"===i.method){if(n===D)throw n=M,i.arg;i.dispatchException(i.arg)}else"return"===i.method&&i.abrupt("return",i.arg);n=T;var l=S(t,e,i);if("normal"===l.type){if(n=i.done?M:C,l.arg===O)continue;return{value:l.arg,done:i.done}}"throw"===l.type&&(n=M,i.method="throw",i.arg=l.arg)}}}function Y(t,e){var i=e.method,n=t.iterator[i];if(n===p)return e.delegate=null,"throw"===i&&t.iterator.return&&(e.method="return",e.arg=p,Y(t,e),"throw"===e.method)||"return"!==i&&(e.method="throw",e.arg=new TypeError("The iterator does not provide a '"+i+"' method")),O;var r=S(n,t.iterator,e.arg);if("throw"===r.type)return e.method="throw",e.arg=r.arg,e.delegate=null,O;var o=r.arg;return o?o.done?(e[t.resultName]=o.value,e.next=t.nextLoc,"return"!==e.method&&(e.method="next",e.arg=p),e.delegate=null,O):o:(e.method="throw",e.arg=new TypeError("iterator result is not an object"),e.delegate=null,O)}function H(t){var e,i={tryLoc:t[0]};1 in t&&(i.catchLoc=t[1]),2 in t&&(i.finallyLoc=t[2],i.afterLoc=t[3]),a(e=this.tryEntries).call(e,i)}function B(t){var e=t.completion||{};e.type="normal",delete e.arg,t.completion=e}function z(t){this.tryEntries=[{tryLoc:"root"}],s(t).call(t,H,this),this.reset(!0)}function G(t){if(t||""===t){var i=t[b];if(i)return i.call(t);if("function"==typeof t.next)return t;if(!isNaN(t.length)){var n=-1,r=function e(){for(;++n<t.length;)if(v.call(t,n))return e.value=t[n],e.done=!1,e;return e.value=p,e.done=!0,e};return r.next=r}}throw new TypeError(e(t)+" is not iterable")}return E.prototype=I,g(N,"constructor",{value:I,configurable:!0}),g(I,"constructor",{value:E,configurable:!0}),E.displayName=k(I,w,"GeneratorFunction"),f.isGeneratorFunction=function(t){var e="function"==typeof t&&t.constructor;return!!e&&(e===E||"GeneratorFunction"===(e.displayName||e.name))},f.mark=function(t){return l?l(t,I):(t.__proto__=I,k(t,w,"GeneratorFunction")),t.prototype=r(N),t},f.awrap=function(t){return{__await:t}},R(F.prototype),k(F.prototype,_,(function(){return this})),f.AsyncIterator=F,f.async=function(t,e,i,n,r){void 0===r&&(r=h);var o=new F(x(t,e,i,n),r);return f.isGeneratorFunction(e)?o:o.next().then((function(t){return t.done?t.value:o.next()}))},R(N),k(N,w,"Generator"),k(N,b,(function(){return this})),k(N,"toString",(function(){return"[object Generator]"})),f.keys=function(t){var e=Object(t),i=[];for(var n in e)a(i).call(i,n);return u(i).call(i),function t(){for(;i.length;){var n=i.pop();if(n in e)return t.value=n,t.done=!1,t}return t.done=!0,t}},f.values=G,z.prototype={constructor:z,reset:function(t){var e;if(this.prev=0,this.next=0,this.sent=this._sent=p,this.done=!1,this.delegate=null,this.method="next",this.arg=p,s(e=this.tryEntries).call(e,B),!t)for(var i in this)"t"===i.charAt(0)&&v.call(this,i)&&!isNaN(+c(i).call(i,1))&&(this[i]=p)},stop:function(){this.done=!0;var t=this.tryEntries[0].completion;if("throw"===t.type)throw t.arg;return this.rval},dispatchException:function(t){if(this.done)throw t;var e=this;function i(i,n){return o.type="throw",o.arg=t,e.next=i,n&&(e.method="next",e.arg=p),!!n}for(var n=this.tryEntries.length-1;n>=0;--n){var r=this.tryEntries[n],o=r.completion;if("root"===r.tryLoc)return i("end");if(r.tryLoc<=this.prev){var s=v.call(r,"catchLoc"),a=v.call(r,"finallyLoc");if(s&&a){if(this.prev<r.catchLoc)return i(r.catchLoc,!0);if(this.prev<r.finallyLoc)return i(r.finallyLoc)}else if(s){if(this.prev<r.catchLoc)return i(r.catchLoc,!0)}else{if(!a)throw new Error("try statement without catch or finally");if(this.prev<r.finallyLoc)return i(r.finallyLoc)}}}},abrupt:function(t,e){for(var i=this.tryEntries.length-1;i>=0;--i){var n=this.tryEntries[i];if(n.tryLoc<=this.prev&&v.call(n,"finallyLoc")&&this.prev<n.finallyLoc){var r=n;break}}r&&("break"===t||"continue"===t)&&r.tryLoc<=e&&e<=r.finallyLoc&&(r=null);var o=r?r.completion:{};return o.type=t,o.arg=e,r?(this.method="next",this.next=r.finallyLoc,O):this.complete(o)},complete:function(t,e){if("throw"===t.type)throw t.arg;return"break"===t.type||"continue"===t.type?this.next=t.arg:"return"===t.type?(this.rval=this.arg=t.arg,this.method="return",this.next="end"):"normal"===t.type&&e&&(this.next=e),O},finish:function(t){for(var e=this.tryEntries.length-1;e>=0;--e){var i=this.tryEntries[e];if(i.finallyLoc===t)return this.complete(i.completion,i.afterLoc),B(i),O}},catch:function(t){for(var e=this.tryEntries.length-1;e>=0;--e){var i=this.tryEntries[e];if(i.tryLoc===t){var n=i.completion;if("throw"===n.type){var r=n.arg;B(i)}return r}}throw new Error("illegal catch attempt")},delegateYield:function(t,e,i){return this.delegate={iterator:G(t),resultName:e,nextLoc:i},"next"===this.method&&(this.arg=p),O}},f}t.exports=d,t.exports.__esModule=!0,t.exports.default=t.exports}(jb);var vS=(0,jb.exports)(),gS=vS;try{regeneratorRuntime=vS}catch(t){"object"==typeof globalThis?globalThis.regeneratorRuntime=vS:Function("r","regeneratorRuntime = r")(vS)}var yS=n(gS),bS=Te,_S=R,wS=Gi,kS=Bn,xS=TypeError,SS=function(t){return function(e,i,n,r){bS(i);var o=_S(e),s=wS(o),a=kS(o),l=t?a-1:0,h=t?-1:1;if(n<2)for(;;){if(l in s){r=s[l],l+=h;break}if(l+=h,t?l<0:a<=l)throw new xS("Reduce of empty array with no initial value")}for(;t?l>=0:a>l;l+=h)l in s&&(r=i(r,s[l],l,o));return r}},DS=[SS(!1),SS(!0)][0];Tn({target:"Array",proto:!0,forced:!F_&&J>79&&J<83||!cp("reduce")},{reduce:function(t){var e=arguments.length;return DS(this,t,e,e>1?arguments[1]:void 0)}});var CS=Yc("Array").reduce,TS=ve,MS=CS,OS=Array.prototype,PS=n((function(t){var e=t.reduce;return t===OS||TS(OS,t)&&e===OS.reduce?MS:e})),ES=Ma,IS=Bn,LS=Pa,AS=mn,NS=function(t,e,i,n,r,o,s,a){for(var l,h,u=r,c=0,d=!!s&&AS(s,a);c<n;)c in i&&(l=d?d(i[c],c,e):i[c],o>0&&ES(l)?(h=IS(l),u=NS(t,e,l,h,u,o-1)-1):(LS(u+1),t[u]=l),u++),c++;return u},RS=NS,FS=Te,jS=R,YS=Bn,HS=Ra;Tn({target:"Array",proto:!0},{flatMap:function(t){var e,i=jS(this),n=YS(i);return FS(t),(e=HS(i,0)).length=RS(e,i,i,n,0,1,t,arguments.length>1?arguments[1]:void 0),e}});var BS=Yc("Array").flatMap,zS=ve,GS=BS,WS=Array.prototype,VS=n((function(t){var e=t.flatMap;return t===WS||zS(WS,t)&&e===WS.flatMap?GS:e})),US={exports:{}},XS=l((function(){if("function"==typeof ArrayBuffer){var t=new ArrayBuffer(8);Object.isExtensible(t)&&Object.defineProperty(t,"a",{value:8})}})),qS=l,$S=Xt,KS=kt,ZS=XS,JS=Object.isExtensible,QS=qS((function(){JS(1)}))||ZS?function(t){return!!$S(t)&&(!ZS||"ArrayBuffer"!==KS(t))&&(!JS||JS(t))}:JS,tD=!l((function(){return Object.isExtensible(Object.preventExtensions({}))})),eD=Tn,iD=f,nD=ci,rD=Xt,oD=Y,sD=$t.f,aD=el,lD=rl,hD=QS,uD=tD,cD=!1,dD=W("meta"),pD=0,fD=function(t){sD(t,dD,{value:{objectID:"O"+pD++,weakData:{}}})},mD=US.exports={enable:function(){mD.enable=function(){},cD=!0;var t=aD.f,e=iD([].splice),i={};i[dD]=1,t(i).length&&(aD.f=function(i){for(var n=t(i),r=0,o=n.length;r<o;r++)if(n[r]===dD){e(n,r,1);break}return n},eD({target:"Object",stat:!0,forced:!0},{getOwnPropertyNames:lD.f}))},fastKey:function(t,e){if(!rD(t))return"symbol"==typeof t?t:("string"==typeof t?"S":"P")+t;if(!oD(t,dD)){if(!hD(t))return"F";if(!e)return"E";fD(t)}return t[dD].objectID},getWeakData:function(t,e){if(!oD(t,dD)){if(!hD(t))return!0;if(!e)return!1;fD(t)}return t[dD].weakData},onFreeze:function(t){return uD&&cD&&hD(t)&&!oD(t,dD)&&fD(t),t}};nD[dD]=!0;var vD=US.exports,gD=Tn,yD=_,bD=vD,_D=l,wD=ai,kD=g_,xD=V_,SD=yt,DD=Xt,CD=P,TD=no,MD=$t.f,OD=jl.forEach,PD=qt,ED=Di.set,ID=Di.getterFor,LD=function(t,e,i){var n,r=-1!==t.indexOf("Map"),o=-1!==t.indexOf("Weak"),s=r?"set":"add",a=yD[t],l=a&&a.prototype,h={};if(PD&&SD(a)&&(o||l.forEach&&!_D((function(){(new a).entries().next()})))){var u=(n=e((function(e,i){ED(xD(e,u),{type:t,collection:new a}),CD(i)||kD(i,e[s],{that:e,AS_ENTRIES:r})}))).prototype,c=ID(t);OD(["add","clear","delete","forEach","get","has","set","keys","values","entries"],(function(t){var e="add"===t||"set"===t;!(t in l)||o&&"clear"===t||wD(u,t,(function(i,n){var r=c(this).collection;if(!e&&o&&!DD(i))return"get"===t&&void 0;var s=r[t](0===i?0:i,n);return e?this:s}))})),o||MD(u,"size",{configurable:!0,get:function(){return c(this).collection.size}})}else n=i.getConstructor(e,t,r,s),bD.enable();return TD(n,t,!1,!0),h[t]=n,gD({global:!0,forced:!0},h),o||i.setStrong(n,t,r),n},AD=jr,ND=Tr,RD=yl,FD=function(t,e,i){for(var n in e)i&&i.unsafe&&t[n]?t[n]=e[n]:AD(t,n,e[n],i);return t},jD=mn,YD=V_,HD=P,BD=g_,zD=Io,GD=Lo,WD=z_,VD=qt,UD=vD.fastKey,XD=Di.set,qD=Di.getterFor,$D={getConstructor:function(t,e,i,n){var r=t((function(t,r){YD(t,o),XD(t,{type:e,index:ND(null),first:void 0,last:void 0,size:0}),VD||(t.size=0),HD(r)||BD(r,t[n],{that:t,AS_ENTRIES:i})})),o=r.prototype,s=qD(e),a=function(t,e,i){var n,r,o=s(t),a=l(t,e);return a?a.value=i:(o.last=a={index:r=UD(e,!0),key:e,value:i,previous:n=o.last,next:void 0,removed:!1},o.first||(o.first=a),n&&(n.next=a),VD?o.size++:t.size++,"F"!==r&&(o.index[r]=a)),t},l=function(t,e){var i,n=s(t),r=UD(e);if("F"!==r)return n.index[r];for(i=n.first;i;i=i.next)if(i.key===e)return i};return FD(o,{clear:function(){for(var t=s(this),e=t.index,i=t.first;i;)i.removed=!0,i.previous&&(i.previous=i.previous.next=void 0),delete e[i.index],i=i.next;t.first=t.last=void 0,VD?t.size=0:this.size=0},delete:function(t){var e=this,i=s(e),n=l(e,t);if(n){var r=n.next,o=n.previous;delete i.index[n.index],n.removed=!0,o&&(o.next=r),r&&(r.previous=o),i.first===n&&(i.first=r),i.last===n&&(i.last=o),VD?i.size--:e.size--}return!!n},forEach:function(t){for(var e,i=s(this),n=jD(t,arguments.length>1?arguments[1]:void 0);e=e?e.next:i.first;)for(n(e.value,e.key,this);e&&e.removed;)e=e.previous},has:function(t){return!!l(this,t)}}),FD(o,i?{get:function(t){var e=l(this,t);return e&&e.value},set:function(t,e){return a(this,0===t?0:t,e)}}:{add:function(t){return a(this,t=0===t?0:t,t)}}),VD&&RD(o,"size",{configurable:!0,get:function(){return s(this).size}}),r},setStrong:function(t,e,i){var n=e+" Iterator",r=qD(e),o=qD(n);zD(t,e,(function(t,e){XD(this,{type:n,target:t,state:r(t),kind:e,last:void 0})}),(function(){for(var t=o(this),e=t.kind,i=t.last;i&&i.removed;)i=i.previous;return t.target&&(t.last=i=i?i.next:t.state.first)?GD("keys"===e?i.key:"values"===e?i.value:[i.key,i.value],!1):(t.target=void 0,GD(void 0,!0))}),i?"entries":"values",!i,!0),WD(e)}};LD("Map",(function(t){return function(){return t(this,arguments.length?arguments[0]:void 0)}}),$D);var KD=n(ue.Map);LD("Set",(function(t){return function(){return t(this,arguments.length?arguments[0]:void 0)}}),$D);var ZD=n(ue.Set),JD=n(bc),QD=n(Is),tC=ul,eC=Math.floor,iC=function(t,e){var i=t.length,n=eC(i/2);return i<8?nC(t,e):rC(t,iC(tC(t,0,n),e),iC(tC(t,n),e),e)},nC=function(t,e){for(var i,n,r=t.length,o=1;o<r;){for(n=o,i=t[o];n&&e(t[n-1],i)>0;)t[n]=t[--n];n!==o++&&(t[n]=i)}return t},rC=function(t,e,i,n){for(var r=e.length,o=i.length,s=0,a=0;s<r||a<o;)t[s+a]=s<r&&a<o?n(e[s],i[a])<=0?e[s++]:i[a++]:s<r?e[s++]:i[a++];return t},oC=iC,sC=V.match(/firefox\/(\d+)/i),aC=!!sC&&+sC[1],lC=/MSIE|Trident/.test(V),hC=V.match(/AppleWebKit\/(\d+)\./),uC=!!hC&&+hC[1],cC=Tn,dC=f,pC=Te,fC=R,mC=Bn,vC=Np,gC=It,yC=l,bC=oC,_C=cp,wC=aC,kC=lC,xC=J,SC=uC,DC=[],CC=dC(DC.sort),TC=dC(DC.push),MC=yC((function(){DC.sort(void 0)})),OC=yC((function(){DC.sort(null)})),PC=_C("sort"),EC=!yC((function(){if(xC)return xC<70;if(!(wC&&wC>3)){if(kC)return!0;if(SC)return SC<603;var t,e,i,n,r="";for(t=65;t<76;t++){switch(e=String.fromCharCode(t),t){case 66:case 69:case 70:case 72:i=3;break;case 68:case 71:i=4;break;default:i=2}for(n=0;n<47;n++)DC.push({k:e+n,v:i})}for(DC.sort((function(t,e){return e.v-t.v})),n=0;n<DC.length;n++)e=DC[n].k.charAt(0),r.charAt(r.length-1)!==e&&(r+=e);return"DGBEFHACIJK"!==r}}));cC({target:"Array",proto:!0,forced:MC||!OC||!PC||!EC},{sort:function(t){void 0!==t&&pC(t);var e=fC(this);if(EC)return void 0===t?CC(e):CC(e,t);var i,n,r=[],o=mC(e);for(n=0;n<o;n++)n in e&&TC(r,e[n]);for(bC(r,function(t){return function(e,i){return void 0===i?-1:void 0===e?1:void 0!==t?+t(e,i)||0:gC(e)>gC(i)?1:-1}}(t)),i=mC(r),n=0;n<i;)e[n]=r[n++];for(;n<o;)vC(e,n++);return e}});var IC=Yc("Array").sort,LC=ve,AC=IC,NC=Array.prototype,RC=n((function(t){var e=t.sort;return t===NC||LC(NC,t)&&e===NC.sort?AC:e})),FC=jl.some;Tn({target:"Array",proto:!0,forced:!cp("some")},{some:function(t){return FC(this,t,arguments.length>1?arguments[1]:void 0)}});var jC=Yc("Array").some,YC=ve,HC=jC,BC=Array.prototype,zC=n((function(t){var e=t.some;return t===BC||YC(BC,t)&&e===BC.some?HC:e})),GC=Yc("Array").keys,WC=Ot,VC=Y,UC=ve,XC=GC,qC=Array.prototype,$C={DOMTokenList:!0,NodeList:!0},KC=n((function(t){var e=t.keys;return t===qC||UC(qC,t)&&e===qC.keys||VC($C,WC(t))?XC:e})),ZC=Yc("Array").values,JC=Ot,QC=Y,tT=ve,eT=ZC,iT=Array.prototype,nT={DOMTokenList:!0,NodeList:!0},rT=n((function(t){var e=t.values;return t===iT||tT(iT,t)&&e===iT.values||QC(nT,JC(t))?eT:e})),oT=Yc("Array").entries,sT=Ot,aT=Y,lT=ve,hT=oT,uT=Array.prototype,cT={DOMTokenList:!0,NodeList:!0},dT=n((function(t){var e=t.entries;return t===uT||lT(uT,t)&&e===uT.entries||aT(cT,sT(t))?hT:e})),pT=n(Sa),fT=Tn,mT=Pi,vT=ip,gT=$_,yT=se,bT=Xt,_T=Tr,wT=l,kT=me("Reflect","construct"),xT=Object.prototype,ST=[].push,DT=wT((function(){function t(){}return!(kT((function(){}),[],t)instanceof t)})),CT=!wT((function(){kT((function(){}))})),TT=DT||CT;fT({target:"Reflect",stat:!0,forced:TT,sham:TT},{construct:function(t,e){gT(t),yT(e);var i=arguments.length<3?t:gT(arguments[2]);if(CT&&!DT)return kT(t,e,i);if(t===i){switch(e.length){case 0:return new t;case 1:return new t(e[0]);case 2:return new t(e[0],e[1]);case 3:return new t(e[0],e[1],e[2]);case 4:return new t(e[0],e[1],e[2],e[3])}var n=[null];return mT(ST,n,e),new(mT(vT,t,n))}var r=i.prototype,o=_T(bT(r)?r:xT),s=mT(t,o,e);return bT(s)?s:o}});var MT=n(ue.Reflect.construct),OT=n(ue.Object.getOwnPropertySymbols),PT={exports:{}},ET=Tn,IT=l,LT=Ui,AT=Ai.f,NT=qt;ET({target:"Object",stat:!0,forced:!NT||IT((function(){AT(1)})),sham:!NT},{getOwnPropertyDescriptor:function(t,e){return AT(LT(t),e)}});var RT=ue.Object,FT=PT.exports=function(t,e){return RT.getOwnPropertyDescriptor(t,e)};RT.getOwnPropertyDescriptor.sham&&(FT.sham=!0);var jT=n(PT.exports),YT=Pd,HT=Ui,BT=Ai,zT=bs;Tn({target:"Object",stat:!0,sham:!qt},{getOwnPropertyDescriptors:function(t){for(var e,i,n=HT(t),r=BT.f,o=YT(n),s={},a=0;o.length>a;)void 0!==(i=r(n,e=o[a++]))&&zT(s,e,i);return s}});var GT=n(ue.Object.getOwnPropertyDescriptors),WT={exports:{}},VT=Tn,UT=qt,XT=An.f;VT({target:"Object",stat:!0,forced:Object.defineProperties!==XT,sham:!UT},{defineProperties:XT});var qT=ue.Object,$T=WT.exports=function(t,e){return qT.defineProperties(t,e)};qT.defineProperties.sham&&($T.sham=!0);var KT=n(WT.exports);let ZT;const JT=new Uint8Array(16);function QT(){if(!ZT&&(ZT="undefined"!=typeof crypto&&crypto.getRandomValues&&crypto.getRandomValues.bind(crypto),!ZT))throw new Error("crypto.getRandomValues() not supported. See https://github.com/uuidjs/uuid#getrandomvalues-not-supported");return ZT(JT)}const tM=[];for(let t=0;t<256;++t)tM.push((t+256).toString(16).slice(1));var eM,iM={randomUUID:"undefined"!=typeof crypto&&crypto.randomUUID&&crypto.randomUUID.bind(crypto)};function nM(t,e,i){if(iM.randomUUID&&!e&&!t)return iM.randomUUID();const n=(t=t||{}).random||(t.rng||QT)();if(n[6]=15&n[6]|64,n[8]=63&n[8]|128,e){i=i||0;for(let t=0;t<16;++t)e[i+t]=n[t];return e}return function(t,e=0){return tM[t[e+0]]+tM[t[e+1]]+tM[t[e+2]]+tM[t[e+3]]+"-"+tM[t[e+4]]+tM[t[e+5]]+"-"+tM[t[e+6]]+tM[t[e+7]]+"-"+tM[t[e+8]]+tM[t[e+9]]+"-"+tM[t[e+10]]+tM[t[e+11]]+tM[t[e+12]]+tM[t[e+13]]+tM[t[e+14]]+tM[t[e+15]]}(n)}function rM(t,e){var i=Bd(t);if(OT){var n=OT(t);e&&(n=Vf(n).call(n,(function(e){return jT(t,e).enumerable}))),i.push.apply(i,n)}return i}function oM(t){for(var e=1;e<arguments.length;e++){var i,n,r=null!=arguments[e]?arguments[e]:{};e%2?kp(i=rM(Object(r),!0)).call(i,(function(e){Fb(t,e,r[e])})):GT?KT(t,GT(r)):kp(n=rM(Object(r))).call(n,(function(e){pT(t,e,jT(r,e))}))}return t}function sM(t){var e=function(){if("undefined"==typeof Reflect||!MT)return!1;if(MT.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(MT(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var i,n=Rb(t);if(e){var r=Rb(this).constructor;i=MT(n,arguments,r)}else i=n.apply(this,arguments);return Lb(this,i)}}function aM(t,e){var i=void 0!==yd&&va(t)||t["@@iterator"];if(!i){if(Id(t)||(i=function(t,e){var i;if(t){if("string"==typeof t)return lM(t,e);var n=Sd(i=Object.prototype.toString.call(t)).call(i,8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Ks(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?lM(t,e):void 0}}(t))||e&&t&&"number"==typeof t.length){i&&(t=i);var n=0,r=function(){};return{s:r,n:function(){return n>=t.length?{done:!0}:{done:!1,value:t[n++]}},e:function(t){throw t},f:r}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var o,s=!0,a=!1;return{s:function(){i=i.call(t)},n:function(){var t=i.next();return s=t.done,t},e:function(t){a=!0,o=t},f:function(){try{s||null==i.return||i.return()}finally{if(a)throw o}}}}function lM(t,e){(null==e||e>t.length)&&(e=t.length);for(var i=0,n=new Array(e);i<e;i++)n[i]=t[i];return n}var hM=function(){function t(e,i,n){var r,o,s;ga(this,t),Fb(this,"_source",void 0),Fb(this,"_transformers",void 0),Fb(this,"_target",void 0),Fb(this,"_listeners",{add:hp(r=this._add).call(r,this),remove:hp(o=this._remove).call(o,this),update:hp(s=this._update).call(s,this)}),this._source=e,this._transformers=i,this._target=n}return Cc(t,[{key:"all",value:function(){return this._target.update(this._transformItems(this._source.get())),this}},{key:"start",value:function(){return this._source.on("add",this._listeners.add),this._source.on("remove",this._listeners.remove),this._source.on("update",this._listeners.update),this}},{key:"stop",value:function(){return this._source.off("add",this._listeners.add),this._source.off("remove",this._listeners.remove),this._source.off("update",this._listeners.update),this}},{key:"_transformItems",value:function(t){var e;return PS(e=this._transformers).call(e,(function(t,e){return e(t)}),t)}},{key:"_add",value:function(t,e){null!=e&&this._target.add(this._transformItems(this._source.get(e.items)))}},{key:"_update",value:function(t,e){null!=e&&this._target.update(this._transformItems(this._source.get(e.items)))}},{key:"_remove",value:function(t,e){null!=e&&this._target.remove(this._transformItems(e.oldData))}}]),t}(),uM=function(){function t(e){ga(this,t),Fb(this,"_source",void 0),Fb(this,"_transformers",[]),this._source=e}return Cc(t,[{key:"filter",value:function(t){return this._transformers.push((function(e){return Vf(e).call(e,t)})),this}},{key:"map",value:function(t){return this._transformers.push((function(e){return jd(e).call(e,t)})),this}},{key:"flatMap",value:function(t){return this._transformers.push((function(e){return VS(e).call(e,t)})),this}},{key:"to",value:function(t){return new hM(this._source,this._transformers,t)}}]),t}();function cM(t){return"string"==typeof t||"number"==typeof t}var dM=function(){function t(e){ga(this,t),Fb(this,"delay",void 0),Fb(this,"max",void 0),Fb(this,"_queue",[]),Fb(this,"_timeout",null),Fb(this,"_extended",null),this.delay=null,this.max=1/0,this.setOptions(e)}return Cc(t,[{key:"setOptions",value:function(t){t&&void 0!==t.delay&&(this.delay=t.delay),t&&void 0!==t.max&&(this.max=t.max),this._flushIfNeeded()}},{key:"destroy",value:function(){if(this.flush(),this._extended){for(var t=this._extended.object,e=this._extended.methods,i=0;i<e.length;i++){var n=e[i];n.original?t[n.name]=n.original:delete t[n.name]}this._extended=null}}},{key:"replace",value:function(t,e){var i=this,n=t[e];if(!n)throw new Error("Method "+e+" undefined");t[e]=function(){for(var t=arguments.length,e=new Array(t),r=0;r<t;r++)e[r]=arguments[r];i.queue({args:e,fn:n,context:this})}}},{key:"queue",value:function(t){"function"==typeof t?this._queue.push({fn:t}):this._queue.push(t),this._flushIfNeeded()}},{key:"_flushIfNeeded",value:function(){var t=this;this._queue.length>this.max&&this.flush(),null!=this._timeout&&(clearTimeout(this._timeout),this._timeout=null),this.queue.length>0&&"number"==typeof this.delay&&(this._timeout=uv((function(){t.flush()}),this.delay))}},{key:"flush",value:function(){var t,e;kp(t=Qp(e=this._queue).call(e,0)).call(t,(function(t){t.fn.apply(t.context||t.fn,t.args||[])}))}}],[{key:"extend",value:function(e,i){var n=new t(i);if(void 0!==e.flush)throw new Error("Target object already has a property flush");e.flush=function(){n.flush()};var r=[{name:"flush",original:void 0}];if(i&&i.replace)for(var o=0;o<i.replace.length;o++){var s=i.replace[o];r.push({name:s,original:e[s]}),n.replace(e,s)}return n._extended={object:e,methods:r},n}}]),t}(),pM=function(){function t(){ga(this,t),Fb(this,"_subscribers",{"*":[],add:[],remove:[],update:[]}),Fb(this,"subscribe",t.prototype.on),Fb(this,"unsubscribe",t.prototype.off)}return Cc(t,[{key:"_trigger",value:function(t,e,i){var n,r;if("*"===t)throw new Error("Cannot trigger event *");kp(n=xd(r=[]).call(r,gd(this._subscribers[t]),gd(this._subscribers["*"]))).call(n,(function(n){n(t,e,null!=i?i:null)}))}},{key:"on",value:function(t,e){"function"==typeof e&&this._subscribers[t].push(e)}},{key:"off",value:function(t,e){var i;this._subscribers[t]=Vf(i=this._subscribers[t]).call(i,(function(t){return t!==e}))}}]),t}();eM=JD;var fM=function(){function t(e){ga(this,t),Fb(this,"_pairs",void 0),this._pairs=e}return Cc(t,[{key:eM,value:yS.mark((function t(){var e,i,n,r,o;return yS.wrap((function(t){for(;;)switch(t.prev=t.next){case 0:e=aM(this._pairs),t.prev=1,e.s();case 3:if((i=e.n()).done){t.next=9;break}return n=vd(i.value,2),r=n[0],o=n[1],t.next=7,[r,o];case 7:t.next=3;break;case 9:t.next=14;break;case 11:t.prev=11,t.t0=t.catch(1),e.e(t.t0);case 14:return t.prev=14,e.f(),t.finish(14);case 17:case"end":return t.stop()}}),t,this,[[1,11,14,17]])}))},{key:"entries",value:yS.mark((function t(){var e,i,n,r,o;return yS.wrap((function(t){for(;;)switch(t.prev=t.next){case 0:e=aM(this._pairs),t.prev=1,e.s();case 3:if((i=e.n()).done){t.next=9;break}return n=vd(i.value,2),r=n[0],o=n[1],t.next=7,[r,o];case 7:t.next=3;break;case 9:t.next=14;break;case 11:t.prev=11,t.t0=t.catch(1),e.e(t.t0);case 14:return t.prev=14,e.f(),t.finish(14);case 17:case"end":return t.stop()}}),t,this,[[1,11,14,17]])}))},{key:"keys",value:yS.mark((function t(){var e,i,n,r;return yS.wrap((function(t){for(;;)switch(t.prev=t.next){case 0:e=aM(this._pairs),t.prev=1,e.s();case 3:if((i=e.n()).done){t.next=9;break}return n=vd(i.value,1),r=n[0],t.next=7,r;case 7:t.next=3;break;case 9:t.next=14;break;case 11:t.prev=11,t.t0=t.catch(1),e.e(t.t0);case 14:return t.prev=14,e.f(),t.finish(14);case 17:case"end":return t.stop()}}),t,this,[[1,11,14,17]])}))},{key:"values",value:yS.mark((function t(){var e,i,n,r;return yS.wrap((function(t){for(;;)switch(t.prev=t.next){case 0:e=aM(this._pairs),t.prev=1,e.s();case 3:if((i=e.n()).done){t.next=9;break}return n=vd(i.value,2),r=n[1],t.next=7,r;case 7:t.next=3;break;case 9:t.next=14;break;case 11:t.prev=11,t.t0=t.catch(1),e.e(t.t0);case 14:return t.prev=14,e.f(),t.finish(14);case 17:case"end":return t.stop()}}),t,this,[[1,11,14,17]])}))},{key:"toIdArray",value:function(){var t;return jd(t=gd(this._pairs)).call(t,(function(t){return t[0]}))}},{key:"toItemArray",value:function(){var t;return jd(t=gd(this._pairs)).call(t,(function(t){return t[1]}))}},{key:"toEntryArray",value:function(){return gd(this._pairs)}},{key:"toObjectMap",value:function(){var t,e=Bm(null),i=aM(this._pairs);try{for(i.s();!(t=i.n()).done;){var n=vd(t.value,2),r=n[0],o=n[1];e[r]=o}}catch(t){i.e(t)}finally{i.f()}return e}},{key:"toMap",value:function(){return new KD(this._pairs)}},{key:"toIdSet",value:function(){return new ZD(this.toIdArray())}},{key:"toItemSet",value:function(){return new ZD(this.toItemArray())}},{key:"cache",value:function(){return new t(gd(this._pairs))}},{key:"distinct",value:function(t){var e,i=new ZD,n=aM(this._pairs);try{for(n.s();!(e=n.n()).done;){var r=vd(e.value,2),o=r[0],s=r[1];i.add(t(s,o))}}catch(t){n.e(t)}finally{n.f()}return i}},{key:"filter",value:function(e){var i=this._pairs;return new t(Fb({},JD,yS.mark((function t(){var n,r,o,s,a;return yS.wrap((function(t){for(;;)switch(t.prev=t.next){case 0:n=aM(i),t.prev=1,n.s();case 3:if((r=n.n()).done){t.next=10;break}if(o=vd(r.value,2),s=o[0],a=o[1],!e(a,s)){t.next=8;break}return t.next=8,[s,a];case 8:t.next=3;break;case 10:t.next=15;break;case 12:t.prev=12,t.t0=t.catch(1),n.e(t.t0);case 15:return t.prev=15,n.f(),t.finish(15);case 18:case"end":return t.stop()}}),t,null,[[1,12,15,18]])}))))}},{key:"forEach",value:function(t){var e,i=aM(this._pairs);try{for(i.s();!(e=i.n()).done;){var n=vd(e.value,2),r=n[0];t(n[1],r)}}catch(t){i.e(t)}finally{i.f()}}},{key:"map",value:function(e){var i=this._pairs;return new t(Fb({},JD,yS.mark((function t(){var n,r,o,s,a;return yS.wrap((function(t){for(;;)switch(t.prev=t.next){case 0:n=aM(i),t.prev=1,n.s();case 3:if((r=n.n()).done){t.next=9;break}return o=vd(r.value,2),s=o[0],a=o[1],t.next=7,[s,e(a,s)];case 7:t.next=3;break;case 9:t.next=14;break;case 11:t.prev=11,t.t0=t.catch(1),n.e(t.t0);case 14:return t.prev=14,n.f(),t.finish(14);case 17:case"end":return t.stop()}}),t,null,[[1,11,14,17]])}))))}},{key:"max",value:function(t){var e=QD(this._pairs),i=e.next();if(i.done)return null;for(var n=i.value[1],r=t(i.value[1],i.value[0]);!(i=e.next()).done;){var o=vd(i.value,2),s=o[0],a=o[1],l=t(a,s);l>r&&(r=l,n=a)}return n}},{key:"min",value:function(t){var e=QD(this._pairs),i=e.next();if(i.done)return null;for(var n=i.value[1],r=t(i.value[1],i.value[0]);!(i=e.next()).done;){var o=vd(i.value,2),s=o[0],a=o[1],l=t(a,s);l<r&&(r=l,n=a)}return n}},{key:"reduce",value:function(t,e){var i,n=aM(this._pairs);try{for(n.s();!(i=n.n()).done;){var r=vd(i.value,2),o=r[0];e=t(e,r[1],o)}}catch(t){n.e(t)}finally{n.f()}return e}},{key:"sort",value:function(e){var i=this;return new t(Fb({},JD,(function(){var t;return QD(RC(t=gd(i._pairs)).call(t,(function(t,i){var n=vd(t,2),r=n[0],o=n[1],s=vd(i,2),a=s[0],l=s[1];return e(o,l,r,a)})))})))}}]),t}(),mM=function(t){Ib(i,t);var e=sM(i);function i(t,n){var r;return ga(this,i),Fb(Db(r=e.call(this)),"flush",void 0),Fb(Db(r),"length",void 0),Fb(Db(r),"_options",void 0),Fb(Db(r),"_data",void 0),Fb(Db(r),"_idProp",void 0),Fb(Db(r),"_queue",null),t&&!Id(t)&&(n=t,t=[]),r._options=n||{},r._data=new KD,r.length=0,r._idProp=r._options.fieldId||"id",t&&t.length&&r.add(t),r.setOptions(n),r}return Cc(i,[{key:"idProp",get:function(){return this._idProp}},{key:"setOptions",value:function(t){t&&void 0!==t.queue&&(!1===t.queue?this._queue&&(this._queue.destroy(),this._queue=null):(this._queue||(this._queue=dM.extend(this,{replace:["add","update","remove"]})),t.queue&&"object"===kc(t.queue)&&this._queue.setOptions(t.queue)))}},{key:"add",value:function(t,e){var i,n=this,r=[];if(Id(t)){var o=jd(t).call(t,(function(t){return t[n._idProp]}));if(zC(o).call(o,(function(t){return n._data.has(t)})))throw new Error("A duplicate id was found in the parameter array.");for(var s=0,a=t.length;s<a;s++)i=this._addItem(t[s]),r.push(i)}else{if(!t||"object"!==kc(t))throw new Error("Unknown dataType");i=this._addItem(t),r.push(i)}return r.length&&this._trigger("add",{items:r},e),r}},{key:"update",value:function(t,e){var i=this,n=[],r=[],o=[],s=[],a=this._idProp,l=function(t){var e=t[a];if(null!=e&&i._data.has(e)){var l=t,h=mf({},i._data.get(e)),u=i._updateItem(l);r.push(u),s.push(l),o.push(h)}else{var c=i._addItem(t);n.push(c)}};if(Id(t))for(var h=0,u=t.length;h<u;h++)t[h]&&"object"===kc(t[h])?l(t[h]):console.warn("Ignoring input item, which is not an object at index "+h);else{if(!t||"object"!==kc(t))throw new Error("Unknown dataType");l(t)}if(n.length&&this._trigger("add",{items:n},e),r.length){var c={items:r,oldData:o,data:s};this._trigger("update",c,e)}return xd(n).call(n,r)}},{key:"updateOnly",value:function(t,e){var i,n=this;Id(t)||(t=[t]);var r=jd(i=jd(t).call(t,(function(t){var e=n._data.get(t[n._idProp]);if(null==e)throw new Error("Updating non-existent items is not allowed.");return{oldData:e,update:t}}))).call(i,(function(t){var e=t.oldData,i=t.update,r=e[n._idProp],o=by(e,i);return n._data.set(r,o),{id:r,oldData:e,updatedData:o}}));if(r.length){var o={items:jd(r).call(r,(function(t){return t.id})),oldData:jd(r).call(r,(function(t){return t.oldData})),data:jd(r).call(r,(function(t){return t.updatedData}))};return this._trigger("update",o,e),o.items}return[]}},{key:"get",value:function(t,e){var i=void 0,n=void 0,r=void 0;cM(t)?(i=t,r=e):Id(t)?(n=t,r=e):r=t;var o,s=r&&"Object"===r.returnType?"Object":"Array",a=r&&Vf(r),l=[],h=void 0,u=void 0,c=void 0;if(null!=i)(h=this._data.get(i))&&a&&!a(h)&&(h=void 0);else if(null!=n)for(var d=0,p=n.length;d<p;d++)null==(h=this._data.get(n[d]))||a&&!a(h)||l.push(h);else for(var f,m=0,v=(u=gd(KC(f=this._data).call(f))).length;m<v;m++)c=u[m],null==(h=this._data.get(c))||a&&!a(h)||l.push(h);if(r&&r.order&&null==i&&this._sort(l,r.order),r&&r.fields){var g=r.fields;if(null!=i&&null!=h)h=this._filterFields(h,g);else for(var y=0,b=l.length;y<b;y++)l[y]=this._filterFields(l[y],g)}if("Object"==s){for(var _={},w=0,k=l.length;w<k;w++){var x=l[w];_[x[this._idProp]]=x}return _}return null!=i?null!==(o=h)&&void 0!==o?o:null:l}},{key:"getIds",value:function(t){var e=this._data,i=t&&Vf(t),n=t&&t.order,r=gd(KC(e).call(e)),o=[];if(i)if(n){for(var s=[],a=0,l=r.length;a<l;a++){var h=r[a],u=this._data.get(h);null!=u&&i(u)&&s.push(u)}this._sort(s,n);for(var c=0,d=s.length;c<d;c++)o.push(s[c][this._idProp])}else for(var p=0,f=r.length;p<f;p++){var m=r[p],v=this._data.get(m);null!=v&&i(v)&&o.push(v[this._idProp])}else if(n){for(var g=[],y=0,b=r.length;y<b;y++){var _=r[y];g.push(e.get(_))}this._sort(g,n);for(var w=0,k=g.length;w<k;w++)o.push(g[w][this._idProp])}else for(var x=0,S=r.length;x<S;x++){var D=r[x],C=e.get(D);null!=C&&o.push(C[this._idProp])}return o}},{key:"getDataSet",value:function(){return this}},{key:"forEach",value:function(t,e){var i=e&&Vf(e),n=this._data,r=gd(KC(n).call(n));if(e&&e.order)for(var o=this.get(e),s=0,a=o.length;s<a;s++){var l=o[s];t(l,l[this._idProp])}else for(var h=0,u=r.length;h<u;h++){var c=r[h],d=this._data.get(c);null==d||i&&!i(d)||t(d,c)}}},{key:"map",value:function(t,e){for(var i=e&&Vf(e),n=[],r=this._data,o=gd(KC(r).call(r)),s=0,a=o.length;s<a;s++){var l=o[s],h=this._data.get(l);null==h||i&&!i(h)||n.push(t(h,l))}return e&&e.order&&this._sort(n,e.order),n}},{key:"_filterFields",value:function(t,e){var i;return t?PS(i=Id(e)?e:Bd(e)).call(i,(function(e,i){return e[i]=t[i],e}),{}):t}},{key:"_sort",value:function(t,e){if("string"==typeof e){var i=e;RC(t).call(t,(function(t,e){var n=t[i],r=e[i];return n>r?1:n<r?-1:0}))}else{if("function"!=typeof e)throw new TypeError("Order must be a function or a string");RC(t).call(t,e)}}},{key:"remove",value:function(t,e){for(var i=[],n=[],r=Id(t)?t:[t],o=0,s=r.length;o<s;o++){var a=this._remove(r[o]);if(a){var l=a[this._idProp];null!=l&&(i.push(l),n.push(a))}}return i.length&&this._trigger("remove",{items:i,oldData:n},e),i}},{key:"_remove",value:function(t){var e;if(cM(t)?e=t:t&&"object"===kc(t)&&(e=t[this._idProp]),null!=e&&this._data.has(e)){var i=this._data.get(e)||null;return this._data.delete(e),--this.length,i}return null}},{key:"clear",value:function(t){for(var e,i=gd(KC(e=this._data).call(e)),n=[],r=0,o=i.length;r<o;r++)n.push(this._data.get(i[r]));return this._data.clear(),this.length=0,this._trigger("remove",{items:i,oldData:n},t),i}},{key:"max",value:function(t){var e,i,n=null,r=null,o=aM(rT(e=this._data).call(e));try{for(o.s();!(i=o.n()).done;){var s=i.value,a=s[t];"number"==typeof a&&(null==r||a>r)&&(n=s,r=a)}}catch(t){o.e(t)}finally{o.f()}return n||null}},{key:"min",value:function(t){var e,i,n=null,r=null,o=aM(rT(e=this._data).call(e));try{for(o.s();!(i=o.n()).done;){var s=i.value,a=s[t];"number"==typeof a&&(null==r||a<r)&&(n=s,r=a)}}catch(t){o.e(t)}finally{o.f()}return n||null}},{key:"distinct",value:function(t){for(var e=this._data,i=gd(KC(e).call(e)),n=[],r=0,o=0,s=i.length;o<s;o++){for(var a=i[o],l=e.get(a)[t],h=!1,u=0;u<r;u++)if(n[u]==l){h=!0;break}h||void 0===l||(n[r]=l,r++)}return n}},{key:"_addItem",value:function(t){var e=function(t,e){return null==t[e]&&(t[e]=nM()),t}(t,this._idProp),i=e[this._idProp];if(this._data.has(i))throw new Error("Cannot add item: item with id "+i+" already exists");return this._data.set(i,e),++this.length,i}},{key:"_updateItem",value:function(t){var e=t[this._idProp];if(null==e)throw new Error("Cannot update item: item has no id (item: "+Wm(t)+")");var i=this._data.get(e);if(!i)throw new Error("Cannot update item: no item with id "+e+" found");return this._data.set(e,oM(oM({},i),t)),e}},{key:"stream",value:function(t){if(t){var e=this._data;return new fM(Fb({},JD,yS.mark((function i(){var n,r,o,s;return yS.wrap((function(i){for(;;)switch(i.prev=i.next){case 0:n=aM(t),i.prev=1,n.s();case 3:if((r=n.n()).done){i.next=11;break}if(o=r.value,null==(s=e.get(o))){i.next=9;break}return i.next=9,[o,s];case 9:i.next=3;break;case 11:i.next=16;break;case 13:i.prev=13,i.t0=i.catch(1),n.e(i.t0);case 16:return i.prev=16,n.f(),i.finish(16);case 19:case"end":return i.stop()}}),i,null,[[1,13,16,19]])}))))}var i;return new fM(Fb({},JD,hp(i=dT(this._data)).call(i,this._data)))}}]),i}(pM),vM=function(t){Ib(i,t);var e=sM(i);function i(t,n){var r,o;return ga(this,i),Fb(Db(o=e.call(this)),"length",0),Fb(Db(o),"_listener",void 0),Fb(Db(o),"_data",void 0),Fb(Db(o),"_ids",new ZD),Fb(Db(o),"_options",void 0),o._options=n||{},o._listener=hp(r=o._onEvent).call(r,Db(o)),o.setData(t),o}return Cc(i,[{key:"idProp",get:function(){return this.getDataSet().idProp}},{key:"setData",value:function(t){if(this._data){this._data.off&&this._data.off("*",this._listener);var e=this._data.getIds({filter:Vf(this._options)}),i=this._data.get(e);this._ids.clear(),this.length=0,this._trigger("remove",{items:e,oldData:i})}if(null!=t){this._data=t;for(var n=this._data.getIds({filter:Vf(this._options)}),r=0,o=n.length;r<o;r++){var s=n[r];this._ids.add(s)}this.length=n.length,this._trigger("add",{items:n})}else this._data=new mM;this._data.on&&this._data.on("*",this._listener)}},{key:"refresh",value:function(){for(var t=this._data.getIds({filter:Vf(this._options)}),e=gd(this._ids),i={},n=[],r=[],o=[],s=0,a=t.length;s<a;s++){var l=t[s];i[l]=!0,this._ids.has(l)||(n.push(l),this._ids.add(l))}for(var h=0,u=e.length;h<u;h++){var c=e[h],d=this._data.get(c);null==d?console.error("If you see this, report it please."):i[c]||(r.push(c),o.push(d),this._ids.delete(c))}this.length+=n.length-r.length,n.length&&this._trigger("add",{items:n}),r.length&&this._trigger("remove",{items:r,oldData:o})}},{key:"get",value:function(t,e){if(null==this._data)return null;var i,n=null;cM(t)||Id(t)?(n=t,i=e):i=t;var r=mf({},this._options,i),o=Vf(this._options),s=i&&Vf(i);return o&&s&&(r.filter=function(t){return o(t)&&s(t)}),null==n?this._data.get(r):this._data.get(n,r)}},{key:"getIds",value:function(t){if(this._data.length){var e,i=Vf(this._options),n=null!=t?Vf(t):null;return e=n?i?function(t){return i(t)&&n(t)}:n:i,this._data.getIds({filter:e,order:t&&t.order})}return[]}},{key:"forEach",value:function(t,e){if(this._data){var i,n,r=Vf(this._options),o=e&&Vf(e);n=o?r?function(t){return r(t)&&o(t)}:o:r,kp(i=this._data).call(i,t,{filter:n,order:e&&e.order})}}},{key:"map",value:function(t,e){if(this._data){var i,n,r=Vf(this._options),o=e&&Vf(e);return n=o?r?function(t){return r(t)&&o(t)}:o:r,jd(i=this._data).call(i,t,{filter:n,order:e&&e.order})}return[]}},{key:"getDataSet",value:function(){return this._data.getDataSet()}},{key:"stream",value:function(t){var e;return this._data.stream(t||Fb({},JD,hp(e=KC(this._ids)).call(e,this._ids)))}},{key:"dispose",value:function(){var t;null!==(t=this._data)&&void 0!==t&&t.off&&this._data.off("*",this._listener);var e,n="This data view has already been disposed of.",r={get:function(){throw new Error(n)},set:function(){throw new Error(n)},configurable:!1},o=aM(Ed(i.prototype));try{for(o.s();!(e=o.n()).done;){var s=e.value;pT(this,s,r)}}catch(t){o.e(t)}finally{o.f()}}},{key:"_onEvent",value:function(t,e,i){if(e&&e.items&&this._data){var n=e.items,r=[],o=[],s=[],a=[],l=[],h=[];switch(t){case"add":for(var u=0,c=n.length;u<c;u++){var d=n[u];this.get(d)&&(this._ids.add(d),r.push(d))}break;case"update":for(var p=0,f=n.length;p<f;p++){var m=n[p];this.get(m)?this._ids.has(m)?(o.push(m),l.push(e.data[p]),a.push(e.oldData[p])):(this._ids.add(m),r.push(m)):this._ids.has(m)&&(this._ids.delete(m),s.push(m),h.push(e.oldData[p]))}break;case"remove":for(var v=0,g=n.length;v<g;v++){var y=n[v];this._ids.has(y)&&(this._ids.delete(y),s.push(y),h.push(e.oldData[v]))}}this.length+=r.length-s.length,r.length&&this._trigger("add",{items:r},i),o.length&&this._trigger("update",{items:o,oldData:a,data:l},i),s.length&&this._trigger("remove",{items:s,oldData:h},i)}}}]),i}(pM);var gM=n("undefined"!=typeof window&&window.moment||a()),yM=n(a()),bM={exports:{}},_M={},wM={exports:{}},kM={};function xM(){return{"align-content":!1,"align-items":!1,"align-self":!1,"alignment-adjust":!1,"alignment-baseline":!1,all:!1,"anchor-point":!1,animation:!1,"animation-delay":!1,"animation-direction":!1,"animation-duration":!1,"animation-fill-mode":!1,"animation-iteration-count":!1,"animation-name":!1,"animation-play-state":!1,"animation-timing-function":!1,azimuth:!1,"backface-visibility":!1,background:!0,"background-attachment":!0,"background-clip":!0,"background-color":!0,"background-image":!0,"background-origin":!0,"background-position":!0,"background-repeat":!0,"background-size":!0,"baseline-shift":!1,binding:!1,bleed:!1,"bookmark-label":!1,"bookmark-level":!1,"bookmark-state":!1,border:!0,"border-bottom":!0,"border-bottom-color":!0,"border-bottom-left-radius":!0,"border-bottom-right-radius":!0,"border-bottom-style":!0,"border-bottom-width":!0,"border-collapse":!0,"border-color":!0,"border-image":!0,"border-image-outset":!0,"border-image-repeat":!0,"border-image-slice":!0,"border-image-source":!0,"border-image-width":!0,"border-left":!0,"border-left-color":!0,"border-left-style":!0,"border-left-width":!0,"border-radius":!0,"border-right":!0,"border-right-color":!0,"border-right-style":!0,"border-right-width":!0,"border-spacing":!0,"border-style":!0,"border-top":!0,"border-top-color":!0,"border-top-left-radius":!0,"border-top-right-radius":!0,"border-top-style":!0,"border-top-width":!0,"border-width":!0,bottom:!1,"box-decoration-break":!0,"box-shadow":!0,"box-sizing":!0,"box-snap":!0,"box-suppress":!0,"break-after":!0,"break-before":!0,"break-inside":!0,"caption-side":!1,chains:!1,clear:!0,clip:!1,"clip-path":!1,"clip-rule":!1,color:!0,"color-interpolation-filters":!0,"column-count":!1,"column-fill":!1,"column-gap":!1,"column-rule":!1,"column-rule-color":!1,"column-rule-style":!1,"column-rule-width":!1,"column-span":!1,"column-width":!1,columns:!1,contain:!1,content:!1,"counter-increment":!1,"counter-reset":!1,"counter-set":!1,crop:!1,cue:!1,"cue-after":!1,"cue-before":!1,cursor:!1,direction:!1,display:!0,"display-inside":!0,"display-list":!0,"display-outside":!0,"dominant-baseline":!1,elevation:!1,"empty-cells":!1,filter:!1,flex:!1,"flex-basis":!1,"flex-direction":!1,"flex-flow":!1,"flex-grow":!1,"flex-shrink":!1,"flex-wrap":!1,float:!1,"float-offset":!1,"flood-color":!1,"flood-opacity":!1,"flow-from":!1,"flow-into":!1,font:!0,"font-family":!0,"font-feature-settings":!0,"font-kerning":!0,"font-language-override":!0,"font-size":!0,"font-size-adjust":!0,"font-stretch":!0,"font-style":!0,"font-synthesis":!0,"font-variant":!0,"font-variant-alternates":!0,"font-variant-caps":!0,"font-variant-east-asian":!0,"font-variant-ligatures":!0,"font-variant-numeric":!0,"font-variant-position":!0,"font-weight":!0,grid:!1,"grid-area":!1,"grid-auto-columns":!1,"grid-auto-flow":!1,"grid-auto-rows":!1,"grid-column":!1,"grid-column-end":!1,"grid-column-start":!1,"grid-row":!1,"grid-row-end":!1,"grid-row-start":!1,"grid-template":!1,"grid-template-areas":!1,"grid-template-columns":!1,"grid-template-rows":!1,"hanging-punctuation":!1,height:!0,hyphens:!1,icon:!1,"image-orientation":!1,"image-resolution":!1,"ime-mode":!1,"initial-letters":!1,"inline-box-align":!1,"justify-content":!1,"justify-items":!1,"justify-self":!1,left:!1,"letter-spacing":!0,"lighting-color":!0,"line-box-contain":!1,"line-break":!1,"line-grid":!1,"line-height":!1,"line-snap":!1,"line-stacking":!1,"line-stacking-ruby":!1,"line-stacking-shift":!1,"line-stacking-strategy":!1,"list-style":!0,"list-style-image":!0,"list-style-position":!0,"list-style-type":!0,margin:!0,"margin-bottom":!0,"margin-left":!0,"margin-right":!0,"margin-top":!0,"marker-offset":!1,"marker-side":!1,marks:!1,mask:!1,"mask-box":!1,"mask-box-outset":!1,"mask-box-repeat":!1,"mask-box-slice":!1,"mask-box-source":!1,"mask-box-width":!1,"mask-clip":!1,"mask-image":!1,"mask-origin":!1,"mask-position":!1,"mask-repeat":!1,"mask-size":!1,"mask-source-type":!1,"mask-type":!1,"max-height":!0,"max-lines":!1,"max-width":!0,"min-height":!0,"min-width":!0,"move-to":!1,"nav-down":!1,"nav-index":!1,"nav-left":!1,"nav-right":!1,"nav-up":!1,"object-fit":!1,"object-position":!1,opacity:!1,order:!1,orphans:!1,outline:!1,"outline-color":!1,"outline-offset":!1,"outline-style":!1,"outline-width":!1,overflow:!1,"overflow-wrap":!1,"overflow-x":!1,"overflow-y":!1,padding:!0,"padding-bottom":!0,"padding-left":!0,"padding-right":!0,"padding-top":!0,page:!1,"page-break-after":!1,"page-break-before":!1,"page-break-inside":!1,"page-policy":!1,pause:!1,"pause-after":!1,"pause-before":!1,perspective:!1,"perspective-origin":!1,pitch:!1,"pitch-range":!1,"play-during":!1,position:!1,"presentation-level":!1,quotes:!1,"region-fragment":!1,resize:!1,rest:!1,"rest-after":!1,"rest-before":!1,richness:!1,right:!1,rotation:!1,"rotation-point":!1,"ruby-align":!1,"ruby-merge":!1,"ruby-position":!1,"shape-image-threshold":!1,"shape-outside":!1,"shape-margin":!1,size:!1,speak:!1,"speak-as":!1,"speak-header":!1,"speak-numeral":!1,"speak-punctuation":!1,"speech-rate":!1,stress:!1,"string-set":!1,"tab-size":!1,"table-layout":!1,"text-align":!0,"text-align-last":!0,"text-combine-upright":!0,"text-decoration":!0,"text-decoration-color":!0,"text-decoration-line":!0,"text-decoration-skip":!0,"text-decoration-style":!0,"text-emphasis":!0,"text-emphasis-color":!0,"text-emphasis-position":!0,"text-emphasis-style":!0,"text-height":!0,"text-indent":!0,"text-justify":!0,"text-orientation":!0,"text-overflow":!0,"text-shadow":!0,"text-space-collapse":!0,"text-transform":!0,"text-underline-position":!0,"text-wrap":!0,top:!1,transform:!1,"transform-origin":!1,"transform-style":!1,transition:!1,"transition-delay":!1,"transition-duration":!1,"transition-property":!1,"transition-timing-function":!1,"unicode-bidi":!1,"vertical-align":!1,visibility:!1,"voice-balance":!1,"voice-duration":!1,"voice-family":!1,"voice-pitch":!1,"voice-range":!1,"voice-rate":!1,"voice-stress":!1,"voice-volume":!1,volume:!1,"white-space":!1,widows:!1,width:!0,"will-change":!1,"word-break":!0,"word-spacing":!0,"word-wrap":!0,"wrap-flow":!1,"wrap-through":!1,"writing-mode":!1,"z-index":!1}}var SM=/javascript\s*\:/gim;kM.whiteList={"align-content":!1,"align-items":!1,"align-self":!1,"alignment-adjust":!1,"alignment-baseline":!1,all:!1,"anchor-point":!1,animation:!1,"animation-delay":!1,"animation-direction":!1,"animation-duration":!1,"animation-fill-mode":!1,"animation-iteration-count":!1,"animation-name":!1,"animation-play-state":!1,"animation-timing-function":!1,azimuth:!1,"backface-visibility":!1,background:!0,"background-attachment":!0,"background-clip":!0,"background-color":!0,"background-image":!0,"background-origin":!0,"background-position":!0,"background-repeat":!0,"background-size":!0,"baseline-shift":!1,binding:!1,bleed:!1,"bookmark-label":!1,"bookmark-level":!1,"bookmark-state":!1,border:!0,"border-bottom":!0,"border-bottom-color":!0,"border-bottom-left-radius":!0,"border-bottom-right-radius":!0,"border-bottom-style":!0,"border-bottom-width":!0,"border-collapse":!0,"border-color":!0,"border-image":!0,"border-image-outset":!0,"border-image-repeat":!0,"border-image-slice":!0,"border-image-source":!0,"border-image-width":!0,"border-left":!0,"border-left-color":!0,"border-left-style":!0,"border-left-width":!0,"border-radius":!0,"border-right":!0,"border-right-color":!0,"border-right-style":!0,"border-right-width":!0,"border-spacing":!0,"border-style":!0,"border-top":!0,"border-top-color":!0,"border-top-left-radius":!0,"border-top-right-radius":!0,"border-top-style":!0,"border-top-width":!0,"border-width":!0,bottom:!1,"box-decoration-break":!0,"box-shadow":!0,"box-sizing":!0,"box-snap":!0,"box-suppress":!0,"break-after":!0,"break-before":!0,"break-inside":!0,"caption-side":!1,chains:!1,clear:!0,clip:!1,"clip-path":!1,"clip-rule":!1,color:!0,"color-interpolation-filters":!0,"column-count":!1,"column-fill":!1,"column-gap":!1,"column-rule":!1,"column-rule-color":!1,"column-rule-style":!1,"column-rule-width":!1,"column-span":!1,"column-width":!1,columns:!1,contain:!1,content:!1,"counter-increment":!1,"counter-reset":!1,"counter-set":!1,crop:!1,cue:!1,"cue-after":!1,"cue-before":!1,cursor:!1,direction:!1,display:!0,"display-inside":!0,"display-list":!0,"display-outside":!0,"dominant-baseline":!1,elevation:!1,"empty-cells":!1,filter:!1,flex:!1,"flex-basis":!1,"flex-direction":!1,"flex-flow":!1,"flex-grow":!1,"flex-shrink":!1,"flex-wrap":!1,float:!1,"float-offset":!1,"flood-color":!1,"flood-opacity":!1,"flow-from":!1,"flow-into":!1,font:!0,"font-family":!0,"font-feature-settings":!0,"font-kerning":!0,"font-language-override":!0,"font-size":!0,"font-size-adjust":!0,"font-stretch":!0,"font-style":!0,"font-synthesis":!0,"font-variant":!0,"font-variant-alternates":!0,"font-variant-caps":!0,"font-variant-east-asian":!0,"font-variant-ligatures":!0,"font-variant-numeric":!0,"font-variant-position":!0,"font-weight":!0,grid:!1,"grid-area":!1,"grid-auto-columns":!1,"grid-auto-flow":!1,"grid-auto-rows":!1,"grid-column":!1,"grid-column-end":!1,"grid-column-start":!1,"grid-row":!1,"grid-row-end":!1,"grid-row-start":!1,"grid-template":!1,"grid-template-areas":!1,"grid-template-columns":!1,"grid-template-rows":!1,"hanging-punctuation":!1,height:!0,hyphens:!1,icon:!1,"image-orientation":!1,"image-resolution":!1,"ime-mode":!1,"initial-letters":!1,"inline-box-align":!1,"justify-content":!1,"justify-items":!1,"justify-self":!1,left:!1,"letter-spacing":!0,"lighting-color":!0,"line-box-contain":!1,"line-break":!1,"line-grid":!1,"line-height":!1,"line-snap":!1,"line-stacking":!1,"line-stacking-ruby":!1,"line-stacking-shift":!1,"line-stacking-strategy":!1,"list-style":!0,"list-style-image":!0,"list-style-position":!0,"list-style-type":!0,margin:!0,"margin-bottom":!0,"margin-left":!0,"margin-right":!0,"margin-top":!0,"marker-offset":!1,"marker-side":!1,marks:!1,mask:!1,"mask-box":!1,"mask-box-outset":!1,"mask-box-repeat":!1,"mask-box-slice":!1,"mask-box-source":!1,"mask-box-width":!1,"mask-clip":!1,"mask-image":!1,"mask-origin":!1,"mask-position":!1,"mask-repeat":!1,"mask-size":!1,"mask-source-type":!1,"mask-type":!1,"max-height":!0,"max-lines":!1,"max-width":!0,"min-height":!0,"min-width":!0,"move-to":!1,"nav-down":!1,"nav-index":!1,"nav-left":!1,"nav-right":!1,"nav-up":!1,"object-fit":!1,"object-position":!1,opacity:!1,order:!1,orphans:!1,outline:!1,"outline-color":!1,"outline-offset":!1,"outline-style":!1,"outline-width":!1,overflow:!1,"overflow-wrap":!1,"overflow-x":!1,"overflow-y":!1,padding:!0,"padding-bottom":!0,"padding-left":!0,"padding-right":!0,"padding-top":!0,page:!1,"page-break-after":!1,"page-break-before":!1,"page-break-inside":!1,"page-policy":!1,pause:!1,"pause-after":!1,"pause-before":!1,perspective:!1,"perspective-origin":!1,pitch:!1,"pitch-range":!1,"play-during":!1,position:!1,"presentation-level":!1,quotes:!1,"region-fragment":!1,resize:!1,rest:!1,"rest-after":!1,"rest-before":!1,richness:!1,right:!1,rotation:!1,"rotation-point":!1,"ruby-align":!1,"ruby-merge":!1,"ruby-position":!1,"shape-image-threshold":!1,"shape-outside":!1,"shape-margin":!1,size:!1,speak:!1,"speak-as":!1,"speak-header":!1,"speak-numeral":!1,"speak-punctuation":!1,"speech-rate":!1,stress:!1,"string-set":!1,"tab-size":!1,"table-layout":!1,"text-align":!0,"text-align-last":!0,"text-combine-upright":!0,"text-decoration":!0,"text-decoration-color":!0,"text-decoration-line":!0,"text-decoration-skip":!0,"text-decoration-style":!0,"text-emphasis":!0,"text-emphasis-color":!0,"text-emphasis-position":!0,"text-emphasis-style":!0,"text-height":!0,"text-indent":!0,"text-justify":!0,"text-orientation":!0,"text-overflow":!0,"text-shadow":!0,"text-space-collapse":!0,"text-transform":!0,"text-underline-position":!0,"text-wrap":!0,top:!1,transform:!1,"transform-origin":!1,"transform-style":!1,transition:!1,"transition-delay":!1,"transition-duration":!1,"transition-property":!1,"transition-timing-function":!1,"unicode-bidi":!1,"vertical-align":!1,visibility:!1,"voice-balance":!1,"voice-duration":!1,"voice-family":!1,"voice-pitch":!1,"voice-range":!1,"voice-rate":!1,"voice-stress":!1,"voice-volume":!1,volume:!1,"white-space":!1,widows:!1,width:!0,"will-change":!1,"word-break":!0,"word-spacing":!0,"word-wrap":!0,"wrap-flow":!1,"wrap-through":!1,"writing-mode":!1,"z-index":!1},kM.getDefaultWhiteList=xM,kM.onAttr=function(t,e,i){},kM.onIgnoreAttr=function(t,e,i){},kM.safeAttrValue=function(t,e){return SM.test(e)?"":e};var DM=function(t){return String.prototype.trim?t.trim():t.replace(/(^\s*)|(\s*$)/g,"")},CM=function(t){return String.prototype.trimRight?t.trimRight():t.replace(/(\s*$)/g,"")},TM=kM,MM=function(t,e){";"!==(t=CM(t))[t.length-1]&&(t+=";");var i=t.length,n=!1,r=0,o=0,s="";function a(){if(!n){var i=DM(t.slice(r,o)),a=i.indexOf(":");if(-1!==a){var l=DM(i.slice(0,a)),h=DM(i.slice(a+1));if(l){var u=e(r,s.length,l,h,i);u&&(s+=u+"; ")}}}r=o+1}for(;o<i;o++){var l=t[o];if("/"===l&&"*"===t[o+1]){var h=t.indexOf("*/",o+2);if(-1===h)break;r=(o=h+1)+1,n=!1}else"("===l?n=!0:")"===l?n=!1:";"===l?n||a():"\n"===l&&a()}return DM(s)};function OM(t){return null==t}function PM(t){(t=function(t){var e={};for(var i in t)e[i]=t[i];return e}(t||{})).whiteList=t.whiteList||TM.whiteList,t.onAttr=t.onAttr||TM.onAttr,t.onIgnoreAttr=t.onIgnoreAttr||TM.onIgnoreAttr,t.safeAttrValue=t.safeAttrValue||TM.safeAttrValue,this.options=t}PM.prototype.process=function(t){if(!(t=(t=t||"").toString()))return"";var e=this.options,i=e.whiteList,n=e.onAttr,r=e.onIgnoreAttr,o=e.safeAttrValue,s=MM(t,(function(t,e,s,a,l){var h=i[s],u=!1;if(!0===h?u=h:"function"==typeof h?u=h(a):h instanceof RegExp&&(u=h.test(a)),!0!==u&&(u=!1),a=o(s,a)){var c,d={position:e,sourcePosition:t,source:l,isWhite:u};return u?OM(c=n(s,a,d))?s+":"+a:c:OM(c=r(s,a,d))?void 0:c}}));return s};var EM=PM;!function(t,e){var i=kM,n=EM;for(var r in(e=t.exports=function(t,e){return new n(e).process(t)}).FilterCSS=n,i)e[r]=i[r];"undefined"!=typeof window&&(window.filterCSS=t.exports)}(wM,wM.exports);var IM=wM.exports,LM={indexOf:function(t,e){var i,n;if(Array.prototype.indexOf)return t.indexOf(e);for(i=0,n=t.length;i<n;i++)if(t[i]===e)return i;return-1},forEach:function(t,e,i){var n,r;if(Array.prototype.forEach)return t.forEach(e,i);for(n=0,r=t.length;n<r;n++)e.call(i,t[n],n,t)},trim:function(t){return String.prototype.trim?t.trim():t.replace(/(^\s*)|(\s*$)/g,"")},spaceIndex:function(t){var e=/\s|\n|\t/.exec(t);return e?e.index:-1}},AM=IM.FilterCSS,NM=IM.getDefaultWhiteList,RM=LM;var FM=new AM;function jM(t){return t.replace(YM,"&lt;").replace(HM,"&gt;")}var YM=/</g,HM=/>/g,BM=/"/g,zM=/&quot;/g,GM=/&#([a-zA-Z0-9]*);?/gim,WM=/&colon;?/gim,VM=/&newline;?/gim,UM=/((j\s*a\s*v\s*a|v\s*b|l\s*i\s*v\s*e)\s*s\s*c\s*r\s*i\s*p\s*t\s*|m\s*o\s*c\s*h\s*a):/gi,XM=/e\s*x\s*p\s*r\s*e\s*s\s*s\s*i\s*o\s*n\s*\(.*/gi,qM=/u\s*r\s*l\s*\(.*/gi;function $M(t){return t.replace(BM,"&quot;")}function KM(t){return t.replace(zM,'"')}function ZM(t){return t.replace(GM,(function(t,e){return"x"===e[0]||"X"===e[0]?String.fromCharCode(parseInt(e.substr(1),16)):String.fromCharCode(parseInt(e,10))}))}function JM(t){return t.replace(WM,":").replace(VM," ")}function QM(t){for(var e="",i=0,n=t.length;i<n;i++)e+=t.charCodeAt(i)<32?" ":t.charAt(i);return RM.trim(e)}function tO(t){return QM(t=JM(t=ZM(t=KM(t))))}function eO(t){return jM(t=$M(t))}_M.whiteList={a:["target","href","title"],abbr:["title"],address:[],area:["shape","coords","href","alt"],article:[],aside:[],audio:["autoplay","controls","crossorigin","loop","muted","preload","src"],b:[],bdi:["dir"],bdo:["dir"],big:[],blockquote:["cite"],br:[],caption:[],center:[],cite:[],code:[],col:["align","valign","span","width"],colgroup:["align","valign","span","width"],dd:[],del:["datetime"],details:["open"],div:[],dl:[],dt:[],em:[],figcaption:[],figure:[],font:["color","size","face"],footer:[],h1:[],h2:[],h3:[],h4:[],h5:[],h6:[],header:[],hr:[],i:[],img:["src","alt","title","width","height"],ins:["datetime"],li:[],mark:[],nav:[],ol:[],p:[],pre:[],s:[],section:[],small:[],span:[],sub:[],summary:[],sup:[],strong:[],strike:[],table:["width","border","align","valign"],tbody:["align","valign"],td:["width","rowspan","colspan","align","valign"],tfoot:["align","valign"],th:["width","rowspan","colspan","align","valign"],thead:["align","valign"],tr:["rowspan","align","valign"],tt:[],u:[],ul:[],video:["autoplay","controls","crossorigin","loop","muted","playsinline","poster","preload","src","height","width"]},_M.getDefaultWhiteList=function(){return{a:["target","href","title"],abbr:["title"],address:[],area:["shape","coords","href","alt"],article:[],aside:[],audio:["autoplay","controls","crossorigin","loop","muted","preload","src"],b:[],bdi:["dir"],bdo:["dir"],big:[],blockquote:["cite"],br:[],caption:[],center:[],cite:[],code:[],col:["align","valign","span","width"],colgroup:["align","valign","span","width"],dd:[],del:["datetime"],details:["open"],div:[],dl:[],dt:[],em:[],figcaption:[],figure:[],font:["color","size","face"],footer:[],h1:[],h2:[],h3:[],h4:[],h5:[],h6:[],header:[],hr:[],i:[],img:["src","alt","title","width","height"],ins:["datetime"],li:[],mark:[],nav:[],ol:[],p:[],pre:[],s:[],section:[],small:[],span:[],sub:[],summary:[],sup:[],strong:[],strike:[],table:["width","border","align","valign"],tbody:["align","valign"],td:["width","rowspan","colspan","align","valign"],tfoot:["align","valign"],th:["width","rowspan","colspan","align","valign"],thead:["align","valign"],tr:["rowspan","align","valign"],tt:[],u:[],ul:[],video:["autoplay","controls","crossorigin","loop","muted","playsinline","poster","preload","src","height","width"]}},_M.onTag=function(t,e,i){},_M.onIgnoreTag=function(t,e,i){},_M.onTagAttr=function(t,e,i){},_M.onIgnoreTagAttr=function(t,e,i){},_M.safeAttrValue=function(t,e,i,n){if(i=tO(i),"href"===e||"src"===e){if("#"===(i=RM.trim(i)))return"#";if("http://"!==i.substr(0,7)&&"https://"!==i.substr(0,8)&&"mailto:"!==i.substr(0,7)&&"tel:"!==i.substr(0,4)&&"data:image/"!==i.substr(0,11)&&"ftp://"!==i.substr(0,6)&&"./"!==i.substr(0,2)&&"../"!==i.substr(0,3)&&"#"!==i[0]&&"/"!==i[0])return""}else if("background"===e){if(UM.lastIndex=0,UM.test(i))return""}else if("style"===e){if(XM.lastIndex=0,XM.test(i))return"";if(qM.lastIndex=0,qM.test(i)&&(UM.lastIndex=0,UM.test(i)))return"";!1!==n&&(i=(n=n||FM).process(i))}return eO(i)},_M.escapeHtml=jM,_M.escapeQuote=$M,_M.unescapeQuote=KM,_M.escapeHtmlEntities=ZM,_M.escapeDangerHtml5Entities=JM,_M.clearNonPrintableCharacter=QM,_M.friendlyAttrValue=tO,_M.escapeAttrValue=eO,_M.onIgnoreTagStripAll=function(){return""},_M.StripTagBody=function(t,e){"function"!=typeof e&&(e=function(){});var i=!Array.isArray(t),n=[],r=!1;return{onIgnoreTag:function(o,s,a){if(function(e){return!!i||-1!==RM.indexOf(t,e)}(o)){if(a.isClosing){var l=a.position+10;return n.push([!1!==r?r:a.position,l]),r=!1,"[/removed]"}return r||(r=a.position),"[removed]"}return e(o,s,a)},remove:function(t){var e="",i=0;return RM.forEach(n,(function(n){e+=t.slice(i,n[0]),i=n[1]})),e+=t.slice(i)}}},_M.stripCommentTag=function(t){for(var e="",i=0;i<t.length;){var n=t.indexOf("\x3c!--",i);if(-1===n){e+=t.slice(i);break}e+=t.slice(i,n);var r=t.indexOf("--\x3e",n);if(-1===r)break;i=r+3}return e},_M.stripBlankChar=function(t){var e=t.split("");return(e=e.filter((function(t){var e=t.charCodeAt(0);return!(127===e||e<=31&&10!==e&&13!==e)}))).join("")},_M.cssFilter=FM,_M.getDefaultCSSWhiteList=NM;var iO={},nO=LM;function rO(t){var e,i=nO.spaceIndex(t);return e=-1===i?t.slice(1,-1):t.slice(1,i+1),"/"===(e=nO.trim(e).toLowerCase()).slice(0,1)&&(e=e.slice(1)),"/"===e.slice(-1)&&(e=e.slice(0,-1)),e}function oO(t){return"</"===t.slice(0,2)}var sO=/[^a-zA-Z0-9\\_:.-]/gim;function aO(t,e){for(;e<t.length;e++){var i=t[e];if(" "!==i)return"="===i?e:-1}}function lO(t,e){for(;e<t.length;e++){var i=t[e];if(" "!==i)return"'"===i||'"'===i?e:-1}}function hO(t,e){for(;e>0;e--){var i=t[e];if(" "!==i)return"="===i?e:-1}}function uO(t){return function(t){return'"'===t[0]&&'"'===t[t.length-1]||"'"===t[0]&&"'"===t[t.length-1]}(t)?t.substr(1,t.length-2):t}iO.parseTag=function(t,e,i){var n="",r=0,o=!1,s=!1,a=0,l=t.length,h="",u="";t:for(a=0;a<l;a++){var c=t.charAt(a);if(!1===o){if("<"===c){o=a;continue}}else if(!1===s){if("<"===c){n+=i(t.slice(r,a)),o=a,r=a;continue}if(">"===c||a===l-1){n+=i(t.slice(r,o)),h=rO(u=t.slice(o,a+1)),n+=e(o,n.length,h,u,oO(u)),r=a+1,o=!1;continue}if('"'===c||"'"===c)for(var d=1,p=t.charAt(a-d);""===p.trim()||"="===p;){if("="===p){s=c;continue t}p=t.charAt(a-++d)}}else if(c===s){s=!1;continue}}return r<l&&(n+=i(t.substr(r))),n},iO.parseAttr=function(t,e){var i=0,n=0,r=[],o=!1,s=t.length;function a(t,i){if(!((t=(t=nO.trim(t)).replace(sO,"").toLowerCase()).length<1)){var n=e(t,i||"");n&&r.push(n)}}for(var l=0;l<s;l++){var h,u=t.charAt(l);if(!1!==o||"="!==u)if(!1===o||l!==n){if(/\s|\n|\t/.test(u)){if(t=t.replace(/\s|\n|\t/g," "),!1===o){if(-1===(h=aO(t,l))){a(nO.trim(t.slice(i,l))),o=!1,i=l+1;continue}l=h-1;continue}if(-1===(h=hO(t,l-1))){a(o,uO(nO.trim(t.slice(i,l)))),o=!1,i=l+1;continue}}}else{if(-1===(h=t.indexOf(u,l+1)))break;a(o,nO.trim(t.slice(n+1,h))),o=!1,i=(l=h)+1}else o=t.slice(i,l),i=l+1,n='"'===t.charAt(i)||"'"===t.charAt(i)?i:lO(t,l+1)}return i<t.length&&(!1===o?a(t.slice(i)):a(o,uO(nO.trim(t.slice(i))))),nO.trim(r.join(" "))};var cO=IM.FilterCSS,dO=_M,pO=iO,fO=pO.parseTag,mO=pO.parseAttr,vO=LM;function gO(t){return null==t}function yO(t){(t=function(t){var e={};for(var i in t)e[i]=t[i];return e}(t||{})).stripIgnoreTag&&(t.onIgnoreTag&&console.error('Notes: cannot use these two options "stripIgnoreTag" and "onIgnoreTag" at the same time'),t.onIgnoreTag=dO.onIgnoreTagStripAll),t.whiteList||t.allowList?t.whiteList=function(t){var e={};for(var i in t)Array.isArray(t[i])?e[i.toLowerCase()]=t[i].map((function(t){return t.toLowerCase()})):e[i.toLowerCase()]=t[i];return e}(t.whiteList||t.allowList):t.whiteList=dO.whiteList,t.onTag=t.onTag||dO.onTag,t.onTagAttr=t.onTagAttr||dO.onTagAttr,t.onIgnoreTag=t.onIgnoreTag||dO.onIgnoreTag,t.onIgnoreTagAttr=t.onIgnoreTagAttr||dO.onIgnoreTagAttr,t.safeAttrValue=t.safeAttrValue||dO.safeAttrValue,t.escapeHtml=t.escapeHtml||dO.escapeHtml,this.options=t,!1===t.css?this.cssFilter=!1:(t.css=t.css||{},this.cssFilter=new cO(t.css))}yO.prototype.process=function(t){if(!(t=(t=t||"").toString()))return"";var e=this.options,i=e.whiteList,n=e.onTag,r=e.onIgnoreTag,o=e.onTagAttr,s=e.onIgnoreTagAttr,a=e.safeAttrValue,l=e.escapeHtml,h=this.cssFilter;e.stripBlankChar&&(t=dO.stripBlankChar(t)),e.allowCommentTag||(t=dO.stripCommentTag(t));var u=!1;e.stripIgnoreTagBody&&(u=dO.StripTagBody(e.stripIgnoreTagBody,r),r=u.onIgnoreTag);var c=fO(t,(function(t,e,u,c,d){var p={sourcePosition:t,position:e,isClosing:d,isWhite:Object.prototype.hasOwnProperty.call(i,u)},f=n(u,c,p);if(!gO(f))return f;if(p.isWhite){if(p.isClosing)return"</"+u+">";var m=function(t){var e=vO.spaceIndex(t);if(-1===e)return{html:"",closing:"/"===t[t.length-2]};var i="/"===(t=vO.trim(t.slice(e+1,-1)))[t.length-1];return i&&(t=vO.trim(t.slice(0,-1))),{html:t,closing:i}}(c),v=i[u],g=mO(m.html,(function(t,e){var i=-1!==vO.indexOf(v,t),n=o(u,t,e,i);return gO(n)?i?(e=a(u,t,e,h))?t+'="'+e+'"':t:gO(n=s(u,t,e,i))?void 0:n:n}));return c="<"+u,g&&(c+=" "+g),m.closing&&(c+=" /"),c+">"}return gO(f=r(u,c,p))?l(c):f}),l);return u&&(c=u.remove(c)),c};var bO=yO;!function(t,e){var i=_M,n=iO,r=bO;function o(t,e){return new r(e).process(t)}(e=t.exports=o).filterXSS=o,e.FilterXSS=r,function(){for(var t in i)e[t]=i[t];for(var r in n)e[r]=n[r]}(),"undefined"!=typeof window&&(window.filterXSS=t.exports),"undefined"!=typeof self&&"undefined"!=typeof DedicatedWorkerGlobalScope&&self instanceof DedicatedWorkerGlobalScope&&(self.filterXSS=t.exports)}(bM,bM.exports);var _O=n(bM.exports);function wO(t,e){var i=Bd(t);if(OT){var n=OT(t);e&&(n=Vf(n).call(n,(function(e){return jT(t,e).enumerable}))),i.push.apply(i,n)}return i}function kO(t){for(var e=1;e<arguments.length;e++){var i,n,r=null!=arguments[e]?arguments[e]:{};e%2?kp(i=wO(Object(r),!0)).call(i,(function(e){Fb(t,e,r[e])})):GT?KT(t,GT(r)):kp(n=wO(Object(r))).call(n,(function(e){pT(t,e,jT(r,e))}))}return t}function xO(t){var e;if(!t)return!1;var i=null!==(e=t.idProp)&&void 0!==e?e:t._idProp;return!!i&&function(t,e){return"object"===kc(e)&&null!==e&&t===e.idProp&&"function"==typeof kp(e)&&"function"==typeof e.get&&"function"==typeof e.getDataSet&&"function"==typeof e.getIds&&"number"==typeof e.length&&"function"==typeof jd(e)&&"function"==typeof e.off&&"function"==typeof e.on&&"function"==typeof e.stream&&function(t,e){return"object"===kc(e)&&null!==e&&t===e.idProp&&"function"==typeof e.add&&"function"==typeof e.clear&&"function"==typeof e.distinct&&"function"==typeof kp(e)&&"function"==typeof e.get&&"function"==typeof e.getDataSet&&"function"==typeof e.getIds&&"number"==typeof e.length&&"function"==typeof jd(e)&&"function"==typeof e.max&&"function"==typeof e.min&&"function"==typeof e.off&&"function"==typeof e.on&&"function"==typeof e.remove&&"function"==typeof e.setOptions&&"function"==typeof e.stream&&"function"==typeof e.update&&"function"==typeof e.updateOnly}(t,e.getDataSet())}(i,t)}var SO=/^\/?Date\((-?\d+)/i,DO=/^\d+$/;function CO(t,e){var i;if(void 0!==t){if(null===t)return null;if(!e)return t;if("string"!=typeof e&&!(e instanceof String))throw new Error("Type must be a string");switch(e){case"boolean":case"Boolean":return Boolean(t);case"number":case"Number":return Iy(t)&&!isNaN(Date.parse(t))?yM(t).valueOf():Number(t.valueOf());case"string":case"String":return String(t);case"Date":try{return CO(t,"Moment").toDate()}catch(i){throw i instanceof TypeError?new TypeError("Cannot convert object of type "+Fy(t)+" to type "+e):i}case"Moment":if(Ey(t))return yM(t);if(t instanceof Date)return yM(t.valueOf());if(yM.isMoment(t))return yM(t);if(Iy(t))return(i=SO.exec(t))?yM(Number(i[1])):(i=DO.exec(t),yM(i?Number(t):t));throw new TypeError("Cannot convert object of type "+Fy(t)+" to type "+e);case"ISODate":if(Ey(t))return new Date(t);if(t instanceof Date)return t.toISOString();if(yM.isMoment(t))return t.toDate().toISOString();if(Iy(t))return(i=SO.exec(t))?new Date(Number(i[1])).toISOString():yM(t).format();throw new Error("Cannot convert object of type "+Fy(t)+" to type ISODate");case"ASPDate":if(Ey(t))return"/Date("+t+")/";if(t instanceof Date||yM.isMoment(t))return"/Date("+t.valueOf()+")/";if(Iy(t))return"/Date("+((i=SO.exec(t))?new Date(Number(i[1])).valueOf():new Date(t).valueOf())+")/";throw new Error("Cannot convert object of type "+Fy(t)+" to type ASPDate");default:throw new Error("Unknown type ".concat(e))}}}function TO(t){var e,i,n,r,o,s,a=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{start:"Date",end:"Date"},l=t._idProp,h=new mM({fieldId:l}),u=jd(e=function(t){return new uM(t)}(t)).call(e,(function(t){var e;return PS(e=Bd(t)).call(e,(function(e,i){return e[i]=CO(t[i],a[i]),e}),{})})).to(h);return u.all().start(),{add:function(){var e;return(e=t.getDataSet()).add.apply(e,arguments)},remove:function(){var e;return(e=t.getDataSet()).remove.apply(e,arguments)},update:function(){var e;return(e=t.getDataSet()).update.apply(e,arguments)},updateOnly:function(){var e;return(e=t.getDataSet()).updateOnly.apply(e,arguments)},clear:function(){var e;return(e=t.getDataSet()).clear.apply(e,arguments)},forEach:hp(i=kp(h)).call(i,h),get:hp(n=h.get).call(n,h),getIds:hp(r=h.getIds).call(r,h),off:hp(o=h.off).call(o,h),on:hp(s=h.on).call(s,h),get length(){return h.length},idProp:l,type:a,rawDS:t,coercedDS:h,dispose:function(){return u.stop()}}}var MO=function(t){var e=new _O.FilterXSS(t);return function(t){return e.process(t)}},OO=function(t){return t},PO=MO(),EO=kO(kO({},mb),{},{convert:CO,setupXSSProtection:function(t){t&&(!0===t.disabled?(PO=OO,console.warn("You disabled XSS protection for vis-Timeline. I sure hope you know what you're doing!")):t.filterOptions&&(PO=MO(t.filterOptions)))}});pT(EO,"xss",{get:function(){return PO}});var IO=_,LO=l,AO=It,NO=pm.trim,RO=om,FO=f("".charAt),jO=IO.parseFloat,YO=IO.Symbol,HO=YO&&YO.iterator,BO=1/jO(RO+"-0")!=-1/0||HO&&!LO((function(){jO(Object(HO))}))?function(t){var e=NO(AO(t)),i=jO(e);return 0===i&&"-"===FO(e,0)?-0:i}:jO;Tn({global:!0,forced:parseFloat!==BO},{parseFloat:BO});var zO=n(ue.parseFloat),GO=function(){function t(e,i){ga(this,t),this.options=null,this.props=null}return Cc(t,[{key:"setOptions",value:function(t){t&&EO.extend(this.options,t)}},{key:"redraw",value:function(){return!1}},{key:"destroy",value:function(){}},{key:"_isResized",value:function(){var t=this.props._previousWidth!==this.props.width||this.props._previousHeight!==this.props.height;return this.props._previousWidth=this.props.width,this.props._previousHeight=this.props.height,t}}]),t}(),WO=y,VO=It,UO=L,XO=RangeError;Tn({target:"String",proto:!0},{repeat:function(t){var e=VO(UO(this)),i="",n=WO(t);if(n<0||n===1/0)throw new XO("Wrong number of repetitions");for(;n>0;(n>>>=1)&&(e+=e))1&n&&(i+=e);return i}});var qO=Yc("String").repeat,$O=ve,KO=qO,ZO=String.prototype,JO=n((function(t){var e=t.repeat;return"string"==typeof t||t===ZO||$O(ZO,t)&&e===ZO.repeat?KO:e}));function QO(t,e,i){if(i&&!Id(i))return QO(t,e,[i]);if(e.hiddenDates=[],i&&1==Id(i)){for(var n,r=0;r<i.length;r++)if(void 0===JO(i[r])){var o={};o.start=t(i[r].start).toDate().valueOf(),o.end=t(i[r].end).toDate().valueOf(),e.hiddenDates.push(o)}RC(n=e.hiddenDates).call(n,(function(t,e){return t.start-e.start}))}}function tP(t,e,i){if(i&&!Id(i))return tP(t,e,[i]);if(i&&void 0!==e.domProps.centerContainer.width){QO(t,e,i);for(var n=t(e.range.start),r=t(e.range.end),o=(e.range.end-e.range.start)/e.domProps.centerContainer.width,s=0;s<i.length;s++)if(void 0!==JO(i[s])){var a=t(i[s].start),l=t(i[s].end);if("Invalid Date"==a._d)throw new Error("Supplied start date is not valid: ".concat(i[s].start));if("Invalid Date"==l._d)throw new Error("Supplied end date is not valid: ".concat(i[s].end));if(l-a>=4*o){var h=0,u=r.clone();switch(JO(i[s])){case"daily":a.day()!=l.day()&&(h=1),a.dayOfYear(n.dayOfYear()),a.year(n.year()),a.subtract(7,"days"),l.dayOfYear(n.dayOfYear()),l.year(n.year()),l.subtract(7-h,"days"),u.add(1,"weeks");break;case"weekly":var c=l.diff(a,"days"),d=a.day();a.date(n.date()),a.month(n.month()),a.year(n.year()),l=a.clone(),a.day(d),l.day(d),l.add(c,"days"),a.subtract(1,"weeks"),l.subtract(1,"weeks"),u.add(1,"weeks");break;case"monthly":a.month()!=l.month()&&(h=1),a.month(n.month()),a.year(n.year()),a.subtract(1,"months"),l.month(n.month()),l.year(n.year()),l.subtract(1,"months"),l.add(h,"months"),u.add(1,"months");break;case"yearly":a.year()!=l.year()&&(h=1),a.year(n.year()),a.subtract(1,"years"),l.year(n.year()),l.subtract(1,"years"),l.add(h,"years"),u.add(1,"years");break;default:return void console.log("Wrong repeat format, allowed are: daily, weekly, monthly, yearly. Given:",JO(i[s]))}for(;a<u;)switch(e.hiddenDates.push({start:a.valueOf(),end:l.valueOf()}),JO(i[s])){case"daily":a.add(1,"days"),l.add(1,"days");break;case"weekly":a.add(1,"weeks"),l.add(1,"weeks");break;case"monthly":a.add(1,"months"),l.add(1,"months");break;case"yearly":a.add(1,"y"),l.add(1,"y");break;default:return void console.log("Wrong repeat format, allowed are: daily, weekly, monthly, yearly. Given:",JO(i[s]))}e.hiddenDates.push({start:a.valueOf(),end:l.valueOf()})}}eP(e);var p=cP(e.range.start,e.hiddenDates),f=cP(e.range.end,e.hiddenDates),m=e.range.start,v=e.range.end;1==p.hidden&&(m=1==e.range.startToFront?p.startDate-1:p.endDate+1),1==f.hidden&&(v=1==e.range.endToFront?f.startDate-1:f.endDate+1),1!=p.hidden&&1!=f.hidden||e.range._applyRange(m,v)}}function eP(t){for(var e,i=t.hiddenDates,n=[],r=0;r<i.length;r++)for(var o=0;o<i.length;o++)r!=o&&1!=i[o].remove&&1!=i[r].remove&&(i[o].start>=i[r].start&&i[o].end<=i[r].end?i[o].remove=!0:i[o].start>=i[r].start&&i[o].start<=i[r].end?(i[r].end=i[o].end,i[o].remove=!0):i[o].end>=i[r].start&&i[o].end<=i[r].end&&(i[r].start=i[o].start,i[o].remove=!0));for(r=0;r<i.length;r++)!0!==i[r].remove&&n.push(i[r]);t.hiddenDates=n,RC(e=t.hiddenDates).call(e,(function(t,e){return t.start-e.start}))}function iP(t,e,i){for(var n=!1,r=e.current.valueOf(),o=0;o<e.hiddenDates.length;o++){var s=e.hiddenDates[o].start,a=e.hiddenDates[o].end;if(r>=s&&r<a){n=!0;break}}if(1==n&&r<e._end.valueOf()&&r!=i){var l=t(i),h=t(a);l.year()!=h.year()?e.switchedYear=!0:l.month()!=h.month()?e.switchedMonth=!0:l.dayOfYear()!=h.dayOfYear()&&(e.switchedDay=!0),e.current=h}}function nP(t,e,i){var n;if(0==t.body.hiddenDates.length)return n=t.range.conversion(i),(e.valueOf()-n.offset)*n.scale;var r=cP(e,t.body.hiddenDates);1==r.hidden&&(e=r.startDate);var o=oP(t.body.hiddenDates,t.range.start,t.range.end);if(e<t.range.start){n=t.range.conversion(i,o);var s=sP(t.body.hiddenDates,e,n.offset);return e=t.options.moment(e).toDate().valueOf(),e+=s,-(n.offset-e.valueOf())*n.scale}if(e>t.range.end){var a={start:t.range.start,end:e};return e=aP(t.options.moment,t.body.hiddenDates,a,e),n=t.range.conversion(i,o),(e.valueOf()-n.offset)*n.scale}return e=aP(t.options.moment,t.body.hiddenDates,t.range,e),n=t.range.conversion(i,o),(e.valueOf()-n.offset)*n.scale}function rP(t,e,i){if(0==t.body.hiddenDates.length){var n=t.range.conversion(i);return new Date(e/n.scale+n.offset)}var r=oP(t.body.hiddenDates,t.range.start,t.range.end),o=(t.range.end-t.range.start-r)*e/i,s=hP(t.body.hiddenDates,t.range,o);return new Date(s+o+t.range.start)}function oP(t,e,i){for(var n=0,r=0;r<t.length;r++){var o=t[r].start,s=t[r].end;o>=e&&s<i&&(n+=s-o)}return n}function sP(t,e,i){for(var n=0,r=0;r<t.length;r++){var o=t[r].start,s=t[r].end;o>=e&&s<=i&&(n+=s-o)}return n}function aP(t,e,i,n){return(n=t(n).toDate().valueOf())-lP(t,e,i,n)}function lP(t,e,i,n){var r=0;n=t(n).toDate().valueOf();for(var o=0;o<e.length;o++){var s=e[o].start,a=e[o].end;s>=i.start&&a<i.end&&n>=a&&(r+=a-s)}return r}function hP(t,e,i){for(var n=0,r=0,o=e.start,s=0;s<t.length;s++){var a=t[s].start,l=t[s].end;if(a>=e.start&&l<e.end){if(r+=a-o,o=l,r>=i)break;n+=l-a}}return n}function uP(t,e,i,n){var r=cP(e,t);return 1==r.hidden?i<0?1==n?r.startDate-(r.endDate-e)-1:r.startDate-1:1==n?r.endDate+(e-r.startDate)+1:r.endDate+1:e}function cP(t,e){for(var i=0;i<e.length;i++){var n=e[i].start,r=e[i].end;if(t>=n&&t<r)return{hidden:!0,startDate:n,endDate:r}}return{hidden:!1,startDate:n,endDate:r}}var dP=Object.freeze({__proto__:null,convertHiddenOptions:QO,correctTimeForHidden:aP,getAccumulatedHiddenDuration:hP,getHiddenDurationBefore:lP,getHiddenDurationBeforeStart:sP,getHiddenDurationBetween:oP,getIsHidden:cP,printDates:function(t){for(var e=0;e<t.length;e++)console.log(e,new Date(t[e].start),new Date(t[e].end),t[e].start,t[e].end,t[e].remove)},removeDuplicates:eP,snapAwayFromHidden:uP,stepOverHiddenDates:iP,toScreen:nP,toTime:rP,updateHiddenDates:tP});var pP=function(t){Ib(i,t);var e=function(t){var e=function(){if("undefined"==typeof Reflect||!MT)return!1;if(MT.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(MT(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var i,n=Rb(t);if(e){var r=Rb(this).constructor;i=MT(n,arguments,r)}else i=n.apply(this,arguments);return Lb(this,i)}}(i);function i(t,n){var r,o,s,a,l,h,u,c;ga(this,i),c=e.call(this);var d=gM().hours(0).minutes(0).seconds(0).milliseconds(0),p=d.clone().add(-3,"days").valueOf(),f=d.clone().add(3,"days").valueOf();return c.millisecondsPerPixelCache=void 0,void 0===n?(c.start=p,c.end=f):(c.start=n.start||p,c.end=n.end||f),c.rolling=!1,c.body=t,c.deltaDifference=0,c.scaleOffset=0,c.startToFront=!1,c.endToFront=!0,c.defaultOptions={rtl:!1,start:null,end:null,moment:gM,direction:"horizontal",moveable:!0,zoomable:!0,min:null,max:null,zoomMin:10,zoomMax:31536e10,rollingMode:{follow:!1,offset:.5}},c.options=EO.extend({},c.defaultOptions),c.props={touch:{}},c.animationTimer=null,c.body.emitter.on("panstart",hp(r=c._onDragStart).call(r,Db(c))),c.body.emitter.on("panmove",hp(o=c._onDrag).call(o,Db(c))),c.body.emitter.on("panend",hp(s=c._onDragEnd).call(s,Db(c))),c.body.emitter.on("mousewheel",hp(a=c._onMouseWheel).call(a,Db(c))),c.body.emitter.on("touch",hp(l=c._onTouch).call(l,Db(c))),c.body.emitter.on("pinch",hp(h=c._onPinch).call(h,Db(c))),c.body.dom.rollingModeBtn.addEventListener("click",hp(u=c.startRolling).call(u,Db(c))),c.setOptions(n),c}return Cc(i,[{key:"setOptions",value:function(t){t&&(EO.selectiveExtend(["animation","direction","min","max","zoomMin","zoomMax","moveable","zoomable","moment","activate","hiddenDates","zoomKey","zoomFriction","rtl","showCurrentTime","rollingMode","horizontalScroll"],this.options,t),t.rollingMode&&t.rollingMode.follow&&this.startRolling(),("start"in t||"end"in t)&&this.setRange(t.start,t.end))}},{key:"startRolling",value:function(){var t=this;!function e(){t.stopRolling(),t.rolling=!0;var i=t.end-t.start,n=EO.convert(new Date,"Date").valueOf(),r=t.options.rollingMode&&t.options.rollingMode.offset||.5,o=n-i*r,s=n+i*(1-r);t.setRange(o,s,{animation:!1}),(i=1/t.conversion(t.body.domProps.center.width).scale/10)<30&&(i=30),i>1e3&&(i=1e3),t.body.dom.rollingModeBtn.style.visibility="hidden",t.currentTimeTimer=uv(e,i)}()}},{key:"stopRolling",value:function(){void 0!==this.currentTimeTimer&&(clearTimeout(this.currentTimeTimer),this.rolling=!1,this.body.dom.rollingModeBtn.style.visibility="visible")}},{key:"setRange",value:function(t,e,i,n,r){i||(i={}),!0!==i.byUser&&(i.byUser=!1);var o=this,s=null!=t?EO.convert(t,"Date").valueOf():null,a=null!=e?EO.convert(e,"Date").valueOf():null;if(this._cancelAnimation(),this.millisecondsPerPixelCache=void 0,i.animation){var l,h=this.start,u=this.end,c="object"===kc(i.animation)&&"duration"in i.animation?i.animation.duration:500,d="object"===kc(i.animation)&&"easingFunction"in i.animation?i.animation.easingFunction:"easeInOutQuad",p=EO.easingFunctions[d];if(!p)throw new Error(xd(l="Unknown easing function ".concat(Wm(d),". Choose from: ")).call(l,Bd(EO.easingFunctions).join(", ")));var f=Vd(),m=!1;return function t(){if(!o.props.touch.dragging){var e=Vd()-f,l=p(e/c),d=e>c,g=d||null===s?s:h+(s-h)*l,y=d||null===a?a:u+(a-u)*l;v=o._applyRange(g,y),tP(o.options.moment,o.body,o.options.hiddenDates),m=m||v;var b={start:new Date(o.start),end:new Date(o.end),byUser:i.byUser,event:i.event};if(r&&r(l,v,d),v&&o.body.emitter.emit("rangechange",b),d){if(m&&(o.body.emitter.emit("rangechanged",b),n))return n()}else o.animationTimer=uv(t,20)}}()}var v=this._applyRange(s,a);if(tP(this.options.moment,this.body,this.options.hiddenDates),v){var g={start:new Date(this.start),end:new Date(this.end),byUser:i.byUser,event:i.event};if(this.body.emitter.emit("rangechange",g),clearTimeout(o.timeoutID),o.timeoutID=uv((function(){o.body.emitter.emit("rangechanged",g)}),200),n)return n()}}},{key:"getMillisecondsPerPixel",value:function(){return void 0===this.millisecondsPerPixelCache&&(this.millisecondsPerPixelCache=(this.end-this.start)/this.body.dom.center.clientWidth),this.millisecondsPerPixelCache}},{key:"_cancelAnimation",value:function(){this.animationTimer&&(clearTimeout(this.animationTimer),this.animationTimer=null)}},{key:"_applyRange",value:function(t,e){var i,n=null!=t?EO.convert(t,"Date").valueOf():this.start,r=null!=e?EO.convert(e,"Date").valueOf():this.end,o=null!=this.options.max?EO.convert(this.options.max,"Date").valueOf():null,s=null!=this.options.min?EO.convert(this.options.min,"Date").valueOf():null;if(isNaN(n)||null===n)throw new Error('Invalid start "'.concat(t,'"'));if(isNaN(r)||null===r)throw new Error('Invalid end "'.concat(e,'"'));if(r<n&&(r=n),null!==s&&n<s&&(n+=i=s-n,r+=i,null!=o&&r>o&&(r=o)),null!==o&&r>o&&(n-=i=r-o,r-=i,null!=s&&n<s&&(n=s)),null!==this.options.zoomMin){var a=zO(this.options.zoomMin);a<0&&(a=0),r-n<a&&(this.end-this.start===a&&n>=this.start-.5&&r<=this.end?(n=this.start,r=this.end):(n-=(i=a-(r-n))/2,r+=i/2))}if(null!==this.options.zoomMax){var l=zO(this.options.zoomMax);l<0&&(l=0),r-n>l&&(this.end-this.start===l&&n<this.start&&r>this.end?(n=this.start,r=this.end):(n+=(i=r-n-l)/2,r-=i/2))}var h=this.start!=n||this.end!=r;return n>=this.start&&n<=this.end||r>=this.start&&r<=this.end||this.start>=n&&this.start<=r||this.end>=n&&this.end<=r||this.body.emitter.emit("checkRangedItems"),this.start=n,this.end=r,h}},{key:"getRange",value:function(){return{start:this.start,end:this.end}}},{key:"conversion",value:function(t,e){return i.conversion(this.start,this.end,t,e)}},{key:"_onDragStart",value:function(t){this.deltaDifference=0,this.previousDelta=0,this.options.moveable&&this._isInsideRange(t)&&this.props.touch.allowDragging&&(this.stopRolling(),this.props.touch.start=this.start,this.props.touch.end=this.end,this.props.touch.dragging=!0,this.body.dom.root&&(this.body.dom.root.style.cursor="move"))}},{key:"_onDrag",value:function(t){if(t&&this.props.touch.dragging&&this.options.moveable&&this.props.touch.allowDragging){var e=this.options.direction;fP(e);var i="horizontal"==e?t.deltaX:t.deltaY;i-=this.deltaDifference;var n=this.props.touch.end-this.props.touch.start;n-=oP(this.body.hiddenDates,this.start,this.end);var r,o="horizontal"==e?this.body.domProps.center.width:this.body.domProps.center.height;r=this.options.rtl?i/o*n:-i/o*n;var s=this.props.touch.start+r,a=this.props.touch.end+r,l=uP(this.body.hiddenDates,s,this.previousDelta-i,!0),h=uP(this.body.hiddenDates,a,this.previousDelta-i,!0);if(l!=s||h!=a)return this.deltaDifference+=i,this.props.touch.start=l,this.props.touch.end=h,void this._onDrag(t);this.previousDelta=i,this._applyRange(s,a);var u=new Date(this.start),c=new Date(this.end);this.body.emitter.emit("rangechange",{start:u,end:c,byUser:!0,event:t}),this.body.emitter.emit("panmove")}}},{key:"_onDragEnd",value:function(t){this.props.touch.dragging&&this.options.moveable&&this.props.touch.allowDragging&&(this.props.touch.dragging=!1,this.body.dom.root&&(this.body.dom.root.style.cursor="auto"),this.body.emitter.emit("rangechanged",{start:new Date(this.start),end:new Date(this.end),byUser:!0,event:t}))}},{key:"_onMouseWheel",value:function(t){var e=0;if(t.wheelDelta?e=t.wheelDelta/120:t.detail?e=-t.detail/3:t.deltaY&&(e=-t.deltaY/3),!(this.options.zoomKey&&!t[this.options.zoomKey]&&this.options.zoomable||!this.options.zoomable&&this.options.moveable)&&this.options.zoomable&&this.options.moveable&&this._isInsideRange(t)&&e){var i,n,r=this.options.zoomFriction||5;if(i=e<0?1-e/r:1/(1+e/r),this.rolling){var o=this.options.rollingMode&&this.options.rollingMode.offset||.5;n=this.start+(this.end-this.start)*o}else{var s=this.getPointer({x:t.clientX,y:t.clientY},this.body.dom.center);n=this._pointerToDate(s)}this.zoom(i,n,e,t),t.preventDefault()}}},{key:"_onTouch",value:function(t){this.props.touch.start=this.start,this.props.touch.end=this.end,this.props.touch.allowDragging=!0,this.props.touch.center=null,this.props.touch.centerDate=null,this.scaleOffset=0,this.deltaDifference=0,EO.preventDefault(t)}},{key:"_onPinch",value:function(t){if(this.options.zoomable&&this.options.moveable){EO.preventDefault(t),this.props.touch.allowDragging=!1,this.props.touch.center||(this.props.touch.center=this.getPointer(t.center,this.body.dom.center),this.props.touch.centerDate=this._pointerToDate(this.props.touch.center)),this.stopRolling();var e=1/(t.scale+this.scaleOffset),i=this.props.touch.centerDate,n=oP(this.body.hiddenDates,this.start,this.end),r=lP(this.options.moment,this.body.hiddenDates,this,i),o=n-r,s=i-r+(this.props.touch.start-(i-r))*e,a=i+o+(this.props.touch.end-(i+o))*e;this.startToFront=1-e<=0,this.endToFront=e-1<=0;var l=uP(this.body.hiddenDates,s,1-e,!0),h=uP(this.body.hiddenDates,a,e-1,!0);l==s&&h==a||(this.props.touch.start=l,this.props.touch.end=h,this.scaleOffset=1-t.scale,s=l,a=h);var u={animation:!1,byUser:!0,event:t};this.setRange(s,a,u),this.startToFront=!1,this.endToFront=!0}}},{key:"_isInsideRange",value:function(t){var e=t.center?t.center.x:t.clientX,i=this.body.dom.centerContainer.getBoundingClientRect(),n=this.options.rtl?e-i.left:i.right-e,r=this.body.util.toTime(n);return r>=this.start&&r<=this.end}},{key:"_pointerToDate",value:function(t){var e,i=this.options.direction;if(fP(i),"horizontal"==i)return this.body.util.toTime(t.x).valueOf();var n=this.body.domProps.center.height;return e=this.conversion(n),t.y/e.scale+e.offset}},{key:"getPointer",value:function(t,e){var i=e.getBoundingClientRect();return this.options.rtl?{x:i.right-t.x,y:t.y-i.top}:{x:t.x-i.left,y:t.y-i.top}}},{key:"zoom",value:function(t,e,i,n){null==e&&(e=(this.start+this.end)/2);var r=oP(this.body.hiddenDates,this.start,this.end),o=lP(this.options.moment,this.body.hiddenDates,this,e),s=r-o,a=e-o+(this.start-(e-o))*t,l=e+s+(this.end-(e+s))*t;this.startToFront=!(i>0),this.endToFront=!(-i>0);var h=uP(this.body.hiddenDates,a,i,!0),u=uP(this.body.hiddenDates,l,-i,!0);h==a&&u==l||(a=h,l=u);var c={animation:!1,byUser:!0,event:n};this.setRange(a,l,c),this.startToFront=!1,this.endToFront=!0}},{key:"move",value:function(t){var e=this.end-this.start,i=this.start+e*t,n=this.end+e*t;this.start=i,this.end=n}},{key:"moveTo",value:function(t){var e=(this.start+this.end)/2-t,i=this.start-e,n=this.end-e;this.setRange(i,n,{animation:!1,byUser:!0,event:null})}},{key:"destroy",value:function(){this.stopRolling()}}],[{key:"conversion",value:function(t,e,i,n){return void 0===n&&(n=0),0!=i&&e-t!=0?{offset:t,scale:i/(e-t-n)}:{offset:0,scale:1}}}]),i}(GO);function fP(t){if("horizontal"!=t&&"vertical"!=t)throw new TypeError('Unknown direction "'.concat(t,'". Choose "horizontal" or "vertical".'))}var mP,vP=n(ue.setInterval),gP=null;mP="undefined"!=typeof window?function t(e,i){var n=i||{preventDefault:!1};if(e.Manager){var r=e,o=function(e,i){var o=Object.create(n);return i&&r.assign(o,i),t(new r(e,o),o)};return r.assign(o,r),o.Manager=function(e,i){var o=Object.create(n);return i&&r.assign(o,i),t(new r.Manager(e,o),o)},o}var s=Object.create(e),a=e.element;function l(t){return t.match(/[^ ]+/g)}function h(t){if("hammer.input"!==t.type){if(t.srcEvent._handled||(t.srcEvent._handled={}),t.srcEvent._handled[t.type])return;t.srcEvent._handled[t.type]=!0}var e=!1;t.stopPropagation=function(){e=!0};var i=t.srcEvent.stopPropagation.bind(t.srcEvent);"function"==typeof i&&(t.srcEvent.stopPropagation=function(){i(),t.stopPropagation()}),t.firstTarget=gP;for(var n=gP;n&&!e;){var r=n.hammer;if(r)for(var o,s=0;s<r.length;s++)if(o=r[s]._handlers[t.type])for(var a=0;a<o.length&&!e;a++)o[a](t);n=n.parentNode}}return a.hammer||(a.hammer=[]),a.hammer.push(s),e.on("hammer.input",(function(t){!0!==n.preventDefault&&n.preventDefault!==t.pointerType||t.preventDefault(),t.isFirst&&(gP=t.target)})),s._handlers={},s.on=function(t,i){return l(t).forEach((function(t){var n=s._handlers[t];n||(s._handlers[t]=n=[],e.on(t,h)),n.push(i)})),s},s.off=function(t,i){return l(t).forEach((function(t){var n=s._handlers[t];n&&((n=i?n.filter((function(t){return t!==i})):[]).length>0?s._handlers[t]=n:(e.off(t,h),delete s._handlers[t]))})),s},s.emit=function(t,i){gP=i.target,e.emit(t,i)},s.destroy=function(){var t=e.element.hammer,i=t.indexOf(s);-1!==i&&t.splice(i,1),t.length||delete e.element.hammer,s._handlers={},e.destroy()},s}(window.Hammer||my,{preventDefault:"mouse"}):function(){return function(){var t=function(){};return{on:t,off:t,destroy:t,emit:t,get:function(e){return{set:t}}}}()};var yP=mP;function bP(t,e){e.inputHandler=function(t){t.isFirst&&e(t)},t.on("hammer.input",e.inputHandler)}var _P=function(){function t(e,i,n,r,o){ga(this,t),this.moment=o&&o.moment||gM,this.options=o||{},this.current=this.moment(),this._start=this.moment(),this._end=this.moment(),this.autoScale=!0,this.scale="day",this.step=1,this.setRange(e,i,n),this.switchedDay=!1,this.switchedMonth=!1,this.switchedYear=!1,Id(r)?this.hiddenDates=r:this.hiddenDates=null!=r?[r]:[],this.format=t.FORMAT}return Cc(t,[{key:"setMoment",value:function(t){this.moment=t,this.current=this.moment(this.current.valueOf()),this._start=this.moment(this._start.valueOf()),this._end=this.moment(this._end.valueOf())}},{key:"setFormat",value:function(e){var i=EO.deepExtend({},t.FORMAT);this.format=EO.deepExtend(i,e)}},{key:"setRange",value:function(t,e,i){if(!(t instanceof Date&&e instanceof Date))throw"No legal start or end date in method setRange";this._start=null!=t?this.moment(t.valueOf()):Vd(),this._end=null!=e?this.moment(e.valueOf()):Vd(),this.autoScale&&this.setMinimumStep(i)}},{key:"start",value:function(){this.current=this._start.clone(),this.roundToMinor()}},{key:"roundToMinor",value:function(){switch("week"==this.scale&&this.current.weekday(0),this.scale){case"year":this.current.year(this.step*Math.floor(this.current.year()/this.step)),this.current.month(0);case"month":this.current.date(1);case"week":case"day":case"weekday":this.current.hours(0);case"hour":this.current.minutes(0);case"minute":this.current.seconds(0);case"second":this.current.milliseconds(0)}if(1!=this.step){var t=this.current.clone();switch(this.scale){case"millisecond":this.current.subtract(this.current.milliseconds()%this.step,"milliseconds");break;case"second":this.current.subtract(this.current.seconds()%this.step,"seconds");break;case"minute":this.current.subtract(this.current.minutes()%this.step,"minutes");break;case"hour":this.current.subtract(this.current.hours()%this.step,"hours");break;case"weekday":case"day":this.current.subtract((this.current.date()-1)%this.step,"day");break;case"week":this.current.subtract(this.current.week()%this.step,"week");break;case"month":this.current.subtract(this.current.month()%this.step,"month");break;case"year":this.current.subtract(this.current.year()%this.step,"year")}t.isSame(this.current)||(this.current=this.moment(uP(this.hiddenDates,this.current.valueOf(),-1,!0)))}}},{key:"hasNext",value:function(){return this.current.valueOf()<=this._end.valueOf()}},{key:"next",value:function(){var t=this.current.valueOf();switch(this.scale){case"millisecond":this.current.add(this.step,"millisecond");break;case"second":this.current.add(this.step,"second");break;case"minute":this.current.add(this.step,"minute");break;case"hour":this.current.add(this.step,"hour"),this.current.month()<6?this.current.subtract(this.current.hours()%this.step,"hour"):this.current.hours()%this.step!=0&&this.current.add(this.step-this.current.hours()%this.step,"hour");break;case"weekday":case"day":this.current.add(this.step,"day");break;case"week":if(0!==this.current.weekday())this.current.weekday(0),this.current.add(this.step,"week");else if(!1===this.options.showMajorLabels)this.current.add(this.step,"week");else{var e=this.current.clone();e.add(1,"week"),e.isSame(this.current,"month")?this.current.add(this.step,"week"):(this.current.add(this.step,"week"),this.current.date(1))}break;case"month":this.current.add(this.step,"month");break;case"year":this.current.add(this.step,"year")}if(1!=this.step)switch(this.scale){case"millisecond":this.current.milliseconds()>0&&this.current.milliseconds()<this.step&&this.current.milliseconds(0);break;case"second":this.current.seconds()>0&&this.current.seconds()<this.step&&this.current.seconds(0);break;case"minute":this.current.minutes()>0&&this.current.minutes()<this.step&&this.current.minutes(0);break;case"hour":this.current.hours()>0&&this.current.hours()<this.step&&this.current.hours(0);break;case"weekday":case"day":this.current.date()<this.step+1&&this.current.date(1);break;case"week":this.current.week()<this.step&&this.current.week(1);break;case"month":this.current.month()<this.step&&this.current.month(0)}this.current.valueOf()==t&&(this.current=this._end.clone()),this.switchedDay=!1,this.switchedMonth=!1,this.switchedYear=!1,iP(this.moment,this,t)}},{key:"getCurrent",value:function(){return this.current.clone()}},{key:"setScale",value:function(t){t&&"string"==typeof t.scale&&(this.scale=t.scale,this.step=t.step>0?t.step:1,this.autoScale=!1)}},{key:"setAutoScale",value:function(t){this.autoScale=t}},{key:"setMinimumStep",value:function(t){if(null!=t){var e=31104e6;1e3*e>t&&(this.scale="year",this.step=1e3),500*e>t&&(this.scale="year",this.step=500),100*e>t&&(this.scale="year",this.step=100),50*e>t&&(this.scale="year",this.step=50),10*e>t&&(this.scale="year",this.step=10),5*e>t&&(this.scale="year",this.step=5),e>t&&(this.scale="year",this.step=1),7776e6>t&&(this.scale="month",this.step=3),2592e6>t&&(this.scale="month",this.step=1),6048e5>t&&this.options.showWeekScale&&(this.scale="week",this.step=1),1728e5>t&&(this.scale="day",this.step=2),864e5>t&&(this.scale="day",this.step=1),432e5>t&&(this.scale="weekday",this.step=1),144e5>t&&(this.scale="hour",this.step=4),36e5>t&&(this.scale="hour",this.step=1),9e5>t&&(this.scale="minute",this.step=15),6e5>t&&(this.scale="minute",this.step=10),3e5>t&&(this.scale="minute",this.step=5),6e4>t&&(this.scale="minute",this.step=1),15e3>t&&(this.scale="second",this.step=15),1e4>t&&(this.scale="second",this.step=10),5e3>t&&(this.scale="second",this.step=5),1e3>t&&(this.scale="second",this.step=1),200>t&&(this.scale="millisecond",this.step=200),100>t&&(this.scale="millisecond",this.step=100),50>t&&(this.scale="millisecond",this.step=50),10>t&&(this.scale="millisecond",this.step=10),5>t&&(this.scale="millisecond",this.step=5),1>t&&(this.scale="millisecond",this.step=1)}}},{key:"isMajor",value:function(){if(1==this.switchedYear)switch(this.scale){case"year":case"month":case"week":case"weekday":case"day":case"hour":case"minute":case"second":case"millisecond":return!0;default:return!1}else if(1==this.switchedMonth)switch(this.scale){case"week":case"weekday":case"day":case"hour":case"minute":case"second":case"millisecond":return!0;default:return!1}else if(1==this.switchedDay)switch(this.scale){case"millisecond":case"second":case"minute":case"hour":return!0;default:return!1}var t=this.moment(this.current);switch(this.scale){case"millisecond":return 0==t.milliseconds();case"second":return 0==t.seconds();case"minute":return 0==t.hours()&&0==t.minutes();case"hour":return 0==t.hours();case"weekday":case"day":return this.options.showWeekScale?1==t.isoWeekday():1==t.date();case"week":return 1==t.date();case"month":return 0==t.month();default:return!1}}},{key:"getLabelMinor",value:function(t){if(null==t&&(t=this.current),t instanceof Date&&(t=this.moment(t)),"function"==typeof this.format.minorLabels)return this.format.minorLabels(t,this.scale,this.step);var e=this.format.minorLabels[this.scale];return"week"===this.scale&&1===t.date()&&0!==t.weekday()?"":e&&e.length>0?this.moment(t).format(e):""}},{key:"getLabelMajor",value:function(t){if(null==t&&(t=this.current),t instanceof Date&&(t=this.moment(t)),"function"==typeof this.format.majorLabels)return this.format.majorLabels(t,this.scale,this.step);var e=this.format.majorLabels[this.scale];return e&&e.length>0?this.moment(t).format(e):""}},{key:"getClassName",value:function(){var t,e=this.moment,i=this.moment(this.current),n=i.locale?i.locale("en"):i.lang("en"),r=this.step,o=[];function s(t){return t/r%2==0?" vis-even":" vis-odd"}function a(t){return t.isSame(Vd(),"day")?" vis-today":t.isSame(e().add(1,"day"),"day")?" vis-tomorrow":t.isSame(e().add(-1,"day"),"day")?" vis-yesterday":""}function l(t){return t.isSame(Vd(),"week")?" vis-current-week":""}function h(t){return t.isSame(Vd(),"month")?" vis-current-month":""}switch(this.scale){case"millisecond":o.push(a(n)),o.push(s(n.milliseconds()));break;case"second":o.push(a(n)),o.push(s(n.seconds()));break;case"minute":o.push(a(n)),o.push(s(n.minutes()));break;case"hour":o.push(xd(t="vis-h".concat(n.hours())).call(t,4==this.step?"-h"+(n.hours()+4):"")),o.push(a(n)),o.push(s(n.hours()));break;case"weekday":o.push("vis-".concat(n.format("dddd").toLowerCase())),o.push(a(n)),o.push(l(n)),o.push(s(n.date()));break;case"day":o.push("vis-day".concat(n.date())),o.push("vis-".concat(n.format("MMMM").toLowerCase())),o.push(a(n)),o.push(h(n)),o.push(this.step<=2?a(n):""),o.push(this.step<=2?"vis-".concat(n.format("dddd").toLowerCase()):""),o.push(s(n.date()-1));break;case"week":o.push("vis-week".concat(n.format("w"))),o.push(l(n)),o.push(s(n.week()));break;case"month":o.push("vis-".concat(n.format("MMMM").toLowerCase())),o.push(h(n)),o.push(s(n.month()));break;case"year":o.push("vis-year".concat(n.year())),o.push(function(t){return t.isSame(Vd(),"year")?" vis-current-year":""}(n)),o.push(s(n.year()))}return Vf(o).call(o,String).join(" ")}}],[{key:"snap",value:function(t,e,i){var n=gM(t);if("year"==e){var r=n.year()+Math.round(n.month()/12);n.year(Math.round(r/i)*i),n.month(0),n.date(0),n.hours(0),n.minutes(0),n.seconds(0),n.milliseconds(0)}else if("month"==e)n.date()>15?(n.date(1),n.add(1,"month")):n.date(1),n.hours(0),n.minutes(0),n.seconds(0),n.milliseconds(0);else if("week"==e)n.weekday()>2?(n.weekday(0),n.add(1,"week")):n.weekday(0),n.hours(0),n.minutes(0),n.seconds(0),n.milliseconds(0);else if("day"==e){switch(i){case 5:case 2:n.hours(24*Math.round(n.hours()/24));break;default:n.hours(12*Math.round(n.hours()/12))}n.minutes(0),n.seconds(0),n.milliseconds(0)}else if("weekday"==e){switch(i){case 5:case 2:n.hours(12*Math.round(n.hours()/12));break;default:n.hours(6*Math.round(n.hours()/6))}n.minutes(0),n.seconds(0),n.milliseconds(0)}else if("hour"==e)4===i?n.minutes(60*Math.round(n.minutes()/60)):n.minutes(30*Math.round(n.minutes()/30)),n.seconds(0),n.milliseconds(0);else if("minute"==e){switch(i){case 15:case 10:n.minutes(5*Math.round(n.minutes()/5)),n.seconds(0);break;case 5:n.seconds(60*Math.round(n.seconds()/60));break;default:n.seconds(30*Math.round(n.seconds()/30))}n.milliseconds(0)}else if("second"==e)switch(i){case 15:case 10:n.seconds(5*Math.round(n.seconds()/5)),n.milliseconds(0);break;case 5:n.milliseconds(1e3*Math.round(n.milliseconds()/1e3));break;default:n.milliseconds(500*Math.round(n.milliseconds()/500))}else if("millisecond"==e){var o=i>5?i/2:1;n.milliseconds(Math.round(n.milliseconds()/o)*o)}return n}}]),t}();function wP(t,e){void 0===e&&(e={});var i=e.insertAt;if(t&&"undefined"!=typeof document){var n=document.head||document.getElementsByTagName("head")[0],r=document.createElement("style");r.type="text/css","top"===i&&n.firstChild?n.insertBefore(r,n.firstChild):n.appendChild(r),r.styleSheet?r.styleSheet.cssText=t:r.appendChild(document.createTextNode(t))}}_P.FORMAT={minorLabels:{millisecond:"SSS",second:"s",minute:"HH:mm",hour:"HH:mm",weekday:"ddd D",day:"D",week:"w",month:"MMM",year:"YYYY"},majorLabels:{millisecond:"HH:mm:ss",second:"D MMMM HH:mm",minute:"ddd D MMMM",hour:"ddd D MMMM",weekday:"MMMM YYYY",day:"MMMM YYYY",week:"MMMM YYYY",month:"YYYY",year:""}},wP(".vis-time-axis{overflow:hidden;position:relative}.vis-time-axis.vis-foreground{left:0;top:0;width:100%}.vis-time-axis.vis-background{height:100%;left:0;position:absolute;top:0;width:100%}.vis-time-axis .vis-text{box-sizing:border-box;color:#4d4d4d;overflow:hidden;padding:3px;position:absolute;white-space:nowrap}.vis-time-axis .vis-text.vis-measure{margin-left:0;margin-right:0;padding-left:0;padding-right:0;position:absolute;visibility:hidden}.vis-time-axis .vis-grid.vis-vertical{border-left:1px solid;position:absolute}.vis-time-axis .vis-grid.vis-vertical-rtl{border-right:1px solid;position:absolute}.vis-time-axis .vis-grid.vis-minor{border-color:#e5e5e5}.vis-time-axis .vis-grid.vis-major{border-color:#bfbfbf}");var kP=function(t){Ib(i,t);var e=function(t){var e=function(){if("undefined"==typeof Reflect||!MT)return!1;if(MT.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(MT(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var i,n=Rb(t);if(e){var r=Rb(this).constructor;i=MT(n,arguments,r)}else i=n.apply(this,arguments);return Lb(this,i)}}(i);function i(t,n){var r;return ga(this,i),(r=e.call(this)).dom={foreground:null,lines:[],majorTexts:[],minorTexts:[],redundant:{lines:[],majorTexts:[],minorTexts:[]}},r.props={range:{start:0,end:0,minimumStep:0},lineTop:0},r.defaultOptions={orientation:{axis:"bottom"},showMinorLabels:!0,showMajorLabels:!0,showWeekScale:!1,maxMinorChars:7,format:EO.extend({},_P.FORMAT),moment:gM,timeAxis:null},r.options=EO.extend({},r.defaultOptions),r.body=t,r._create(),r.setOptions(n),r}return Cc(i,[{key:"setOptions",value:function(t){t&&(EO.selectiveExtend(["showMinorLabels","showMajorLabels","showWeekScale","maxMinorChars","hiddenDates","timeAxis","moment","rtl"],this.options,t),EO.selectiveDeepExtend(["format"],this.options,t),"orientation"in t&&("string"==typeof t.orientation?this.options.orientation.axis=t.orientation:"object"===kc(t.orientation)&&"axis"in t.orientation&&(this.options.orientation.axis=t.orientation.axis)),"locale"in t&&("function"==typeof gM.locale?gM.locale(t.locale):gM.lang(t.locale)))}},{key:"_create",value:function(){this.dom.foreground=document.createElement("div"),this.dom.background=document.createElement("div"),this.dom.foreground.className="vis-time-axis vis-foreground",this.dom.background.className="vis-time-axis vis-background"}},{key:"destroy",value:function(){this.dom.foreground.parentNode&&this.dom.foreground.parentNode.removeChild(this.dom.foreground),this.dom.background.parentNode&&this.dom.background.parentNode.removeChild(this.dom.background),this.body=null}},{key:"redraw",value:function(){var t=this.props,e=this.dom.foreground,i=this.dom.background,n="top"==this.options.orientation.axis?this.body.dom.top:this.body.dom.bottom,r=e.parentNode!==n;this._calculateCharSize();var o=this.options.showMinorLabels&&"none"!==this.options.orientation.axis,s=this.options.showMajorLabels&&"none"!==this.options.orientation.axis;t.minorLabelHeight=o?t.minorCharHeight:0,t.majorLabelHeight=s?t.majorCharHeight:0,t.height=t.minorLabelHeight+t.majorLabelHeight,t.width=e.offsetWidth,t.minorLineHeight=this.body.domProps.root.height-t.majorLabelHeight-("top"==this.options.orientation.axis?this.body.domProps.bottom.height:this.body.domProps.top.height),t.minorLineWidth=1,t.majorLineHeight=t.minorLineHeight+t.majorLabelHeight,t.majorLineWidth=1;var a=e.nextSibling,l=i.nextSibling;return e.parentNode&&e.parentNode.removeChild(e),i.parentNode&&i.parentNode.removeChild(i),e.style.height="".concat(this.props.height,"px"),this._repaintLabels(),a?n.insertBefore(e,a):n.appendChild(e),l?this.body.dom.backgroundVertical.insertBefore(i,l):this.body.dom.backgroundVertical.appendChild(i),this._isResized()||r}},{key:"_repaintLabels",value:function(){var t=this.options.orientation.axis,e=EO.convert(this.body.range.start,"Number"),i=EO.convert(this.body.range.end,"Number"),n=this.body.util.toTime((this.props.minorCharWidth||10)*this.options.maxMinorChars).valueOf(),r=n-lP(this.options.moment,this.body.hiddenDates,this.body.range,n);r-=this.body.util.toTime(0).valueOf();var o=new _P(new Date(e),new Date(i),r,this.body.hiddenDates,this.options);o.setMoment(this.options.moment),this.options.format&&o.setFormat(this.options.format),this.options.timeAxis&&o.setScale(this.options.timeAxis),this.step=o;var s,a,l,h,u,c,d=this.dom;d.redundant.lines=d.lines,d.redundant.majorTexts=d.majorTexts,d.redundant.minorTexts=d.minorTexts,d.lines=[],d.majorTexts=[],d.minorTexts=[];var p,f,m,v=0,g=void 0,y=0,b=1e3;for(o.start(),a=o.getCurrent(),h=this.body.util.toScreen(a);o.hasNext()&&y<b;){if(y++,u=o.isMajor(),m=o.getClassName(),s=a,l=h,o.next(),a=o.getCurrent(),p=v,v=(h=this.body.util.toScreen(a))-l,c="week"===o.scale||v>=.4*p,this.options.showMinorLabels&&c){var _=this._repaintMinorText(l,o.getLabelMinor(s),t,m);_.style.width="".concat(v,"px")}u&&this.options.showMajorLabels?(l>0&&(null==g&&(g=l),_=this._repaintMajorText(l,o.getLabelMajor(s),t,m)),f=this._repaintMajorLine(l,v,t,m)):c?f=this._repaintMinorLine(l,v,t,m):f&&(f.style.width="".concat(Cm(f.style.width)+v,"px"))}if(y!==b||xP||(console.warn("Something is wrong with the Timeline scale. Limited drawing of grid lines to ".concat(b," lines.")),xP=!0),this.options.showMajorLabels){var w=this.body.util.toTime(0),k=o.getLabelMajor(w),x=k.length*(this.props.majorCharWidth||10)+10;(null==g||x<g)&&this._repaintMajorText(0,k,t,m)}kp(EO).call(EO,this.dom.redundant,(function(t){for(;t.length;){var e=t.pop();e&&e.parentNode&&e.parentNode.removeChild(e)}}))}},{key:"_repaintMinorText",value:function(t,e,i,n){var r=this.dom.redundant.minorTexts.shift();if(!r){var o=document.createTextNode("");(r=document.createElement("div")).appendChild(o),this.dom.foreground.appendChild(r)}this.dom.minorTexts.push(r),r.innerHTML=EO.xss(e);var s="top"==i?this.props.majorLabelHeight:0;return this._setXY(r,t,s),r.className="vis-text vis-minor ".concat(n),r}},{key:"_repaintMajorText",value:function(t,e,i,n){var r=this.dom.redundant.majorTexts.shift();if(!r){var o=document.createElement("div");(r=document.createElement("div")).appendChild(o),this.dom.foreground.appendChild(r)}r.childNodes[0].innerHTML=EO.xss(e),r.className="vis-text vis-major ".concat(n);var s="top"==i?0:this.props.minorLabelHeight;return this._setXY(r,t,s),this.dom.majorTexts.push(r),r}},{key:"_setXY",value:function(t,e,i){var n,r=this.options.rtl?-1*e:e;t.style.transform=xd(n="translate(".concat(r,"px, ")).call(n,i,"px)")}},{key:"_repaintMinorLine",value:function(t,e,i,n){var r,o=this.dom.redundant.lines.shift();o||(o=document.createElement("div"),this.dom.background.appendChild(o)),this.dom.lines.push(o);var s=this.props;o.style.width="".concat(e,"px"),o.style.height="".concat(s.minorLineHeight,"px");var a="top"==i?s.majorLabelHeight:this.body.domProps.top.height,l=t-s.minorLineWidth/2;return this._setXY(o,l,a),o.className=xd(r="vis-grid ".concat(this.options.rtl?"vis-vertical-rtl":"vis-vertical"," vis-minor ")).call(r,n),o}},{key:"_repaintMajorLine",value:function(t,e,i,n){var r,o=this.dom.redundant.lines.shift();o||(o=document.createElement("div"),this.dom.background.appendChild(o)),this.dom.lines.push(o);var s=this.props;o.style.width="".concat(e,"px"),o.style.height="".concat(s.majorLineHeight,"px");var a="top"==i?0:this.body.domProps.top.height,l=t-s.majorLineWidth/2;return this._setXY(o,l,a),o.className=xd(r="vis-grid ".concat(this.options.rtl?"vis-vertical-rtl":"vis-vertical"," vis-major ")).call(r,n),o}},{key:"_calculateCharSize",value:function(){this.dom.measureCharMinor||(this.dom.measureCharMinor=document.createElement("DIV"),this.dom.measureCharMinor.className="vis-text vis-minor vis-measure",this.dom.measureCharMinor.style.position="absolute",this.dom.measureCharMinor.appendChild(document.createTextNode("0")),this.dom.foreground.appendChild(this.dom.measureCharMinor)),this.props.minorCharHeight=this.dom.measureCharMinor.clientHeight,this.props.minorCharWidth=this.dom.measureCharMinor.clientWidth,this.dom.measureCharMajor||(this.dom.measureCharMajor=document.createElement("DIV"),this.dom.measureCharMajor.className="vis-text vis-major vis-measure",this.dom.measureCharMajor.style.position="absolute",this.dom.measureCharMajor.appendChild(document.createTextNode("0")),this.dom.foreground.appendChild(this.dom.measureCharMajor)),this.props.majorCharHeight=this.dom.measureCharMajor.clientHeight,this.props.majorCharWidth=this.dom.measureCharMajor.clientWidth}}]),i}(GO),xP=!1;function SP(t){var e,i=t&&t.preventDefault||!1,n=t&&t.container||window,r={},o={keydown:{},keyup:{}},s={};for(e=97;e<=122;e++)s[String.fromCharCode(e)]={code:e-97+65,shift:!1};for(e=65;e<=90;e++)s[String.fromCharCode(e)]={code:e,shift:!0};for(e=0;e<=9;e++)s[""+e]={code:48+e,shift:!1};for(e=1;e<=12;e++)s["F"+e]={code:111+e,shift:!1};for(e=0;e<=9;e++)s["num"+e]={code:96+e,shift:!1};s["num*"]={code:106,shift:!1},s["num+"]={code:107,shift:!1},s["num-"]={code:109,shift:!1},s["num/"]={code:111,shift:!1},s["num."]={code:110,shift:!1},s.left={code:37,shift:!1},s.up={code:38,shift:!1},s.right={code:39,shift:!1},s.down={code:40,shift:!1},s.space={code:32,shift:!1},s.enter={code:13,shift:!1},s.shift={code:16,shift:void 0},s.esc={code:27,shift:!1},s.backspace={code:8,shift:!1},s.tab={code:9,shift:!1},s.ctrl={code:17,shift:!1},s.alt={code:18,shift:!1},s.delete={code:46,shift:!1},s.pageup={code:33,shift:!1},s.pagedown={code:34,shift:!1},s["="]={code:187,shift:!1},s["-"]={code:189,shift:!1},s["]"]={code:221,shift:!1},s["["]={code:219,shift:!1};var a=function(t){h(t,"keydown")},l=function(t){h(t,"keyup")},h=function(t,e){if(void 0!==o[e][t.keyCode]){for(var n=o[e][t.keyCode],r=0;r<n.length;r++)(void 0===n[r].shift||1==n[r].shift&&1==t.shiftKey||0==n[r].shift&&0==t.shiftKey)&&n[r].fn(t);1==i&&t.preventDefault()}};return r.bind=function(t,e,i){if(void 0===i&&(i="keydown"),void 0===s[t])throw new Error("unsupported key: "+t);void 0===o[i][s[t].code]&&(o[i][s[t].code]=[]),o[i][s[t].code].push({fn:e,shift:s[t].shift})},r.bindAll=function(t,e){for(var i in void 0===e&&(e="keydown"),s)s.hasOwnProperty(i)&&r.bind(i,t,e)},r.getKey=function(t){for(var e in s)if(s.hasOwnProperty(e)){if(1==t.shiftKey&&1==s[e].shift&&t.keyCode==s[e].code)return e;if(0==t.shiftKey&&0==s[e].shift&&t.keyCode==s[e].code)return e;if(t.keyCode==s[e].code&&"shift"==e)return e}return"unknown key, currently not supported"},r.unbind=function(t,e,i){if(void 0===i&&(i="keydown"),void 0===s[t])throw new Error("unsupported key: "+t);if(void 0!==e){var n=[],r=o[i][s[t].code];if(void 0!==r)for(var a=0;a<r.length;a++)r[a].fn==e&&r[a].shift==s[t].shift||n.push(o[i][s[t].code][a]);o[i][s[t].code]=n}else o[i][s[t].code]=[]},r.reset=function(){o={keydown:{},keyup:{}}},r.destroy=function(){o={keydown:{},keyup:{}},n.removeEventListener("keydown",a,!0),n.removeEventListener("keyup",l,!0)},n.addEventListener("keydown",a,!0),n.addEventListener("keyup",l,!0),r}function DP(t){var e,i;this.active=!1,this.dom={container:t},this.dom.overlay=document.createElement("div"),this.dom.overlay.className="vis-overlay",this.dom.container.appendChild(this.dom.overlay),this.hammer=yP(this.dom.overlay),this.hammer.on("tap",hp(e=this._onTapOverlay).call(e,this));var n=this,r=["tap","doubletap","press","pinch","pan","panstart","panmove","panend"];kp(r).call(r,(function(t){n.hammer.on(t,(function(t){t.stopPropagation()}))})),document&&document.body&&(this.onClick=function(e){(function(t,e){for(;t;){if(t===e)return!0;t=t.parentNode}return!1})(e.target,t)||n.deactivate()},document.body.addEventListener("click",this.onClick)),void 0!==this.keycharm&&this.keycharm.destroy(),this.keycharm=SP(),this.escListener=hp(i=this.deactivate).call(i,this)}wP(".vis .overlay{height:100%;left:0;position:absolute;top:0;width:100%;z-index:10}.vis-active{box-shadow:0 0 10px #86d5f8}"),wv(DP.prototype),DP.current=null,DP.prototype.destroy=function(){this.deactivate(),this.dom.overlay.parentNode.removeChild(this.dom.overlay),this.onClick&&document.body.removeEventListener("click",this.onClick),void 0!==this.keycharm&&this.keycharm.destroy(),this.keycharm=null,this.hammer.destroy(),this.hammer=null},DP.prototype.activate=function(){var t;DP.current&&DP.current.deactivate(),DP.current=this,this.active=!0,this.dom.overlay.style.display="none",EO.addClassName(this.dom.container,"vis-active"),this.emit("change"),this.emit("activate"),hp(t=this.keycharm).call(t,"esc",this.escListener)},DP.prototype.deactivate=function(){DP.current===this&&(DP.current=null),this.active=!1,this.dom.overlay.style.display="",EO.removeClassName(this.dom.container,"vis-active"),this.keycharm.unbind("esc",this.escListener),this.emit("change"),this.emit("deactivate")},DP.prototype._onTapOverlay=function(t){this.activate(),t.stopPropagation()};var CP={current:"current",time:"time",deleteSelected:"Delete selected"},TP={current:"attuale",time:"tempo",deleteSelected:"Cancella la selezione"},MP={current:"huidige",time:"tijd",deleteSelected:"Selectie verwijderen"},OP={current:"Aktuelle",time:"Zeit",deleteSelected:"Lösche Auswahl"},PP={current:"actuel",time:"heure",deleteSelected:"Effacer la selection"},EP={current:"corriente",time:"hora",deleteSelected:"Eliminar selección"},IP={current:"поточний",time:"час",deleteSelected:"Видалити обране"},LP={current:"текущее",time:"время",deleteSelected:"Удалить выбранное"},AP={current:"aktualny",time:"czas",deleteSelected:"Usuń wybrane"},NP={current:"atual",time:"data",deleteSelected:"Apagar selecionado"},RP={current:"現在",time:"時刻",deleteSelected:"選択されたものを削除"},FP={current:"nuvarande",time:"tid",deleteSelected:"Radera valda"},jP={current:"nåværende",time:"tid",deleteSelected:"Slett valgte"},YP={current:"einamas",time:"laikas",deleteSelected:"Pašalinti pasirinktą"},HP={en:CP,en_EN:CP,en_US:CP,it:TP,it_IT:TP,it_CH:TP,nl:MP,nl_NL:MP,nl_BE:MP,de:OP,de_DE:OP,fr:PP,fr_FR:PP,fr_CA:PP,fr_BE:PP,es:EP,es_ES:EP,uk:IP,uk_UA:IP,ru:LP,ru_RU:LP,pl:AP,pl_PL:AP,pt:NP,pt_BR:NP,pt_PT:NP,ja:RP,ja_JP:RP,lt:YP,lt_LT:YP,sv:FP,sv_SE:FP,nb:jP,nn:jP,nb_NO:jP,nn_NO:jP};wP(".vis-custom-time{background-color:#6e94ff;cursor:move;width:2px;z-index:1}.vis-custom-time>.vis-custom-time-marker{background-color:inherit;color:#fff;cursor:auto;font-size:12px;padding:3px 5px;top:0;white-space:nowrap;z-index:inherit}");var BP=function(t){Ib(i,t);var e=function(t){var e=function(){if("undefined"==typeof Reflect||!MT)return!1;if(MT.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(MT(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var i,n=Rb(t);if(e){var r=Rb(this).constructor;i=MT(n,arguments,r)}else i=n.apply(this,arguments);return Lb(this,i)}}(i);function i(t,n){var r,o;ga(this,i),(o=e.call(this)).body=t,o.defaultOptions={moment:gM,locales:HP,locale:"en",id:void 0,title:void 0},o.options=EO.extend({},o.defaultOptions),o.setOptions(n),o.options.locales=EO.extend({},HP,o.options.locales);var s=o.defaultOptions.locales[o.defaultOptions.locale];return kp(r=Bd(o.options.locales)).call(r,(function(t){o.options.locales[t]=EO.extend({},s,o.options.locales[t])})),n&&null!=n.time?o.customTime=n.time:o.customTime=new Date,o.eventParams={},o._create(),o}return Cc(i,[{key:"setOptions",value:function(t){t&&EO.selectiveExtend(["moment","locale","locales","id","title","rtl","snap"],this.options,t)}},{key:"_create",value:function(){var t,e,i,n=document.createElement("div");n["custom-time"]=this,n.className="vis-custom-time ".concat(this.options.id||""),n.style.position="absolute",n.style.top="0px",n.style.height="100%",this.bar=n;var r=document.createElement("div");function o(t){this.body.range._onMouseWheel(t)}r.style.position="relative",r.style.top="0px",this.options.rtl?r.style.right="-10px":r.style.left="-10px",r.style.height="100%",r.style.width="20px",r.addEventListener?(r.addEventListener("mousewheel",hp(o).call(o,this),!1),r.addEventListener("DOMMouseScroll",hp(o).call(o,this),!1)):r.attachEvent("onmousewheel",hp(o).call(o,this)),n.appendChild(r),this.hammer=new yP(r),this.hammer.on("panstart",hp(t=this._onDragStart).call(t,this)),this.hammer.on("panmove",hp(e=this._onDrag).call(e,this)),this.hammer.on("panend",hp(i=this._onDragEnd).call(i,this)),this.hammer.get("pan").set({threshold:5,direction:yP.DIRECTION_ALL}),this.hammer.get("press").set({time:1e4})}},{key:"destroy",value:function(){this.hide(),this.hammer.destroy(),this.hammer=null,this.body=null}},{key:"redraw",value:function(){var t=this.body.dom.backgroundVertical;this.bar.parentNode!=t&&(this.bar.parentNode&&this.bar.parentNode.removeChild(this.bar),t.appendChild(this.bar));var e=this.body.util.toScreen(this.customTime),i=this.options.locales[this.options.locale];i||(this.warned||(console.warn("WARNING: options.locales['".concat(this.options.locale,"'] not found. See https://visjs.github.io/vis-timeline/docs/timeline/#Localization")),this.warned=!0),i=this.options.locales.en);var n,r=this.options.title;return void 0===r?r=(r=xd(n="".concat(i.time,": ")).call(n,this.options.moment(this.customTime).format("dddd, MMMM Do YYYY, H:mm:ss"))).charAt(0).toUpperCase()+r.substring(1):"function"==typeof r&&(r=r.call(this,this.customTime)),this.options.rtl?this.bar.style.right="".concat(e,"px"):this.bar.style.left="".concat(e,"px"),this.bar.title=r,!1}},{key:"hide",value:function(){this.bar.parentNode&&this.bar.parentNode.removeChild(this.bar)}},{key:"setCustomTime",value:function(t){this.customTime=EO.convert(t,"Date"),this.redraw()}},{key:"getCustomTime",value:function(){return new Date(this.customTime.valueOf())}},{key:"setCustomMarker",value:function(t,e){var i,n;this.marker&&this.bar.removeChild(this.marker),this.marker=document.createElement("div"),this.marker.className="vis-custom-time-marker",this.marker.innerHTML=EO.xss(t),this.marker.style.position="absolute",e&&(this.marker.setAttribute("contenteditable","true"),this.marker.addEventListener("pointerdown",(function(){this.marker.focus()})),this.marker.addEventListener("input",hp(i=this._onMarkerChange).call(i,this)),this.marker.title=t,this.marker.addEventListener("blur",hp(n=function(t){this.title!=t.target.innerHTML&&(this._onMarkerChanged(t),this.title=t.target.innerHTML)}).call(n,this))),this.bar.appendChild(this.marker)}},{key:"setCustomTitle",value:function(t){this.options.title=t}},{key:"_onDragStart",value:function(t){this.eventParams.dragging=!0,this.eventParams.customTime=this.customTime,t.stopPropagation()}},{key:"_onDrag",value:function(t){if(this.eventParams.dragging){var e=this.options.rtl?-1*t.deltaX:t.deltaX,i=this.body.util.toScreen(this.eventParams.customTime)+e,n=this.body.util.toTime(i),r=this.body.util.getScale(),o=this.body.util.getStep(),s=this.options.snap,a=s?s(n,r,o):n;this.setCustomTime(a),this.body.emitter.emit("timechange",{id:this.options.id,time:new Date(this.customTime.valueOf()),event:t}),t.stopPropagation()}}},{key:"_onDragEnd",value:function(t){this.eventParams.dragging&&(this.body.emitter.emit("timechanged",{id:this.options.id,time:new Date(this.customTime.valueOf()),event:t}),t.stopPropagation())}},{key:"_onMarkerChange",value:function(t){this.body.emitter.emit("markerchange",{id:this.options.id,title:t.target.innerHTML,event:t}),t.stopPropagation()}},{key:"_onMarkerChanged",value:function(t){this.body.emitter.emit("markerchanged",{id:this.options.id,title:t.target.innerHTML,event:t}),t.stopPropagation()}}],[{key:"customTimeFromTarget",value:function(t){for(var e=t.target;e;){if(e.hasOwnProperty("custom-time"))return e["custom-time"];e=e.parentNode}return null}}]),i}(GO);wP(""),wP('.vis-current-time{background-color:#ff7f6e;pointer-events:none;width:2px;z-index:1}.vis-rolling-mode-btn{background:#3876c2;border-radius:50%;color:#fff;cursor:pointer;font-size:28px;font-weight:700;height:40px;opacity:.8;position:absolute;right:20px;text-align:center;top:7px;width:40px}.vis-rolling-mode-btn:before{content:"\\26F6"}.vis-rolling-mode-btn:hover{opacity:1}'),wP(".vis-panel{box-sizing:border-box;margin:0;padding:0;position:absolute}.vis-panel.vis-bottom,.vis-panel.vis-center,.vis-panel.vis-left,.vis-panel.vis-right,.vis-panel.vis-top{border:1px #bfbfbf}.vis-panel.vis-center,.vis-panel.vis-left,.vis-panel.vis-right{border-bottom-style:solid;border-top-style:solid;overflow:hidden}.vis-left.vis-panel.vis-vertical-scroll,.vis-right.vis-panel.vis-vertical-scroll{height:100%;overflow-x:hidden;overflow-y:scroll}.vis-left.vis-panel.vis-vertical-scroll{direction:rtl}.vis-left.vis-panel.vis-vertical-scroll .vis-content,.vis-right.vis-panel.vis-vertical-scroll{direction:ltr}.vis-right.vis-panel.vis-vertical-scroll .vis-content{direction:rtl}.vis-panel.vis-bottom,.vis-panel.vis-center,.vis-panel.vis-top{border-left-style:solid;border-right-style:solid}.vis-background{overflow:hidden}.vis-panel>.vis-content{position:relative}.vis-panel .vis-shadow{box-shadow:0 0 10px rgba(0,0,0,.8);height:1px;position:absolute;width:100%}.vis-panel .vis-shadow.vis-top{left:0;top:-1px}.vis-panel .vis-shadow.vis-bottom{bottom:-1px;left:0}"),wP(".vis-graph-group0{fill:#4f81bd;fill-opacity:0;stroke-width:2px;stroke:#4f81bd}.vis-graph-group1{fill:#f79646;fill-opacity:0;stroke-width:2px;stroke:#f79646}.vis-graph-group2{fill:#8c51cf;fill-opacity:0;stroke-width:2px;stroke:#8c51cf}.vis-graph-group3{fill:#75c841;fill-opacity:0;stroke-width:2px;stroke:#75c841}.vis-graph-group4{fill:#ff0100;fill-opacity:0;stroke-width:2px;stroke:#ff0100}.vis-graph-group5{fill:#37d8e6;fill-opacity:0;stroke-width:2px;stroke:#37d8e6}.vis-graph-group6{fill:#042662;fill-opacity:0;stroke-width:2px;stroke:#042662}.vis-graph-group7{fill:#00ff26;fill-opacity:0;stroke-width:2px;stroke:#00ff26}.vis-graph-group8{fill:#f0f;fill-opacity:0;stroke-width:2px;stroke:#f0f}.vis-graph-group9{fill:#8f3938;fill-opacity:0;stroke-width:2px;stroke:#8f3938}.vis-timeline .vis-fill{fill-opacity:.1;stroke:none}.vis-timeline .vis-bar{fill-opacity:.5;stroke-width:1px}.vis-timeline .vis-point{stroke-width:2px;fill-opacity:1}.vis-timeline .vis-legend-background{stroke-width:1px;fill-opacity:.9;fill:#fff;stroke:#c2c2c2}.vis-timeline .vis-outline{stroke-width:1px;fill-opacity:1;fill:#fff;stroke:#e5e5e5}.vis-timeline .vis-icon-fill{fill-opacity:.3;stroke:none}"),wP(".vis-timeline{border:1px solid #bfbfbf;box-sizing:border-box;margin:0;overflow:hidden;padding:0;position:relative}.vis-loading-screen{height:100%;left:0;position:absolute;top:0;width:100%}"),wP(".vis [class*=span]{min-height:0;width:auto}");var zP=function(){function t(){ga(this,t)}return Cc(t,[{key:"_create",value:function(t){var e,i,n,r=this;this.dom={},this.dom.container=t,this.dom.container.style.position="relative",this.dom.root=document.createElement("div"),this.dom.background=document.createElement("div"),this.dom.backgroundVertical=document.createElement("div"),this.dom.backgroundHorizontal=document.createElement("div"),this.dom.centerContainer=document.createElement("div"),this.dom.leftContainer=document.createElement("div"),this.dom.rightContainer=document.createElement("div"),this.dom.center=document.createElement("div"),this.dom.left=document.createElement("div"),this.dom.right=document.createElement("div"),this.dom.top=document.createElement("div"),this.dom.bottom=document.createElement("div"),this.dom.shadowTop=document.createElement("div"),this.dom.shadowBottom=document.createElement("div"),this.dom.shadowTopLeft=document.createElement("div"),this.dom.shadowBottomLeft=document.createElement("div"),this.dom.shadowTopRight=document.createElement("div"),this.dom.shadowBottomRight=document.createElement("div"),this.dom.rollingModeBtn=document.createElement("div"),this.dom.loadingScreen=document.createElement("div"),this.dom.root.className="vis-timeline",this.dom.background.className="vis-panel vis-background",this.dom.backgroundVertical.className="vis-panel vis-background vis-vertical",this.dom.backgroundHorizontal.className="vis-panel vis-background vis-horizontal",this.dom.centerContainer.className="vis-panel vis-center",this.dom.leftContainer.className="vis-panel vis-left",this.dom.rightContainer.className="vis-panel vis-right",this.dom.top.className="vis-panel vis-top",this.dom.bottom.className="vis-panel vis-bottom",this.dom.left.className="vis-content",this.dom.center.className="vis-content",this.dom.right.className="vis-content",this.dom.shadowTop.className="vis-shadow vis-top",this.dom.shadowBottom.className="vis-shadow vis-bottom",this.dom.shadowTopLeft.className="vis-shadow vis-top",this.dom.shadowBottomLeft.className="vis-shadow vis-bottom",this.dom.shadowTopRight.className="vis-shadow vis-top",this.dom.shadowBottomRight.className="vis-shadow vis-bottom",this.dom.rollingModeBtn.className="vis-rolling-mode-btn",this.dom.loadingScreen.className="vis-loading-screen",this.dom.root.appendChild(this.dom.background),this.dom.root.appendChild(this.dom.backgroundVertical),this.dom.root.appendChild(this.dom.backgroundHorizontal),this.dom.root.appendChild(this.dom.centerContainer),this.dom.root.appendChild(this.dom.leftContainer),this.dom.root.appendChild(this.dom.rightContainer),this.dom.root.appendChild(this.dom.top),this.dom.root.appendChild(this.dom.bottom),this.dom.root.appendChild(this.dom.rollingModeBtn),this.dom.centerContainer.appendChild(this.dom.center),this.dom.leftContainer.appendChild(this.dom.left),this.dom.rightContainer.appendChild(this.dom.right),this.dom.centerContainer.appendChild(this.dom.shadowTop),this.dom.centerContainer.appendChild(this.dom.shadowBottom),this.dom.leftContainer.appendChild(this.dom.shadowTopLeft),this.dom.leftContainer.appendChild(this.dom.shadowBottomLeft),this.dom.rightContainer.appendChild(this.dom.shadowTopRight),this.dom.rightContainer.appendChild(this.dom.shadowBottomRight),this.props={root:{},background:{},centerContainer:{},leftContainer:{},rightContainer:{},center:{},left:{},right:{},top:{},bottom:{},border:{},scrollTop:0,scrollTopMin:0},this.on("rangechange",(function(){!0===r.initialDrawDone&&r._redraw()})),this.on("rangechanged",(function(){r.initialRangeChangeDone||(r.initialRangeChangeDone=!0)})),this.on("touch",hp(e=this._onTouch).call(e,this)),this.on("panmove",hp(i=this._onDrag).call(i,this));var o=this;this._origRedraw=hp(n=this._redraw).call(n,this),this._redraw=EO.throttle(this._origRedraw),this.on("_change",(function(t){o.itemSet&&o.itemSet.initialItemSetDrawn&&t&&1==t.queue?o._redraw():o._origRedraw()})),this.hammer=new yP(this.dom.root);var s=this.hammer.get("pinch").set({enable:!0});s&&function(t){t.getTouchAction=function(){return["pan-y"]}}(s),this.hammer.get("pan").set({threshold:5,direction:yP.DIRECTION_ALL}),this.timelineListeners={};var a,l,h=["tap","doubletap","press","pinch","pan","panstart","panmove","panend"];function u(t){this.isActive()&&this.emit("mousewheel",t);var e=0,i=0;if("detail"in t&&(i=-1*t.detail),"wheelDelta"in t&&(i=t.wheelDelta),"wheelDeltaY"in t&&(i=t.wheelDeltaY),"wheelDeltaX"in t&&(e=-1*t.wheelDeltaX),"axis"in t&&t.axis===t.HORIZONTAL_AXIS&&(e=-1*i,i=0),"deltaY"in t&&(i=-1*t.deltaY),"deltaX"in t&&(e=t.deltaX),t.deltaMode&&(1===t.deltaMode?(e*=40,i*=40):(e*=40,i*=800)),this.options.preferZoom){if(!this.options.zoomKey||t[this.options.zoomKey])return}else if(this.options.zoomKey&&t[this.options.zoomKey])return;if(this.options.verticalScroll||this.options.horizontalScroll)if(this.options.verticalScroll&&Math.abs(i)>=Math.abs(e)){var n=this.props.scrollTop,r=n+i;this.isActive()&&this._setScrollTop(r)!==n&&(this._redraw(),this.emit("scroll",t),t.preventDefault())}else if(this.options.horizontalScroll){var o=(Math.abs(e)>=Math.abs(i)?e:i)/120*(this.range.end-this.range.start)/20,s=this.range.start+o,a=this.range.end+o,l={animation:!1,byUser:!0,event:t};this.range.setRange(s,a,l),t.preventDefault()}}kp(h).call(h,(function(t){var e=function(e){o.isActive()&&o.emit(t,e)};o.hammer.on(t,e),o.timelineListeners[t]=e})),bP(this.hammer,(function(t){o.emit("touch",t)})),a=this.hammer,(l=function(t){o.emit("release",t)}).inputHandler=function(t){t.isFinal&&l(t)},a.on("hammer.input",l.inputHandler);var c="onwheel"in document.createElement("div")?"wheel":void 0!==document.onmousewheel?"mousewheel":this.dom.centerContainer.addEventListener?"DOMMouseScroll":"onmousewheel";function d(t){if(o.options.verticalScroll&&(t.preventDefault(),o.isActive())){var e=-t.target.scrollTop;o._setScrollTop(e),o._redraw(),o.emit("scrollSide",t)}}this.dom.top.addEventListener,this.dom.bottom.addEventListener,this.dom.centerContainer.addEventListener(c,hp(u).call(u,this),!1),this.dom.top.addEventListener(c,hp(u).call(u,this),!1),this.dom.bottom.addEventListener(c,hp(u).call(u,this),!1),this.dom.left.parentNode.addEventListener("scroll",hp(d).call(d,this)),this.dom.right.parentNode.addEventListener("scroll",hp(d).call(d,this));var p=!1;function f(t){var e;if(t.preventDefault&&(o.emit("dragover",o.getEventProperties(t)),t.preventDefault()),Rm(e=t.target.className).call(e,"timeline")>-1&&!p)return t.dataTransfer.dropEffect="move",p=!0,!1}function m(t){t.preventDefault&&t.preventDefault(),t.stopPropagation&&t.stopPropagation();try{var e=JSON.parse(t.dataTransfer.getData("text"));if(!e||!e.content)return}catch(t){return!1}return p=!1,t.center={x:t.clientX,y:t.clientY},"item"!==e.target?o.itemSet._onAddItem(t):o.itemSet._onDropObjectOnItem(t),o.emit("drop",o.getEventProperties(t)),!1}if(this.dom.center.addEventListener("dragover",hp(f).call(f,this),!1),this.dom.center.addEventListener("drop",hp(m).call(m,this),!1),this.customTimes=[],this.touch={},this.redrawCount=0,this.initialDrawDone=!1,this.initialRangeChangeDone=!1,!t)throw new Error("No container provided");t.appendChild(this.dom.root),t.appendChild(this.dom.loadingScreen)}},{key:"setOptions",value:function(t){var e;if(t){if(EO.selectiveExtend(["width","height","minHeight","maxHeight","autoResize","start","end","clickToUse","dataAttributes","hiddenDates","locale","locales","moment","preferZoom","rtl","zoomKey","horizontalScroll","verticalScroll","longSelectPressTime","snap"],this.options,t),this.dom.rollingModeBtn.style.visibility="hidden",this.options.rtl&&(this.dom.container.style.direction="rtl",this.dom.backgroundVertical.className="vis-panel vis-background vis-vertical-rtl"),this.options.verticalScroll&&(this.options.rtl?this.dom.rightContainer.className="vis-panel vis-right vis-vertical-scroll":this.dom.leftContainer.className="vis-panel vis-left vis-vertical-scroll"),"object"!==kc(this.options.orientation)&&(this.options.orientation={item:void 0,axis:void 0}),"orientation"in t&&("string"==typeof t.orientation?this.options.orientation={item:t.orientation,axis:t.orientation}:"object"===kc(t.orientation)&&("item"in t.orientation&&(this.options.orientation.item=t.orientation.item),"axis"in t.orientation&&(this.options.orientation.axis=t.orientation.axis))),"both"===this.options.orientation.axis){if(!this.timeAxis2){var i=this.timeAxis2=new kP(this.body,this.options);i.setOptions=function(t){var e=t?EO.extend({},t):{};e.orientation="top",kP.prototype.setOptions.call(i,e)},this.components.push(i)}}else if(this.timeAxis2){var n,r,o=Rm(n=this.components).call(n,this.timeAxis2);-1!==o&&Qp(r=this.components).call(r,o,1),this.timeAxis2.destroy(),this.timeAxis2=null}"function"==typeof t.drawPoints&&(t.drawPoints={onRender:t.drawPoints}),"hiddenDates"in this.options&&QO(this.options.moment,this.body,this.options.hiddenDates),"clickToUse"in t&&(t.clickToUse?this.activator||(this.activator=new DP(this.dom.root)):this.activator&&(this.activator.destroy(),delete this.activator)),this._initAutoResize()}if(kp(e=this.components).call(e,(function(e){return e.setOptions(t)})),"configure"in t){var s;this.configurator||(this.configurator=this._createConfigurator()),this.configurator.setOptions(t.configure);var a=EO.deepExtend({},this.options);kp(s=this.components).call(s,(function(t){EO.deepExtend(a,t.options)})),this.configurator.setModuleOptions({global:a})}this._redraw()}},{key:"isActive",value:function(){return!this.activator||this.activator.active}},{key:"destroy",value:function(){var t;for(var e in this.setItems(null),this.setGroups(null),this.off(),this._stopAutoResize(),this.dom.root.parentNode&&this.dom.root.parentNode.removeChild(this.dom.root),this.dom=null,this.activator&&(this.activator.destroy(),delete this.activator),this.timelineListeners)this.timelineListeners.hasOwnProperty(e)&&delete this.timelineListeners[e];this.timelineListeners=null,this.hammer&&this.hammer.destroy(),this.hammer=null,kp(t=this.components).call(t,(function(t){return t.destroy()})),this.body=null}},{key:"setCustomTime",value:function(t,e){var i,n=Vf(i=this.customTimes).call(i,(function(t){return e===t.options.id}));if(0===n.length)throw new Error("No custom time bar found with id ".concat(Wm(e)));n.length>0&&n[0].setCustomTime(t)}},{key:"getCustomTime",value:function(t){var e,i=Vf(e=this.customTimes).call(e,(function(e){return e.options.id===t}));if(0===i.length)throw new Error("No custom time bar found with id ".concat(Wm(t)));return i[0].getCustomTime()}},{key:"setCustomTimeMarker",value:function(t,e,i){var n,r=Vf(n=this.customTimes).call(n,(function(t){return t.options.id===e}));if(0===r.length)throw new Error("No custom time bar found with id ".concat(Wm(e)));r.length>0&&r[0].setCustomMarker(t,i)}},{key:"setCustomTimeTitle",value:function(t,e){var i,n=Vf(i=this.customTimes).call(i,(function(t){return t.options.id===e}));if(0===n.length)throw new Error("No custom time bar found with id ".concat(Wm(e)));if(n.length>0)return n[0].setCustomTitle(t)}},{key:"getEventProperties",value:function(t){return{event:t}}},{key:"addCustomTime",value:function(t,e){var i,n=void 0!==t?EO.convert(t,"Date"):new Date,r=zC(i=this.customTimes).call(i,(function(t){return t.options.id===e}));if(r)throw new Error("A custom time with id ".concat(Wm(e)," already exists"));var o=new BP(this.body,EO.extend({},this.options,{time:n,id:e,snap:this.itemSet?this.itemSet.options.snap:this.options.snap}));return this.customTimes.push(o),this.components.push(o),this._redraw(),e}},{key:"removeCustomTime",value:function(t){var e,i=this,n=Vf(e=this.customTimes).call(e,(function(e){return e.options.id===t}));if(0===n.length)throw new Error("No custom time bar found with id ".concat(Wm(t)));kp(n).call(n,(function(t){var e,n,r,o;Qp(e=i.customTimes).call(e,Rm(n=i.customTimes).call(n,t),1),Qp(r=i.components).call(r,Rm(o=i.components).call(o,t),1),t.destroy()}))}},{key:"getVisibleItems",value:function(){return this.itemSet&&this.itemSet.getVisibleItems()||[]}},{key:"getItemsAtCurrentTime",value:function(t){return this.time=t,this.itemSet&&this.itemSet.getItemsAtCurrentTime(this.time)||[]}},{key:"getVisibleGroups",value:function(){return this.itemSet&&this.itemSet.getVisibleGroups()||[]}},{key:"fit",value:function(t,e){var i=this.getDataRange();if(null!==i.min||null!==i.max){var n=i.max-i.min,r=new Date(i.min.valueOf()-.01*n),o=new Date(i.max.valueOf()+.01*n),s=!t||void 0===t.animation||t.animation;this.range.setRange(r,o,{animation:s},e)}}},{key:"getDataRange",value:function(){throw new Error("Cannot invoke abstract method getDataRange")}},{key:"setWindow",value:function(t,e,i,n){var r,o;"function"==typeof arguments[2]&&(n=arguments[2],i={}),1==arguments.length?(r=void 0===(o=arguments[0]).animation||o.animation,this.range.setRange(o.start,o.end,{animation:r})):2==arguments.length&&"function"==typeof arguments[1]?(n=arguments[1],r=void 0===(o=arguments[0]).animation||o.animation,this.range.setRange(o.start,o.end,{animation:r},n)):(r=!i||void 0===i.animation||i.animation,this.range.setRange(t,e,{animation:r},n))}},{key:"moveTo",value:function(t,e,i){"function"==typeof arguments[1]&&(i=arguments[1],e={});var n=this.range.end-this.range.start,r=EO.convert(t,"Date").valueOf(),o=r-n/2,s=r+n/2,a=!e||void 0===e.animation||e.animation;this.range.setRange(o,s,{animation:a},i)}},{key:"getWindow",value:function(){var t=this.range.getRange();return{start:new Date(t.start),end:new Date(t.end)}}},{key:"zoomIn",value:function(t,e,i){if(!(!t||t<0||t>1)){"function"==typeof arguments[1]&&(i=arguments[1],e={});var n=this.getWindow(),r=n.start.valueOf(),o=n.end.valueOf(),s=o-r,a=(s-s/(1+t))/2,l=r+a,h=o-a;this.setWindow(l,h,e,i)}}},{key:"zoomOut",value:function(t,e,i){if(!(!t||t<0||t>1)){"function"==typeof arguments[1]&&(i=arguments[1],e={});var n=this.getWindow(),r=n.start.valueOf(),o=n.end.valueOf(),s=o-r,a=r-s*t/2,l=o+s*t/2;this.setWindow(a,l,e,i)}}},{key:"redraw",value:function(){this._redraw()}},{key:"_redraw",value:function(){var t;this.redrawCount++;var e=this.dom;if(e&&e.container&&0!=e.root.offsetWidth){var i=!1,n=this.options,r=this.props;tP(this.options.moment,this.body,this.options.hiddenDates),"top"==n.orientation?(EO.addClassName(e.root,"vis-top"),EO.removeClassName(e.root,"vis-bottom")):(EO.removeClassName(e.root,"vis-top"),EO.addClassName(e.root,"vis-bottom")),n.rtl?(EO.addClassName(e.root,"vis-rtl"),EO.removeClassName(e.root,"vis-ltr")):(EO.addClassName(e.root,"vis-ltr"),EO.removeClassName(e.root,"vis-rtl")),e.root.style.maxHeight=EO.option.asSize(n.maxHeight,""),e.root.style.minHeight=EO.option.asSize(n.minHeight,""),e.root.style.width=EO.option.asSize(n.width,"");var o=e.root.offsetWidth;r.border.left=1,r.border.right=1,r.border.top=1,r.border.bottom=1,r.center.height=e.center.offsetHeight,r.left.height=e.left.offsetHeight,r.right.height=e.right.offsetHeight,r.top.height=e.top.clientHeight||-r.border.top,r.bottom.height=Math.round(e.bottom.getBoundingClientRect().height)||e.bottom.clientHeight||-r.border.bottom;var s=Math.max(r.left.height,r.center.height,r.right.height),a=r.top.height+s+r.bottom.height+r.border.top+r.border.bottom;e.root.style.height=EO.option.asSize(n.height,"".concat(a,"px")),r.root.height=e.root.offsetHeight,r.background.height=r.root.height;var l=r.root.height-r.top.height-r.bottom.height;r.centerContainer.height=l,r.leftContainer.height=l,r.rightContainer.height=r.leftContainer.height,r.root.width=o,r.background.width=r.root.width,this.initialDrawDone||(r.scrollbarWidth=EO.getScrollBarWidth());var h=e.leftContainer.clientWidth,u=e.rightContainer.clientWidth;n.verticalScroll?n.rtl?(r.left.width=h||-r.border.left,r.right.width=u+r.scrollbarWidth||-r.border.right):(r.left.width=h+r.scrollbarWidth||-r.border.left,r.right.width=u||-r.border.right):(r.left.width=h||-r.border.left,r.right.width=u||-r.border.right),this._setDOM();var c=this._updateScrollTop();"top"!=n.orientation.item&&(c+=Math.max(r.centerContainer.height-r.center.height-r.border.top-r.border.bottom,0)),e.center.style.transform="translateY(".concat(c,"px)");var d=0==r.scrollTop?"hidden":"",p=r.scrollTop==r.scrollTopMin?"hidden":"";e.shadowTop.style.visibility=d,e.shadowBottom.style.visibility=p,e.shadowTopLeft.style.visibility=d,e.shadowBottomLeft.style.visibility=p,e.shadowTopRight.style.visibility=d,e.shadowBottomRight.style.visibility=p,n.verticalScroll&&(e.rightContainer.className="vis-panel vis-right vis-vertical-scroll",e.leftContainer.className="vis-panel vis-left vis-vertical-scroll",e.shadowTopRight.style.visibility="hidden",e.shadowBottomRight.style.visibility="hidden",e.shadowTopLeft.style.visibility="hidden",e.shadowBottomLeft.style.visibility="hidden",e.left.style.top="0px",e.right.style.top="0px"),(!n.verticalScroll||r.center.height<r.centerContainer.height)&&(e.left.style.top="".concat(c,"px"),e.right.style.top="".concat(c,"px"),e.rightContainer.className=e.rightContainer.className.replace(new RegExp("(?:^|\\s)vis-vertical-scroll(?:\\s|$)")," "),e.leftContainer.className=e.leftContainer.className.replace(new RegExp("(?:^|\\s)vis-vertical-scroll(?:\\s|$)")," "),r.left.width=h||-r.border.left,r.right.width=u||-r.border.right,this._setDOM());var f=r.center.height>r.centerContainer.height;if(this.hammer.get("pan").set({direction:f?yP.DIRECTION_ALL:yP.DIRECTION_HORIZONTAL}),this.hammer.get("press").set({time:this.options.longSelectPressTime}),kp(t=this.components).call(t,(function(t){i=t.redraw()||i})),i){if(this.redrawCount<5)return void this.body.emitter.emit("_change");console.log("WARNING: infinite loop in redraw?")}else this.redrawCount=0;this.body.emitter.emit("changed")}}},{key:"_setDOM",value:function(){var t=this.props,e=this.dom;t.leftContainer.width=t.left.width,t.rightContainer.width=t.right.width;var i=t.root.width-t.left.width-t.right.width;t.center.width=i,t.centerContainer.width=i,t.top.width=i,t.bottom.width=i,e.background.style.height="".concat(t.background.height,"px"),e.backgroundVertical.style.height="".concat(t.background.height,"px"),e.backgroundHorizontal.style.height="".concat(t.centerContainer.height,"px"),e.centerContainer.style.height="".concat(t.centerContainer.height,"px"),e.leftContainer.style.height="".concat(t.leftContainer.height,"px"),e.rightContainer.style.height="".concat(t.rightContainer.height,"px"),e.background.style.width="".concat(t.background.width,"px"),e.backgroundVertical.style.width="".concat(t.centerContainer.width,"px"),e.backgroundHorizontal.style.width="".concat(t.background.width,"px"),e.centerContainer.style.width="".concat(t.center.width,"px"),e.top.style.width="".concat(t.top.width,"px"),e.bottom.style.width="".concat(t.bottom.width,"px"),e.background.style.left="0",e.background.style.top="0",e.backgroundVertical.style.left="".concat(t.left.width+t.border.left,"px"),e.backgroundVertical.style.top="0",e.backgroundHorizontal.style.left="0",e.backgroundHorizontal.style.top="".concat(t.top.height,"px"),e.centerContainer.style.left="".concat(t.left.width,"px"),e.centerContainer.style.top="".concat(t.top.height,"px"),e.leftContainer.style.left="0",e.leftContainer.style.top="".concat(t.top.height,"px"),e.rightContainer.style.left="".concat(t.left.width+t.center.width,"px"),e.rightContainer.style.top="".concat(t.top.height,"px"),e.top.style.left="".concat(t.left.width,"px"),e.top.style.top="0",e.bottom.style.left="".concat(t.left.width,"px"),e.bottom.style.top="".concat(t.top.height+t.centerContainer.height,"px"),e.center.style.left="0",e.left.style.left="0",e.right.style.left="0"}},{key:"setCurrentTime",value:function(t){if(!this.currentTime)throw new Error("Option showCurrentTime must be true");this.currentTime.setCurrentTime(t)}},{key:"getCurrentTime",value:function(){if(!this.currentTime)throw new Error("Option showCurrentTime must be true");return this.currentTime.getCurrentTime()}},{key:"_toTime",value:function(t){return rP(this,t,this.props.center.width)}},{key:"_toGlobalTime",value:function(t){return rP(this,t,this.props.root.width)}},{key:"_toScreen",value:function(t){return nP(this,t,this.props.center.width)}},{key:"_toGlobalScreen",value:function(t){return nP(this,t,this.props.root.width)}},{key:"_initAutoResize",value:function(){1==this.options.autoResize?this._startAutoResize():this._stopAutoResize()}},{key:"_startAutoResize",value:function(){var t=this;this._stopAutoResize(),this._onResize=function(){if(1==t.options.autoResize){if(t.dom.root){var e=t.dom.root.offsetHeight,i=t.dom.root.offsetWidth;i==t.props.lastWidth&&e==t.props.lastHeight||(t.props.lastWidth=i,t.props.lastHeight=e,t.props.scrollbarWidth=EO.getScrollBarWidth(),t.body.emitter.emit("_change"))}}else t._stopAutoResize()},window.addEventListener("resize",this._onResize),t.dom.root&&(t.props.lastWidth=t.dom.root.offsetWidth,t.props.lastHeight=t.dom.root.offsetHeight),this.watchTimer=vP(this._onResize,1e3)}},{key:"_stopAutoResize",value:function(){this.watchTimer&&(clearInterval(this.watchTimer),this.watchTimer=void 0),this._onResize&&(window.removeEventListener("resize",this._onResize),this._onResize=null)}},{key:"_onTouch",value:function(t){this.touch.allowDragging=!0,this.touch.initialScrollTop=this.props.scrollTop}},{key:"_onPinch",value:function(t){this.touch.allowDragging=!1}},{key:"_onDrag",value:function(t){if(t&&this.touch.allowDragging){var e=t.deltaY,i=this._getScrollTop(),n=this._setScrollTop(this.touch.initialScrollTop+e);this.options.verticalScroll&&(this.dom.left.parentNode.scrollTop=-this.props.scrollTop,this.dom.right.parentNode.scrollTop=-this.props.scrollTop),n!=i&&this.emit("verticalDrag")}}},{key:"_setScrollTop",value:function(t){return this.props.scrollTop=t,this._updateScrollTop(),this.props.scrollTop}},{key:"_updateScrollTop",value:function(){var t=Math.min(this.props.centerContainer.height-this.props.border.top-this.props.border.bottom-this.props.center.height,0);return t!=this.props.scrollTopMin&&("top"!=this.options.orientation.item&&(this.props.scrollTop+=t-this.props.scrollTopMin),this.props.scrollTopMin=t),this.props.scrollTop>0&&(this.props.scrollTop=0),this.props.scrollTop<t&&(this.props.scrollTop=t),this.options.verticalScroll&&(this.dom.left.parentNode.scrollTop=-this.props.scrollTop,this.dom.right.parentNode.scrollTop=-this.props.scrollTop),this.props.scrollTop}},{key:"_getScrollTop",value:function(){return this.props.scrollTop}},{key:"_createConfigurator",value:function(){throw new Error("Cannot invoke abstract method _createConfigurator")}}]),t}();wv(zP.prototype);var GP=function(t){Ib(i,t);var e=function(t){var e=function(){if("undefined"==typeof Reflect||!MT)return!1;if(MT.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(MT(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var i,n=Rb(t);if(e){var r=Rb(this).constructor;i=MT(n,arguments,r)}else i=n.apply(this,arguments);return Lb(this,i)}}(i);function i(t,n){var r,o;ga(this,i),(o=e.call(this)).body=t,o.defaultOptions={rtl:!1,showCurrentTime:!0,alignCurrentTime:void 0,moment:gM,locales:HP,locale:"en"},o.options=EO.extend({},o.defaultOptions),o.setOptions(n),o.options.locales=EO.extend({},HP,o.options.locales);var s=o.defaultOptions.locales[o.defaultOptions.locale];return kp(r=Bd(o.options.locales)).call(r,(function(t){o.options.locales[t]=EO.extend({},s,o.options.locales[t])})),o.offset=0,o._create(),o}return Cc(i,[{key:"_create",value:function(){var t=document.createElement("div");t.className="vis-current-time",t.style.position="absolute",t.style.top="0px",t.style.height="100%",this.bar=t}},{key:"destroy",value:function(){this.options.showCurrentTime=!1,this.redraw(),this.body=null}},{key:"setOptions",value:function(t){t&&EO.selectiveExtend(["rtl","showCurrentTime","alignCurrentTime","moment","locale","locales"],this.options,t)}},{key:"redraw",value:function(){if(this.options.showCurrentTime){var t,e,i=this.body.dom.backgroundVertical;this.bar.parentNode!=i&&(this.bar.parentNode&&this.bar.parentNode.removeChild(this.bar),i.appendChild(this.bar),this.start());var n=this.options.moment(Vd()+this.offset);this.options.alignCurrentTime&&(n=n.startOf(this.options.alignCurrentTime));var r=this.body.util.toScreen(n),o=this.options.locales[this.options.locale];o||(this.warned||(console.warn("WARNING: options.locales['".concat(this.options.locale,"'] not found. See https://visjs.github.io/vis-timeline/docs/timeline/#Localization")),this.warned=!0),o=this.options.locales.en);var s=xd(t=xd(e="".concat(o.current," ")).call(e,o.time,": ")).call(t,n.format("dddd, MMMM Do YYYY, H:mm:ss"));s=s.charAt(0).toUpperCase()+s.substring(1),this.options.rtl?this.bar.style.transform="translateX(".concat(-1*r,"px)"):this.bar.style.transform="translateX(".concat(r,"px)"),this.bar.title=s}else this.bar.parentNode&&this.bar.parentNode.removeChild(this.bar),this.stop();return!1}},{key:"start",value:function(){var t=this;!function e(){t.stop();var i=1/t.body.range.conversion(t.body.domProps.center.width).scale/10;i<30&&(i=30),i>1e3&&(i=1e3),t.redraw(),t.body.emitter.emit("currentTimeTick"),t.currentTimeTimer=uv(e,i)}()}},{key:"stop",value:function(){void 0!==this.currentTimeTimer&&(clearTimeout(this.currentTimeTimer),delete this.currentTimeTimer)}},{key:"setCurrentTime",value:function(t){var e=EO.convert(t,"Date").valueOf(),i=Vd();this.offset=e-i,this.redraw()}},{key:"getCurrentTime",value:function(){return new Date(Vd()+this.offset)}}]),i}(GO),WP=Tn,VP=jl.find,UP="find",XP=!0;UP in[]&&Array(1)[UP]((function(){XP=!1})),WP({target:"Array",proto:!0,forced:XP},{find:function(t){return VP(this,t,arguments.length>1?arguments[1]:void 0)}});var qP=Yc("Array").find,$P=ve,KP=qP,ZP=Array.prototype,JP=n((function(t){var e=t.find;return t===ZP||$P(ZP,t)&&e===ZP.find?KP:e})),QP=Tn,tE=jl.findIndex,eE="findIndex",iE=!0;eE in[]&&Array(1)[eE]((function(){iE=!1})),QP({target:"Array",proto:!0,forced:iE},{findIndex:function(t){return tE(this,t,arguments.length>1?arguments[1]:void 0)}});var nE=Yc("Array").findIndex,rE=ve,oE=nE,sE=Array.prototype,aE=n((function(t){var e=t.findIndex;return t===sE||rE(sE,t)&&e===sE.findIndex?oE:e}));function lE(t,e){(null==e||e>t.length)&&(e=t.length);for(var i=0,n=new Array(e);i<e;i++)n[i]=t[i];return n}var hE=.001;function uE(t){RC(t).call(t,(function(t,e){return t.data.start-e.data.start}))}function cE(t){RC(t).call(t,(function(t,e){return("end"in t.data?t.data.end:t.data.start)-("end"in e.data?e.data.end:e.data.start)}))}function dE(t,e,i,n){return null===gE(t,e.item,!1,(function(t){return t.stack&&(i||null===t.top)}),(function(t){return t.stack}),(function(t){return e.axis}),n)}function pE(t,e,i){var n=gE(t,e.item,!1,(function(t){return t.stack}),(function(t){return!0}),(function(t){return t.baseTop}));i.height=n-i.top+.5*e.item.vertical}function fE(t,e,i,n){for(var r=0;r<t.length;r++)if(null==t[r].data.subgroup)t[r].top=e.item.vertical;else if(void 0!==t[r].data.subgroup&&n){var o=0;for(var s in i)i.hasOwnProperty(s)&&1==i[s].visible&&i[s].index<i[t[r].data.subgroup].index&&(o+=i[s].height,i[t[r].data.subgroup].top=o);t[r].top=o+.5*e.item.vertical}n||mE(t,e,i)}function mE(t,e,i){var n;gE(RC(n=rm(i)).call(n,(function(t,e){return t.index>e.index?1:t.index<e.index?-1:0})),{vertical:0},!0,(function(t){return!0}),(function(t){return!0}),(function(t){return 0}));for(var r=0;r<t.length;r++)void 0!==t[r].data.subgroup&&(t[r].top=i[t[r].data.subgroup].top+.5*e.item.vertical)}function vE(t,e,i){var n=!1,r=[];for(var o in i)i[o].hasOwnProperty("index")?r[i[o].index]=o:r.push(o);for(var s=0;s<r.length;s++)if(o=r[s],i.hasOwnProperty(o)){for(var a in n=n||i[o].stack,i[o].top=0,i)i[a].visible&&i[o].index>i[a].index&&(i[o].top+=i[a].height);for(var l=t[o],h=0;h<l.length;h++)void 0!==l[h].data.subgroup&&(l[h].top=i[l[h].data.subgroup].top+.5*e.item.vertical,i[o].stack&&(l[h].baseTop=l[h].top));n&&i[o].stack&&pE(t[o],e,i[o])}}function gE(t,e,n,r,o,s,a){var l=function(t){return t.start},h=function(t){return t.end};if(!n){var u=!(!t[0]||!t[0].options.rtl);l=u?function(t){return t.right}:function(t){return t.left},h=function(t){return l(t)+t.width+e.horizontal}}var c,d=[],p=[],f=null,m=0,v=function(t,e){var i=void 0!==yd&&va(t)||t["@@iterator"];if(!i){if(Id(t)||(i=function(t,e){var i;if(t){if("string"==typeof t)return lE(t,e);var n=Sd(i=Object.prototype.toString.call(t)).call(i,8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Ks(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?lE(t,e):void 0}}(t))||e&&t&&"number"==typeof t.length){i&&(t=i);var n=0,r=function(){};return{s:r,n:function(){return n>=t.length?{done:!0}:{done:!1,value:t[n++]}},e:function(t){throw t},f:r}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var o,s=!0,a=!1;return{s:function(){i=i.call(t)},n:function(){var t=i.next();return s=t.done,t},e:function(t){a=!0,o=t},f:function(){try{s||null==i.return||i.return()}finally{if(a)throw o}}}}(t);try{var g=function(){var t=c.value;if(r(t))d.push(t);else if(o(t)){var e=l(t);null!==f&&e<f-hE&&(m=0),f=e,m=yE(p,(function(t){return l(t)-hE>e}),m),Qp(p).call(p,m,0,t),m++}};for(v.s();!(c=v.n()).done;)g()}catch(t){v.e(t)}finally{v.f()}f=null;var y=null;m=0;for(var b,_=0,w=0,k=0,x=function(){var t,n,r=d.shift();r.top=s(r);var u=l(r),c=h(r);null!==f&&u<f-hE&&(_=0,w=0,m=0,y=null),f=u,_=yE(p,(function(t){return u<h(t)-hE}),_),(null===y||y<c-hE)&&(w=yE(p,(function(t){return c<l(t)-hE}),Math.max(_,w))),null!==y&&y-hE>c&&(w=function(t,e,n,r){for(n||(n=0),r||(r=t.length),i=r-1;i>=n;i--)if(e(t[i]))return i;return n-1}(p,(function(t){return c+hE>=l(t)}),_,w)+1);for(var v,g,b,x=RC(t=Vf(n=Sd(p).call(p,_,w)).call(n,(function(t){return u<h(t)-hE&&c-hE>l(t)}))).call(t,(function(t,e){return t.top-e.top})),S=0;S<x.length;S++){var D=x[S];g=D,b=e,(v=r).top-b.vertical+hE<g.top+g.height&&v.top+v.height+b.vertical-hE>g.top&&(r.top=D.top+D.height+e.vertical)}o(r)&&(m=yE(p,(function(t){return l(t)-hE>u}),m),Qp(p).call(p,m,0,r),m++);var C=r.top+r.height;if(C>k&&(k=C),a&&a())return{v:null}};d.length>0;)if(b=x())return b.v;return k}function yE(t,e,i){var n;i||(i=0);var r=aE(n=Sd(t).call(t,i)).call(n,e);return-1===r?t.length:r+i}var bE=Object.freeze({__proto__:null,nostack:fE,orderByEnd:cE,orderByStart:uE,stack:dE,stackSubgroups:mE,stackSubgroupsWithInnerStack:vE,substack:pE}),_E="__background__",wE=function(){function t(e,i,n){var r=this;if(ga(this,t),this.groupId=e,this.subgroups={},this.subgroupStack={},this.subgroupStackAll=!1,this.subgroupVisibility={},this.doInnerStack=!1,this.shouldBailStackItems=!1,this.subgroupIndex=0,this.subgroupOrderer=i&&i.subgroupOrder,this.itemSet=n,this.isVisible=null,this.stackDirty=!0,this._disposeCallbacks=[],i&&i.nestedGroups&&(this.nestedGroups=i.nestedGroups,0==i.showNested?this.showNested=!1:this.showNested=!0),i&&i.subgroupStack)if("boolean"==typeof i.subgroupStack)this.doInnerStack=i.subgroupStack,this.subgroupStackAll=i.subgroupStack;else for(var o in i.subgroupStack)this.subgroupStack[o]=i.subgroupStack[o],this.doInnerStack=this.doInnerStack||i.subgroupStack[o];i&&i.heightMode?this.heightMode=i.heightMode:this.heightMode=n.options.groupHeightMode,this.nestedInGroup=null,this.dom={},this.props={label:{width:0,height:0}},this.className=null,this.items={},this.visibleItems=[],this.itemsInRange=[],this.orderedItems={byStart:[],byEnd:[]},this.checkRangedItems=!1;var s=function(){r.checkRangedItems=!0};this.itemSet.body.emitter.on("checkRangedItems",s),this._disposeCallbacks.push((function(){r.itemSet.body.emitter.off("checkRangedItems",s)})),this._create(),this.setData(i)}return Cc(t,[{key:"_create",value:function(){var t=document.createElement("div");this.itemSet.options.groupEditable.order?t.className="vis-label draggable":t.className="vis-label",this.dom.label=t;var e=document.createElement("div");e.className="vis-inner",t.appendChild(e),this.dom.inner=e;var i=document.createElement("div");i.className="vis-group",i["vis-group"]=this,this.dom.foreground=i,this.dom.background=document.createElement("div"),this.dom.background.className="vis-group",this.dom.axis=document.createElement("div"),this.dom.axis.className="vis-group",this.dom.marker=document.createElement("div"),this.dom.marker.style.visibility="hidden",this.dom.marker.style.position="absolute",this.dom.marker.innerHTML="",this.dom.background.appendChild(this.dom.marker)}},{key:"setData",value:function(t){if(!this.itemSet.groupTouchParams.isDragging){var e,i,n;if(t&&t.subgroupVisibility)for(var r in t.subgroupVisibility)this.subgroupVisibility[r]=t.subgroupVisibility[r];if((e=this.itemSet.options&&this.itemSet.options.groupTemplate?(i=hp(n=this.itemSet.options.groupTemplate).call(n,this))(t,this.dom.inner):t&&t.content)instanceof Element){for(;this.dom.inner.firstChild;)this.dom.inner.removeChild(this.dom.inner.firstChild);this.dom.inner.appendChild(e)}else e instanceof Object&&e.isReactComponent||(e instanceof Object?i(t,this.dom.inner):this.dom.inner.innerHTML=null!=e?EO.xss(e):EO.xss(this.groupId||""));this.dom.label.title=t&&t.title||"",this.dom.inner.firstChild?EO.removeClassName(this.dom.inner,"vis-hidden"):EO.addClassName(this.dom.inner,"vis-hidden"),t&&t.nestedGroups?(this.nestedGroups&&this.nestedGroups==t.nestedGroups||(this.nestedGroups=t.nestedGroups),void 0===t.showNested&&void 0!==this.showNested||(0==t.showNested?this.showNested=!1:this.showNested=!0),EO.addClassName(this.dom.label,"vis-nesting-group"),this.showNested?(EO.removeClassName(this.dom.label,"collapsed"),EO.addClassName(this.dom.label,"expanded")):(EO.removeClassName(this.dom.label,"expanded"),EO.addClassName(this.dom.label,"collapsed"))):this.nestedGroups&&(this.nestedGroups=null,EO.removeClassName(this.dom.label,"collapsed"),EO.removeClassName(this.dom.label,"expanded"),EO.removeClassName(this.dom.label,"vis-nesting-group")),t&&(t.treeLevel||t.nestedInGroup)?(EO.addClassName(this.dom.label,"vis-nested-group"),t.treeLevel?EO.addClassName(this.dom.label,"vis-group-level-"+t.treeLevel):EO.addClassName(this.dom.label,"vis-group-level-unknown-but-gte1")):EO.addClassName(this.dom.label,"vis-group-level-0");var o=t&&t.className||null;o!=this.className&&(this.className&&(EO.removeClassName(this.dom.label,this.className),EO.removeClassName(this.dom.foreground,this.className),EO.removeClassName(this.dom.background,this.className),EO.removeClassName(this.dom.axis,this.className)),EO.addClassName(this.dom.label,o),EO.addClassName(this.dom.foreground,o),EO.addClassName(this.dom.background,o),EO.addClassName(this.dom.axis,o),this.className=o),this.style&&(EO.removeCssText(this.dom.label,this.style),this.style=null),t&&t.style&&(EO.addCssText(this.dom.label,t.style),this.style=t.style)}}},{key:"getLabelWidth",value:function(){return this.props.label.width}},{key:"_didMarkerHeightChange",value:function(){var t=this.dom.marker.clientHeight;if(t!=this.lastMarkerHeight){this.lastMarkerHeight=t;var e={},i=0;if(kp(EO).call(EO,this.items,(function(t,n){t.dirty=!0,t.displayed&&(e[n]=t.redraw(!0),i=e[n].length)})),i>0)for(var n=function(t){kp(EO).call(EO,e,(function(e){e[t]()}))},r=0;r<i;r++)n(r);return!0}return!1}},{key:"_calculateGroupSizeAndPosition",value:function(){var t=this.dom.foreground,e=t.offsetTop,i=t.offsetLeft,n=t.offsetWidth;this.top=e,this.right=i,this.width=n}},{key:"_shouldBailItemsRedraw",value:function(){var t=this,e=this.itemSet.options.onTimeout,i={relativeBailingTime:this.itemSet.itemsSettingTime,bailTimeMs:e&&e.timeoutMs,userBailFunction:e&&e.callback,shouldBailStackItems:this.shouldBailStackItems},n=null;if(!this.itemSet.initialDrawDone){if(i.shouldBailStackItems)return!0;Math.abs(Vd()-new Date(i.relativeBailingTime))>i.bailTimeMs&&(i.userBailFunction&&null==this.itemSet.userContinueNotBail?i.userBailFunction((function(e){t.itemSet.userContinueNotBail=e,n=!e})):n=0==t.itemSet.userContinueNotBail)}return n}},{key:"_redrawItems",value:function(t,e,i,n){var r=this;if(t||this.stackDirty||this.isVisible&&!e){var o,s,a,l,h,u,c={byEnd:Vf(o=this.orderedItems.byEnd).call(o,(function(t){return!t.isCluster})),byStart:Vf(s=this.orderedItems.byStart).call(s,(function(t){return!t.isCluster}))},d={byEnd:gd(new ZD(Vf(a=jd(l=this.orderedItems.byEnd).call(l,(function(t){return t.cluster}))).call(a,(function(t){return!!t})))),byStart:gd(new ZD(Vf(h=jd(u=this.orderedItems.byStart).call(u,(function(t){return t.cluster}))).call(h,(function(t){return!!t}))))},p=function(){var t,e,i,o=r._updateItemsInRange(c,Vf(t=r.visibleItems).call(t,(function(t){return!t.isCluster})),n),s=r._updateClustersInRange(d,Vf(e=r.visibleItems).call(e,(function(t){return t.isCluster})),n);return xd(i=[]).call(i,gd(o),gd(s))},f=function(t){var e={},i=function(i){var n,o=Vf(n=r.visibleItems).call(n,(function(t){return t.data.subgroup===i}));e[i]=t?RC(o).call(o,(function(e,i){return t(e.data,i.data)})):o};for(var n in r.subgroups)i(n);return e};if("function"==typeof this.itemSet.options.order){var m=this;if(this.doInnerStack&&this.itemSet.options.stackSubgroups)vE(f(this.itemSet.options.order),i,this.subgroups),this.visibleItems=p(),this._updateSubGroupHeights(i);else{var v,g,y,b;this.visibleItems=p(),this._updateSubGroupHeights(i);var _=RC(v=Vf(g=Sd(y=this.visibleItems).call(y)).call(g,(function(t){return t.isCluster||!t.isCluster&&!t.cluster}))).call(v,(function(t,e){return m.itemSet.options.order(t.data,e.data)}));this.shouldBailStackItems=dE(_,i,!0,hp(b=this._shouldBailItemsRedraw).call(b,this))}}else{var w;this.visibleItems=p(),this._updateSubGroupHeights(i),this.itemSet.options.stack?this.doInnerStack&&this.itemSet.options.stackSubgroups?vE(f(),i,this.subgroups):this.shouldBailStackItems=dE(this.visibleItems,i,!0,hp(w=this._shouldBailItemsRedraw).call(w,this)):fE(this.visibleItems,i,this.subgroups,this.itemSet.options.stackSubgroups)}for(var k=0;k<this.visibleItems.length;k++)this.visibleItems[k].repositionX(),void 0!==this.subgroupVisibility[this.visibleItems[k].data.subgroup]&&(this.subgroupVisibility[this.visibleItems[k].data.subgroup]||this.visibleItems[k].hide());this.itemSet.options.cluster&&kp(EO).call(EO,this.items,(function(t){t.cluster&&t.displayed&&t.hide()})),this.shouldBailStackItems&&this.itemSet.body.emitter.emit("destroyTimeline"),this.stackDirty=!1}}},{key:"_didResize",value:function(t,e){t=EO.updateProperty(this,"height",e)||t;var i=this.dom.inner.clientWidth,n=this.dom.inner.clientHeight;return t=EO.updateProperty(this.props.label,"width",i)||t,EO.updateProperty(this.props.label,"height",n)||t}},{key:"_applyGroupHeight",value:function(t){this.dom.background.style.height="".concat(t,"px"),this.dom.foreground.style.height="".concat(t,"px"),this.dom.label.style.height="".concat(t,"px")}},{key:"_updateItemsVerticalPosition",value:function(t){for(var e=0,i=this.visibleItems.length;e<i;e++){var n=this.visibleItems[e];n.repositionY(t),this.isVisible||this.groupId==_E||n.displayed&&n.hide()}}},{key:"redraw",value:function(t,e,i,n){var r,o,s,a,l,h,u,c=this,d=!1,p=this.isVisible,f=[function(){i=c._didMarkerHeightChange.call(c)||i},hp(r=this._updateSubGroupHeights).call(r,this,e),hp(o=this._calculateGroupSizeAndPosition).call(o,this),function(){var i;c.isVisible=hp(i=c._isGroupVisible).call(i,c)(t,e)},function(){var n;hp(n=c._redrawItems).call(n,c)(i,p,e,t)},hp(s=this._updateSubgroupsSizes).call(s,this),function(){var t;h=hp(t=c._calculateHeight).call(t,c)(e)},hp(a=this._calculateGroupSizeAndPosition).call(a,this),function(){var t;d=hp(t=c._didResize).call(t,c)(d,h)},function(){var t;hp(t=c._applyGroupHeight).call(t,c)(h)},function(){var t;hp(t=c._updateItemsVerticalPosition).call(t,c)(e)},hp(l=function(){return!c.isVisible&&c.height&&(d=!1),d}).call(l,this)];return n?f:(kp(f).call(f,(function(t){u=t()})),u)}},{key:"_updateSubGroupHeights",value:function(t){var e=this;if(Bd(this.subgroups).length>0){var i=this;this._resetSubgroups(),kp(EO).call(EO,this.visibleItems,(function(n){void 0!==n.data.subgroup&&(i.subgroups[n.data.subgroup].height=Math.max(i.subgroups[n.data.subgroup].height,n.height+t.item.vertical),i.subgroups[n.data.subgroup].visible=void 0===e.subgroupVisibility[n.data.subgroup]||Boolean(e.subgroupVisibility[n.data.subgroup]))}))}}},{key:"_isGroupVisible",value:function(t,e){return this.top<=t.body.domProps.centerContainer.height-t.body.domProps.scrollTop+e.axis&&this.top+this.height+e.axis>=-t.body.domProps.scrollTop}},{key:"_calculateHeight",value:function(t){var e,i;if((i="fixed"===this.heightMode?EO.toArray(this.items):this.visibleItems).length>0){var n=i[0].top,r=i[0].top+i[0].height;if(kp(EO).call(EO,i,(function(t){n=Math.min(n,t.top),r=Math.max(r,t.top+t.height)})),n>t.axis){var o=n-t.axis;r-=o,kp(EO).call(EO,i,(function(t){t.top-=o}))}e=Math.ceil(r+t.item.vertical/2),"fitItems"!==this.heightMode&&(e=Math.max(e,this.props.label.height))}else e=this.props.label.height;return e}},{key:"show",value:function(){this.dom.label.parentNode||this.itemSet.dom.labelSet.appendChild(this.dom.label),this.dom.foreground.parentNode||this.itemSet.dom.foreground.appendChild(this.dom.foreground),this.dom.background.parentNode||this.itemSet.dom.background.appendChild(this.dom.background),this.dom.axis.parentNode||this.itemSet.dom.axis.appendChild(this.dom.axis)}},{key:"hide",value:function(){var t=this.dom.label;t.parentNode&&t.parentNode.removeChild(t);var e=this.dom.foreground;e.parentNode&&e.parentNode.removeChild(e);var i=this.dom.background;i.parentNode&&i.parentNode.removeChild(i);var n=this.dom.axis;n.parentNode&&n.parentNode.removeChild(n)}},{key:"add",value:function(t){var e;if(this.items[t.id]=t,t.setParent(this),this.stackDirty=!0,void 0!==t.data.subgroup&&(this._addToSubgroup(t),this.orderSubgroups()),!Af(e=this.visibleItems).call(e,t)){var i=this.itemSet.body.range;this._checkIfVisible(t,this.visibleItems,i)}}},{key:"_addToSubgroup",value:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:t.data.subgroup;null!=e&&void 0===this.subgroups[e]&&(this.subgroups[e]={height:0,top:0,start:t.data.start,end:t.data.end||t.data.start,visible:!1,index:this.subgroupIndex,items:[],stack:this.subgroupStackAll||this.subgroupStack[e]||!1},this.subgroupIndex++),new Date(t.data.start)<new Date(this.subgroups[e].start)&&(this.subgroups[e].start=t.data.start);var i=t.data.end||t.data.start;new Date(i)>new Date(this.subgroups[e].end)&&(this.subgroups[e].end=i),this.subgroups[e].items.push(t)}},{key:"_updateSubgroupsSizes",value:function(){var t=this;if(t.subgroups){var e=function(){var e,n=t.subgroups[i].items[0].data.end||t.subgroups[i].items[0].data.start,r=t.subgroups[i].items[0].data.start,o=n-1;kp(e=t.subgroups[i].items).call(e,(function(t){new Date(t.data.start)<new Date(r)&&(r=t.data.start);var e=t.data.end||t.data.start;new Date(e)>new Date(o)&&(o=e)})),t.subgroups[i].start=r,t.subgroups[i].end=new Date(o-1)};for(var i in t.subgroups)e()}}},{key:"orderSubgroups",value:function(){if(void 0!==this.subgroupOrderer){var t=[];if("string"==typeof this.subgroupOrderer){for(var e in this.subgroups)t.push({subgroup:e,sortField:this.subgroups[e].items[0].data[this.subgroupOrderer]});RC(t).call(t,(function(t,e){return t.sortField-e.sortField}))}else if("function"==typeof this.subgroupOrderer){for(var i in this.subgroups)t.push(this.subgroups[i].items[0].data);RC(t).call(t,this.subgroupOrderer)}if(t.length>0)for(var n=0;n<t.length;n++)this.subgroups[t[n].subgroup].index=n}}},{key:"_resetSubgroups",value:function(){for(var t in this.subgroups)this.subgroups.hasOwnProperty(t)&&(this.subgroups[t].visible=!1,this.subgroups[t].height=0)}},{key:"remove",value:function(t){var e,i;delete this.items[t.id],t.setParent(null),this.stackDirty=!0;var n=Rm(e=this.visibleItems).call(e,t);-1!=n&&Qp(i=this.visibleItems).call(i,n,1),void 0!==t.data.subgroup&&(this._removeFromSubgroup(t),this.orderSubgroups())}},{key:"_removeFromSubgroup",value:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:t.data.subgroup;if(null!=e){var i=this.subgroups[e];if(i){var n,r,o=Rm(n=i.items).call(n,t);o>=0&&(Qp(r=i.items).call(r,o,1),i.items.length?this._updateSubgroupsSizes():delete this.subgroups[e])}}}},{key:"removeFromDataSet",value:function(t){this.itemSet.removeItem(t.id)}},{key:"order",value:function(){for(var t=EO.toArray(this.items),e=[],i=[],n=0;n<t.length;n++)void 0!==t[n].data.end&&i.push(t[n]),e.push(t[n]);this.orderedItems={byStart:e,byEnd:i},uE(this.orderedItems.byStart),cE(this.orderedItems.byEnd)}},{key:"_updateItemsInRange",value:function(t,e,i){var n=[],r={};if(!this.isVisible&&void 0!==this.height&&this.groupId!=_E){for(var o=0;o<e.length;o++){var s=e[o];s.displayed&&s.hide()}return n}var a=(i.end-i.start)/4,l=i.start-a,h=i.end+a;if(e.length>0)for(var u=0;u<e.length;u++)this._checkIfVisibleWithReference(e[u],n,r,i);var c=EO.binarySearchCustom(t.byStart,(function(t){return t<l?-1:t<=h?0:1}),"data","start");if(this._traceVisible(c,t.byStart,n,r,(function(t){return t.data.start<l||t.data.start>h})),1==this.checkRangedItems){this.checkRangedItems=!1;for(var d=0;d<t.byEnd.length;d++)this._checkIfVisibleWithReference(t.byEnd[d],n,r,i)}else{var p=EO.binarySearchCustom(t.byEnd,(function(t){var e=t.start;return t.end<l?-1:e<=h?0:1}),"data");this._traceVisible(p,t.byEnd,n,r,(function(t){return t.data.end<l||t.data.start>h}))}for(var f={},m=0,v=0;v<n.length;v++){var g=n[v];g.displayed||(f[v]=g.redraw(!0),m=f[v].length)}if(m>0)for(var y=function(t){kp(EO).call(EO,f,(function(e){e[t]()}))},b=0;b<m;b++)y(b);for(var _=0;_<n.length;_++)n[_].repositionX();return n}},{key:"_traceVisible",value:function(t,e,i,n,r){if(-1!=t){for(var o=t;o>=0;o--){var s=e[o];if(r(s))break;s.isCluster&&!s.hasItems()||s.cluster||void 0===n[s.id]&&(n[s.id]=!0,i.push(s))}for(var a=t+1;a<e.length;a++){var l=e[a];if(r(l))break;l.isCluster&&!l.hasItems()||l.cluster||void 0===n[l.id]&&(n[l.id]=!0,i.push(l))}}}},{key:"_checkIfVisible",value:function(t,e,i){t.isVisible(i)?(t.displayed||t.show(),t.repositionX(),e.push(t)):t.displayed&&t.hide()}},{key:"_checkIfVisibleWithReference",value:function(t,e,i,n){t.isVisible(n)?void 0===i[t.id]&&(i[t.id]=!0,e.push(t)):t.displayed&&t.hide()}},{key:"_updateClustersInRange",value:function(t,e,i){var n=[],r={};if(e.length>0)for(var o=0;o<e.length;o++)this._checkIfVisibleWithReference(e[o],n,r,i);for(var s=0;s<t.byStart.length;s++)this._checkIfVisibleWithReference(t.byStart[s],n,r,i);for(var a=0;a<t.byEnd.length;a++)this._checkIfVisibleWithReference(t.byEnd[a],n,r,i);for(var l={},h=0,u=0;u<n.length;u++){var c=n[u];c.displayed||(l[u]=c.redraw(!0),h=l[u].length)}if(h>0)for(var d=0;d<h;d++)kp(EO).call(EO,l,(function(t){t[d]()}));for(var p=0;p<n.length;p++)n[p].repositionX();return n}},{key:"changeSubgroup",value:function(t,e,i){this._removeFromSubgroup(t,e),this._addToSubgroup(t,i),this.orderSubgroups()}},{key:"dispose",value:function(){var t;for(this.hide();t=this._disposeCallbacks.pop();)t()}}]),t}();var kE=function(t){Ib(i,t);var e=function(t){var e=function(){if("undefined"==typeof Reflect||!MT)return!1;if(MT.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(MT(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var i,n=Rb(t);if(e){var r=Rb(this).constructor;i=MT(n,arguments,r)}else i=n.apply(this,arguments);return Lb(this,i)}}(i);function i(t,n,r){var o;return ga(this,i),(o=e.call(this,t,n,r)).width=0,o.height=0,o.top=0,o.left=0,o}return Cc(i,[{key:"redraw",value:function(t,e,i){this.visibleItems=this._updateItemsInRange(this.orderedItems,this.visibleItems,t),this.width=this.dom.background.offsetWidth,this.dom.background.style.height="0";for(var n=0,r=this.visibleItems.length;n<r;n++)this.visibleItems[n].repositionY(e);return!1}},{key:"show",value:function(){this.dom.background.parentNode||this.itemSet.dom.background.appendChild(this.dom.background)}}]),i}(wE);function xE(t,e){(null==e||e>t.length)&&(e=t.length);for(var i=0,n=new Array(e);i<e;i++)n[i]=t[i];return n}wP('.vis-item{background-color:#d5ddf6;border-color:#97b0f8;border-width:1px;color:#1a1a1a;display:inline-block;position:absolute;z-index:1}.vis-item.vis-selected{background-color:#fff785;border-color:#ffc200;z-index:2}.vis-editable.vis-selected{cursor:move}.vis-item.vis-point.vis-selected{background-color:#fff785}.vis-item.vis-box{border-radius:2px;border-style:solid;text-align:center}.vis-item.vis-point{background:none}.vis-item.vis-dot{border-radius:4px;border-style:solid;border-width:4px;padding:0;position:absolute}.vis-item.vis-range{border-radius:2px;border-style:solid;box-sizing:border-box}.vis-item.vis-background{background-color:rgba(213,221,246,.4);border:none;box-sizing:border-box;margin:0;padding:0}.vis-item .vis-item-overflow{height:100%;margin:0;overflow:hidden;padding:0;position:relative;width:100%}.vis-item-visible-frame{white-space:nowrap}.vis-item.vis-range .vis-item-content{display:inline-block;position:relative}.vis-item.vis-background .vis-item-content{display:inline-block;position:absolute}.vis-item.vis-line{border-left-style:solid;border-left-width:1px;padding:0;position:absolute;width:0}.vis-item .vis-item-content{box-sizing:border-box;padding:5px;white-space:nowrap}.vis-item .vis-onUpdateTime-tooltip{background:#4f81bd;border-radius:1px;color:#fff;padding:5px;position:absolute;text-align:center;transition:.4s;-o-transition:.4s;-moz-transition:.4s;-webkit-transition:.4s;white-space:nowrap;width:200px}.vis-item .vis-delete,.vis-item .vis-delete-rtl{box-sizing:border-box;cursor:pointer;height:24px;padding:0 5px;position:absolute;top:0;-webkit-transition:background .2s linear;-moz-transition:background .2s linear;-ms-transition:background .2s linear;-o-transition:background .2s linear;transition:background .2s linear;width:24px}.vis-item .vis-delete{right:-24px}.vis-item .vis-delete-rtl{left:-24px}.vis-item .vis-delete-rtl:after,.vis-item .vis-delete:after{color:red;content:"\\00D7";font-family:arial,sans-serif;font-size:22px;font-weight:700;-webkit-transition:color .2s linear;-moz-transition:color .2s linear;-ms-transition:color .2s linear;-o-transition:color .2s linear;transition:color .2s linear}.vis-item .vis-delete-rtl:hover,.vis-item .vis-delete:hover{background:red}.vis-item .vis-delete-rtl:hover:after,.vis-item .vis-delete:hover:after{color:#fff}.vis-item .vis-drag-center{cursor:move;height:100%;left:0;position:absolute;top:0;width:100%}.vis-item.vis-range .vis-drag-left{cursor:w-resize;left:-4px}.vis-item.vis-range .vis-drag-left,.vis-item.vis-range .vis-drag-right{height:100%;max-width:20%;min-width:2px;position:absolute;top:0;width:24px}.vis-item.vis-range .vis-drag-right{cursor:e-resize;right:-4px}.vis-range.vis-item.vis-readonly .vis-drag-left,.vis-range.vis-item.vis-readonly .vis-drag-right{cursor:auto}.vis-item.vis-cluster{border-radius:2px;border-style:solid;text-align:center;vertical-align:center}.vis-item.vis-cluster-line{border-left-style:solid;border-left-width:1px;padding:0;position:absolute;width:0}.vis-item.vis-cluster-dot{border-radius:4px;border-style:solid;border-width:4px;padding:0;position:absolute}');var SE=function(){function t(e,i,n){var r,o=this;ga(this,t),this.id=null,this.parent=null,this.data=e,this.dom=null,this.conversion=i||{},this.defaultOptions={locales:HP,locale:"en"},this.options=EO.extend({},this.defaultOptions,n),this.options.locales=EO.extend({},HP,this.options.locales);var s=this.defaultOptions.locales[this.defaultOptions.locale];kp(r=Bd(this.options.locales)).call(r,(function(t){o.options.locales[t]=EO.extend({},s,o.options.locales[t])})),this.selected=!1,this.displayed=!1,this.groupShowing=!0,this.selectable=n&&n.selectable||!1,this.dirty=!0,this.top=null,this.right=null,this.left=null,this.width=null,this.height=null,this.setSelectability(e),this.editable=null,this._updateEditStatus()}return Cc(t,[{key:"select",value:function(){this.selectable&&(this.selected=!0,this.dirty=!0,this.displayed&&this.redraw())}},{key:"unselect",value:function(){this.selected=!1,this.dirty=!0,this.displayed&&this.redraw()}},{key:"setData",value:function(t){null!=t.group&&this.data.group!=t.group&&null!=this.parent&&this.parent.itemSet._moveToGroup(this,t.group),this.setSelectability(t),this.parent&&(this.parent.stackDirty=!0),null!=t.subgroup&&this.data.subgroup!=t.subgroup&&null!=this.parent&&this.parent.changeSubgroup(this,this.data.subgroup,t.subgroup),this.data=t,this._updateEditStatus(),this.dirty=!0,this.displayed&&this.redraw()}},{key:"setSelectability",value:function(t){t&&(this.selectable=void 0===t.selectable||Boolean(t.selectable))}},{key:"setParent",value:function(t){this.displayed?(this.hide(),this.parent=t,this.parent&&this.show()):this.parent=t}},{key:"isVisible",value:function(t){return!1}},{key:"show",value:function(){return!1}},{key:"hide",value:function(){return!1}},{key:"redraw",value:function(){}},{key:"repositionX",value:function(){}},{key:"repositionY",value:function(){}},{key:"_repaintDragCenter",value:function(){if(this.selected&&this.editable.updateTime&&!this.dom.dragCenter){var t,e,i=this,n=document.createElement("div");n.className="vis-drag-center",n.dragCenterItem=this,this.hammerDragCenter=new yP(n),this.hammerDragCenter.on("tap",(function(t){i.parent.itemSet.body.emitter.emit("click",{event:t,item:i.id})})),this.hammerDragCenter.on("doubletap",(function(t){t.stopPropagation(),i.parent.itemSet._onUpdateItem(i),i.parent.itemSet.body.emitter.emit("doubleClick",{event:t,item:i.id})})),this.hammerDragCenter.on("panstart",(function(t){t.stopPropagation(),i.parent.itemSet._onDragStart(t)})),this.hammerDragCenter.on("panmove",hp(t=i.parent.itemSet._onDrag).call(t,i.parent.itemSet)),this.hammerDragCenter.on("panend",hp(e=i.parent.itemSet._onDragEnd).call(e,i.parent.itemSet)),this.hammerDragCenter.get("press").set({time:1e4}),this.dom.box?this.dom.dragLeft?this.dom.box.insertBefore(n,this.dom.dragLeft):this.dom.box.appendChild(n):this.dom.point&&this.dom.point.appendChild(n),this.dom.dragCenter=n}else!this.selected&&this.dom.dragCenter&&(this.dom.dragCenter.parentNode&&this.dom.dragCenter.parentNode.removeChild(this.dom.dragCenter),this.dom.dragCenter=null,this.hammerDragCenter&&(this.hammerDragCenter.destroy(),this.hammerDragCenter=null))}},{key:"_repaintDeleteButton",value:function(t){var e=(this.options.editable.overrideItems||null==this.editable)&&this.options.editable.remove||!this.options.editable.overrideItems&&null!=this.editable&&this.editable.remove;if(this.selected&&e&&!this.dom.deleteButton){var i=this,n=document.createElement("div");this.options.rtl?n.className="vis-delete-rtl":n.className="vis-delete";var r=this.options.locales[this.options.locale];r||(this.warned||(console.warn("WARNING: options.locales['".concat(this.options.locale,"'] not found. See https://visjs.github.io/vis-timeline/docs/timeline/#Localization")),this.warned=!0),r=this.options.locales.en),n.title=r.deleteSelected,this.hammerDeleteButton=new yP(n).on("tap",(function(t){t.stopPropagation(),i.parent.removeFromDataSet(i)})),t.appendChild(n),this.dom.deleteButton=n}else this.selected&&e||!this.dom.deleteButton||(this.dom.deleteButton.parentNode&&this.dom.deleteButton.parentNode.removeChild(this.dom.deleteButton),this.dom.deleteButton=null,this.hammerDeleteButton&&(this.hammerDeleteButton.destroy(),this.hammerDeleteButton=null))}},{key:"_repaintOnItemUpdateTimeTooltip",value:function(t){if(this.options.tooltipOnItemUpdateTime){var e=(this.options.editable.updateTime||!0===this.data.editable)&&!1!==this.data.editable;if(this.selected&&e&&!this.dom.onItemUpdateTimeTooltip){var i=document.createElement("div");i.className="vis-onUpdateTime-tooltip",t.appendChild(i),this.dom.onItemUpdateTimeTooltip=i}else!this.selected&&this.dom.onItemUpdateTimeTooltip&&(this.dom.onItemUpdateTimeTooltip.parentNode&&this.dom.onItemUpdateTimeTooltip.parentNode.removeChild(this.dom.onItemUpdateTimeTooltip),this.dom.onItemUpdateTimeTooltip=null);if(this.dom.onItemUpdateTimeTooltip){this.dom.onItemUpdateTimeTooltip.style.visibility=this.parent.itemSet.touchParams.itemIsDragging?"visible":"hidden",this.dom.onItemUpdateTimeTooltip.style.transform="translateX(-50%)",this.dom.onItemUpdateTimeTooltip.style.left="50%";var n,r,o=this.parent.itemSet.body.domProps.scrollTop;("top"==this.options.orientation.item?this.top:this.parent.height-this.top-this.height)+this.parent.top-50<-o?(this.dom.onItemUpdateTimeTooltip.style.bottom="",this.dom.onItemUpdateTimeTooltip.style.top="".concat(this.height+2,"px")):(this.dom.onItemUpdateTimeTooltip.style.top="",this.dom.onItemUpdateTimeTooltip.style.bottom="".concat(this.height+2,"px")),this.options.tooltipOnItemUpdateTime&&this.options.tooltipOnItemUpdateTime.template?n=hp(r=this.options.tooltipOnItemUpdateTime.template).call(r,this)(this.data):(n="start: ".concat(gM(this.data.start).format("MM/DD/YYYY hh:mm")),this.data.end&&(n+="<br> end: ".concat(gM(this.data.end).format("MM/DD/YYYY hh:mm")))),this.dom.onItemUpdateTimeTooltip.innerHTML=EO.xss(n)}}}},{key:"_getItemData",value:function(){return this.parent.itemSet.itemsData.get(this.id)}},{key:"_updateContents",value:function(t){var e,i,n,r,o,s,a=this._getItemData(),l=(this.dom.box||this.dom.point).getElementsByClassName("vis-item-visible-frame")[0];if(this.options.visibleFrameTemplate?(r=hp(o=this.options.visibleFrameTemplate).call(o,this),n=EO.xss(r(a,l))):n="",l)if(n instanceof Object&&!(n instanceof Element))r(a,l);else if(this._contentToString(this.itemVisibleFrameContent)!==this._contentToString(n)){if(n instanceof Element)l.innerHTML="",l.appendChild(n);else if(null!=n)l.innerHTML=EO.xss(n);else if("background"!=this.data.type||void 0!==this.data.content)throw new Error('Property "content" missing in item '.concat(this.id));this.itemVisibleFrameContent=n}if((e=this.options.template?(i=hp(s=this.options.template).call(s,this))(a,t,this.data):this.data.content)instanceof Object&&!(e instanceof Element))i(a,t);else if(this._contentToString(this.content)!==this._contentToString(e)){if(e instanceof Element)t.innerHTML="",t.appendChild(e);else if(null!=e)t.innerHTML=EO.xss(e);else if("background"!=this.data.type||void 0!==this.data.content)throw new Error('Property "content" missing in item '.concat(this.id));this.content=e}}},{key:"_updateDataAttributes",value:function(t){if(this.options.dataAttributes&&this.options.dataAttributes.length>0){var e=[];if(Id(this.options.dataAttributes))e=this.options.dataAttributes;else{if("all"!=this.options.dataAttributes)return;e=Bd(this.data)}var i,n=function(t,e){var i=void 0!==yd&&va(t)||t["@@iterator"];if(!i){if(Id(t)||(i=function(t,e){var i;if(t){if("string"==typeof t)return xE(t,e);var n=Sd(i=Object.prototype.toString.call(t)).call(i,8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Ks(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?xE(t,e):void 0}}(t))||e&&t&&"number"==typeof t.length){i&&(t=i);var n=0,r=function(){};return{s:r,n:function(){return n>=t.length?{done:!0}:{done:!1,value:t[n++]}},e:function(t){throw t},f:r}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var o,s=!0,a=!1;return{s:function(){i=i.call(t)},n:function(){var t=i.next();return s=t.done,t},e:function(t){a=!0,o=t},f:function(){try{s||null==i.return||i.return()}finally{if(a)throw o}}}}(e);try{for(n.s();!(i=n.n()).done;){var r=i.value,o=this.data[r];null!=o?t.setAttribute("data-".concat(r),o):t.removeAttribute("data-".concat(r))}}catch(t){n.e(t)}finally{n.f()}}}},{key:"_updateStyle",value:function(t){this.style&&(EO.removeCssText(t,this.style),this.style=null),this.data.style&&(EO.addCssText(t,this.data.style),this.style=this.data.style)}},{key:"_contentToString",value:function(t){return"string"==typeof t?t:t&&"outerHTML"in t?t.outerHTML:t}},{key:"_updateEditStatus",value:function(){this.options&&("boolean"==typeof this.options.editable?this.editable={updateTime:this.options.editable,updateGroup:this.options.editable,remove:this.options.editable}:"object"===kc(this.options.editable)&&(this.editable={},EO.selectiveExtend(["updateTime","updateGroup","remove"],this.editable,this.options.editable))),this.options&&this.options.editable&&!0===this.options.editable.overrideItems||this.data&&("boolean"==typeof this.data.editable?this.editable={updateTime:this.data.editable,updateGroup:this.data.editable,remove:this.data.editable}:"object"===kc(this.data.editable)&&(this.editable={},EO.selectiveExtend(["updateTime","updateGroup","remove"],this.editable,this.data.editable)))}},{key:"getWidthLeft",value:function(){return 0}},{key:"getWidthRight",value:function(){return 0}},{key:"getTitle",value:function(){var t;return this.options.tooltip&&this.options.tooltip.template?hp(t=this.options.tooltip.template).call(t,this)(this._getItemData(),this.data):this.data.title}}]),t}();SE.prototype.stack=!0;var DE=function(t){Ib(i,t);var e=function(t){var e=function(){if("undefined"==typeof Reflect||!MT)return!1;if(MT.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(MT(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var i,n=Rb(t);if(e){var r=Rb(this).constructor;i=MT(n,arguments,r)}else i=n.apply(this,arguments);return Lb(this,i)}}(i);function i(t,n,r){var o;if(ga(this,i),(o=e.call(this,t,n,r)).props={dot:{width:0,height:0},line:{width:0,height:0}},t&&null==t.start)throw new Error('Property "start" missing in item '.concat(t));return o}return Cc(i,[{key:"isVisible",value:function(t){if(this.cluster)return!1;var e=this.data.align||this.options.align,i=this.width*t.getMillisecondsPerPixel();return"right"==e?this.data.start.getTime()>t.start&&this.data.start.getTime()-i<t.end:"left"==e?this.data.start.getTime()+i>t.start&&this.data.start.getTime()<t.end:this.data.start.getTime()+i/2>t.start&&this.data.start.getTime()-i/2<t.end}},{key:"_createDomElement",value:function(){this.dom||(this.dom={},this.dom.box=document.createElement("DIV"),this.dom.content=document.createElement("DIV"),this.dom.content.className="vis-item-content",this.dom.box.appendChild(this.dom.content),this.dom.line=document.createElement("DIV"),this.dom.line.className="vis-line",this.dom.dot=document.createElement("DIV"),this.dom.dot.className="vis-dot",this.dom.box["vis-item"]=this,this.dirty=!0)}},{key:"_appendDomElement",value:function(){if(!this.parent)throw new Error("Cannot redraw item: no parent attached");if(!this.dom.box.parentNode){var t=this.parent.dom.foreground;if(!t)throw new Error("Cannot redraw item: parent has no foreground container element");t.appendChild(this.dom.box)}if(!this.dom.line.parentNode){var e=this.parent.dom.background;if(!e)throw new Error("Cannot redraw item: parent has no background container element");e.appendChild(this.dom.line)}if(!this.dom.dot.parentNode){var i=this.parent.dom.axis;if(!e)throw new Error("Cannot redraw item: parent has no axis container element");i.appendChild(this.dom.dot)}this.displayed=!0}},{key:"_updateDirtyDomComponents",value:function(){if(this.dirty){this._updateContents(this.dom.content),this._updateDataAttributes(this.dom.box),this._updateStyle(this.dom.box);var t=this.editable.updateTime||this.editable.updateGroup,e=(this.data.className?" "+this.data.className:"")+(this.selected?" vis-selected":"")+(t?" vis-editable":" vis-readonly");this.dom.box.className="vis-item vis-box".concat(e),this.dom.line.className="vis-item vis-line".concat(e),this.dom.dot.className="vis-item vis-dot".concat(e)}}},{key:"_getDomComponentsSizes",value:function(){return{previous:{right:this.dom.box.style.right,left:this.dom.box.style.left},dot:{height:this.dom.dot.offsetHeight,width:this.dom.dot.offsetWidth},line:{width:this.dom.line.offsetWidth},box:{width:this.dom.box.offsetWidth,height:this.dom.box.offsetHeight}}}},{key:"_updateDomComponentsSizes",value:function(t){this.options.rtl?this.dom.box.style.right="0px":this.dom.box.style.left="0px",this.props.dot.height=t.dot.height,this.props.dot.width=t.dot.width,this.props.line.width=t.line.width,this.width=t.box.width,this.height=t.box.height,this.options.rtl?this.dom.box.style.right=t.previous.right:this.dom.box.style.left=t.previous.left,this.dirty=!1}},{key:"_repaintDomAdditionals",value:function(){this._repaintOnItemUpdateTimeTooltip(this.dom.box),this._repaintDragCenter(),this._repaintDeleteButton(this.dom.box)}},{key:"redraw",value:function(t){var e,i,n,r,o,s,a=this,l=[hp(e=this._createDomElement).call(e,this),hp(i=this._appendDomElement).call(i,this),hp(n=this._updateDirtyDomComponents).call(n,this),function(){a.dirty&&(o=a._getDomComponentsSizes())},function(){var t;a.dirty&&hp(t=a._updateDomComponentsSizes).call(t,a)(o)},hp(r=this._repaintDomAdditionals).call(r,this)];return t?l:(kp(l).call(l,(function(t){s=t()})),s)}},{key:"show",value:function(t){if(!this.displayed)return this.redraw(t)}},{key:"hide",value:function(){if(this.displayed){var t=this.dom;t.box.remove?t.box.remove():t.box.parentNode&&t.box.parentNode.removeChild(t.box),t.line.remove?t.line.remove():t.line.parentNode&&t.line.parentNode.removeChild(t.line),t.dot.remove?t.dot.remove():t.dot.parentNode&&t.dot.parentNode.removeChild(t.dot),this.displayed=!1}}},{key:"repositionXY",value:function(){var t=this.options.rtl,e=function(t,e,i){var n;if(void 0!==e||void 0!==i){var r=arguments.length>3&&void 0!==arguments[3]&&arguments[3]?-1*e:e;t.style.transform=void 0!==i?void 0!==e?xd(n="translate(".concat(r,"px, ")).call(n,i,"px)"):"translateY(".concat(i,"px)"):"translateX(".concat(r,"px)")}};e(this.dom.box,this.boxX,this.boxY,t),e(this.dom.dot,this.dotX,this.dotY,t),e(this.dom.line,this.lineX,this.lineY,t)}},{key:"repositionX",value:function(){var t=this.conversion.toScreen(this.data.start),e=void 0===this.data.align?this.options.align:this.data.align,i=this.props.line.width,n=this.props.dot.width;"right"==e?(this.boxX=t-this.width,this.lineX=t-i,this.dotX=t-i/2-n/2):"left"==e?(this.boxX=t,this.lineX=t,this.dotX=t+i/2-n/2):(this.boxX=t-this.width/2,this.lineX=this.options.rtl?t-i:t-i/2,this.dotX=t-n/2),this.options.rtl?this.right=this.boxX:this.left=this.boxX,this.repositionXY()}},{key:"repositionY",value:function(){var t=this.options.orientation.item,e=this.dom.line.style;if("top"==t){var i=this.parent.top+this.top+1;this.boxY=this.top||0,e.height="".concat(i,"px"),e.bottom="",e.top="0"}else{var n=this.parent.itemSet.props.height-this.parent.top-this.parent.height+this.top;this.boxY=this.parent.height-this.top-(this.height||0),e.height="".concat(n,"px"),e.top="",e.bottom="0"}this.dotY=-this.props.dot.height/2,this.repositionXY()}},{key:"getWidthLeft",value:function(){return this.width/2}},{key:"getWidthRight",value:function(){return this.width/2}}]),i}(SE);var CE=function(t){Ib(i,t);var e=function(t){var e=function(){if("undefined"==typeof Reflect||!MT)return!1;if(MT.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(MT(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var i,n=Rb(t);if(e){var r=Rb(this).constructor;i=MT(n,arguments,r)}else i=n.apply(this,arguments);return Lb(this,i)}}(i);function i(t,n,r){var o;if(ga(this,i),(o=e.call(this,t,n,r)).props={dot:{top:0,width:0,height:0},content:{height:0,marginLeft:0,marginRight:0}},t&&null==t.start)throw new Error('Property "start" missing in item '.concat(t));return o}return Cc(i,[{key:"isVisible",value:function(t){if(this.cluster)return!1;var e=this.width*t.getMillisecondsPerPixel();return this.data.start.getTime()+e>t.start&&this.data.start<t.end}},{key:"_createDomElement",value:function(){this.dom||(this.dom={},this.dom.point=document.createElement("div"),this.dom.content=document.createElement("div"),this.dom.content.className="vis-item-content",this.dom.point.appendChild(this.dom.content),this.dom.dot=document.createElement("div"),this.dom.point.appendChild(this.dom.dot),this.dom.point["vis-item"]=this,this.dirty=!0)}},{key:"_appendDomElement",value:function(){if(!this.parent)throw new Error("Cannot redraw item: no parent attached");if(!this.dom.point.parentNode){var t=this.parent.dom.foreground;if(!t)throw new Error("Cannot redraw item: parent has no foreground container element");t.appendChild(this.dom.point)}this.displayed=!0}},{key:"_updateDirtyDomComponents",value:function(){if(this.dirty){this._updateContents(this.dom.content),this._updateDataAttributes(this.dom.point),this._updateStyle(this.dom.point);var t=this.editable.updateTime||this.editable.updateGroup,e=(this.data.className?" "+this.data.className:"")+(this.selected?" vis-selected":"")+(t?" vis-editable":" vis-readonly");this.dom.point.className="vis-item vis-point".concat(e),this.dom.dot.className="vis-item vis-dot".concat(e)}}},{key:"_getDomComponentsSizes",value:function(){return{dot:{width:this.dom.dot.offsetWidth,height:this.dom.dot.offsetHeight},content:{width:this.dom.content.offsetWidth,height:this.dom.content.offsetHeight},point:{width:this.dom.point.offsetWidth,height:this.dom.point.offsetHeight}}}},{key:"_updateDomComponentsSizes",value:function(t){this.props.dot.width=t.dot.width,this.props.dot.height=t.dot.height,this.props.content.height=t.content.height,this.options.rtl?this.dom.content.style.marginRight="".concat(this.props.dot.width/2,"px"):this.dom.content.style.marginLeft="".concat(this.props.dot.width/2,"px"),this.width=t.point.width,this.height=t.point.height,this.dom.dot.style.top="".concat((this.height-this.props.dot.height)/2,"px");var e=this.props.dot.width,i=this.options.rtl?e/2:e/2*-1;this.dom.dot.style.transform="translateX(".concat(i,"px"),this.dirty=!1}},{key:"_repaintDomAdditionals",value:function(){this._repaintOnItemUpdateTimeTooltip(this.dom.point),this._repaintDragCenter(),this._repaintDeleteButton(this.dom.point)}},{key:"redraw",value:function(t){var e,i,n,r,o,s,a=this,l=[hp(e=this._createDomElement).call(e,this),hp(i=this._appendDomElement).call(i,this),hp(n=this._updateDirtyDomComponents).call(n,this),function(){a.dirty&&(o=a._getDomComponentsSizes())},function(){var t;a.dirty&&hp(t=a._updateDomComponentsSizes).call(t,a)(o)},hp(r=this._repaintDomAdditionals).call(r,this)];return t?l:(kp(l).call(l,(function(t){s=t()})),s)}},{key:"repositionXY",value:function(){var t=this.options.rtl;!function(t,e,i){var n;if(void 0!==e||void 0!==i){var r=arguments.length>3&&void 0!==arguments[3]&&arguments[3]?-1*e:e;t.style.transform=void 0!==i?void 0!==e?xd(n="translate(".concat(r,"px, ")).call(n,i,"px)"):"translateY(".concat(i,"px)"):"translateX(".concat(r,"px)")}}(this.dom.point,this.pointX,this.pointY,t)}},{key:"show",value:function(t){if(!this.displayed)return this.redraw(t)}},{key:"hide",value:function(){this.displayed&&(this.dom.point.parentNode&&this.dom.point.parentNode.removeChild(this.dom.point),this.displayed=!1)}},{key:"repositionX",value:function(){var t=this.conversion.toScreen(this.data.start);this.pointX=t,this.options.rtl?this.right=t-this.props.dot.width:this.left=t-this.props.dot.width,this.repositionXY()}},{key:"repositionY",value:function(){var t=this.options.orientation.item;this.pointY="top"==t?this.top:this.parent.height-this.top-this.height,this.repositionXY()}},{key:"getWidthLeft",value:function(){return this.props.dot.width}},{key:"getWidthRight",value:function(){return this.props.dot.width}}]),i}(SE);var TE=function(t){Ib(i,t);var e=function(t){var e=function(){if("undefined"==typeof Reflect||!MT)return!1;if(MT.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(MT(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var i,n=Rb(t);if(e){var r=Rb(this).constructor;i=MT(n,arguments,r)}else i=n.apply(this,arguments);return Lb(this,i)}}(i);function i(t,n,r){var o;if(ga(this,i),(o=e.call(this,t,n,r)).props={content:{width:0}},o.overflow=!1,t){if(null==t.start)throw new Error('Property "start" missing in item '.concat(t.id));if(null==t.end)throw new Error('Property "end" missing in item '.concat(t.id))}return o}return Cc(i,[{key:"isVisible",value:function(t){return!this.cluster&&this.data.start<t.end&&this.data.end>t.start}},{key:"_createDomElement",value:function(){this.dom||(this.dom={},this.dom.box=document.createElement("div"),this.dom.frame=document.createElement("div"),this.dom.frame.className="vis-item-overflow",this.dom.box.appendChild(this.dom.frame),this.dom.visibleFrame=document.createElement("div"),this.dom.visibleFrame.className="vis-item-visible-frame",this.dom.box.appendChild(this.dom.visibleFrame),this.dom.content=document.createElement("div"),this.dom.content.className="vis-item-content",this.dom.frame.appendChild(this.dom.content),this.dom.box["vis-item"]=this,this.dirty=!0)}},{key:"_appendDomElement",value:function(){if(!this.parent)throw new Error("Cannot redraw item: no parent attached");if(!this.dom.box.parentNode){var t=this.parent.dom.foreground;if(!t)throw new Error("Cannot redraw item: parent has no foreground container element");t.appendChild(this.dom.box)}this.displayed=!0}},{key:"_updateDirtyDomComponents",value:function(){if(this.dirty){this._updateContents(this.dom.content),this._updateDataAttributes(this.dom.box),this._updateStyle(this.dom.box);var t=this.editable.updateTime||this.editable.updateGroup,e=(this.data.className?" "+this.data.className:"")+(this.selected?" vis-selected":"")+(t?" vis-editable":" vis-readonly");this.dom.box.className=this.baseClassName+e,this.dom.content.style.maxWidth="none"}}},{key:"_getDomComponentsSizes",value:function(){return this.overflow="hidden"!==window.getComputedStyle(this.dom.frame).overflow,this.whiteSpace="nowrap"!==window.getComputedStyle(this.dom.content).whiteSpace,{content:{width:this.dom.content.offsetWidth},box:{height:this.dom.box.offsetHeight}}}},{key:"_updateDomComponentsSizes",value:function(t){this.props.content.width=t.content.width,this.height=t.box.height,this.dom.content.style.maxWidth="",this.dirty=!1}},{key:"_repaintDomAdditionals",value:function(){this._repaintOnItemUpdateTimeTooltip(this.dom.box),this._repaintDeleteButton(this.dom.box),this._repaintDragCenter(),this._repaintDragLeft(),this._repaintDragRight()}},{key:"redraw",value:function(t){var e,i,n,r,o,s,a=this,l=[hp(e=this._createDomElement).call(e,this),hp(i=this._appendDomElement).call(i,this),hp(n=this._updateDirtyDomComponents).call(n,this),function(){var t;a.dirty&&(o=hp(t=a._getDomComponentsSizes).call(t,a)())},function(){var t;a.dirty&&hp(t=a._updateDomComponentsSizes).call(t,a)(o)},hp(r=this._repaintDomAdditionals).call(r,this)];return t?l:(kp(l).call(l,(function(t){s=t()})),s)}},{key:"show",value:function(t){if(!this.displayed)return this.redraw(t)}},{key:"hide",value:function(){if(this.displayed){var t=this.dom.box;t.parentNode&&t.parentNode.removeChild(t),this.displayed=!1}}},{key:"repositionX",value:function(t){var e,i,n=this.parent.width,r=this.conversion.toScreen(this.data.start),o=this.conversion.toScreen(this.data.end),s=void 0===this.data.align?this.options.align:this.data.align;!1===this.data.limitSize||void 0!==t&&!0!==t||(r<-n&&(r=-n),o>2*n&&(o=2*n));var a=Math.max(Math.round(1e3*(o-r))/1e3,1);switch(this.overflow?(this.options.rtl?this.right=r:this.left=r,this.width=a+this.props.content.width,i=this.props.content.width):(this.options.rtl?this.right=r:this.left=r,this.width=a,i=Math.min(o-r,this.props.content.width)),this.options.rtl?this.dom.box.style.transform="translateX(".concat(-1*this.right,"px)"):this.dom.box.style.transform="translateX(".concat(this.left,"px)"),this.dom.box.style.width="".concat(a,"px"),this.whiteSpace&&(this.height=this.dom.box.offsetHeight),s){case"left":this.dom.content.style.transform="translateX(0)";break;case"right":if(this.options.rtl){var l=-1*Math.max(a-i,0);this.dom.content.style.transform="translateX(".concat(l,"px)")}else this.dom.content.style.transform="translateX(".concat(Math.max(a-i,0),"px)");break;case"center":if(this.options.rtl){var h=-1*Math.max((a-i)/2,0);this.dom.content.style.transform="translateX(".concat(h,"px)")}else this.dom.content.style.transform="translateX(".concat(Math.max((a-i)/2,0),"px)");break;default:if(e=this.overflow?o>0?Math.max(-r,0):-i:r<0?-r:0,this.options.rtl){var u=-1*e;this.dom.content.style.transform="translateX(".concat(u,"px)")}else this.dom.content.style.transform="translateX(".concat(e,"px)")}}},{key:"repositionY",value:function(){var t=this.options.orientation.item;this.dom.box.style.top="".concat("top"==t?this.top:this.parent.height-this.top-this.height,"px")}},{key:"_repaintDragLeft",value:function(){if((this.selected||this.options.itemsAlwaysDraggable.range)&&this.editable.updateTime&&!this.dom.dragLeft){var t=document.createElement("div");t.className="vis-drag-left",t.dragLeftItem=this,this.dom.box.appendChild(t),this.dom.dragLeft=t}else this.selected||this.options.itemsAlwaysDraggable.range||!this.dom.dragLeft||(this.dom.dragLeft.parentNode&&this.dom.dragLeft.parentNode.removeChild(this.dom.dragLeft),this.dom.dragLeft=null)}},{key:"_repaintDragRight",value:function(){if((this.selected||this.options.itemsAlwaysDraggable.range)&&this.editable.updateTime&&!this.dom.dragRight){var t=document.createElement("div");t.className="vis-drag-right",t.dragRightItem=this,this.dom.box.appendChild(t),this.dom.dragRight=t}else this.selected||this.options.itemsAlwaysDraggable.range||!this.dom.dragRight||(this.dom.dragRight.parentNode&&this.dom.dragRight.parentNode.removeChild(this.dom.dragRight),this.dom.dragRight=null)}}]),i}(SE);TE.prototype.baseClassName="vis-item vis-range";var ME=function(t){Ib(i,t);var e=function(t){var e=function(){if("undefined"==typeof Reflect||!MT)return!1;if(MT.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(MT(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var i,n=Rb(t);if(e){var r=Rb(this).constructor;i=MT(n,arguments,r)}else i=n.apply(this,arguments);return Lb(this,i)}}(i);function i(t,n,r){var o;if(ga(this,i),(o=e.call(this,t,n,r)).props={content:{width:0}},o.overflow=!1,t){if(null==t.start)throw new Error('Property "start" missing in item '.concat(t.id));if(null==t.end)throw new Error('Property "end" missing in item '.concat(t.id))}return o}return Cc(i,[{key:"isVisible",value:function(t){return this.data.start<t.end&&this.data.end>t.start}},{key:"_createDomElement",value:function(){this.dom||(this.dom={},this.dom.box=document.createElement("div"),this.dom.frame=document.createElement("div"),this.dom.frame.className="vis-item-overflow",this.dom.box.appendChild(this.dom.frame),this.dom.content=document.createElement("div"),this.dom.content.className="vis-item-content",this.dom.frame.appendChild(this.dom.content),this.dirty=!0)}},{key:"_appendDomElement",value:function(){if(!this.parent)throw new Error("Cannot redraw item: no parent attached");if(!this.dom.box.parentNode){var t=this.parent.dom.background;if(!t)throw new Error("Cannot redraw item: parent has no background container element");t.appendChild(this.dom.box)}this.displayed=!0}},{key:"_updateDirtyDomComponents",value:function(){if(this.dirty){this._updateContents(this.dom.content),this._updateDataAttributes(this.dom.content),this._updateStyle(this.dom.box);var t=(this.data.className?" "+this.data.className:"")+(this.selected?" vis-selected":"");this.dom.box.className=this.baseClassName+t}}},{key:"_getDomComponentsSizes",value:function(){return this.overflow="hidden"!==window.getComputedStyle(this.dom.content).overflow,{content:{width:this.dom.content.offsetWidth}}}},{key:"_updateDomComponentsSizes",value:function(t){this.props.content.width=t.content.width,this.height=0,this.dirty=!1}},{key:"_repaintDomAdditionals",value:function(){}},{key:"redraw",value:function(t){var e,i,n,r,o,s,a=this,l=[hp(e=this._createDomElement).call(e,this),hp(i=this._appendDomElement).call(i,this),hp(n=this._updateDirtyDomComponents).call(n,this),function(){var t;a.dirty&&(o=hp(t=a._getDomComponentsSizes).call(t,a)())},function(){var t;a.dirty&&hp(t=a._updateDomComponentsSizes).call(t,a)(o)},hp(r=this._repaintDomAdditionals).call(r,this)];return t?l:(kp(l).call(l,(function(t){s=t()})),s)}},{key:"repositionY",value:function(t){var e,i=this.options.orientation.item;if(void 0!==this.data.subgroup){var n=this.data.subgroup;this.dom.box.style.height="".concat(this.parent.subgroups[n].height,"px"),this.dom.box.style.top="".concat("top"==i?this.parent.top+this.parent.subgroups[n].top:this.parent.top+this.parent.height-this.parent.subgroups[n].top-this.parent.subgroups[n].height,"px"),this.dom.box.style.bottom=""}else this.parent instanceof kE?(e=Math.max(this.parent.height,this.parent.itemSet.body.domProps.center.height,this.parent.itemSet.body.domProps.centerContainer.height),this.dom.box.style.bottom="bottom"==i?"0":"",this.dom.box.style.top="top"==i?"0":""):(e=this.parent.height,this.dom.box.style.top="".concat(this.parent.top,"px"),this.dom.box.style.bottom="");this.dom.box.style.height="".concat(e,"px")}}]),i}(SE);ME.prototype.baseClassName="vis-item vis-background",ME.prototype.stack=!1,ME.prototype.show=TE.prototype.show,ME.prototype.hide=TE.prototype.hide,ME.prototype.repositionX=TE.prototype.repositionX,wP("div.vis-tooltip{background-color:#f5f4ed;border:1px solid #808074;-moz-border-radius:3px;-webkit-border-radius:3px;border-radius:3px;box-shadow:3px 3px 10px rgba(0,0,0,.2);color:#000;font-family:verdana;font-size:14px;padding:5px;pointer-events:none;position:absolute;visibility:hidden;white-space:nowrap;z-index:5}");var OE=function(){function t(e,i){ga(this,t),this.container=e,this.overflowMethod=i||"cap",this.x=0,this.y=0,this.padding=5,this.hidden=!1,this.frame=document.createElement("div"),this.frame.className="vis-tooltip",this.container.appendChild(this.frame)}return Cc(t,[{key:"setPosition",value:function(t,e){this.x=Cm(t),this.y=Cm(e)}},{key:"setText",value:function(t){t instanceof Element?(this.frame.innerHTML="",this.frame.appendChild(t)):this.frame.innerHTML=EO.xss(t)}},{key:"show",value:function(t){if(void 0===t&&(t=!0),!0===t){var e=this.frame.clientHeight,i=this.frame.clientWidth,n=this.frame.parentNode.clientHeight,r=this.frame.parentNode.clientWidth,o=0,s=0;if("flip"==this.overflowMethod||"none"==this.overflowMethod){var a=!1,l=!0;"flip"==this.overflowMethod&&(this.y-e<this.padding&&(l=!1),this.x+i>r-this.padding&&(a=!0)),o=a?this.x-i:this.x,s=l?this.y-e:this.y}else(s=this.y-e)+e+this.padding>n&&(s=n-e-this.padding),s<this.padding&&(s=this.padding),(o=this.x)+i+this.padding>r&&(o=r-i-this.padding),o<this.padding&&(o=this.padding);this.frame.style.left=o+"px",this.frame.style.top=s+"px",this.frame.style.visibility="visible",this.hidden=!1}else this.hide()}},{key:"hide",value:function(){this.hidden=!0,this.frame.style.left="0",this.frame.style.top="0",this.frame.style.visibility="hidden"}},{key:"destroy",value:function(){this.frame.parentNode.removeChild(this.frame)}}]),t}(),PE=jl.every;Tn({target:"Array",proto:!0,forced:!cp("every")},{every:function(t){return PE(this,t,arguments.length>1?arguments[1]:void 0)}});var EE=Yc("Array").every,IE=ve,LE=EE,AE=Array.prototype,NE=n((function(t){var e=t.every;return t===AE||IE(AE,t)&&e===AE.every?LE:e}));function RE(t,e){var i=void 0!==yd&&va(t)||t["@@iterator"];if(!i){if(Id(t)||(i=function(t,e){var i;if(t){if("string"==typeof t)return FE(t,e);var n=Sd(i=Object.prototype.toString.call(t)).call(i,8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Ks(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?FE(t,e):void 0}}(t))||e&&t&&"number"==typeof t.length){i&&(t=i);var n=0,r=function(){};return{s:r,n:function(){return n>=t.length?{done:!0}:{done:!1,value:t[n++]}},e:function(t){throw t},f:r}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var o,s=!0,a=!1;return{s:function(){i=i.call(t)},n:function(){var t=i.next();return s=t.done,t},e:function(t){a=!0,o=t},f:function(){try{s||null==i.return||i.return()}finally{if(a)throw o}}}}function FE(t,e){(null==e||e>t.length)&&(e=t.length);for(var i=0,n=new Array(e);i<e;i++)n[i]=t[i];return n}var jE=function(t){Ib(i,t);var e=function(t){var e=function(){if("undefined"==typeof Reflect||!MT)return!1;if(MT.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(MT(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var i,n=Rb(t);if(e){var r=Rb(this).constructor;i=MT(n,arguments,r)}else i=n.apply(this,arguments);return Lb(this,i)}}(i);function i(t,n,r){var o;ga(this,i);var s=mf({},{fitOnDoubleClick:!0},r,{editable:!1});if((o=e.call(this,t,n,s)).props={content:{width:0,height:0}},!t||null==t.uiItems)throw new Error('Property "uiItems" missing in item '+t.id);return o.id=nM(),o.group=t.group,o._setupRange(),o.emitter=o.data.eventEmitter,o.range=o.data.range,o.attached=!1,o.isCluster=!0,o.data.isCluster=!0,o}return Cc(i,[{key:"hasItems",value:function(){return this.data.uiItems&&this.data.uiItems.length&&this.attached}},{key:"setUiItems",value:function(t){this.detach(),this.data.uiItems=t,this._setupRange(),this.attach()}},{key:"isVisible",value:function(t){var e=this.data.end?this.data.end-this.data.start:0,i=this.width*t.getMillisecondsPerPixel(),n=Math.max(this.data.start.getTime()+e,this.data.start.getTime()+i);return this.data.start<t.end&&n>t.start&&this.hasItems()}},{key:"getData",value:function(){return{isCluster:!0,id:this.id,items:this.data.items||[],data:this.data}}},{key:"redraw",value:function(t){var e,i,n,r,o,s,a,l,h=[hp(e=this._createDomElement).call(e,this),hp(i=this._appendDomElement).call(i,this),hp(n=this._updateDirtyDomComponents).call(n,this),hp(r=function(){this.dirty&&(a=this._getDomComponentsSizes())}).call(r,this),hp(o=function(){var t;this.dirty&&hp(t=this._updateDomComponentsSizes).call(t,this)(a)}).call(o,this),hp(s=this._repaintDomAdditionals).call(s,this)];return t?h:(kp(h).call(h,(function(t){l=t()})),l)}},{key:"show",value:function(){this.displayed||this.redraw()}},{key:"hide",value:function(){if(this.displayed){var t=this.dom;t.box.parentNode&&t.box.parentNode.removeChild(t.box),this.options.showStipes&&(t.line.parentNode&&t.line.parentNode.removeChild(t.line),t.dot.parentNode&&t.dot.parentNode.removeChild(t.dot)),this.displayed=!1}}},{key:"repositionX",value:function(){var t=this.conversion.toScreen(this.data.start),e=this.data.end?this.conversion.toScreen(this.data.end):0;if(e)this.repositionXWithRanges(t,e);else{var i=void 0===this.data.align?this.options.align:this.data.align;this.repositionXWithoutRanges(t,i)}this.options.showStipes&&(this.dom.line.style.display=this._isStipeVisible()?"block":"none",this.dom.dot.style.display=this._isStipeVisible()?"block":"none",this._isStipeVisible()&&this.repositionStype(t,e))}},{key:"repositionStype",value:function(t,e){this.dom.line.style.display="block",this.dom.dot.style.display="block";var i=this.dom.line.offsetWidth,n=this.dom.dot.offsetWidth;if(e){var r=i+t+(e-t)/2,o=r-n/2,s=this.options.rtl?-1*r:r,a=this.options.rtl?-1*o:o;this.dom.line.style.transform="translateX(".concat(s,"px)"),this.dom.dot.style.transform="translateX(".concat(a,"px)")}else{var l=this.options.rtl?-1*t:t,h=this.options.rtl?-1*(t-n/2):t-n/2;this.dom.line.style.transform="translateX(".concat(l,"px)"),this.dom.dot.style.transform="translateX(".concat(h,"px)")}}},{key:"repositionXWithoutRanges",value:function(t,e){"right"==e?this.options.rtl?(this.right=t-this.width,this.dom.box.style.right=this.right+"px"):(this.left=t-this.width,this.dom.box.style.left=this.left+"px"):"left"==e?this.options.rtl?(this.right=t,this.dom.box.style.right=this.right+"px"):(this.left=t,this.dom.box.style.left=this.left+"px"):this.options.rtl?(this.right=t-this.width/2,this.dom.box.style.right=this.right+"px"):(this.left=t-this.width/2,this.dom.box.style.left=this.left+"px")}},{key:"repositionXWithRanges",value:function(t,e){var i=Math.round(Math.max(e-t+.5,1));this.options.rtl?this.right=t:this.left=t,this.width=Math.max(i,this.minWidth||0),this.options.rtl?this.dom.box.style.right=this.right+"px":this.dom.box.style.left=this.left+"px",this.dom.box.style.width=i+"px"}},{key:"repositionY",value:function(){var t=this.options.orientation.item;if(this.dom.box.style.top="top"==t?(this.top||0)+"px":(this.parent.height-this.top-this.height||0)+"px",this.options.showStipes){if("top"==t)this.dom.line.style.top="0",this.dom.line.style.height=this.parent.top+this.top+1+"px",this.dom.line.style.bottom="";else{var e=this.parent.itemSet.props.height,i=e-this.parent.top-this.parent.height+this.top;this.dom.line.style.top=e-i+"px",this.dom.line.style.bottom="0"}this.dom.dot.style.top=-this.dom.dot.offsetHeight/2+"px"}}},{key:"getWidthLeft",value:function(){return this.width/2}},{key:"getWidthRight",value:function(){return this.width/2}},{key:"move",value:function(){this.repositionX(),this.repositionY()}},{key:"attach",value:function(){var t,e,i=RE(this.data.uiItems);try{for(i.s();!(e=i.n()).done;)e.value.cluster=this}catch(t){i.e(t)}finally{i.f()}this.data.items=jd(t=this.data.uiItems).call(t,(function(t){return t.data})),this.attached=!0,this.dirty=!0}},{key:"detach",value:function(){var t=arguments.length>0&&void 0!==arguments[0]&&arguments[0];if(this.hasItems()){var e,i=RE(this.data.uiItems);try{for(i.s();!(e=i.n()).done;)delete e.value.cluster}catch(t){i.e(t)}finally{i.f()}this.attached=!1,t&&this.group&&(this.group.remove(this),this.group=null),this.data.items=[],this.dirty=!0}}},{key:"_onDoubleClick",value:function(){this._fit()}},{key:"_setupRange",value:function(){var t,e,i,n=jd(t=this.data.uiItems).call(t,(function(t){return{start:t.data.start.valueOf(),end:t.data.end?t.data.end.valueOf():t.data.start.valueOf()}}));this.data.min=Math.min.apply(Math,gd(jd(n).call(n,(function(t){return Math.min(t.start,t.end||t.start)})))),this.data.max=Math.max.apply(Math,gd(jd(n).call(n,(function(t){return Math.max(t.start,t.end||t.start)}))));var r=jd(e=this.data.uiItems).call(e,(function(t){return t.center})),o=PS(r).call(r,(function(t,e){return t+e}),0)/this.data.uiItems.length;zC(i=this.data.uiItems).call(i,(function(t){return t.data.end}))?(this.data.start=new Date(this.data.min),this.data.end=new Date(this.data.max)):(this.data.start=new Date(o),this.data.end=null)}},{key:"_getUiItems",value:function(){var t,e=this;return this.data.uiItems&&this.data.uiItems.length?Vf(t=this.data.uiItems).call(t,(function(t){return t.cluster===e})):[]}},{key:"_createDomElement",value:function(){var t;this.dom||(this.dom={},this.dom.box=document.createElement("DIV"),this.dom.content=document.createElement("DIV"),this.dom.content.className="vis-item-content",this.dom.box.appendChild(this.dom.content),this.options.showStipes&&(this.dom.line=document.createElement("DIV"),this.dom.line.className="vis-cluster-line",this.dom.line.style.display="none",this.dom.dot=document.createElement("DIV"),this.dom.dot.className="vis-cluster-dot",this.dom.dot.style.display="none"),this.options.fitOnDoubleClick&&(this.dom.box.ondblclick=hp(t=i.prototype._onDoubleClick).call(t,this)),this.dom.box["vis-item"]=this,this.dirty=!0)}},{key:"_appendDomElement",value:function(){if(!this.parent)throw new Error("Cannot redraw item: no parent attached");if(!this.dom.box.parentNode){var t=this.parent.dom.foreground;if(!t)throw new Error("Cannot redraw item: parent has no foreground container element");t.appendChild(this.dom.box)}var e=this.parent.dom.background;if(this.options.showStipes){if(!this.dom.line.parentNode){if(!e)throw new Error("Cannot redraw item: parent has no background container element");e.appendChild(this.dom.line)}if(!this.dom.dot.parentNode){var i=this.parent.dom.axis;if(!e)throw new Error("Cannot redraw item: parent has no axis container element");i.appendChild(this.dom.dot)}}this.displayed=!0}},{key:"_updateDirtyDomComponents",value:function(){if(this.dirty){this._updateContents(this.dom.content),this._updateDataAttributes(this.dom.box),this._updateStyle(this.dom.box);var t=this.baseClassName+" "+(this.data.className?" "+this.data.className:"")+(this.selected?" vis-selected":"")+" vis-readonly";this.dom.box.className="vis-item "+t,this.options.showStipes&&(this.dom.line.className="vis-item vis-cluster-line "+(this.selected?" vis-selected":""),this.dom.dot.className="vis-item vis-cluster-dot "+(this.selected?" vis-selected":"")),this.data.end&&(this.dom.content.style.maxWidth="none")}}},{key:"_getDomComponentsSizes",value:function(){var t={previous:{right:this.dom.box.style.right,left:this.dom.box.style.left},box:{width:this.dom.box.offsetWidth,height:this.dom.box.offsetHeight}};return this.options.showStipes&&(t.dot={height:this.dom.dot.offsetHeight,width:this.dom.dot.offsetWidth},t.line={width:this.dom.line.offsetWidth}),t}},{key:"_updateDomComponentsSizes",value:function(t){this.options.rtl?this.dom.box.style.right="0px":this.dom.box.style.left="0px",this.data.end?this.minWidth=t.box.width:this.width=t.box.width,this.height=t.box.height,this.options.rtl?this.dom.box.style.right=t.previous.right:this.dom.box.style.left=t.previous.left,this.dirty=!1}},{key:"_repaintDomAdditionals",value:function(){this._repaintOnItemUpdateTimeTooltip(this.dom.box)}},{key:"_isStipeVisible",value:function(){return this.minWidth>=this.width||!this.data.end}},{key:"_getFitRange",value:function(){var t=.05*(this.data.max-this.data.min)/2;return{fitStart:this.data.min-t,fitEnd:this.data.max+t}}},{key:"_fit",value:function(){if(this.emitter){var t=this._getFitRange(),e=t.fitStart,i=t.fitEnd,n={start:new Date(e),end:new Date(i),animation:!0};this.emitter.emit("fit",n)}}},{key:"_getItemData",value:function(){return this.data}}]),i}(SE);function YE(t,e){(null==e||e>t.length)&&(e=t.length);for(var i=0,n=new Array(e);i<e;i++)n[i]=t[i];return n}jE.prototype.baseClassName="vis-item vis-range vis-cluster";var HE=function(){function t(e){ga(this,t),this.itemSet=e,this.groups={},this.cache={},this.cache[-1]=[]}return Cc(t,[{key:"createClusterItem",value:function(t,e,i){return new jE(t,e,i)}},{key:"setItems",value:function(t,e){this.items=t||[],this.dataChanged=!0,this.applyOnChangedLevel=!1,e&&e.applyOnChangedLevel&&(this.applyOnChangedLevel=e.applyOnChangedLevel)}},{key:"updateData",value:function(){this.dataChanged=!0,this.applyOnChangedLevel=!1}},{key:"getClusters",value:function(t,e,i){var n="boolean"==typeof i?{}:i,r=n.maxItems,o=n.clusterCriteria;o||(o=function(){return!0}),r=r||1;var s=-1,a=0;if(e>0){if(e>=1)return[];s=Math.abs(Math.round(Math.log(100/e)/Math.log(2))),a=Math.abs(Math.pow(2,s))}if(this.dataChanged){var l=s!=this.cacheLevel;(!this.applyOnChangedLevel||l)&&(this._dropLevelsCache(),this._filterData())}this.cacheLevel=s;var h=this.cache[s];if(!h){for(var u in h=[],this.groups)if(this.groups.hasOwnProperty(u))for(var c=this.groups[u],d=c.length,p=0;p<d;){for(var f=c[p],m=1,v=p-1;v>=0&&f.center-c[v].center<a/2;)!c[v].cluster&&o(f.data,c[v].data)&&m++,v--;for(var g=p+1;g<c.length&&c[g].center-f.center<a/2;)o(f.data,c[g].data)&&m++,g++;for(var y=h.length-1;y>=0&&f.center-h[y].center<a;)f.group==h[y].group&&o(f.data,h[y].data)&&m++,y--;if(m>r){for(var b=m-r+1,_=[],w=p;_.length<b&&w<c.length;)o(c[p].data,c[w].data)&&_.push(c[w]),w++;var k=this.itemSet.getGroupId(f.data),x=this.itemSet.groups[k]||this.itemSet.groups.__ungrouped__,S=this._getClusterForItems(_,x,t,i);h.push(S),p+=b}else delete f.cluster,p+=1}this.cache[s]=h}return h}},{key:"_filterData",value:function(){var t={};this.groups=t;for(var e=0,i=rm(this.items);e<i.length;e++){var n=i[e],r=n.parent?n.parent.groupId:"",o=t[r];o||(o=[],t[r]=o),o.push(n),n.data.start&&(n.data.end?n.center=(n.data.start.valueOf()+n.data.end.valueOf())/2:n.center=n.data.start.valueOf())}for(var s in t){var a;t.hasOwnProperty(s)&&RC(a=t[s]).call(a,(function(t,e){return t.center-e.center}))}this.dataChanged=!1}},{key:"_getClusterForItems",value:function(t,e,i,n){var r,o,s=jd(r=i||[]).call(r,(function(t){var e;return{cluster:t,itemsIds:new ZD(jd(e=t.data.uiItems).call(e,(function(t){return t.id})))}}));if(s.length){var a,l=function(t,e){var i=void 0!==yd&&va(t)||t["@@iterator"];if(!i){if(Id(t)||(i=function(t,e){var i;if(t){if("string"==typeof t)return YE(t,e);var n=Sd(i=Object.prototype.toString.call(t)).call(i,8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Ks(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?YE(t,e):void 0}}(t))||e&&t&&"number"==typeof t.length){i&&(t=i);var n=0,r=function(){};return{s:r,n:function(){return n>=t.length?{done:!0}:{done:!1,value:t[n++]}},e:function(t){throw t},f:r}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var o,s=!0,a=!1;return{s:function(){i=i.call(t)},n:function(){var t=i.next();return s=t.done,t},e:function(t){a=!0,o=t},f:function(){try{s||null==i.return||i.return()}finally{if(a)throw o}}}}(s);try{var h=function(){var e=a.value;if(e.itemsIds.size===t.length&&NE(t).call(t,(function(t){return e.itemsIds.has(t.id)})))return o=e.cluster,1};for(l.s();!(a=l.n()).done&&!h(););}catch(t){l.e(t)}finally{l.f()}}if(o)return o.setUiItems(t),o.group!==e&&(o.group&&o.group.remove(o),e&&(e.add(o),o.group=e)),o;var u=n.titleTemplate||"",c={toScreen:this.itemSet.body.util.toScreen,toTime:this.itemSet.body.util.toTime},d=u.replace(/{count}/,t.length),p='<div title="'+d+'">'+t.length+"</div>",f=mf({},n,this.itemSet.options),m={content:p,title:d,group:e,uiItems:t,eventEmitter:this.itemSet.body.emitter,range:this.itemSet.body.range};return o=this.createClusterItem(m,c,f),e&&(e.add(o),o.group=e),o.attach(),o}},{key:"_dropLevelsCache",value:function(){this.cache={},this.cacheLevel=-1,this.cache[this.cacheLevel]=[]}}]),t}();function BE(t,e){var i=void 0!==yd&&va(t)||t["@@iterator"];if(!i){if(Id(t)||(i=function(t,e){var i;if(t){if("string"==typeof t)return zE(t,e);var n=Sd(i=Object.prototype.toString.call(t)).call(i,8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Ks(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?zE(t,e):void 0}}(t))||e&&t&&"number"==typeof t.length){i&&(t=i);var n=0,r=function(){};return{s:r,n:function(){return n>=t.length?{done:!0}:{done:!1,value:t[n++]}},e:function(t){throw t},f:r}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var o,s=!0,a=!1;return{s:function(){i=i.call(t)},n:function(){var t=i.next();return s=t.done,t},e:function(t){a=!0,o=t},f:function(){try{s||null==i.return||i.return()}finally{if(a)throw o}}}}function zE(t,e){(null==e||e>t.length)&&(e=t.length);for(var i=0,n=new Array(e);i<e;i++)n[i]=t[i];return n}wP('.vis-itemset{box-sizing:border-box;margin:0;padding:0;position:relative}.vis-itemset .vis-background,.vis-itemset .vis-foreground{height:100%;overflow:visible;position:absolute;width:100%}.vis-axis{height:0;left:0;position:absolute;width:100%;z-index:1}.vis-foreground .vis-group{border-bottom:1px solid #bfbfbf;box-sizing:border-box;position:relative}.vis-foreground .vis-group:last-child{border-bottom:none}.vis-nesting-group{cursor:pointer}.vis-label.vis-nested-group.vis-group-level-unknown-but-gte1{background:#f5f5f5}.vis-label.vis-nested-group.vis-group-level-0{background-color:#fff}.vis-ltr .vis-label.vis-nested-group.vis-group-level-0 .vis-inner{padding-left:0}.vis-rtl .vis-label.vis-nested-group.vis-group-level-0 .vis-inner{padding-right:0}.vis-label.vis-nested-group.vis-group-level-1{background-color:rgba(0,0,0,.05)}.vis-ltr .vis-label.vis-nested-group.vis-group-level-1 .vis-inner{padding-left:15px}.vis-rtl .vis-label.vis-nested-group.vis-group-level-1 .vis-inner{padding-right:15px}.vis-label.vis-nested-group.vis-group-level-2{background-color:rgba(0,0,0,.1)}.vis-ltr .vis-label.vis-nested-group.vis-group-level-2 .vis-inner{padding-left:30px}.vis-rtl .vis-label.vis-nested-group.vis-group-level-2 .vis-inner{padding-right:30px}.vis-label.vis-nested-group.vis-group-level-3{background-color:rgba(0,0,0,.15)}.vis-ltr .vis-label.vis-nested-group.vis-group-level-3 .vis-inner{padding-left:45px}.vis-rtl .vis-label.vis-nested-group.vis-group-level-3 .vis-inner{padding-right:45px}.vis-label.vis-nested-group.vis-group-level-4{background-color:rgba(0,0,0,.2)}.vis-ltr .vis-label.vis-nested-group.vis-group-level-4 .vis-inner{padding-left:60px}.vis-rtl .vis-label.vis-nested-group.vis-group-level-4 .vis-inner{padding-right:60px}.vis-label.vis-nested-group.vis-group-level-5{background-color:rgba(0,0,0,.25)}.vis-ltr .vis-label.vis-nested-group.vis-group-level-5 .vis-inner{padding-left:75px}.vis-rtl .vis-label.vis-nested-group.vis-group-level-5 .vis-inner{padding-right:75px}.vis-label.vis-nested-group.vis-group-level-6{background-color:rgba(0,0,0,.3)}.vis-ltr .vis-label.vis-nested-group.vis-group-level-6 .vis-inner{padding-left:90px}.vis-rtl .vis-label.vis-nested-group.vis-group-level-6 .vis-inner{padding-right:90px}.vis-label.vis-nested-group.vis-group-level-7{background-color:rgba(0,0,0,.35)}.vis-ltr .vis-label.vis-nested-group.vis-group-level-7 .vis-inner{padding-left:105px}.vis-rtl .vis-label.vis-nested-group.vis-group-level-7 .vis-inner{padding-right:105px}.vis-label.vis-nested-group.vis-group-level-8{background-color:rgba(0,0,0,.4)}.vis-ltr .vis-label.vis-nested-group.vis-group-level-8 .vis-inner{padding-left:120px}.vis-rtl .vis-label.vis-nested-group.vis-group-level-8 .vis-inner{padding-right:120px}.vis-label.vis-nested-group.vis-group-level-9{background-color:rgba(0,0,0,.45)}.vis-ltr .vis-label.vis-nested-group.vis-group-level-9 .vis-inner{padding-left:135px}.vis-rtl .vis-label.vis-nested-group.vis-group-level-9 .vis-inner{padding-right:135px}.vis-label.vis-nested-group{background-color:rgba(0,0,0,.5)}.vis-ltr .vis-label.vis-nested-group .vis-inner{padding-left:150px}.vis-rtl .vis-label.vis-nested-group .vis-inner{padding-right:150px}.vis-group-level-unknown-but-gte1{border:1px solid red}.vis-label.vis-nesting-group:before{display:inline-block;width:15px}.vis-label.vis-nesting-group.expanded:before{content:"\\25BC"}.vis-label.vis-nesting-group.collapsed:before{content:"\\25B6"}.vis-rtl .vis-label.vis-nesting-group.collapsed:before{content:"\\25C0"}.vis-ltr .vis-label:not(.vis-nesting-group):not(.vis-group-level-0){padding-left:15px}.vis-rtl .vis-label:not(.vis-nesting-group):not(.vis-group-level-0){padding-right:15px}.vis-overlay{height:100%;left:0;position:absolute;top:0;width:100%;z-index:10}'),wP(".vis-labelset{overflow:hidden}.vis-labelset,.vis-labelset .vis-label{box-sizing:border-box;position:relative}.vis-labelset .vis-label{border-bottom:1px solid #bfbfbf;color:#4d4d4d;left:0;top:0;width:100%}.vis-labelset .vis-label.draggable{cursor:pointer}.vis-group-is-dragging{background:rgba(0,0,0,.1)}.vis-labelset .vis-label:last-child{border-bottom:none}.vis-labelset .vis-label .vis-inner{display:inline-block;padding:5px}.vis-labelset .vis-label .vis-inner.vis-hidden{padding:0}");var GE="__ungrouped__",WE="__background__",VE=function(t){Ib(i,t);var e=function(t){var e=function(){if("undefined"==typeof Reflect||!MT)return!1;if(MT.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(MT(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var i,n=Rb(t);if(e){var r=Rb(this).constructor;i=MT(n,arguments,r)}else i=n.apply(this,arguments);return Lb(this,i)}}(i);function i(t,n){var r;ga(this,i),(r=e.call(this)).body=t,r.defaultOptions={type:null,orientation:{item:"bottom"},align:"auto",stack:!0,stackSubgroups:!0,groupOrderSwap:function(t,e,i){var n=e.order;e.order=t.order,t.order=n},groupOrder:"order",selectable:!0,multiselect:!1,longSelectPressTime:251,itemsAlwaysDraggable:{item:!1,range:!1},editable:{updateTime:!1,updateGroup:!1,add:!1,remove:!1,overrideItems:!1},groupEditable:{order:!1,add:!1,remove:!1},snap:_P.snap,onDropObjectOnItem:function(t,e,i){i(e)},onAdd:function(t,e){e(t)},onUpdate:function(t,e){e(t)},onMove:function(t,e){e(t)},onRemove:function(t,e){e(t)},onMoving:function(t,e){e(t)},onAddGroup:function(t,e){e(t)},onMoveGroup:function(t,e){e(t)},onRemoveGroup:function(t,e){e(t)},margin:{item:{horizontal:10,vertical:10},axis:20},showTooltips:!0,tooltip:{followMouse:!1,overflowMethod:"flip",delay:500},tooltipOnItemUpdateTime:!1},r.options=EO.extend({},r.defaultOptions),r.options.rtl=n.rtl,r.options.onTimeout=n.onTimeout,r.conversion={toScreen:t.util.toScreen,toTime:t.util.toTime},r.dom={},r.props={},r.hammer=null;var o=Db(r);return r.itemsData=null,r.groupsData=null,r.itemsSettingTime=null,r.initialItemSetDrawn=!1,r.userContinueNotBail=null,r.sequentialSelection=!1,r.itemListeners={add:function(t,e,i){o._onAdd(e.items),o.options.cluster&&o.clusterGenerator.setItems(o.items,{applyOnChangedLevel:!1}),o.redraw()},update:function(t,e,i){o._onUpdate(e.items),o.options.cluster&&o.clusterGenerator.setItems(o.items,{applyOnChangedLevel:!1}),o.redraw()},remove:function(t,e,i){o._onRemove(e.items),o.options.cluster&&o.clusterGenerator.setItems(o.items,{applyOnChangedLevel:!1}),o.redraw()}},r.groupListeners={add:function(t,e,i){if(o._onAddGroups(e.items),o.groupsData&&o.groupsData.length>0){var n,r=o.groupsData.getDataSet();kp(n=r.get()).call(n,(function(t){if(t.nestedGroups){var e;0!=t.showNested&&(t.showNested=!0);var n=[];kp(e=t.nestedGroups).call(e,(function(e){var i=r.get(e);i&&(i.nestedInGroup=t.id,0==t.showNested&&(i.visible=!1),n=xd(n).call(n,i))})),r.update(n,i)}}))}},update:function(t,e,i){o._onUpdateGroups(e.items)},remove:function(t,e,i){o._onRemoveGroups(e.items)}},r.items={},r.groups={},r.groupIds=[],r.selection=[],r.popup=null,r.popupTimer=null,r.touchParams={},r.groupTouchParams={group:null,isDragging:!1},r._create(),r.setOptions(n),r.clusters=[],r}return Cc(i,[{key:"_create",value:function(){var t,e,i,n,r,o,s,a,l,h,u,c,d,p,f,m=this,v=document.createElement("div");v.className="vis-itemset",v["vis-itemset"]=this,this.dom.frame=v;var g=document.createElement("div");g.className="vis-background",v.appendChild(g),this.dom.background=g;var y=document.createElement("div");y.className="vis-foreground",v.appendChild(y),this.dom.foreground=y;var b=document.createElement("div");b.className="vis-axis",this.dom.axis=b;var _=document.createElement("div");_.className="vis-labelset",this.dom.labelSet=_,this._updateUngrouped();var w=new kE(WE,null,this);w.show(),this.groups[WE]=w,this.hammer=new yP(this.body.dom.centerContainer),this.hammer.on("hammer.input",(function(t){t.isFirst&&m._onTouch(t)})),this.hammer.on("panstart",hp(t=this._onDragStart).call(t,this)),this.hammer.on("panmove",hp(e=this._onDrag).call(e,this)),this.hammer.on("panend",hp(i=this._onDragEnd).call(i,this)),this.hammer.get("pan").set({threshold:5,direction:yP.ALL}),this.hammer.get("press").set({time:1e4}),this.hammer.on("tap",hp(n=this._onSelectItem).call(n,this)),this.hammer.on("press",hp(r=this._onMultiSelectItem).call(r,this)),this.hammer.get("press").set({time:1e4}),this.hammer.on("doubletap",hp(o=this._onAddItem).call(o,this)),this.options.rtl?this.groupHammer=new yP(this.body.dom.rightContainer):this.groupHammer=new yP(this.body.dom.leftContainer),this.groupHammer.on("tap",hp(s=this._onGroupClick).call(s,this)),this.groupHammer.on("panstart",hp(a=this._onGroupDragStart).call(a,this)),this.groupHammer.on("panmove",hp(l=this._onGroupDrag).call(l,this)),this.groupHammer.on("panend",hp(h=this._onGroupDragEnd).call(h,this)),this.groupHammer.get("pan").set({threshold:5,direction:yP.DIRECTION_VERTICAL}),this.body.dom.centerContainer.addEventListener("mouseover",hp(u=this._onMouseOver).call(u,this)),this.body.dom.centerContainer.addEventListener("mouseout",hp(c=this._onMouseOut).call(c,this)),this.body.dom.centerContainer.addEventListener("mousemove",hp(d=this._onMouseMove).call(d,this)),this.body.dom.centerContainer.addEventListener("contextmenu",hp(p=this._onDragEnd).call(p,this)),this.body.dom.centerContainer.addEventListener("mousewheel",hp(f=this._onMouseWheel).call(f,this)),this.show()}},{key:"setOptions",value:function(t){var e,i,n=this;t&&(EO.selectiveExtend(["type","rtl","align","order","stack","stackSubgroups","selectable","multiselect","sequentialSelection","multiselectPerGroup","longSelectPressTime","groupOrder","dataAttributes","template","groupTemplate","visibleFrameTemplate","hide","snap","groupOrderSwap","showTooltips","tooltip","tooltipOnItemUpdateTime","groupHeightMode","onTimeout"],this.options,t),"itemsAlwaysDraggable"in t&&("boolean"==typeof t.itemsAlwaysDraggable?(this.options.itemsAlwaysDraggable.item=t.itemsAlwaysDraggable,this.options.itemsAlwaysDraggable.range=!1):"object"===kc(t.itemsAlwaysDraggable)&&(EO.selectiveExtend(["item","range"],this.options.itemsAlwaysDraggable,t.itemsAlwaysDraggable),this.options.itemsAlwaysDraggable.item||(this.options.itemsAlwaysDraggable.range=!1))),"sequentialSelection"in t&&"boolean"==typeof t.sequentialSelection&&(this.options.sequentialSelection=t.sequentialSelection),"orientation"in t&&("string"==typeof t.orientation?this.options.orientation.item="top"===t.orientation?"top":"bottom":"object"===kc(t.orientation)&&"item"in t.orientation&&(this.options.orientation.item=t.orientation.item)),"margin"in t&&("number"==typeof t.margin?(this.options.margin.axis=t.margin,this.options.margin.item.horizontal=t.margin,this.options.margin.item.vertical=t.margin):"object"===kc(t.margin)&&(EO.selectiveExtend(["axis"],this.options.margin,t.margin),"item"in t.margin&&("number"==typeof t.margin.item?(this.options.margin.item.horizontal=t.margin.item,this.options.margin.item.vertical=t.margin.item):"object"===kc(t.margin.item)&&EO.selectiveExtend(["horizontal","vertical"],this.options.margin.item,t.margin.item)))),kp(e=["locale","locales"]).call(e,(function(e){e in t&&(n.options[e]=t[e])})),"editable"in t&&("boolean"==typeof t.editable?(this.options.editable.updateTime=t.editable,this.options.editable.updateGroup=t.editable,this.options.editable.add=t.editable,this.options.editable.remove=t.editable,this.options.editable.overrideItems=!1):"object"===kc(t.editable)&&EO.selectiveExtend(["updateTime","updateGroup","add","remove","overrideItems"],this.options.editable,t.editable)),"groupEditable"in t&&("boolean"==typeof t.groupEditable?(this.options.groupEditable.order=t.groupEditable,this.options.groupEditable.add=t.groupEditable,this.options.groupEditable.remove=t.groupEditable):"object"===kc(t.groupEditable)&&EO.selectiveExtend(["order","add","remove"],this.options.groupEditable,t.groupEditable)),kp(i=["onDropObjectOnItem","onAdd","onUpdate","onRemove","onMove","onMoving","onAddGroup","onMoveGroup","onRemoveGroup"]).call(i,(function(e){var i=t[e];if(i){var r;if("function"!=typeof i)throw new Error(xd(r="option ".concat(e," must be a function ")).call(r,e,"(item, callback)"));n.options[e]=i}})),t.cluster?(mf(this.options,{cluster:t.cluster}),this.clusterGenerator||(this.clusterGenerator=new HE(this)),this.clusterGenerator.setItems(this.items,{applyOnChangedLevel:!1}),this.markDirty({refreshItems:!0,restackGroups:!0}),this.redraw()):this.clusterGenerator?(this._detachAllClusters(),this.clusters=[],this.clusterGenerator=null,this.options.cluster=void 0,this.markDirty({refreshItems:!0,restackGroups:!0}),this.redraw()):this.markDirty())}},{key:"markDirty",value:function(t){this.groupIds=[],t&&(t.refreshItems&&kp(EO).call(EO,this.items,(function(t){t.dirty=!0,t.displayed&&t.redraw()})),t.restackGroups&&kp(EO).call(EO,this.groups,(function(t,e){e!==WE&&(t.stackDirty=!0)})))}},{key:"destroy",value:function(){this.clearPopupTimer(),this.hide(),this.setItems(null),this.setGroups(null),this.hammer&&this.hammer.destroy(),this.groupHammer&&this.groupHammer.destroy(),this.hammer=null,this.body=null,this.conversion=null}},{key:"hide",value:function(){this.dom.frame.parentNode&&this.dom.frame.parentNode.removeChild(this.dom.frame),this.dom.axis.parentNode&&this.dom.axis.parentNode.removeChild(this.dom.axis),this.dom.labelSet.parentNode&&this.dom.labelSet.parentNode.removeChild(this.dom.labelSet)}},{key:"show",value:function(){this.dom.frame.parentNode||this.body.dom.center.appendChild(this.dom.frame),this.dom.axis.parentNode||this.body.dom.backgroundVertical.appendChild(this.dom.axis),this.dom.labelSet.parentNode||(this.options.rtl?this.body.dom.right.appendChild(this.dom.labelSet):this.body.dom.left.appendChild(this.dom.labelSet))}},{key:"setPopupTimer",value:function(t){if(this.clearPopupTimer(),t){var e=this.options.tooltip.delay||"number"==typeof this.options.tooltip.delay?this.options.tooltip.delay:500;this.popupTimer=uv((function(){t.show()}),e)}}},{key:"clearPopupTimer",value:function(){null!=this.popupTimer&&(clearTimeout(this.popupTimer),this.popupTimer=null)}},{key:"setSelection",value:function(t){var e;null==t&&(t=[]),Id(t)||(t=[t]);var i,n=BE(Vf(e=this.selection).call(e,(function(e){return-1===Rm(t).call(t,e)})));try{for(n.s();!(i=n.n()).done;){var r=i.value,o=this.getItemById(r);o&&o.unselect()}}catch(t){n.e(t)}finally{n.f()}this.selection=gd(t);var s,a=BE(t);try{for(a.s();!(s=a.n()).done;){var l=s.value,h=this.getItemById(l);h&&h.select()}}catch(t){a.e(t)}finally{a.f()}}},{key:"getSelection",value:function(){var t;return xd(t=this.selection).call(t,[])}},{key:"getVisibleItems",value:function(){var t,e,i=this.body.range.getRange();this.options.rtl?(t=this.body.util.toScreen(i.start),e=this.body.util.toScreen(i.end)):(e=this.body.util.toScreen(i.start),t=this.body.util.toScreen(i.end));var n=[];for(var r in this.groups)if(this.groups.hasOwnProperty(r)){var o,s=this.groups[r],a=BE(s.isVisible?s.visibleItems:[]);try{for(a.s();!(o=a.n()).done;){var l=o.value;this.options.rtl?l.right<e&&l.right+l.width>t&&n.push(l.id):l.left<t&&l.left+l.width>e&&n.push(l.id)}}catch(t){a.e(t)}finally{a.f()}}return n}},{key:"getItemsAtCurrentTime",value:function(t){var e,i;this.options.rtl?(e=this.body.util.toScreen(t),i=this.body.util.toScreen(t)):(i=this.body.util.toScreen(t),e=this.body.util.toScreen(t));var n=[];for(var r in this.groups)if(this.groups.hasOwnProperty(r)){var o,s=this.groups[r],a=BE(s.isVisible?s.visibleItems:[]);try{for(a.s();!(o=a.n()).done;){var l=o.value;this.options.rtl?l.right<i&&l.right+l.width>e&&n.push(l.id):l.left<e&&l.left+l.width>i&&n.push(l.id)}}catch(t){a.e(t)}finally{a.f()}}return n}},{key:"getVisibleGroups",value:function(){var t=[];for(var e in this.groups)this.groups.hasOwnProperty(e)&&this.groups[e].isVisible&&t.push(e);return t}},{key:"getItemById",value:function(t){var e;return this.items[t]||JP(e=this.clusters).call(e,(function(e){return e.id===t}))}},{key:"_deselect",value:function(t){for(var e=this.selection,i=0,n=e.length;i<n;i++)if(e[i]==t){Qp(e).call(e,i,1);break}}},{key:"redraw",value:function(){var t=this.options.margin,e=this.body.range,i=EO.option.asSize,n=this.options,r=n.orientation.item,o=!1,s=this.dom.frame;this.props.top=this.body.domProps.top.height+this.body.domProps.border.top,this.options.rtl?this.props.right=this.body.domProps.right.width+this.body.domProps.border.right:this.props.left=this.body.domProps.left.width+this.body.domProps.border.left,s.className="vis-itemset",this.options.cluster&&this._clusterItems(),o=this._orderGroups()||o;var a=e.end-e.start,l=a!=this.lastVisibleInterval||this.props.width!=this.props.lastWidth,h=e.start!=this.lastRangeStart,u=n.stack!=this.lastStack,c=n.stackSubgroups!=this.lastStackSubgroups,d=l||h||u||c;this.lastVisibleInterval=a,this.lastRangeStart=e.start,this.lastStack=n.stack,this.lastStackSubgroups=n.stackSubgroups,this.props.lastWidth=this.props.width;var p=this._firstGroup(),f={item:t.item,axis:t.axis},m={item:t.item,axis:t.item.vertical/2},v=0,g=t.axis+t.item.vertical;this.groups[WE].redraw(e,m,d);var y={},b=0;if(kp(EO).call(EO,this.groups,(function(t,i){if(i!==WE){var n=t==p?f:m;y[i]=t.redraw(e,n,d,!0),b=y[i].length}})),b>0){for(var _={},w=function(t){kp(EO).call(EO,y,(function(e,i){_[i]=e[t]()}))},k=0;k<b;k++)w(k);kp(EO).call(EO,this.groups,(function(t,e){if(e!==WE){var i=_[e];o=i||o,v+=t.height}})),v=Math.max(v,g)}return v=Math.max(v,g),s.style.height=i(v),this.props.width=s.offsetWidth,this.props.height=v,this.dom.axis.style.top=i("top"==r?this.body.domProps.top.height+this.body.domProps.border.top:this.body.domProps.top.height+this.body.domProps.centerContainer.height),this.options.rtl?this.dom.axis.style.right="0":this.dom.axis.style.left="0",this.hammer.get("press").set({time:this.options.longSelectPressTime}),this.initialItemSetDrawn=!0,o=this._isResized()||o}},{key:"_firstGroup",value:function(){var t="top"==this.options.orientation.item?0:this.groupIds.length-1,e=this.groupIds[t];return this.groups[e]||this.groups[GE]||null}},{key:"_updateUngrouped",value:function(){var t,e,i=this.groups[GE];if(this.groupsData){if(i)for(e in i.dispose(),delete this.groups[GE],this.items)if(this.items.hasOwnProperty(e)){(t=this.items[e]).parent&&t.parent.remove(t);var n=this.getGroupId(t.data),r=this.groups[n];r&&r.add(t)||t.hide()}}else if(!i){for(e in i=new wE(null,null,this),this.groups[GE]=i,this.items)this.items.hasOwnProperty(e)&&(t=this.items[e],i.add(t));i.show()}}},{key:"getLabelSet",value:function(){return this.dom.labelSet}},{key:"setItems",value:function(t){this.itemsSettingTime=new Date;var e,i=this,n=this.itemsData;if(t){if(!xO(t))throw new TypeError("Data must implement the interface of DataSet or DataView");this.itemsData=TO(t)}else this.itemsData=null;if(n&&(kp(EO).call(EO,this.itemListeners,(function(t,e){n.off(e,t)})),n.dispose(),e=n.getIds(),this._onRemove(e)),this.itemsData){var r=this.id;kp(EO).call(EO,this.itemListeners,(function(t,e){i.itemsData.on(e,t,r)})),e=this.itemsData.getIds(),this._onAdd(e),this._updateUngrouped()}this.body.emitter.emit("_change",{queue:!0})}},{key:"getItems",value:function(){return null!=this.itemsData?this.itemsData.rawDS:null}},{key:"setGroups",value:function(t){var e,i=this;if(this.groupsData&&(kp(EO).call(EO,this.groupListeners,(function(t,e){i.groupsData.off(e,t)})),e=this.groupsData.getIds(),this.groupsData=null,this._onRemoveGroups(e)),t){if(!xO(t))throw new TypeError("Data must implement the interface of DataSet or DataView");this.groupsData=t}else this.groupsData=null;if(this.groupsData){var n,r=this.groupsData.getDataSet();kp(n=r.get()).call(n,(function(t){var e;t.nestedGroups&&kp(e=t.nestedGroups).call(e,(function(e){var i=r.get(e);i.nestedInGroup=t.id,0==t.showNested&&(i.visible=!1),r.update(i)}))}));var o=this.id;kp(EO).call(EO,this.groupListeners,(function(t,e){i.groupsData.on(e,t,o)})),e=this.groupsData.getIds(),this._onAddGroups(e)}this._updateUngrouped(),this._order(),this.options.cluster&&(this.clusterGenerator.updateData(),this._clusterItems(),this.markDirty({refreshItems:!0,restackGroups:!0})),this.body.emitter.emit("_change",{queue:!0})}},{key:"getGroups",value:function(){return this.groupsData}},{key:"removeItem",value:function(t){var e=this,i=this.itemsData.get(t);i&&this.options.onRemove(i,(function(i){i&&e.itemsData.remove(t)}))}},{key:"_getType",value:function(t){return t.type||this.options.type||(t.end?"range":"box")}},{key:"getGroupId",value:function(t){return"background"==this._getType(t)&&null==t.group?WE:this.groupsData?t.group:GE}},{key:"_onUpdate",value:function(t){var e=this,n=this;kp(t).call(t,(function(t){var r,o=n.itemsData.get(t),s=n.items[t],a=o?n._getType(o):null,l=i.types[a];if(s&&(l&&s instanceof l?n._updateItem(s,o):(r=s.selected,n._removeItem(s),s=null)),!s&&o){if(!l)throw new TypeError('Unknown item type "'.concat(a,'"'));(s=new l(o,n.conversion,n.options)).id=t,n._addItem(s),r&&(e.selection.push(t),s.select())}})),this._order(),this.options.cluster&&(this.clusterGenerator.setItems(this.items,{applyOnChangedLevel:!1}),this._clusterItems()),this.body.emitter.emit("_change",{queue:!0})}},{key:"_onRemove",value:function(t){var e=0,i=this;kp(t).call(t,(function(t){var n=i.items[t];n&&(e++,i._removeItem(n))})),e&&(this._order(),this.body.emitter.emit("_change",{queue:!0}))}},{key:"_order",value:function(){kp(EO).call(EO,this.groups,(function(t){t.order()}))}},{key:"_onUpdateGroups",value:function(t){this._onAddGroups(t)}},{key:"_onAddGroups",value:function(t){var e=this;kp(t).call(t,(function(t){var i=e.groupsData.get(t),n=e.groups[t];if(n)n.setData(i);else{if(t==GE||t==WE)throw new Error("Illegal group id. ".concat(t," is a reserved id."));var r=Bm(e.options);for(var o in EO.extend(r,{height:null}),n=new wE(t,i,e),e.groups[t]=n,e.items)if(e.items.hasOwnProperty(o)){var s=e.items[o];s.data.group==t&&n.add(s)}n.order(),n.show()}})),this.body.emitter.emit("_change",{queue:!0})}},{key:"_onRemoveGroups",value:function(t){var e=this;kp(t).call(t,(function(t){var i=e.groups[t];i&&(i.dispose(),delete e.groups[t])})),this.options.cluster&&(this.clusterGenerator.updateData(),this._clusterItems()),this.markDirty({restackGroups:!!this.options.cluster}),this.body.emitter.emit("_change",{queue:!0})}},{key:"_orderGroups",value:function(){if(this.groupsData){var t=this.groupsData.getIds({order:this.options.groupOrder});t=this._orderNestedGroups(t);var e=!EO.equalArray(t,this.groupIds);if(e){var i=this.groups;kp(t).call(t,(function(t){i[t].hide()})),kp(t).call(t,(function(t){i[t].show()})),this.groupIds=t}return e}return!1}},{key:"_orderNestedGroups",value:function(t){var e=this;return function t(e,i){var n=[];return kp(i).call(i,(function(i){if(n.push(i),e.groupsData.get(i).nestedGroups){var r,o=jd(r=e.groupsData.get({filter:function(t){return t.nestedInGroup==i},order:e.options.groupOrder})).call(r,(function(t){return t.id}));n=xd(n).call(n,t(e,o))}})),n}(this,Vf(t).call(t,(function(t){return!e.groupsData.get(t).nestedInGroup})))}},{key:"_addItem",value:function(t){this.items[t.id]=t;var e=this.getGroupId(t.data),i=this.groups[e];i?i&&i.data&&i.data.showNested&&(t.groupShowing=!0):t.groupShowing=!1,i&&i.add(t)}},{key:"_updateItem",value:function(t,e){t.setData(e);var i=this.getGroupId(t.data),n=this.groups[i];n?n&&n.data&&n.data.showNested&&(t.groupShowing=!0):t.groupShowing=!1}},{key:"_removeItem",value:function(t){var e,i;t.hide(),delete this.items[t.id];var n=Rm(e=this.selection).call(e,t.id);-1!=n&&Qp(i=this.selection).call(i,n,1),t.parent&&t.parent.remove(t),null!=this.popup&&this.popup.hide()}},{key:"_constructByEndArray",value:function(t){for(var e=[],i=0;i<t.length;i++)t[i]instanceof TE&&e.push(t[i]);return e}},{key:"_onTouch",value:function(t){this.touchParams.item=this.itemFromTarget(t),this.touchParams.dragLeftItem=t.target.dragLeftItem||!1,this.touchParams.dragRightItem=t.target.dragRightItem||!1,this.touchParams.itemProps=null}},{key:"_getGroupIndex",value:function(t){for(var e=0;e<this.groupIds.length;e++)if(t==this.groupIds[e])return e}},{key:"_onDragStart",value:function(t){var e=this;if(!this.touchParams.itemIsDragging){var i,n=this.touchParams.item||null,r=this;if(n&&(n.selected||this.options.itemsAlwaysDraggable.item)){if(this.options.editable.overrideItems&&!this.options.editable.updateTime&&!this.options.editable.updateGroup)return;if(null!=n.editable&&!n.editable.updateTime&&!n.editable.updateGroup&&!this.options.editable.overrideItems)return;var o=this.touchParams.dragLeftItem,s=this.touchParams.dragRightItem;if(this.touchParams.itemIsDragging=!0,this.touchParams.selectedItem=n,o)i={item:o,initialX:t.center.x,dragLeft:!0,data:this._cloneItemData(n.data)},this.touchParams.itemProps=[i];else if(s)i={item:s,initialX:t.center.x,dragRight:!0,data:this._cloneItemData(n.data)},this.touchParams.itemProps=[i];else if(this.options.editable.add&&(t.srcEvent.ctrlKey||t.srcEvent.metaKey))this._onDragStartAddItem(t);else{this.groupIds.length<1&&this.redraw();var a=this._getGroupIndex(n.data.group),l=this.options.itemsAlwaysDraggable.item&&!n.selected?[n.id]:this.getSelection();this.touchParams.itemProps=jd(l).call(l,(function(i){var n=r.items[i],o=r._getGroupIndex(n.data.group);return{item:n,initialX:t.center.x,groupOffset:a-o,data:e._cloneItemData(n.data)}}))}t.stopPropagation()}else this.options.editable.add&&(t.srcEvent.ctrlKey||t.srcEvent.metaKey)&&this._onDragStartAddItem(t)}}},{key:"_onDragStartAddItem",value:function(t){var e=this.options.snap||null,i=this.dom.frame.getBoundingClientRect(),n=this.options.rtl?i.right-t.center.x+10:t.center.x-i.left-10,r=this.body.util.toTime(n),o=this.body.util.getScale(),s=this.body.util.getStep(),a=e?e(r,o,s):r,l={type:"range",start:a,end:a,content:"new item"},h=nM();l[this.itemsData.idProp]=h;var u=this.groupFromTarget(t);u&&(l.group=u.groupId);var c=new TE(l,this.conversion,this.options);c.id=h,c.data=this._cloneItemData(l),this._addItem(c),this.touchParams.selectedItem=c;var d={item:c,initialX:t.center.x,data:c.data};this.options.rtl?d.dragLeft=!0:d.dragRight=!0,this.touchParams.itemProps=[d],t.stopPropagation()}},{key:"_onDrag",value:function(t){var e=this;if(null!=this.popup&&this.options.showTooltips&&!this.popup.hidden){var i=this.body.dom.centerContainer,n=i.getBoundingClientRect();this.popup.setPosition(t.center.x-n.left+i.offsetLeft,t.center.y-n.top+i.offsetTop),this.popup.show()}if(this.touchParams.itemProps){var r;t.stopPropagation();var o=this,s=this.options.snap||null,a=this.body.dom.root.offsetLeft,l=this.options.rtl?a+this.body.domProps.right.width:a+this.body.domProps.left.width,h=this.body.util.getScale(),u=this.body.util.getStep(),c=this.touchParams.selectedItem,d=(this.options.editable.overrideItems||null==c.editable)&&this.options.editable.updateGroup||!this.options.editable.overrideItems&&null!=c.editable&&c.editable.updateGroup,p=null;if(d&&c&&null!=c.data.group){var f=o.groupFromTarget(t);f&&(p=this._getGroupIndex(f.groupId))}kp(r=this.touchParams.itemProps).call(r,(function(i){var n,r,a,f,m,v=o.body.util.toTime(t.center.x-l),g=o.body.util.toTime(i.initialX-l);n=e.options.rtl?-(v-g):v-g;var y=e._cloneItemData(i.item.data);if(null==i.item.editable||i.item.editable.updateTime||i.item.editable.updateGroup||o.options.editable.overrideItems){if((e.options.editable.overrideItems||null==c.editable)&&e.options.editable.updateTime||!e.options.editable.overrideItems&&null!=c.editable&&c.editable.updateTime)if(i.dragLeft)e.options.rtl?null!=y.end&&(a=EO.convert(i.data.end,"Date"),m=new Date(a.valueOf()+n),y.end=s?s(m,h,u):m):null!=y.start&&(r=EO.convert(i.data.start,"Date"),f=new Date(r.valueOf()+n),y.start=s?s(f,h,u):f);else if(i.dragRight)e.options.rtl?null!=y.start&&(r=EO.convert(i.data.start,"Date"),f=new Date(r.valueOf()+n),y.start=s?s(f,h,u):f):null!=y.end&&(a=EO.convert(i.data.end,"Date"),m=new Date(a.valueOf()+n),y.end=s?s(m,h,u):m);else if(null!=y.start)if(r=EO.convert(i.data.start,"Date").valueOf(),f=new Date(r+n),null!=y.end){var b=(a=EO.convert(i.data.end,"Date")).valueOf()-r.valueOf();y.start=s?s(f,h,u):f,y.end=new Date(y.start.valueOf()+b)}else y.start=s?s(f,h,u):f;if(d&&!i.dragLeft&&!i.dragRight&&null!=p&&null!=y.group){var _=p-i.groupOffset;_=Math.max(0,_),_=Math.min(o.groupIds.length-1,_),y.group=o.groupIds[_]}y=e._cloneItemData(y),o.options.onMoving(y,(function(t){t&&i.item.setData(e._cloneItemData(t,"Date"))}))}})),this.body.emitter.emit("_change")}}},{key:"_moveToGroup",value:function(t,e){var i=this.groups[e];if(i&&i.groupId!=t.data.group){var n=t.parent;n.remove(t),n.order(),t.data.group=i.groupId,i.add(t),i.order()}}},{key:"_onDragEnd",value:function(t){var e=this;if(this.touchParams.itemIsDragging=!1,this.touchParams.itemProps){t.stopPropagation();var i=this,n=this.touchParams.itemProps;this.touchParams.itemProps=null,kp(n).call(n,(function(t){var n=t.item.id;if(null!=i.itemsData.get(n)){var r=e._cloneItemData(t.item.data);i.options.onMove(r,(function(r){r?(r[e.itemsData.idProp]=n,e.itemsData.update(r)):(t.item.setData(t.data),i.body.emitter.emit("_change"))}))}else i.options.onAdd(t.item.data,(function(e){i._removeItem(t.item),e&&i.itemsData.add(e),i.body.emitter.emit("_change")}))}))}}},{key:"_onGroupClick",value:function(t){var e=this,i=this.groupFromTarget(t);uv((function(){e.toggleGroupShowNested(i)}),1)}},{key:"toggleGroupShowNested",value:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:void 0;if(t&&t.nestedGroups){var i=this.groupsData.getDataSet();t.showNested=null!=e?!!e:!t.showNested;var n=i.get(t.groupId);n.showNested=t.showNested;for(var r,o=t.nestedGroups,s=o;s.length>0;){var a=s;s=[];for(var l=0;l<a.length;l++){var h=i.get(a[l]);h.nestedGroups&&(s=xd(s).call(s,h.nestedGroups))}s.length>0&&(o=xd(o).call(o,s))}if(n.showNested){for(var u=i.get(n.nestedGroups),c=0;c<u.length;c++){var d=u[c];d.nestedGroups&&d.nestedGroups.length>0&&(null==d.showNested||1==d.showNested)&&u.push.apply(u,gd(i.get(d.nestedGroups)))}r=jd(u).call(u,(function(t){return null==t.visible&&(t.visible=!0),t.visible=!!n.showNested,t}))}else{var p;r=jd(p=i.get(o)).call(p,(function(t){return null==t.visible&&(t.visible=!0),t.visible=!!n.showNested,t}))}i.update(xd(r).call(r,n)),n.showNested?(EO.removeClassName(t.dom.label,"collapsed"),EO.addClassName(t.dom.label,"expanded")):(EO.removeClassName(t.dom.label,"expanded"),EO.addClassName(t.dom.label,"collapsed"))}}},{key:"toggleGroupDragClassName",value:function(t){t.dom.label.classList.toggle("vis-group-is-dragging"),t.dom.foreground.classList.toggle("vis-group-is-dragging")}},{key:"_onGroupDragStart",value:function(t){this.groupTouchParams.isDragging||this.options.groupEditable.order&&(this.groupTouchParams.group=this.groupFromTarget(t),this.groupTouchParams.group&&(t.stopPropagation(),this.groupTouchParams.isDragging=!0,this.toggleGroupDragClassName(this.groupTouchParams.group),this.groupTouchParams.originalOrder=this.groupsData.getIds({order:this.options.groupOrder})))}},{key:"_onGroupDrag",value:function(t){if(this.options.groupEditable.order&&this.groupTouchParams.group){t.stopPropagation();var e=this.groupsData.getDataSet(),i=this.groupFromTarget(t);if(i&&i.height!=this.groupTouchParams.group.height){var n=i.top<this.groupTouchParams.group.top,r=t.center?t.center.y:t.clientY,o=i.dom.foreground.getBoundingClientRect(),s=this.groupTouchParams.group.height;if(n){if(o.top+s<r)return}else{var a=i.height;if(o.top+a-s>r)return}}if(i&&i!=this.groupTouchParams.group){var l=e.get(i.groupId),h=e.get(this.groupTouchParams.group.groupId);h&&l&&(this.options.groupOrderSwap(h,l,e),e.update(h),e.update(l));var u=e.getIds({order:this.options.groupOrder});if(!EO.equalArray(u,this.groupTouchParams.originalOrder))for(var c=this.groupTouchParams.originalOrder,d=this.groupTouchParams.group.groupId,p=Math.min(c.length,u.length),f=0,m=0,v=0;f<p;){for(;f+m<p&&f+v<p&&u[f+m]==c[f+v];)f++;if(f+m>=p)break;if(u[f+m]==d)m=1;else if(c[f+v]==d)v=1;else{var g=Rm(u).call(u,c[f+v]),y=e.get(u[f+m]),b=e.get(c[f+v]);this.options.groupOrderSwap(y,b,e),e.update(y),e.update(b);var _=u[f+m];u[f+m]=c[f+v],u[g]=_,f++}}}}}},{key:"_onGroupDragEnd",value:function(t){if(this.groupTouchParams.isDragging=!1,this.options.groupEditable.order&&this.groupTouchParams.group){t.stopPropagation();var e=this,i=e.groupTouchParams.group.groupId,n=e.groupsData.getDataSet(),r=EO.extend({},n.get(i));e.options.onMoveGroup(r,(function(t){if(t)t[n._idProp]=i,n.update(t);else{var r=n.getIds({order:e.options.groupOrder});if(!EO.equalArray(r,e.groupTouchParams.originalOrder))for(var o=e.groupTouchParams.originalOrder,s=Math.min(o.length,r.length),a=0;a<s;){for(;a<s&&r[a]==o[a];)a++;if(a>=s)break;var l=Rm(r).call(r,o[a]),h=n.get(r[a]),u=n.get(o[a]);e.options.groupOrderSwap(h,u,n),n.update(h),n.update(u);var c=r[a];r[a]=o[a],r[l]=c,a++}}})),e.body.emitter.emit("groupDragged",{groupId:i}),this.toggleGroupDragClassName(this.groupTouchParams.group),this.groupTouchParams.group=null}}},{key:"_onSelectItem",value:function(t){if(this.options.selectable){var e=t.srcEvent&&(t.srcEvent.ctrlKey||t.srcEvent.metaKey),i=t.srcEvent&&t.srcEvent.shiftKey;if(e||i)this._onMultiSelectItem(t);else{var n=this.getSelection(),r=this.itemFromTarget(t),o=r&&r.selectable?[r.id]:[];this.setSelection(o);var s=this.getSelection();(s.length>0||n.length>0)&&this.body.emitter.emit("select",{items:s,event:t})}}}},{key:"_onMouseOver",value:function(t){var e=this.itemFromTarget(t);if(e&&e!==this.itemFromRelatedTarget(t)){var i=e.getTitle();if(this.options.showTooltips&&i){null==this.popup&&(this.popup=new OE(this.body.dom.root,this.options.tooltip.overflowMethod||"flip")),this.popup.setText(i);var n=this.body.dom.centerContainer,r=n.getBoundingClientRect();this.popup.setPosition(t.clientX-r.left+n.offsetLeft,t.clientY-r.top+n.offsetTop),this.setPopupTimer(this.popup)}else this.clearPopupTimer(),null!=this.popup&&this.popup.hide();this.body.emitter.emit("itemover",{item:e.id,event:t})}}},{key:"_onMouseOut",value:function(t){var e=this.itemFromTarget(t);e&&e!==this.itemFromRelatedTarget(t)&&(this.clearPopupTimer(),null!=this.popup&&this.popup.hide(),this.body.emitter.emit("itemout",{item:e.id,event:t}))}},{key:"_onMouseMove",value:function(t){if(this.itemFromTarget(t)&&(null!=this.popupTimer&&this.setPopupTimer(this.popup),this.options.showTooltips&&this.options.tooltip.followMouse&&this.popup&&!this.popup.hidden)){var e=this.body.dom.centerContainer,i=e.getBoundingClientRect();this.popup.setPosition(t.clientX-i.left+e.offsetLeft,t.clientY-i.top+e.offsetTop),this.popup.show()}}},{key:"_onMouseWheel",value:function(t){this.touchParams.itemIsDragging&&this._onDragEnd(t)}},{key:"_onUpdateItem",value:function(t){if(this.options.selectable&&(this.options.editable.updateTime||this.options.editable.updateGroup)){var e=this;if(t){var i=e.itemsData.get(t.id);this.options.onUpdate(i,(function(t){t&&e.itemsData.update(t)}))}}}},{key:"_onDropObjectOnItem",value:function(t){var e=this.itemFromTarget(t),i=JSON.parse(t.dataTransfer.getData("text"));this.options.onDropObjectOnItem(i,e)}},{key:"_onAddItem",value:function(t){if(this.options.selectable&&this.options.editable.add){var e,i,n=this,r=this.options.snap||null,o=this.dom.frame.getBoundingClientRect(),s=this.options.rtl?o.right-t.center.x:t.center.x-o.left,a=this.body.util.toTime(s),l=this.body.util.getScale(),h=this.body.util.getStep();"drop"==t.type?((i=JSON.parse(t.dataTransfer.getData("text"))).content=i.content?i.content:"new item",i.start=i.start?i.start:r?r(a,l,h):a,i.type=i.type||"box",i[this.itemsData.idProp]=i.id||nM(),"range"!=i.type||i.end||(e=this.body.util.toTime(s+this.props.width/5),i.end=r?r(e,l,h):e)):((i={start:r?r(a,l,h):a,content:"new item"})[this.itemsData.idProp]=nM(),"range"===this.options.type&&(e=this.body.util.toTime(s+this.props.width/5),i.end=r?r(e,l,h):e));var u=this.groupFromTarget(t);u&&(i.group=u.groupId),i=this._cloneItemData(i),this.options.onAdd(i,(function(e){e&&(n.itemsData.add(e),"drop"==t.type&&n.setSelection([e.id]))}))}}},{key:"_onMultiSelectItem",value:function(t){var e=this;if(this.options.selectable){var n=this.itemFromTarget(t);if(n){var r=this.options.multiselect?this.getSelection():[];if((t.srcEvent&&t.srcEvent.shiftKey||this.options.sequentialSelection)&&this.options.multiselect){var o=this.itemsData.get(n.id).group,s=void 0;this.options.multiselectPerGroup&&r.length>0&&(s=this.itemsData.get(r[0]).group),this.options.multiselectPerGroup&&null!=s&&s!=o||r.push(n.id);var a=i._getItemRange(this.itemsData.get(r));if(!this.options.multiselectPerGroup||s==o)for(var l in r=[],this.items)if(this.items.hasOwnProperty(l)){var h=this.items[l],u=h.data.start,c=void 0!==h.data.end?h.data.end:u;!(u>=a.min&&c<=a.max)||this.options.multiselectPerGroup&&s!=this.itemsData.get(h.id).group||h instanceof ME||r.push(h.id)}}else{var d=Rm(r).call(r,n.id);-1==d?r.push(n.id):Qp(r).call(r,d,1)}var p=Vf(r).call(r,(function(t){return e.getItemById(t).selectable}));this.setSelection(p),this.body.emitter.emit("select",{items:this.getSelection(),event:t})}}}},{key:"itemFromElement",value:function(t){for(var e=t;e;){if(e.hasOwnProperty("vis-item"))return e["vis-item"];e=e.parentNode}return null}},{key:"itemFromTarget",value:function(t){return this.itemFromElement(t.target)}},{key:"itemFromRelatedTarget",value:function(t){return this.itemFromElement(t.relatedTarget)}},{key:"groupFromTarget",value:function(t){var e=t.center?t.center.y:t.clientY,i=this.groupIds;i.length<=0&&this.groupsData&&(i=this.groupsData.getIds({order:this.options.groupOrder}));for(var n=0;n<i.length;n++){var r=i[n],o=this.groups[r],s=o.dom.foreground,a=s.getBoundingClientRect();if(e>=a.top&&e<a.top+s.offsetHeight)return o;if("top"===this.options.orientation.item){if(n===this.groupIds.length-1&&e>a.top)return o}else if(0===n&&e<a.top+s.offset)return o}return null}},{key:"_cloneItemData",value:function(t,e){var i=EO.extend({},t);return e||(e=this.itemsData.type),null!=i.start&&(i.start=EO.convert(i.start,e&&e.start||"Date")),null!=i.end&&(i.end=EO.convert(i.end,e&&e.end||"Date")),i}},{key:"_clusterItems",value:function(){if(this.options.cluster){var t=this.body.range.conversion(this.body.domProps.center.width).scale,e=this.clusterGenerator.getClusters(this.clusters,t,this.options.cluster);if(this.clusters!=e){if(this._detachAllClusters(),e){var i,n=BE(e);try{for(n.s();!(i=n.n()).done;)i.value.attach()}catch(t){n.e(t)}finally{n.f()}this.clusters=e}this._updateClusters(e)}}}},{key:"_detachAllClusters",value:function(){if(this.options.cluster&&this.clusters&&this.clusters.length){var t,e=BE(this.clusters);try{for(e.s();!(t=e.n()).done;)t.value.detach()}catch(t){e.e(t)}finally{e.f()}}}},{key:"_updateClusters",value:function(t){if(this.clusters&&this.clusters.length){var e,i,n=new ZD(jd(t).call(t,(function(t){return t.id}))),r=Vf(e=this.clusters).call(e,(function(t){return!n.has(t.id)})),o=!1,s=BE(r);try{for(s.s();!(i=s.n()).done;){var a,l,h=i.value,u=Rm(a=this.selection).call(a,h.id);-1!==u&&(h.unselect(),Qp(l=this.selection).call(l,u,1),o=!0)}}catch(t){s.e(t)}finally{s.f()}if(o){var c=this.getSelection();this.body.emitter.emit("select",{items:c,event:event})}}this.clusters=t||[]}}],[{key:"_getItemRange",value:function(t){var e=null,i=null;return kp(t).call(t,(function(t){(null==i||t.start<i)&&(i=t.start),null!=t.end?(null==e||t.end>e)&&(e=t.end):(null==e||t.start>e)&&(e=t.start)})),{min:i,max:e}}},{key:"itemSetFromTarget",value:function(t){for(var e=t.target;e;){if(e.hasOwnProperty("vis-itemset"))return e["vis-itemset"];e=e.parentNode}return null}}]),i}(GO);VE.types={background:ME,box:DE,range:TE,point:CE},VE.prototype._onAdd=VE.prototype._onUpdate;var UE,XE=!1,qE="background: #FFeeee; color: #dd0000",$E=function(){function t(){ga(this,t)}return Cc(t,null,[{key:"validate",value:function(e,i,n){XE=!1,UE=i;var r=i;return void 0!==n&&(r=i[n]),t.parse(e,r,[]),XE}},{key:"parse",value:function(e,i,n){for(var r in e)e.hasOwnProperty(r)&&t.check(r,e,i,n)}},{key:"check",value:function(e,i,n,r){if(void 0!==n[e]||void 0!==n.__any__){var o=e,s=!0;void 0===n[e]&&void 0!==n.__any__&&(o="__any__",s="object"===t.getType(i[e]));var a=n[o];s&&void 0!==a.__type__&&(a=a.__type__),t.checkFields(e,i,n,o,a,r)}else t.getSuggestion(e,n,r)}},{key:"checkFields",value:function(e,i,n,r,o,s){var a=function(i){console.log("%c"+i+t.printLocation(s,e),qE)},l=t.getType(i[e]),h=o[l];void 0!==h?"array"===t.getType(h)&&-1===Rm(h).call(h,i[e])?(a('Invalid option detected in "'+e+'". Allowed values are:'+t.print(h)+' not "'+i[e]+'". '),XE=!0):"object"===l&&"__any__"!==r&&(s=EO.copyAndExtendArray(s,e),t.parse(i[e],n[r],s)):void 0===o.any&&(a('Invalid type received for "'+e+'". Expected: '+t.print(Bd(o))+". Received ["+l+'] "'+i[e]+'"'),XE=!0)}},{key:"getType",value:function(t){var e=kc(t);return"object"===e?null===t?"null":t instanceof Boolean?"boolean":t instanceof Number?"number":t instanceof String?"string":Id(t)?"array":t instanceof Date?"date":void 0!==t.nodeType?"dom":!0===t._isAMomentObject?"moment":"object":"number"===e?"number":"boolean"===e?"boolean":"string"===e?"string":void 0===e?"undefined":e}},{key:"getSuggestion",value:function(e,i,n){var r,o=t.findInOptions(e,i,n,!1),s=t.findInOptions(e,UE,[],!0);r=void 0!==o.indexMatch?" in "+t.printLocation(o.path,e,"")+'Perhaps it was incomplete? Did you mean: "'+o.indexMatch+'"?\n\n':s.distance<=4&&o.distance>s.distance?" in "+t.printLocation(o.path,e,"")+"Perhaps it was misplaced? Matching option found at: "+t.printLocation(s.path,s.closestMatch,""):o.distance<=8?'. Did you mean "'+o.closestMatch+'"?'+t.printLocation(o.path,e):". Did you mean one of these: "+t.print(Bd(i))+t.printLocation(n,e),console.log('%cUnknown option detected: "'+e+'"'+r,qE),XE=!0}},{key:"findInOptions",value:function(e,i,n){var r=arguments.length>3&&void 0!==arguments[3]&&arguments[3],o=1e9,s="",a=[],l=e.toLowerCase(),h=void 0;for(var u in i){var c=void 0;if(void 0!==i[u].__type__&&!0===r){var d=t.findInOptions(e,i[u],EO.copyAndExtendArray(n,u));o>d.distance&&(s=d.closestMatch,a=d.path,o=d.distance,h=d.indexMatch)}else{var p;-1!==Rm(p=u.toLowerCase()).call(p,l)&&(h=u),o>(c=t.levenshteinDistance(e,u))&&(s=u,a=EO.copyArray(n),o=c)}}return{closestMatch:s,path:a,distance:o,indexMatch:h}}},{key:"printLocation",value:function(t,e){for(var i="\n\n"+(arguments.length>2&&void 0!==arguments[2]?arguments[2]:"Problem value found at: \n")+"options = {\n",n=0;n<t.length;n++){for(var r=0;r<n+1;r++)i+="  ";i+=t[n]+": {\n"}for(var o=0;o<t.length+1;o++)i+="  ";i+=e+"\n";for(var s=0;s<t.length+1;s++){for(var a=0;a<t.length-s;a++)i+="  ";i+="}\n"}return i+"\n\n"}},{key:"print",value:function(t){return Wm(t).replace(/(\")|(\[)|(\])|(,"__type__")/g,"").replace(/(\,)/g,", ")}},{key:"levenshteinDistance",value:function(t,e){if(0===t.length)return e.length;if(0===e.length)return t.length;var i,n,r=[];for(i=0;i<=e.length;i++)r[i]=[i];for(n=0;n<=t.length;n++)r[0][n]=n;for(i=1;i<=e.length;i++)for(n=1;n<=t.length;n++)e.charAt(i-1)==t.charAt(n-1)?r[i][n]=r[i-1][n-1]:r[i][n]=Math.min(r[i-1][n-1]+1,Math.min(r[i][n-1]+1,r[i-1][n]+1));return r[e.length][t.length]}}]),t}(),KE="string",ZE="boolean",JE="number",QE="array",tI="date",eI="object",iI="moment",nI={configure:{enabled:{boolean:ZE},filter:{boolean:ZE,function:"function"},container:{dom:"dom"},__type__:{object:eI,boolean:ZE,function:"function"}},align:{string:KE},alignCurrentTime:{string:KE,undefined:"undefined"},rtl:{boolean:ZE,undefined:"undefined"},rollingMode:{follow:{boolean:ZE},offset:{number:JE,undefined:"undefined"},__type__:{object:eI}},onTimeout:{timeoutMs:{number:JE},callback:{function:"function"},__type__:{object:eI}},verticalScroll:{boolean:ZE,undefined:"undefined"},horizontalScroll:{boolean:ZE,undefined:"undefined"},autoResize:{boolean:ZE},throttleRedraw:{number:JE},clickToUse:{boolean:ZE},dataAttributes:{string:KE,array:QE},editable:{add:{boolean:ZE,undefined:"undefined"},remove:{boolean:ZE,undefined:"undefined"},updateGroup:{boolean:ZE,undefined:"undefined"},updateTime:{boolean:ZE,undefined:"undefined"},overrideItems:{boolean:ZE,undefined:"undefined"},__type__:{boolean:ZE,object:eI}},end:{number:JE,date:tI,string:KE,moment:iI},format:{minorLabels:{millisecond:{string:KE,undefined:"undefined"},second:{string:KE,undefined:"undefined"},minute:{string:KE,undefined:"undefined"},hour:{string:KE,undefined:"undefined"},weekday:{string:KE,undefined:"undefined"},day:{string:KE,undefined:"undefined"},week:{string:KE,undefined:"undefined"},month:{string:KE,undefined:"undefined"},year:{string:KE,undefined:"undefined"},__type__:{object:eI,function:"function"}},majorLabels:{millisecond:{string:KE,undefined:"undefined"},second:{string:KE,undefined:"undefined"},minute:{string:KE,undefined:"undefined"},hour:{string:KE,undefined:"undefined"},weekday:{string:KE,undefined:"undefined"},day:{string:KE,undefined:"undefined"},week:{string:KE,undefined:"undefined"},month:{string:KE,undefined:"undefined"},year:{string:KE,undefined:"undefined"},__type__:{object:eI,function:"function"}},__type__:{object:eI}},moment:{function:"function"},groupHeightMode:{string:KE},groupOrder:{string:KE,function:"function"},groupEditable:{add:{boolean:ZE,undefined:"undefined"},remove:{boolean:ZE,undefined:"undefined"},order:{boolean:ZE,undefined:"undefined"},__type__:{boolean:ZE,object:eI}},groupOrderSwap:{function:"function"},height:{string:KE,number:JE},hiddenDates:{start:{date:tI,number:JE,string:KE,moment:iI},end:{date:tI,number:JE,string:KE,moment:iI},repeat:{string:KE},__type__:{object:eI,array:QE}},itemsAlwaysDraggable:{item:{boolean:ZE,undefined:"undefined"},range:{boolean:ZE,undefined:"undefined"},__type__:{boolean:ZE,object:eI}},limitSize:{boolean:ZE},locale:{string:KE},locales:{__any__:{any:"any"},__type__:{object:eI}},longSelectPressTime:{number:JE},margin:{axis:{number:JE},item:{horizontal:{number:JE,undefined:"undefined"},vertical:{number:JE,undefined:"undefined"},__type__:{object:eI,number:JE}},__type__:{object:eI,number:JE}},max:{date:tI,number:JE,string:KE,moment:iI},maxHeight:{number:JE,string:KE},maxMinorChars:{number:JE},min:{date:tI,number:JE,string:KE,moment:iI},minHeight:{number:JE,string:KE},moveable:{boolean:ZE},multiselect:{boolean:ZE},multiselectPerGroup:{boolean:ZE},onAdd:{function:"function"},onDropObjectOnItem:{function:"function"},onUpdate:{function:"function"},onMove:{function:"function"},onMoving:{function:"function"},onRemove:{function:"function"},onAddGroup:{function:"function"},onMoveGroup:{function:"function"},onRemoveGroup:{function:"function"},onInitialDrawComplete:{function:"function"},order:{function:"function"},orientation:{axis:{string:KE,undefined:"undefined"},item:{string:KE,undefined:"undefined"},__type__:{string:KE,object:eI}},selectable:{boolean:ZE},sequentialSelection:{boolean:ZE},showCurrentTime:{boolean:ZE},showMajorLabels:{boolean:ZE},showMinorLabels:{boolean:ZE},showWeekScale:{boolean:ZE},stack:{boolean:ZE},stackSubgroups:{boolean:ZE},cluster:{maxItems:{number:JE,undefined:"undefined"},titleTemplate:{string:KE,undefined:"undefined"},clusterCriteria:{function:"function",undefined:"undefined"},showStipes:{boolean:ZE,undefined:"undefined"},fitOnDoubleClick:{boolean:ZE,undefined:"undefined"},__type__:{boolean:ZE,object:eI}},snap:{function:"function",null:"null"},start:{date:tI,number:JE,string:KE,moment:iI},template:{function:"function"},loadingScreenTemplate:{function:"function"},groupTemplate:{function:"function"},visibleFrameTemplate:{string:KE,function:"function"},showTooltips:{boolean:ZE},tooltip:{followMouse:{boolean:ZE},overflowMethod:{string:["cap","flip","none"]},delay:{number:JE},template:{function:"function"},__type__:{object:eI}},tooltipOnItemUpdateTime:{template:{function:"function"},__type__:{boolean:ZE,object:eI}},timeAxis:{scale:{string:KE,undefined:"undefined"},step:{number:JE,undefined:"undefined"},__type__:{object:eI}},type:{string:KE},width:{string:KE,number:JE},preferZoom:{boolean:ZE},zoomable:{boolean:ZE},zoomKey:{string:["ctrlKey","altKey","shiftKey","metaKey",""]},zoomFriction:{number:JE},zoomMax:{number:JE},zoomMin:{number:JE},xss:{disabled:{boolean:ZE},filterOptions:{__any__:{any:"any"},__type__:{object:eI}},__type__:{object:eI}},__type__:{object:eI}},rI={global:{align:["center","left","right"],alignCurrentTime:["none","year","month","quarter","week","isoWeek","day","date","hour","minute","second"],direction:!1,autoResize:!0,clickToUse:!1,editable:{add:!1,remove:!1,updateGroup:!1,updateTime:!1},end:"",format:{minorLabels:{millisecond:"SSS",second:"s",minute:"HH:mm",hour:"HH:mm",weekday:"ddd D",day:"D",week:"w",month:"MMM",year:"YYYY"},majorLabels:{millisecond:"HH:mm:ss",second:"D MMMM HH:mm",minute:"ddd D MMMM",hour:"ddd D MMMM",weekday:"MMMM YYYY",day:"MMMM YYYY",week:"MMMM YYYY",month:"YYYY",year:""}},groupHeightMode:["auto","fixed","fitItems"],groupsDraggable:!1,height:"",locale:"",longSelectPressTime:251,margin:{axis:[20,0,100,1],item:{horizontal:[10,0,100,1],vertical:[10,0,100,1]}},max:"",maxHeight:"",maxMinorChars:[7,0,20,1],min:"",minHeight:"",moveable:!1,multiselect:!1,multiselectPerGroup:!1,orientation:{axis:["both","bottom","top"],item:["bottom","top"]},preferZoom:!1,selectable:!0,showCurrentTime:!1,showMajorLabels:!0,showMinorLabels:!0,stack:!0,stackSubgroups:!0,cluster:!1,start:"",showTooltips:!0,tooltip:{followMouse:!1,overflowMethod:"flip",delay:[500,0,99999,100]},tooltipOnItemUpdateTime:!1,type:["box","point","range","background"],width:"100%",zoomable:!0,zoomKey:["ctrlKey","altKey","shiftKey","metaKey",""],zoomMax:[31536e10,10,31536e10,1],zoomMin:[10,10,31536e10,1],xss:{disabled:!1}}},oI={black:"#000000",navy:"#000080",darkblue:"#00008B",mediumblue:"#0000CD",blue:"#0000FF",darkgreen:"#006400",green:"#008000",teal:"#008080",darkcyan:"#008B8B",deepskyblue:"#00BFFF",darkturquoise:"#00CED1",mediumspringgreen:"#00FA9A",lime:"#00FF00",springgreen:"#00FF7F",aqua:"#00FFFF",cyan:"#00FFFF",midnightblue:"#191970",dodgerblue:"#1E90FF",lightseagreen:"#20B2AA",forestgreen:"#228B22",seagreen:"#2E8B57",darkslategray:"#2F4F4F",limegreen:"#32CD32",mediumseagreen:"#3CB371",turquoise:"#40E0D0",royalblue:"#4169E1",steelblue:"#4682B4",darkslateblue:"#483D8B",mediumturquoise:"#48D1CC",indigo:"#4B0082",darkolivegreen:"#556B2F",cadetblue:"#5F9EA0",cornflowerblue:"#6495ED",mediumaquamarine:"#66CDAA",dimgray:"#696969",slateblue:"#6A5ACD",olivedrab:"#6B8E23",slategray:"#708090",lightslategray:"#778899",mediumslateblue:"#7B68EE",lawngreen:"#7CFC00",chartreuse:"#7FFF00",aquamarine:"#7FFFD4",maroon:"#800000",purple:"#800080",olive:"#808000",gray:"#808080",skyblue:"#87CEEB",lightskyblue:"#87CEFA",blueviolet:"#8A2BE2",darkred:"#8B0000",darkmagenta:"#8B008B",saddlebrown:"#8B4513",darkseagreen:"#8FBC8F",lightgreen:"#90EE90",mediumpurple:"#9370D8",darkviolet:"#9400D3",palegreen:"#98FB98",darkorchid:"#9932CC",yellowgreen:"#9ACD32",sienna:"#A0522D",brown:"#A52A2A",darkgray:"#A9A9A9",lightblue:"#ADD8E6",greenyellow:"#ADFF2F",paleturquoise:"#AFEEEE",lightsteelblue:"#B0C4DE",powderblue:"#B0E0E6",firebrick:"#B22222",darkgoldenrod:"#B8860B",mediumorchid:"#BA55D3",rosybrown:"#BC8F8F",darkkhaki:"#BDB76B",silver:"#C0C0C0",mediumvioletred:"#C71585",indianred:"#CD5C5C",peru:"#CD853F",chocolate:"#D2691E",tan:"#D2B48C",lightgrey:"#D3D3D3",palevioletred:"#D87093",thistle:"#D8BFD8",orchid:"#DA70D6",goldenrod:"#DAA520",crimson:"#DC143C",gainsboro:"#DCDCDC",plum:"#DDA0DD",burlywood:"#DEB887",lightcyan:"#E0FFFF",lavender:"#E6E6FA",darksalmon:"#E9967A",violet:"#EE82EE",palegoldenrod:"#EEE8AA",lightcoral:"#F08080",khaki:"#F0E68C",aliceblue:"#F0F8FF",honeydew:"#F0FFF0",azure:"#F0FFFF",sandybrown:"#F4A460",wheat:"#F5DEB3",beige:"#F5F5DC",whitesmoke:"#F5F5F5",mintcream:"#F5FFFA",ghostwhite:"#F8F8FF",salmon:"#FA8072",antiquewhite:"#FAEBD7",linen:"#FAF0E6",lightgoldenrodyellow:"#FAFAD2",oldlace:"#FDF5E6",red:"#FF0000",fuchsia:"#FF00FF",magenta:"#FF00FF",deeppink:"#FF1493",orangered:"#FF4500",tomato:"#FF6347",hotpink:"#FF69B4",coral:"#FF7F50",darkorange:"#FF8C00",lightsalmon:"#FFA07A",orange:"#FFA500",lightpink:"#FFB6C1",pink:"#FFC0CB",gold:"#FFD700",peachpuff:"#FFDAB9",navajowhite:"#FFDEAD",moccasin:"#FFE4B5",bisque:"#FFE4C4",mistyrose:"#FFE4E1",blanchedalmond:"#FFEBCD",papayawhip:"#FFEFD5",lavenderblush:"#FFF0F5",seashell:"#FFF5EE",cornsilk:"#FFF8DC",lemonchiffon:"#FFFACD",floralwhite:"#FFFAF0",snow:"#FFFAFA",yellow:"#FFFF00",lightyellow:"#FFFFE0",ivory:"#FFFFF0",white:"#FFFFFF"},sI=function(){function t(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:1;ga(this,t),this.pixelRatio=e,this.generated=!1,this.centerCoordinates={x:144.5,y:144.5},this.r=289*.49,this.color={r:255,g:255,b:255,a:1},this.hueCircle=void 0,this.initialColor={r:255,g:255,b:255,a:1},this.previousColor=void 0,this.applied=!1,this.updateCallback=function(){},this.closeCallback=function(){},this._create()}return Cc(t,[{key:"insertTo",value:function(t){void 0!==this.hammer&&(this.hammer.destroy(),this.hammer=void 0),this.container=t,this.container.appendChild(this.frame),this._bindHammer(),this._setSize()}},{key:"setUpdateCallback",value:function(t){if("function"!=typeof t)throw new Error("Function attempted to set as colorPicker update callback is not a function.");this.updateCallback=t}},{key:"setCloseCallback",value:function(t){if("function"!=typeof t)throw new Error("Function attempted to set as colorPicker closing callback is not a function.");this.closeCallback=t}},{key:"_isColorString",value:function(t){if("string"==typeof t)return oI[t]}},{key:"setColor",value:function(t){var e=!(arguments.length>1&&void 0!==arguments[1])||arguments[1];if("none"!==t){var i,n=this._isColorString(t);if(void 0!==n&&(t=n),!0===EO.isString(t)){if(!0===EO.isValidRGB(t)){var r=t.substr(4).substr(0,t.length-5).split(",");i={r:r[0],g:r[1],b:r[2],a:1}}else if(!0===EO.isValidRGBA(t)){var o=t.substr(5).substr(0,t.length-6).split(",");i={r:o[0],g:o[1],b:o[2],a:o[3]}}else if(!0===EO.isValidHex(t)){var s=EO.hexToRGB(t);i={r:s.r,g:s.g,b:s.b,a:1}}}else if(t instanceof Object&&void 0!==t.r&&void 0!==t.g&&void 0!==t.b){var a=void 0!==t.a?t.a:"1.0";i={r:t.r,g:t.g,b:t.b,a:a}}if(void 0===i)throw new Error("Unknown color passed to the colorPicker. Supported are strings: rgb, hex, rgba. Object: rgb ({r:r,g:g,b:b,[a:a]}). Supplied: "+Wm(t));this._setColor(i,e)}}},{key:"show",value:function(){void 0!==this.closeCallback&&(this.closeCallback(),this.closeCallback=void 0),this.applied=!1,this.frame.style.display="block",this._generateHueCircle()}},{key:"_hide",value:function(){var t=this;!0===(!(arguments.length>0&&void 0!==arguments[0])||arguments[0])&&(this.previousColor=EO.extend({},this.color)),!0===this.applied&&this.updateCallback(this.initialColor),this.frame.style.display="none",uv((function(){void 0!==t.closeCallback&&(t.closeCallback(),t.closeCallback=void 0)}),0)}},{key:"_save",value:function(){this.updateCallback(this.color),this.applied=!1,this._hide()}},{key:"_apply",value:function(){this.applied=!0,this.updateCallback(this.color),this._updatePicker(this.color)}},{key:"_loadLast",value:function(){void 0!==this.previousColor?this.setColor(this.previousColor,!1):alert("There is no last color to load...")}},{key:"_setColor",value:function(t){!0===(!(arguments.length>1&&void 0!==arguments[1])||arguments[1])&&(this.initialColor=EO.extend({},t)),this.color=t;var e=EO.RGBToHSV(t.r,t.g,t.b),i=2*Math.PI,n=this.r*e.s,r=this.centerCoordinates.x+n*Math.sin(i*e.h),o=this.centerCoordinates.y+n*Math.cos(i*e.h);this.colorPickerSelector.style.left=r-.5*this.colorPickerSelector.clientWidth+"px",this.colorPickerSelector.style.top=o-.5*this.colorPickerSelector.clientHeight+"px",this._updatePicker(t)}},{key:"_setOpacity",value:function(t){this.color.a=t/100,this._updatePicker(this.color)}},{key:"_setBrightness",value:function(t){var e=EO.RGBToHSV(this.color.r,this.color.g,this.color.b);e.v=t/100;var i=EO.HSVToRGB(e.h,e.s,e.v);i.a=this.color.a,this.color=i,this._updatePicker()}},{key:"_updatePicker",value:function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:this.color,e=EO.RGBToHSV(t.r,t.g,t.b),i=this.colorPickerCanvas.getContext("2d");void 0===this.pixelRation&&(this.pixelRatio=(window.devicePixelRatio||1)/(i.webkitBackingStorePixelRatio||i.mozBackingStorePixelRatio||i.msBackingStorePixelRatio||i.oBackingStorePixelRatio||i.backingStorePixelRatio||1)),i.setTransform(this.pixelRatio,0,0,this.pixelRatio,0,0);var n=this.colorPickerCanvas.clientWidth,r=this.colorPickerCanvas.clientHeight;i.clearRect(0,0,n,r),i.putImageData(this.hueCircle,0,0),i.fillStyle="rgba(0,0,0,"+(1-e.v)+")",i.circle(this.centerCoordinates.x,this.centerCoordinates.y,this.r),yv(i).call(i),this.brightnessRange.value=100*e.v,this.opacityRange.value=100*t.a,this.initialColorDiv.style.backgroundColor="rgba("+this.initialColor.r+","+this.initialColor.g+","+this.initialColor.b+","+this.initialColor.a+")",this.newColorDiv.style.backgroundColor="rgba("+this.color.r+","+this.color.g+","+this.color.b+","+this.color.a+")"}},{key:"_setSize",value:function(){this.colorPickerCanvas.style.width="100%",this.colorPickerCanvas.style.height="100%",this.colorPickerCanvas.width=289*this.pixelRatio,this.colorPickerCanvas.height=289*this.pixelRatio}},{key:"_create",value:function(){var t,e,i,n;if(this.frame=document.createElement("div"),this.frame.className="vis-color-picker",this.colorPickerDiv=document.createElement("div"),this.colorPickerSelector=document.createElement("div"),this.colorPickerSelector.className="vis-selector",this.colorPickerDiv.appendChild(this.colorPickerSelector),this.colorPickerCanvas=document.createElement("canvas"),this.colorPickerDiv.appendChild(this.colorPickerCanvas),this.colorPickerCanvas.getContext){var r=this.colorPickerCanvas.getContext("2d");this.pixelRatio=(window.devicePixelRatio||1)/(r.webkitBackingStorePixelRatio||r.mozBackingStorePixelRatio||r.msBackingStorePixelRatio||r.oBackingStorePixelRatio||r.backingStorePixelRatio||1),this.colorPickerCanvas.getContext("2d").setTransform(this.pixelRatio,0,0,this.pixelRatio,0,0)}else{var o=document.createElement("DIV");o.style.color="red",o.style.fontWeight="bold",o.style.padding="10px",o.innerHTML="Error: your browser does not support HTML canvas",this.colorPickerCanvas.appendChild(o)}this.colorPickerDiv.className="vis-color",this.opacityDiv=document.createElement("div"),this.opacityDiv.className="vis-opacity",this.brightnessDiv=document.createElement("div"),this.brightnessDiv.className="vis-brightness",this.arrowDiv=document.createElement("div"),this.arrowDiv.className="vis-arrow",this.opacityRange=document.createElement("input");try{this.opacityRange.type="range",this.opacityRange.min="0",this.opacityRange.max="100"}catch(t){}this.opacityRange.value="100",this.opacityRange.className="vis-range",this.brightnessRange=document.createElement("input");try{this.brightnessRange.type="range",this.brightnessRange.min="0",this.brightnessRange.max="100"}catch(t){}this.brightnessRange.value="100",this.brightnessRange.className="vis-range",this.opacityDiv.appendChild(this.opacityRange),this.brightnessDiv.appendChild(this.brightnessRange);var s=this;this.opacityRange.onchange=function(){s._setOpacity(this.value)},this.opacityRange.oninput=function(){s._setOpacity(this.value)},this.brightnessRange.onchange=function(){s._setBrightness(this.value)},this.brightnessRange.oninput=function(){s._setBrightness(this.value)},this.brightnessLabel=document.createElement("div"),this.brightnessLabel.className="vis-label vis-brightness",this.brightnessLabel.innerHTML="brightness:",this.opacityLabel=document.createElement("div"),this.opacityLabel.className="vis-label vis-opacity",this.opacityLabel.innerHTML="opacity:",this.newColorDiv=document.createElement("div"),this.newColorDiv.className="vis-new-color",this.newColorDiv.innerHTML="new",this.initialColorDiv=document.createElement("div"),this.initialColorDiv.className="vis-initial-color",this.initialColorDiv.innerHTML="initial",this.cancelButton=document.createElement("div"),this.cancelButton.className="vis-button vis-cancel",this.cancelButton.innerHTML="cancel",this.cancelButton.onclick=hp(t=this._hide).call(t,this,!1),this.applyButton=document.createElement("div"),this.applyButton.className="vis-button vis-apply",this.applyButton.innerHTML="apply",this.applyButton.onclick=hp(e=this._apply).call(e,this),this.saveButton=document.createElement("div"),this.saveButton.className="vis-button vis-save",this.saveButton.innerHTML="save",this.saveButton.onclick=hp(i=this._save).call(i,this),this.loadButton=document.createElement("div"),this.loadButton.className="vis-button vis-load",this.loadButton.innerHTML="load last",this.loadButton.onclick=hp(n=this._loadLast).call(n,this),this.frame.appendChild(this.colorPickerDiv),this.frame.appendChild(this.arrowDiv),this.frame.appendChild(this.brightnessLabel),this.frame.appendChild(this.brightnessDiv),this.frame.appendChild(this.opacityLabel),this.frame.appendChild(this.opacityDiv),this.frame.appendChild(this.newColorDiv),this.frame.appendChild(this.initialColorDiv),this.frame.appendChild(this.cancelButton),this.frame.appendChild(this.applyButton),this.frame.appendChild(this.saveButton),this.frame.appendChild(this.loadButton)}},{key:"_bindHammer",value:function(){var t=this;this.drag={},this.pinch={},this.hammer=new yP(this.colorPickerCanvas),this.hammer.get("pinch").set({enable:!0}),bP(this.hammer,(function(e){t._moveSelector(e)})),this.hammer.on("tap",(function(e){t._moveSelector(e)})),this.hammer.on("panstart",(function(e){t._moveSelector(e)})),this.hammer.on("panmove",(function(e){t._moveSelector(e)})),this.hammer.on("panend",(function(e){t._moveSelector(e)}))}},{key:"_generateHueCircle",value:function(){if(!1===this.generated){var t=this.colorPickerCanvas.getContext("2d");void 0===this.pixelRation&&(this.pixelRatio=(window.devicePixelRatio||1)/(t.webkitBackingStorePixelRatio||t.mozBackingStorePixelRatio||t.msBackingStorePixelRatio||t.oBackingStorePixelRatio||t.backingStorePixelRatio||1)),t.setTransform(this.pixelRatio,0,0,this.pixelRatio,0,0);var e,i,n,r,o=this.colorPickerCanvas.clientWidth,s=this.colorPickerCanvas.clientHeight;t.clearRect(0,0,o,s),this.centerCoordinates={x:.5*o,y:.5*s},this.r=.49*o;var a,l=2*Math.PI/360,h=1/this.r;for(n=0;n<360;n++)for(r=0;r<this.r;r++)e=this.centerCoordinates.x+r*Math.sin(l*n),i=this.centerCoordinates.y+r*Math.cos(l*n),a=EO.HSVToRGB(.002777777777777778*n,r*h,1),t.fillStyle="rgb("+a.r+","+a.g+","+a.b+")",t.fillRect(e-.5,i-.5,2,2);t.strokeStyle="rgba(0,0,0,1)",t.circle(this.centerCoordinates.x,this.centerCoordinates.y,this.r),t.stroke(),this.hueCircle=t.getImageData(0,0,o,s)}this.generated=!0}},{key:"_moveSelector",value:function(t){var e=this.colorPickerDiv.getBoundingClientRect(),i=t.center.x-e.left,n=t.center.y-e.top,r=.5*this.colorPickerDiv.clientHeight,o=.5*this.colorPickerDiv.clientWidth,s=i-o,a=n-r,l=Math.atan2(s,a),h=.98*Math.min(Math.sqrt(s*s+a*a),o),u=Math.cos(l)*h+r,c=Math.sin(l)*h+o;this.colorPickerSelector.style.top=u-.5*this.colorPickerSelector.clientHeight+"px",this.colorPickerSelector.style.left=c-.5*this.colorPickerSelector.clientWidth+"px";var d=l/(2*Math.PI);d=d<0?d+1:d;var p=h/this.r,f=EO.RGBToHSV(this.color.r,this.color.g,this.color.b);f.h=d,f.s=p;var m=EO.HSVToRGB(f.h,f.s,f.v);m.a=this.color.a,this.color=m,this.initialColorDiv.style.backgroundColor="rgba("+this.initialColor.r+","+this.initialColor.g+","+this.initialColor.b+","+this.initialColor.a+")",this.newColorDiv.style.backgroundColor="rgba("+this.color.r+","+this.color.g+","+this.color.b+","+this.color.a+")"}}]),t}();wP('div.vis-configuration{display:block;float:left;font-size:12px;position:relative}div.vis-configuration-wrapper{display:block;width:700px}div.vis-configuration-wrapper:after{clear:both;content:"";display:block}div.vis-configuration.vis-config-option-container{background-color:#fff;border:2px solid #f7f8fa;border-radius:4px;display:block;left:10px;margin-top:20px;padding-left:5px;width:495px}div.vis-configuration.vis-config-button{background-color:#f7f8fa;border:2px solid #ceced0;border-radius:4px;cursor:pointer;display:block;height:25px;left:10px;line-height:25px;margin-bottom:30px;margin-top:20px;padding-left:5px;vertical-align:middle;width:495px}div.vis-configuration.vis-config-button.hover{background-color:#4588e6;border:2px solid #214373;color:#fff}div.vis-configuration.vis-config-item{display:block;float:left;height:25px;line-height:25px;vertical-align:middle;width:495px}div.vis-configuration.vis-config-item.vis-config-s2{background-color:#f7f8fa;border-radius:3px;left:10px;padding-left:5px}div.vis-configuration.vis-config-item.vis-config-s3{background-color:#e4e9f0;border-radius:3px;left:20px;padding-left:5px}div.vis-configuration.vis-config-item.vis-config-s4{background-color:#cfd8e6;border-radius:3px;left:30px;padding-left:5px}div.vis-configuration.vis-config-header{font-size:18px;font-weight:700}div.vis-configuration.vis-config-label{height:25px;line-height:25px;width:120px}div.vis-configuration.vis-config-label.vis-config-s3{width:110px}div.vis-configuration.vis-config-label.vis-config-s4{width:100px}div.vis-configuration.vis-config-colorBlock{border:1px solid #444;border-radius:2px;cursor:pointer;height:19px;margin:0;padding:0;top:1px;width:30px}input.vis-configuration.vis-config-checkbox{left:-5px}input.vis-configuration.vis-config-rangeinput{margin:0;padding:1px;pointer-events:none;position:relative;top:-5px;width:60px}input.vis-configuration.vis-config-range{-webkit-appearance:none;background-color:transparent;border:0 solid #fff;height:20px;width:300px}input.vis-configuration.vis-config-range::-webkit-slider-runnable-track{background:#dedede;background:-moz-linear-gradient(top,#dedede 0,#c8c8c8 99%);background:-webkit-gradient(linear,left top,left bottom,color-stop(0,#dedede),color-stop(99%,#c8c8c8));background:-webkit-linear-gradient(top,#dedede,#c8c8c8 99%);background:-o-linear-gradient(top,#dedede 0,#c8c8c8 99%);background:-ms-linear-gradient(top,#dedede 0,#c8c8c8 99%);background:linear-gradient(180deg,#dedede 0,#c8c8c8 99%);border:1px solid #999;border-radius:3px;box-shadow:0 0 3px 0 #aaa;filter:progid:DXImageTransform.Microsoft.gradient(startColorstr="#dedede",endColorstr="#c8c8c8",GradientType=0);height:5px;width:300px}input.vis-configuration.vis-config-range::-webkit-slider-thumb{-webkit-appearance:none;background:#3876c2;background:-moz-linear-gradient(top,#3876c2 0,#385380 100%);background:-webkit-gradient(linear,left top,left bottom,color-stop(0,#3876c2),color-stop(100%,#385380));background:-webkit-linear-gradient(top,#3876c2,#385380);background:-o-linear-gradient(top,#3876c2 0,#385380 100%);background:-ms-linear-gradient(top,#3876c2 0,#385380 100%);background:linear-gradient(180deg,#3876c2 0,#385380);border:1px solid #14334b;border-radius:50%;box-shadow:0 0 1px 0 #111927;filter:progid:DXImageTransform.Microsoft.gradient(startColorstr="#3876c2",endColorstr="#385380",GradientType=0);height:17px;margin-top:-7px;width:17px}input.vis-configuration.vis-config-range:focus{outline:none}input.vis-configuration.vis-config-range:focus::-webkit-slider-runnable-track{background:#9d9d9d;background:-moz-linear-gradient(top,#9d9d9d 0,#c8c8c8 99%);background:-webkit-gradient(linear,left top,left bottom,color-stop(0,#9d9d9d),color-stop(99%,#c8c8c8));background:-webkit-linear-gradient(top,#9d9d9d,#c8c8c8 99%);background:-o-linear-gradient(top,#9d9d9d 0,#c8c8c8 99%);background:-ms-linear-gradient(top,#9d9d9d 0,#c8c8c8 99%);background:linear-gradient(180deg,#9d9d9d 0,#c8c8c8 99%);filter:progid:DXImageTransform.Microsoft.gradient(startColorstr="#9d9d9d",endColorstr="#c8c8c8",GradientType=0)}input.vis-configuration.vis-config-range::-moz-range-track{background:#dedede;background:-moz-linear-gradient(top,#dedede 0,#c8c8c8 99%);background:-webkit-gradient(linear,left top,left bottom,color-stop(0,#dedede),color-stop(99%,#c8c8c8));background:-webkit-linear-gradient(top,#dedede,#c8c8c8 99%);background:-o-linear-gradient(top,#dedede 0,#c8c8c8 99%);background:-ms-linear-gradient(top,#dedede 0,#c8c8c8 99%);background:linear-gradient(180deg,#dedede 0,#c8c8c8 99%);border:1px solid #999;border-radius:3px;box-shadow:0 0 3px 0 #aaa;filter:progid:DXImageTransform.Microsoft.gradient(startColorstr="#dedede",endColorstr="#c8c8c8",GradientType=0);height:10px;width:300px}input.vis-configuration.vis-config-range::-moz-range-thumb{background:#385380;border:none;border-radius:50%;height:16px;width:16px}input.vis-configuration.vis-config-range:-moz-focusring{outline:1px solid #fff;outline-offset:-1px}input.vis-configuration.vis-config-range::-ms-track{background:transparent;border-color:transparent;border-width:6px 0;color:transparent;height:5px;width:300px}input.vis-configuration.vis-config-range::-ms-fill-lower{background:#777;border-radius:10px}input.vis-configuration.vis-config-range::-ms-fill-upper{background:#ddd;border-radius:10px}input.vis-configuration.vis-config-range::-ms-thumb{background:#385380;border:none;border-radius:50%;height:16px;width:16px}input.vis-configuration.vis-config-range:focus::-ms-fill-lower{background:#888}input.vis-configuration.vis-config-range:focus::-ms-fill-upper{background:#ccc}.vis-configuration-popup{background:rgba(57,76,89,.85);border:2px solid #f2faff;border-radius:4px;color:#fff;font-size:14px;height:30px;line-height:30px;position:absolute;text-align:center;-webkit-transition:opacity .3s ease-in-out;-moz-transition:opacity .3s ease-in-out;transition:opacity .3s ease-in-out;width:150px}.vis-configuration-popup:after,.vis-configuration-popup:before{border:solid transparent;content:" ";height:0;left:100%;pointer-events:none;position:absolute;top:50%;width:0}.vis-configuration-popup:after{border-color:rgba(136,183,213,0) rgba(136,183,213,0) rgba(136,183,213,0) rgba(57,76,89,.85);border-width:8px;margin-top:-8px}.vis-configuration-popup:before{border-color:rgba(194,225,245,0) rgba(194,225,245,0) rgba(194,225,245,0) #f2faff;border-width:12px;margin-top:-12px}');var aI=function(){function t(e,i,n){var r=arguments.length>3&&void 0!==arguments[3]?arguments[3]:1;ga(this,t),this.parent=e,this.changedOptions=[],this.container=i,this.allowCreation=!1,this.options={},this.initialized=!1,this.popupCounter=0,this.defaultOptions={enabled:!1,filter:!0,container:void 0,showButton:!0},EO.extend(this.options,this.defaultOptions),this.configureOptions=n,this.moduleOptions={},this.domElements=[],this.popupDiv={},this.popupLimit=5,this.popupHistory={},this.colorPicker=new sI(r),this.wrapper=void 0}return Cc(t,[{key:"setOptions",value:function(t){if(void 0!==t){this.popupHistory={},this._removePopup();var e=!0;if("string"==typeof t)this.options.filter=t;else if(Id(t))this.options.filter=t.join();else if("object"===kc(t)){if(null==t)throw new TypeError("options cannot be null");void 0!==t.container&&(this.options.container=t.container),void 0!==Vf(t)&&(this.options.filter=Vf(t)),void 0!==t.showButton&&(this.options.showButton=t.showButton),void 0!==t.enabled&&(e=t.enabled)}else"boolean"==typeof t?(this.options.filter=!0,e=t):"function"==typeof t&&(this.options.filter=t,e=!0);!1===Vf(this.options)&&(e=!1),this.options.enabled=e}this._clean()}},{key:"setModuleOptions",value:function(t){this.moduleOptions=t,!0===this.options.enabled&&(this._clean(),void 0!==this.options.container&&(this.container=this.options.container),this._create())}},{key:"_create",value:function(){this._clean(),this.changedOptions=[];var t=Vf(this.options),e=0,i=!1;for(var n in this.configureOptions)this.configureOptions.hasOwnProperty(n)&&(this.allowCreation=!1,i=!1,"function"==typeof t?i=(i=t(n,[]))||this._handleObject(this.configureOptions[n],[n],!0):!0!==t&&-1===Rm(t).call(t,n)||(i=!0),!1!==i&&(this.allowCreation=!0,e>0&&this._makeItem([]),this._makeHeader(n),this._handleObject(this.configureOptions[n],[n])),e++);this._makeButton(),this._push()}},{key:"_push",value:function(){this.wrapper=document.createElement("div"),this.wrapper.className="vis-configuration-wrapper",this.container.appendChild(this.wrapper);for(var t=0;t<this.domElements.length;t++)this.wrapper.appendChild(this.domElements[t]);this._showPopupIfNeeded()}},{key:"_clean",value:function(){for(var t=0;t<this.domElements.length;t++)this.wrapper.removeChild(this.domElements[t]);void 0!==this.wrapper&&(this.container.removeChild(this.wrapper),this.wrapper=void 0),this.domElements=[],this._removePopup()}},{key:"_getValue",value:function(t){for(var e=this.moduleOptions,i=0;i<t.length;i++){if(void 0===e[t[i]]){e=void 0;break}e=e[t[i]]}return e}},{key:"_makeItem",value:function(t){if(!0===this.allowCreation){var e=document.createElement("div");e.className="vis-configuration vis-config-item vis-config-s"+t.length;for(var i=arguments.length,n=new Array(i>1?i-1:0),r=1;r<i;r++)n[r-1]=arguments[r];return kp(n).call(n,(function(t){e.appendChild(t)})),this.domElements.push(e),this.domElements.length}return 0}},{key:"_makeHeader",value:function(t){var e=document.createElement("div");e.className="vis-configuration vis-config-header",e.innerHTML=EO.xss(t),this._makeItem([],e)}},{key:"_makeLabel",value:function(t,e){var i=arguments.length>2&&void 0!==arguments[2]&&arguments[2],n=document.createElement("div");return n.className="vis-configuration vis-config-label vis-config-s"+e.length,n.innerHTML=!0===i?EO.xss("<i><b>"+t+":</b></i>"):EO.xss(t+":"),n}},{key:"_makeDropdown",value:function(t,e,i){var n=document.createElement("select");n.className="vis-configuration vis-config-select";var r=0;void 0!==e&&-1!==Rm(t).call(t,e)&&(r=Rm(t).call(t,e));for(var o=0;o<t.length;o++){var s=document.createElement("option");s.value=t[o],o===r&&(s.selected="selected"),s.innerHTML=t[o],n.appendChild(s)}var a=this;n.onchange=function(){a._update(this.value,i)};var l=this._makeLabel(i[i.length-1],i);this._makeItem(i,l,n)}},{key:"_makeRange",value:function(t,e,i){var n=t[0],r=t[1],o=t[2],s=t[3],a=document.createElement("input");a.className="vis-configuration vis-config-range";try{a.type="range",a.min=r,a.max=o}catch(t){}a.step=s;var l="",h=0;if(void 0!==e){var u=1.2;e<0&&e*u<r?(a.min=Math.ceil(e*u),h=a.min,l="range increased"):e/u<r&&(a.min=Math.ceil(e/u),h=a.min,l="range increased"),e*u>o&&1!==o&&(a.max=Math.ceil(e*u),h=a.max,l="range increased"),a.value=e}else a.value=n;var c=document.createElement("input");c.className="vis-configuration vis-config-rangeinput",c.value=Number(a.value);var d=this;a.onchange=function(){c.value=this.value,d._update(Number(this.value),i)},a.oninput=function(){c.value=this.value};var p=this._makeLabel(i[i.length-1],i),f=this._makeItem(i,p,a,c);""!==l&&this.popupHistory[f]!==h&&(this.popupHistory[f]=h,this._setupPopup(l,f))}},{key:"_makeButton",value:function(){var t=this;if(!0===this.options.showButton){var e=document.createElement("div");e.className="vis-configuration vis-config-button",e.innerHTML="generate options",e.onclick=function(){t._printOptions()},e.onmouseover=function(){e.className="vis-configuration vis-config-button hover"},e.onmouseout=function(){e.className="vis-configuration vis-config-button"},this.optionsContainer=document.createElement("div"),this.optionsContainer.className="vis-configuration vis-config-option-container",this.domElements.push(this.optionsContainer),this.domElements.push(e)}}},{key:"_setupPopup",value:function(t,e){var i=this;if(!0===this.initialized&&!0===this.allowCreation&&this.popupCounter<this.popupLimit){var n=document.createElement("div");n.id="vis-configuration-popup",n.className="vis-configuration-popup",n.innerHTML=EO.xss(t),n.onclick=function(){i._removePopup()},this.popupCounter+=1,this.popupDiv={html:n,index:e}}}},{key:"_removePopup",value:function(){void 0!==this.popupDiv.html&&(this.popupDiv.html.parentNode.removeChild(this.popupDiv.html),clearTimeout(this.popupDiv.hideTimeout),clearTimeout(this.popupDiv.deleteTimeout),this.popupDiv={})}},{key:"_showPopupIfNeeded",value:function(){var t=this;if(void 0!==this.popupDiv.html){var e=this.domElements[this.popupDiv.index].getBoundingClientRect();this.popupDiv.html.style.left=e.left+"px",this.popupDiv.html.style.top=e.top-30+"px",document.body.appendChild(this.popupDiv.html),this.popupDiv.hideTimeout=uv((function(){t.popupDiv.html.style.opacity=0}),1500),this.popupDiv.deleteTimeout=uv((function(){t._removePopup()}),1800)}}},{key:"_makeCheckbox",value:function(t,e,i){var n=document.createElement("input");n.type="checkbox",n.className="vis-configuration vis-config-checkbox",n.checked=t,void 0!==e&&(n.checked=e,e!==t&&("object"===kc(t)?e!==t.enabled&&this.changedOptions.push({path:i,value:e}):this.changedOptions.push({path:i,value:e})));var r=this;n.onchange=function(){r._update(this.checked,i)};var o=this._makeLabel(i[i.length-1],i);this._makeItem(i,o,n)}},{key:"_makeTextInput",value:function(t,e,i){var n=document.createElement("input");n.type="text",n.className="vis-configuration vis-config-text",n.value=e,e!==t&&this.changedOptions.push({path:i,value:e});var r=this;n.onchange=function(){r._update(this.value,i)};var o=this._makeLabel(i[i.length-1],i);this._makeItem(i,o,n)}},{key:"_makeColorField",value:function(t,e,i){var n=this,r=t[1],o=document.createElement("div");"none"!==(e=void 0===e?r:e)?(o.className="vis-configuration vis-config-colorBlock",o.style.backgroundColor=e):o.className="vis-configuration vis-config-colorBlock none",e=void 0===e?r:e,o.onclick=function(){n._showColorPicker(e,o,i)};var s=this._makeLabel(i[i.length-1],i);this._makeItem(i,s,o)}},{key:"_showColorPicker",value:function(t,e,i){var n=this;e.onclick=function(){},this.colorPicker.insertTo(e),this.colorPicker.show(),this.colorPicker.setColor(t),this.colorPicker.setUpdateCallback((function(t){var r="rgba("+t.r+","+t.g+","+t.b+","+t.a+")";e.style.backgroundColor=r,n._update(r,i)})),this.colorPicker.setCloseCallback((function(){e.onclick=function(){n._showColorPicker(t,e,i)}}))}},{key:"_handleObject",value:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:[],i=arguments.length>2&&void 0!==arguments[2]&&arguments[2],n=!1,r=Vf(this.options),o=!1;for(var s in t)if(t.hasOwnProperty(s)){n=!0;var a=t[s],l=EO.copyAndExtendArray(e,s);if("function"==typeof r&&!1===(n=r(s,e))&&!Id(a)&&"string"!=typeof a&&"boolean"!=typeof a&&a instanceof Object&&(this.allowCreation=!1,n=this._handleObject(a,l,!0),this.allowCreation=!1===i),!1!==n){o=!0;var h=this._getValue(l);if(Id(a))this._handleArray(a,h,l);else if("string"==typeof a)this._makeTextInput(a,h,l);else if("boolean"==typeof a)this._makeCheckbox(a,h,l);else if(a instanceof Object){var u=!0;if(-1!==Rm(e).call(e,"physics")&&this.moduleOptions.physics.solver!==s&&(u=!1),!0===u)if(void 0!==a.enabled){var c=EO.copyAndExtendArray(l,"enabled"),d=this._getValue(c);if(!0===d){var p=this._makeLabel(s,l,!0);this._makeItem(l,p),o=this._handleObject(a,l)||o}else this._makeCheckbox(a,d,l)}else{var f=this._makeLabel(s,l,!0);this._makeItem(l,f),o=this._handleObject(a,l)||o}}else console.error("dont know how to handle",a,s,l)}}return o}},{key:"_handleArray",value:function(t,e,i){"string"==typeof t[0]&&"color"===t[0]?(this._makeColorField(t,e,i),t[1]!==e&&this.changedOptions.push({path:i,value:e})):"string"==typeof t[0]?(this._makeDropdown(t,e,i),t[0]!==e&&this.changedOptions.push({path:i,value:e})):"number"==typeof t[0]&&(this._makeRange(t,e,i),t[0]!==e&&this.changedOptions.push({path:i,value:Number(e)}))}},{key:"_update",value:function(t,e){var i=this._constructOptions(t,e);this.parent.body&&this.parent.body.emitter&&this.parent.body.emitter.emit&&this.parent.body.emitter.emit("configChange",i),this.initialized=!0,this.parent.setOptions(i)}},{key:"_constructOptions",value:function(t,e){var i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},n=i;t="false"!==(t="true"===t||t)&&t;for(var r=0;r<e.length;r++)"global"!==e[r]&&(void 0===n[e[r]]&&(n[e[r]]={}),r!==e.length-1?n=n[e[r]]:n[e[r]]=t);return i}},{key:"_printOptions",value:function(){var t=this.getOptions();this.optionsContainer.innerHTML="<pre>var options = "+Wm(t,null,2)+"</pre>"}},{key:"getOptions",value:function(){for(var t={},e=0;e<this.changedOptions.length;e++)this._constructOptions(this.changedOptions[e].value,this.changedOptions[e].path,t);return t}}]),t}();var lI=function(t){Ib(i,t);var e=function(t){var e=function(){if("undefined"==typeof Reflect||!MT)return!1;if(MT.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(MT(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var i,n=Rb(t);if(e){var r=Rb(this).constructor;i=MT(n,arguments,r)}else i=n.apply(this,arguments);return Lb(this,i)}}(i);function i(t,n,r,o){var s,a,l,h,u,c,d,p;if(ga(this,i),(p=e.call(this)).initTime=new Date,p.itemsDone=!1,!(Db(p)instanceof i))throw new SyntaxError("Constructor must be called with the new operator");if(!Id(r)&&!xO(r)&&r instanceof Object){var f=o;o=r,r=f}o&&o.throttleRedraw&&console.warn('Timeline option "throttleRedraw" is DEPRICATED and no longer supported. It will be removed in the next MAJOR release.');var m=Db(p);if(p.defaultOptions={autoResize:!0,longSelectPressTime:251,orientation:{axis:"bottom",item:"bottom"},moment:gM},p.options=EO.deepExtend({},p.defaultOptions),o&&EO.setupXSSProtection(o.xss),p._create(t),!o||o&&void 0===o.rtl){var v;p.dom.root.style.visibility="hidden";for(var g=p.dom.root;!v&&g;)v=window.getComputedStyle(g,null).direction,g=g.parentElement;p.options.rtl=v&&"rtl"==v.toLowerCase()}else p.options.rtl=o.rtl;o&&(o.rollingMode&&(p.options.rollingMode=o.rollingMode),o.onInitialDrawComplete&&(p.options.onInitialDrawComplete=o.onInitialDrawComplete),o.onTimeout&&(p.options.onTimeout=o.onTimeout),o.loadingScreenTemplate&&(p.options.loadingScreenTemplate=o.loadingScreenTemplate));var y=document.createElement("div");if(p.options.loadingScreenTemplate){var b,_=hp(b=p.options.loadingScreenTemplate).call(b,Db(p)),w=_(p.dom.loadingScreen);w instanceof Object&&!(w instanceof Element)?_(y):w instanceof Element?(y.innerHTML="",y.appendChild(w)):null!=w&&(y.innerHTML=EO.xss(w))}function k(t,e){m.hasListeners(t)&&m.emit(t,m.getEventProperties(e))}return p.dom.loadingScreen.appendChild(y),p.components=[],p.body={dom:p.dom,domProps:p.props,emitter:{on:hp(s=p.on).call(s,Db(p)),off:hp(a=p.off).call(a,Db(p)),emit:hp(l=p.emit).call(l,Db(p))},hiddenDates:[],util:{getScale:function(){return m.timeAxis.step.scale},getStep:function(){return m.timeAxis.step.step},toScreen:hp(h=m._toScreen).call(h,m),toGlobalScreen:hp(u=m._toGlobalScreen).call(u,m),toTime:hp(c=m._toTime).call(c,m),toGlobalTime:hp(d=m._toGlobalTime).call(d,m)}},p.range=new pP(p.body,p.options),p.components.push(p.range),p.body.range=p.range,p.timeAxis=new kP(p.body,p.options),p.timeAxis2=null,p.components.push(p.timeAxis),p.currentTime=new GP(p.body,p.options),p.components.push(p.currentTime),p.itemSet=new VE(p.body,p.options),p.components.push(p.itemSet),p.itemsData=null,p.groupsData=null,p.dom.root.onclick=function(t){k("click",t)},p.dom.root.ondblclick=function(t){k("doubleClick",t)},p.dom.root.oncontextmenu=function(t){k("contextmenu",t)},p.dom.root.onmouseover=function(t){k("mouseOver",t)},window.PointerEvent?(p.dom.root.onpointerdown=function(t){k("mouseDown",t)},p.dom.root.onpointermove=function(t){k("mouseMove",t)},p.dom.root.onpointerup=function(t){k("mouseUp",t)}):(p.dom.root.onmousemove=function(t){k("mouseMove",t)},p.dom.root.onmousedown=function(t){k("mouseDown",t)},p.dom.root.onmouseup=function(t){k("mouseUp",t)}),p.initialFitDone=!1,p.on("changed",(function(){if(null!=m.itemsData){if(!m.initialFitDone&&!m.options.rollingMode)if(m.initialFitDone=!0,null!=m.options.start||null!=m.options.end){if(null==m.options.start||null==m.options.end)var t=m.getItemRange();var e=null!=m.options.start?m.options.start:t.min,i=null!=m.options.end?m.options.end:t.max;m.setWindow(e,i,{animation:!1})}else m.fit({animation:!1});m.initialDrawDone||!m.initialRangeChangeDone&&(m.options.start||m.options.end)&&!m.options.rollingMode||(m.initialDrawDone=!0,m.itemSet.initialDrawDone=!0,m.dom.root.style.visibility="visible",m.dom.loadingScreen.parentNode.removeChild(m.dom.loadingScreen),m.options.onInitialDrawComplete&&uv((function(){return m.options.onInitialDrawComplete()}),0))}})),p.on("destroyTimeline",(function(){m.destroy()})),o&&p.setOptions(o),p.body.emitter.on("fit",(function(t){p._onFit(t),p.redraw()})),r&&p.setGroups(r),n&&p.setItems(n),p._redraw(),p}return Cc(i,[{key:"_createConfigurator",value:function(){return new aI(this,this.dom.container,rI)}},{key:"redraw",value:function(){this.itemSet&&this.itemSet.markDirty({refreshItems:!0}),this._redraw()}},{key:"setOptions",value:function(t){if(!0===$E.validate(t,nI)&&console.log("%cErrors have been found in the supplied options object.",qE),zP.prototype.setOptions.call(this,t),"type"in t&&t.type!==this.options.type){this.options.type=t.type;var e=this.itemsData;if(e){var i=this.getSelection();this.setItems(null),this.setItems(e.rawDS),this.setSelection(i)}}}},{key:"setItems",value:function(t){var e;this.itemsDone=!1,e=t?xO(t)?TO(t):TO(new mM(t)):null,this.itemsData&&this.itemsData.dispose(),this.itemsData=e,this.itemSet&&this.itemSet.setItems(null!=e?e.rawDS:null)}},{key:"setGroups",value:function(t){var e;t?(Id(t)&&(t=new mM(t)),e=new vM(t,{filter:function(t){return!1!==t.visible}})):e=null,null!=this.groupsData&&"function"==typeof this.groupsData.setData&&this.groupsData.setData(null),this.groupsData=e,this.itemSet.setGroups(e)}},{key:"setData",value:function(t){t&&t.groups&&this.setGroups(t.groups),t&&t.items&&this.setItems(t.items)}},{key:"setSelection",value:function(t,e){this.itemSet&&this.itemSet.setSelection(t),e&&e.focus&&this.focus(t,e)}},{key:"getSelection",value:function(){return this.itemSet&&this.itemSet.getSelection()||[]}},{key:"focus",value:function(t,e){if(this.itemsData&&null!=t){var i=Id(t)?t:[t],n=this.itemsData.get(i),r=null,o=null;if(kp(n).call(n,(function(t){var e=t.start.valueOf(),i="end"in t?t.end.valueOf():t.start.valueOf();(null===r||e<r)&&(r=e),(null===o||i>o)&&(o=i)})),null!==r&&null!==o){var s=this,a=this.itemSet.items[i[0]],l=-1*this._getScrollTop(),h=null,u=function(){var t=cI(s,a);t.shouldScroll&&t.itemTop!=h.itemTop&&(s._setScrollTop(-t.scrollOffset),s._redraw())},c=!e||void 0===e.zoom||e.zoom,d=(r+o)/2,p=c?1.1*(o-r):Math.max(this.range.end-this.range.start,1.1*(o-r)),f=!e||void 0===e.animation||e.animation;f||(h={shouldScroll:!1,scrollOffset:-1,itemTop:-1}),this.range.setRange(d-p/2,d+p/2,{animation:f},(function(){u(),uv(u,100)}),(function(t,e,i){var n=cI(s,a);if(!1!==n&&(h||(h=n),h.itemTop!=n.itemTop||h.shouldScroll)){h.itemTop!=n.itemTop&&n.shouldScroll&&(h=n,l=-1*s._getScrollTop());var r=l,o=h.scrollOffset,u=i?o:r+(o-r)*t;s._setScrollTop(-u),e||s._redraw()}}))}}}},{key:"fit",value:function(t,e){var i,n=!t||void 0===t.animation||t.animation;1===this.itemsData.length&&void 0===this.itemsData.get()[0].end?(i=this.getDataRange(),this.moveTo(i.min.valueOf(),{animation:n},e)):(i=this.getItemRange(),this.range.setRange(i.min,i.max,{animation:n},e))}},{key:"getItemRange",value:function(){var t=this,e=this.getDataRange(),i=null!==e.min?e.min.valueOf():null,n=null!==e.max?e.max.valueOf():null,r=null,o=null;if(null!=i&&null!=n){var s=n-i;s<=0&&(s=10);var a=s/this.props.center.width,l={},h=0;if(kp(EO).call(EO,this.itemSet.items,(function(t,e){t.groupShowing&&(l[e]=t.redraw(!0),h=l[e].length)})),h>0)for(var u=function(t){kp(EO).call(EO,l,(function(e){e[t]()}))},c=0;c<h;c++)u(c);if(kp(EO).call(EO,this.itemSet.items,(function(e){var s,l,h=hI(e),u=uI(e);t.options.rtl?(s=h-(e.getWidthRight()+10)*a,l=u+(e.getWidthLeft()+10)*a):(s=h-(e.getWidthLeft()+10)*a,l=u+(e.getWidthRight()+10)*a),s<i&&(i=s,r=e),l>n&&(n=l,o=e)})),r&&o){var d=r.getWidthLeft()+10,p=o.getWidthRight()+10,f=this.props.center.width-d-p;f>0&&(this.options.rtl?(i=hI(r)-p*s/f,n=uI(o)+d*s/f):(i=hI(r)-d*s/f,n=uI(o)+p*s/f))}}return{min:null!=i?new Date(i):null,max:null!=n?new Date(n):null}}},{key:"getDataRange",value:function(){var t,e=null,i=null;return this.itemsData&&kp(t=this.itemsData).call(t,(function(t){var n=EO.convert(t.start,"Date").valueOf(),r=EO.convert(null!=t.end?t.end:t.start,"Date").valueOf();(null===e||n<e)&&(e=n),(null===i||r>i)&&(i=r)})),{min:null!=e?new Date(e):null,max:null!=i?new Date(i):null}}},{key:"getEventProperties",value:function(t){var e=t.center?t.center.x:t.clientX,i=t.center?t.center.y:t.clientY,n=this.dom.centerContainer.getBoundingClientRect(),r=this.options.rtl?n.right-e:e-n.left,o=i-n.top,s=this.itemSet.itemFromTarget(t),a=this.itemSet.groupFromTarget(t),l=BP.customTimeFromTarget(t),h=this.itemSet.options.snap||null,u=this.body.util.getScale(),c=this.body.util.getStep(),d=this._toTime(r),p=h?h(d,u,c):d,f=EO.getTarget(t),m=null;return null!=s?m="item":null!=l?m="custom-time":EO.hasParent(f,this.timeAxis.dom.foreground)||this.timeAxis2&&EO.hasParent(f,this.timeAxis2.dom.foreground)?m="axis":EO.hasParent(f,this.itemSet.dom.labelSet)?m="group-label":EO.hasParent(f,this.currentTime.bar)?m="current-time":EO.hasParent(f,this.dom.center)&&(m="background"),{event:t,item:s?s.id:null,isCluster:!!s&&!!s.isCluster,items:s?s.items||[]:null,group:a?a.groupId:null,customTime:l?l.options.id:null,what:m,pageX:t.srcEvent?t.srcEvent.pageX:t.pageX,pageY:t.srcEvent?t.srcEvent.pageY:t.pageY,x:r,y:o,time:d,snappedTime:p}}},{key:"toggleRollingMode",value:function(){this.range.rolling?this.range.stopRolling():(null==this.options.rollingMode&&this.setOptions(this.options),this.range.startRolling())}},{key:"_redraw",value:function(){zP.prototype._redraw.call(this)}},{key:"_onFit",value:function(t){var e=t.start,i=t.end,n=t.animation;i?this.range.setRange(e,i,{animation:n}):this.moveTo(e.valueOf(),{animation:n})}}]),i}(zP);function hI(t){return EO.convert(t.data.start,"Date").valueOf()}function uI(t){var e=null!=t.data.end?t.data.end:t.data.start;return EO.convert(e,"Date").valueOf()}function cI(t,e){if(!e.parent)return!1;var i=t.options.rtl?t.props.rightContainer.height:t.props.leftContainer.height,n=t.props.center.height,r=e.parent,o=r.top,s=!0,a=t.timeAxis.options.orientation.axis,l=function(){return"bottom"==a?r.height-e.top-e.height:e.top},h=-1*t._getScrollTop(),u=o+l(),c=e.height;return u<h?o+i<=o+l()+c&&(o+=l()-t.itemSet.options.margin.item.vertical):u+c>h+i?o+=l()+c-i+t.itemSet.options.margin.item.vertical:s=!1,{shouldScroll:s,scrollOffset:o=Math.min(o,n-i),itemTop:u}}var dI=function(){function t(e,i,n,r,o,s){var a=arguments.length>6&&void 0!==arguments[6]&&arguments[6],l=arguments.length>7&&void 0!==arguments[7]&&arguments[7];if(ga(this,t),this.majorSteps=[1,2,5,10],this.minorSteps=[.25,.5,1,2],this.customLines=null,this.containerHeight=o,this.majorCharHeight=s,this._start=e,this._end=i,this.scale=1,this.minorStepIdx=-1,this.magnitudefactor=1,this.determineScale(),this.zeroAlign=a,this.autoScaleStart=n,this.autoScaleEnd=r,this.formattingFunction=l,n||r){var h=this,u=function(t){var e=t-t%(h.magnitudefactor*h.minorSteps[h.minorStepIdx]);return t%(h.magnitudefactor*h.minorSteps[h.minorStepIdx])>h.magnitudefactor*h.minorSteps[h.minorStepIdx]*.5?e+h.magnitudefactor*h.minorSteps[h.minorStepIdx]:e};n&&(this._start-=2*this.magnitudefactor*this.minorSteps[this.minorStepIdx],this._start=u(this._start)),r&&(this._end+=this.magnitudefactor*this.minorSteps[this.minorStepIdx],this._end=u(this._end)),this.determineScale()}}return Cc(t,[{key:"setCharHeight",value:function(t){this.majorCharHeight=t}},{key:"setHeight",value:function(t){this.containerHeight=t}},{key:"determineScale",value:function(){var t=this._end-this._start;this.scale=this.containerHeight/t;var e=this.majorCharHeight/this.scale,i=t>0?Math.round(Math.log(t)/Math.LN10):0;this.minorStepIdx=-1,this.magnitudefactor=Math.pow(10,i);var n=0;i<0&&(n=i);for(var r=!1,o=n;Math.abs(o)<=Math.abs(i);o++){this.magnitudefactor=Math.pow(10,o);for(var s=0;s<this.minorSteps.length;s++)if(this.magnitudefactor*this.minorSteps[s]>=e){r=!0,this.minorStepIdx=s;break}if(!0===r)break}}},{key:"is_major",value:function(t){return t%(this.magnitudefactor*this.majorSteps[this.minorStepIdx])==0}},{key:"getStep",value:function(){return this.magnitudefactor*this.minorSteps[this.minorStepIdx]}},{key:"getFirstMajor",value:function(){var t=this.magnitudefactor*this.majorSteps[this.minorStepIdx];return this.convertValue(this._start+(t-this._start%t)%t)}},{key:"formatValue",value:function(t){var e=t.toPrecision(5);return"function"==typeof this.formattingFunction&&(e=this.formattingFunction(t)),"number"==typeof e?"".concat(e):"string"==typeof e?e:t.toPrecision(5)}},{key:"getLines",value:function(){for(var t=[],e=this.getStep(),i=(e-this._start%e)%e,n=this._start+i;this._end-n>1e-5;n+=e)n!=this._start&&t.push({major:this.is_major(n),y:this.convertValue(n),val:this.formatValue(n)});return t}},{key:"followScale",value:function(t){var e=this.minorStepIdx,i=this._start,n=this._end,r=this,o=function(){r.magnitudefactor*=2},s=function(){r.magnitudefactor/=2};t.minorStepIdx<=1&&this.minorStepIdx<=1||t.minorStepIdx>1&&this.minorStepIdx>1||(t.minorStepIdx<this.minorStepIdx?(this.minorStepIdx=1,2==e||o(),o()):(this.minorStepIdx=2,1==e||s(),s()));for(var a=t.convertValue(0),l=t.getStep()*t.scale,h=!1,u=0;!h&&u++<5;){this.scale=l/(this.minorSteps[this.minorStepIdx]*this.magnitudefactor);var c=this.containerHeight/this.scale;this._start=i,this._end=this._start+c;var d=this._end*this.scale,p=this.magnitudefactor*this.majorSteps[this.minorStepIdx],f=this.getFirstMajor()-t.getFirstMajor();if(this.zeroAlign){var m=a-d;this._end+=m/this.scale,this._start=this._end-c}else this.autoScaleStart?(this._start-=f/this.scale,this._end=this._start+c):(this._start+=p-f/this.scale,this._end=this._start+c);if(!this.autoScaleEnd&&this._end>n+1e-5)s(),h=!1;else{if(!this.autoScaleStart&&this._start<i-1e-5){if(!(this.zeroAlign&&i>=0)){s(),h=!1;continue}console.warn("Can't adhere to given 'min' range, due to zeroalign")}this.autoScaleStart&&this.autoScaleEnd&&c<n-i?(o(),h=!1):h=!0}}}},{key:"convertValue",value:function(t){return this.containerHeight-(t-this._start)*this.scale}},{key:"screenToValue",value:function(t){return(this.containerHeight-t)/this.scale+this._start}}]),t}();function pI(t,e){(null==e||e>t.length)&&(e=t.length);for(var i=0,n=new Array(e);i<e;i++)n[i]=t[i];return n}wP(".vis-panel.vis-background.vis-horizontal .vis-grid.vis-horizontal{border-bottom:1px solid;height:0;position:absolute;width:100%}.vis-panel.vis-background.vis-horizontal .vis-grid.vis-minor{border-color:#e5e5e5}.vis-panel.vis-background.vis-horizontal .vis-grid.vis-major{border-color:#bfbfbf}.vis-data-axis .vis-y-axis.vis-major{color:#4d4d4d;position:absolute;white-space:nowrap;width:100%}.vis-data-axis .vis-y-axis.vis-major.vis-measure{border:0;margin:0;padding:0;visibility:hidden;width:auto}.vis-data-axis .vis-y-axis.vis-minor{color:#bebebe;position:absolute;white-space:nowrap;width:100%}.vis-data-axis .vis-y-axis.vis-minor.vis-measure{border:0;margin:0;padding:0;visibility:hidden;width:auto}.vis-data-axis .vis-y-axis.vis-title{bottom:20px;color:#4d4d4d;position:absolute;text-align:center;white-space:nowrap}.vis-data-axis .vis-y-axis.vis-title.vis-measure{margin:0;padding:0;visibility:hidden;width:auto}.vis-data-axis .vis-y-axis.vis-title.vis-left{bottom:0;-webkit-transform:rotate(-90deg);-moz-transform:rotate(-90deg);-ms-transform:rotate(-90deg);-o-transform:rotate(-90deg);transform:rotate(-90deg);-webkit-transform-origin:left top;-moz-transform-origin:left top;-ms-transform-origin:left top;-o-transform-origin:left top;transform-origin:left bottom}.vis-data-axis .vis-y-axis.vis-title.vis-right{bottom:0;-webkit-transform:rotate(90deg);-moz-transform:rotate(90deg);-ms-transform:rotate(90deg);-o-transform:rotate(90deg);transform:rotate(90deg);-webkit-transform-origin:right bottom;-moz-transform-origin:right bottom;-ms-transform-origin:right bottom;-o-transform-origin:right bottom;transform-origin:right bottom}.vis-legend{background-color:rgba(247,252,255,.65);border:1px solid #b3b3b3;box-shadow:2px 2px 10px hsla(0,0%,60%,.55);padding:5px}.vis-legend-text{display:inline-block;white-space:nowrap}");var fI=function(t){Ib(i,t);var e=function(t){var e=function(){if("undefined"==typeof Reflect||!MT)return!1;if(MT.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(MT(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var i,n=Rb(t);if(e){var r=Rb(this).constructor;i=MT(n,arguments,r)}else i=n.apply(this,arguments);return Lb(this,i)}}(i);function i(t,n,r,o){var s;ga(this,i),(s=e.call(this)).id=nM(),s.body=t,s.defaultOptions={orientation:"left",showMinorLabels:!0,showMajorLabels:!0,showWeekScale:!1,icons:!1,majorLinesOffset:7,minorLinesOffset:4,labelOffsetX:10,labelOffsetY:2,iconWidth:20,width:"40px",visible:!0,alignZeros:!0,left:{range:{min:void 0,max:void 0},format:function(t){return"".concat(zO(t.toPrecision(3)))},title:{text:void 0,style:void 0}},right:{range:{min:void 0,max:void 0},format:function(t){return"".concat(zO(t.toPrecision(3)))},title:{text:void 0,style:void 0}}},s.linegraphOptions=o,s.linegraphSVG=r,s.props={},s.DOMelements={lines:{},labels:{},title:{}},s.dom={},s.scale=void 0,s.range={start:0,end:0},s.options=EO.extend({},s.defaultOptions),s.conversionFactor=1,s.setOptions(n),s.width=Number("".concat(s.options.width).replace("px","")),s.minWidth=s.width,s.height=s.linegraphSVG.getBoundingClientRect().height,s.hidden=!1,s.stepPixels=25,s.zeroCrossing=-1,s.amountOfSteps=-1,s.lineOffset=0,s.master=!0,s.masterAxis=null,s.svgElements={},s.iconsRemoved=!1,s.groups={},s.amountOfGroups=0,s._create(),null==s.scale&&s._redrawLabels(),s.framework={svg:s.svg,svgElements:s.svgElements,options:s.options,groups:s.groups};var a=Db(s);return s.body.emitter.on("verticalDrag",(function(){a.dom.lineContainer.style.top="".concat(a.body.domProps.scrollTop,"px")})),s}return Cc(i,[{key:"addGroup",value:function(t,e){this.groups.hasOwnProperty(t)||(this.groups[t]=e),this.amountOfGroups+=1}},{key:"updateGroup",value:function(t,e){this.groups.hasOwnProperty(t)||(this.amountOfGroups+=1),this.groups[t]=e}},{key:"removeGroup",value:function(t){this.groups.hasOwnProperty(t)&&(delete this.groups[t],this.amountOfGroups-=1)}},{key:"setOptions",value:function(t){if(t){var e=!1;this.options.orientation!=t.orientation&&void 0!==t.orientation&&(e=!0),EO.selectiveDeepExtend(["orientation","showMinorLabels","showMajorLabels","icons","majorLinesOffset","minorLinesOffset","labelOffsetX","labelOffsetY","iconWidth","width","visible","left","right","alignZeros"],this.options,t),this.minWidth=Number("".concat(this.options.width).replace("px","")),!0===e&&this.dom.frame&&(this.hide(),this.show())}}},{key:"_create",value:function(){this.dom.frame=document.createElement("div"),this.dom.frame.style.width=this.options.width,this.dom.frame.style.height=this.height,this.dom.lineContainer=document.createElement("div"),this.dom.lineContainer.style.width="100%",this.dom.lineContainer.style.height=this.height,this.dom.lineContainer.style.position="relative",this.dom.lineContainer.style.visibility="visible",this.dom.lineContainer.style.display="block",this.svg=document.createElementNS("http://www.w3.org/2000/svg","svg"),this.svg.style.position="absolute",this.svg.style.top="0px",this.svg.style.height="100%",this.svg.style.width="100%",this.svg.style.display="block",this.dom.frame.appendChild(this.svg)}},{key:"_redrawGroupIcons",value:function(){var t;vb(this.svgElements);var e=this.options.iconWidth,i=11.5;t="left"===this.options.orientation?4:this.width-e-4;var n=Bd(this.groups);RC(n).call(n,(function(t,e){return t<e?-1:1}));var r,o=function(t,e){var i=void 0!==yd&&va(t)||t["@@iterator"];if(!i){if(Id(t)||(i=function(t,e){var i;if(t){if("string"==typeof t)return pI(t,e);var n=Sd(i=Object.prototype.toString.call(t)).call(i,8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Ks(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?pI(t,e):void 0}}(t))||e&&t&&"number"==typeof t.length){i&&(t=i);var n=0,r=function(){};return{s:r,n:function(){return n>=t.length?{done:!0}:{done:!1,value:t[n++]}},e:function(t){throw t},f:r}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var o,s=!0,a=!1;return{s:function(){i=i.call(t)},n:function(){var t=i.next();return s=t.done,t},e:function(t){a=!0,o=t},f:function(){try{s||null==i.return||i.return()}finally{if(a)throw o}}}}(n);try{for(o.s();!(r=o.n()).done;){var s=r.value;!0!==this.groups[s].visible||void 0!==this.linegraphOptions.visibility[s]&&!0!==this.linegraphOptions.visibility[s]||(this.groups[s].getLegend(e,15,this.framework,t,i),i+=19)}}catch(t){o.e(t)}finally{o.f()}gb(this.svgElements),this.iconsRemoved=!1}},{key:"_cleanupIcons",value:function(){!1===this.iconsRemoved&&(vb(this.svgElements),gb(this.svgElements),this.iconsRemoved=!0)}},{key:"show",value:function(){this.hidden=!1,this.dom.frame.parentNode||("left"===this.options.orientation?this.body.dom.left.appendChild(this.dom.frame):this.body.dom.right.appendChild(this.dom.frame)),this.dom.lineContainer.parentNode||this.body.dom.backgroundHorizontal.appendChild(this.dom.lineContainer),this.dom.lineContainer.style.display="block"}},{key:"hide",value:function(){this.hidden=!0,this.dom.frame.parentNode&&this.dom.frame.parentNode.removeChild(this.dom.frame),this.dom.lineContainer.style.display="none"}},{key:"setRange",value:function(t,e){this.range.start=t,this.range.end=e}},{key:"redraw",value:function(){var t=!1,e=0;for(var i in this.dom.lineContainer.style.top="".concat(this.body.domProps.scrollTop,"px"),this.groups)this.groups.hasOwnProperty(i)&&(!0!==this.groups[i].visible||void 0!==this.linegraphOptions.visibility[i]&&!0!==this.linegraphOptions.visibility[i]||e++);if(0===this.amountOfGroups||0===e)this.hide();else{this.show(),this.height=Number(this.linegraphSVG.style.height.replace("px","")),this.dom.lineContainer.style.height="".concat(this.height,"px"),this.width=!0===this.options.visible?Number("".concat(this.options.width).replace("px","")):0;var n=this.props,r=this.dom.frame;r.className="vis-data-axis",this._calculateCharSize();var o=this.options.orientation,s=this.options.showMinorLabels,a=this.options.showMajorLabels,l=this.body.dom.backgroundHorizontal.offsetWidth;n.minorLabelHeight=s?n.minorCharHeight:0,n.majorLabelHeight=a?n.majorCharHeight:0,n.minorLineWidth=l-this.lineOffset-this.width+2*this.options.minorLinesOffset,n.minorLineHeight=1,n.majorLineWidth=l-this.lineOffset-this.width+2*this.options.majorLinesOffset,n.majorLineHeight=1,"left"===o?(r.style.top="0",r.style.left="0",r.style.bottom="",r.style.width="".concat(this.width,"px"),r.style.height="".concat(this.height,"px"),this.props.width=this.body.domProps.left.width,this.props.height=this.body.domProps.left.height):(r.style.top="",r.style.bottom="0",r.style.left="0",r.style.width="".concat(this.width,"px"),r.style.height="".concat(this.height,"px"),this.props.width=this.body.domProps.right.width,this.props.height=this.body.domProps.right.height),t=this._redrawLabels(),t=this._isResized()||t,!0===this.options.icons?this._redrawGroupIcons():this._cleanupIcons(),this._redrawTitle(o)}return t}},{key:"_redrawLabels",value:function(){var t=this,e=!1;vb(this.DOMelements.lines),vb(this.DOMelements.labels);var i=this.options.orientation,n=null!=this.options[i].range?this.options[i].range:{},r=!0;null!=n.max&&(this.range.end=n.max,r=!1);var o=!0;null!=n.min&&(this.range.start=n.min,o=!1),this.scale=new dI(this.range.start,this.range.end,o,r,this.dom.frame.offsetHeight,this.props.majorCharHeight,this.options.alignZeros,this.options[i].format),!1===this.master&&null!=this.masterAxis?(this.scale.followScale(this.masterAxis.scale),this.dom.lineContainer.style.display="none"):this.dom.lineContainer.style.display="block",this.maxLabelSize=0;var s=this.scale.getLines();kp(s).call(s,(function(e){var n=e.y,r=e.major;t.options.showMinorLabels&&!1===r&&t._redrawLabel(n-2,e.val,i,"vis-y-axis vis-minor",t.props.minorCharHeight),r&&n>=0&&t._redrawLabel(n-2,e.val,i,"vis-y-axis vis-major",t.props.majorCharHeight),!0===t.master&&(r?t._redrawLine(n,i,"vis-grid vis-horizontal vis-major",t.options.majorLinesOffset,t.props.majorLineWidth):t._redrawLine(n,i,"vis-grid vis-horizontal vis-minor",t.options.minorLinesOffset,t.props.minorLineWidth))}));var a=0;void 0!==this.options[i].title&&void 0!==this.options[i].title.text&&(a=this.props.titleCharHeight);var l=!0===this.options.icons?Math.max(this.options.iconWidth,a)+this.options.labelOffsetX+15:a+this.options.labelOffsetX+15;return this.maxLabelSize>this.width-l&&!0===this.options.visible?(this.width=this.maxLabelSize+l,this.options.width="".concat(this.width,"px"),gb(this.DOMelements.lines),gb(this.DOMelements.labels),this.redraw(),e=!0):this.maxLabelSize<this.width-l&&!0===this.options.visible&&this.width>this.minWidth?(this.width=Math.max(this.minWidth,this.maxLabelSize+l),this.options.width="".concat(this.width,"px"),gb(this.DOMelements.lines),gb(this.DOMelements.labels),this.redraw(),e=!0):(gb(this.DOMelements.lines),gb(this.DOMelements.labels),e=!1),e}},{key:"convertValue",value:function(t){return this.scale.convertValue(t)}},{key:"screenToValue",value:function(t){return this.scale.screenToValue(t)}},{key:"_redrawLabel",value:function(t,e,i,n,r){var o=_b("div",this.DOMelements.labels,this.dom.frame);o.className=n,o.innerHTML=EO.xss(e),"left"===i?(o.style.left="-".concat(this.options.labelOffsetX,"px"),o.style.textAlign="right"):(o.style.right="-".concat(this.options.labelOffsetX,"px"),o.style.textAlign="left"),o.style.top="".concat(t-.5*r+this.options.labelOffsetY,"px"),e+="";var s=Math.max(this.props.majorCharWidth,this.props.minorCharWidth);this.maxLabelSize<e.length*s&&(this.maxLabelSize=e.length*s)}},{key:"_redrawLine",value:function(t,e,i,n,r){if(!0===this.master){var o=_b("div",this.DOMelements.lines,this.dom.lineContainer);o.className=i,o.innerHTML="","left"===e?o.style.left="".concat(this.width-n,"px"):o.style.right="".concat(this.width-n,"px"),o.style.width="".concat(r,"px"),o.style.top="".concat(t,"px")}}},{key:"_redrawTitle",value:function(t){if(vb(this.DOMelements.title),void 0!==this.options[t].title&&void 0!==this.options[t].title.text){var e=_b("div",this.DOMelements.title,this.dom.frame);e.className="vis-y-axis vis-title vis-".concat(t),e.innerHTML=EO.xss(this.options[t].title.text),void 0!==this.options[t].title.style&&EO.addCssText(e,this.options[t].title.style),"left"===t?e.style.left="".concat(this.props.titleCharHeight,"px"):e.style.right="".concat(this.props.titleCharHeight,"px"),e.style.width="".concat(this.height,"px")}gb(this.DOMelements.title)}},{key:"_calculateCharSize",value:function(){if(!("minorCharHeight"in this.props)){var t=document.createTextNode("0"),e=document.createElement("div");e.className="vis-y-axis vis-minor vis-measure",e.appendChild(t),this.dom.frame.appendChild(e),this.props.minorCharHeight=e.clientHeight,this.props.minorCharWidth=e.clientWidth,this.dom.frame.removeChild(e)}if(!("majorCharHeight"in this.props)){var i=document.createTextNode("0"),n=document.createElement("div");n.className="vis-y-axis vis-major vis-measure",n.appendChild(i),this.dom.frame.appendChild(n),this.props.majorCharHeight=n.clientHeight,this.props.majorCharWidth=n.clientWidth,this.dom.frame.removeChild(n)}if(!("titleCharHeight"in this.props)){var r=document.createTextNode("0"),o=document.createElement("div");o.className="vis-y-axis vis-title vis-measure",o.appendChild(r),this.dom.frame.appendChild(o),this.props.titleCharHeight=o.clientHeight,this.props.titleCharWidth=o.clientWidth,this.dom.frame.removeChild(o)}}}]),i}(GO);function mI(t,e){}function vI(t,e){return{style:(e=void 0===e?{}:e).style||t.options.drawPoints.style,styles:e.styles||t.options.drawPoints.styles,size:e.size||t.options.drawPoints.size,className:e.className||t.className}}function gI(t,e){}function yI(t,e){}function bI(t,e,i,n){this.id=e,this.options=EO.selectiveBridgeObject(["sampling","style","sort","yAxisOrientation","barChart","drawPoints","shaded","interpolation","zIndex","excludeFromStacking","excludeFromLegend"],i),this.usingDefaultStyle=void 0===t.className,this.groupsUsingDefaultStyles=n,this.zeroPosition=0,this.update(t),1==this.usingDefaultStyle&&(this.groupsUsingDefaultStyles[0]+=1),this.itemsData=[],this.visible=void 0===t.visible||t.visible}function _I(t,e,i,n){this.body=t,this.defaultOptions={enabled:!1,icons:!0,iconSize:20,iconSpacing:6,left:{visible:!0,position:"top-left"},right:{visible:!0,position:"top-right"}},this.side=i,this.options=EO.extend({},this.defaultOptions),this.linegraphOptions=n,this.svgElements={},this.dom={},this.groups={},this.amountOfGroups=0,this._create(),this.framework={svg:this.svg,svgElements:this.svgElements,options:this.options,groups:this.groups},this.setOptions(e)}mI.draw=function(t,e,i,n){n=n||0;for(var r=function(t,e){var i=void 0;return t.options&&t.options.drawPoints&&t.options.drawPoints.onRender&&"function"==typeof t.options.drawPoints.onRender&&(i=t.options.drawPoints.onRender),e.group.options&&e.group.options.drawPoints&&e.group.options.drawPoints.onRender&&"function"==typeof e.group.options.drawPoints.onRender&&(i=e.group.options.drawPoints.onRender),i}(i,e),o=0;o<t.length;o++)if(r){var s=r(t[o],e);!0!==s&&"object"!==kc(s)||wb(t[o].screen_x+n,t[o].screen_y,vI(e,s),i.svgElements,i.svg,t[o].label)}else wb(t[o].screen_x+n,t[o].screen_y,vI(e),i.svgElements,i.svg,t[o].label)},mI.drawIcon=function(t,e,i,n,r,o){var s=.5*r,a=bb("rect",o.svgElements,o.svg);a.setAttributeNS(null,"x",e),a.setAttributeNS(null,"y",i-s),a.setAttributeNS(null,"width",n),a.setAttributeNS(null,"height",2*s),a.setAttributeNS(null,"class","vis-outline"),wb(e+.5*n,i,vI(t),o.svgElements,o.svg)},gI.drawIcon=function(t,e,i,n,r,o){var s=.5*r,a=bb("rect",o.svgElements,o.svg);a.setAttributeNS(null,"x",e),a.setAttributeNS(null,"y",i-s),a.setAttributeNS(null,"width",n),a.setAttributeNS(null,"height",2*s),a.setAttributeNS(null,"class","vis-outline");var l=Math.round(.3*n),h=t.options.barChart.width/l,u=Math.round(.4*r),c=Math.round(.75*r),d=Math.round((n-2*l)/3);if(kb(e+.5*l+d,i+s-u-1,l,u,t.className+" vis-bar",o.svgElements,o.svg,t.style),kb(e+1.5*l+d+2,i+s-c-1,l,c,t.className+" vis-bar",o.svgElements,o.svg,t.style),1==t.options.drawPoints.enabled){var p={style:t.options.drawPoints.style,styles:t.options.drawPoints.styles,size:t.options.drawPoints.size/h,className:t.className};wb(e+.5*l+d,i+s-u-1,p,o.svgElements,o.svg),wb(e+1.5*l+d+2,i+s-c-1,p,o.svgElements,o.svg)}},gI.draw=function(t,e,i){var n,r,o,s,a,l,h=[],u={},c=0;for(a=0;a<t.length;a++)if("bar"===(s=i.groups[t[a]]).options.style&&!0===s.visible&&(void 0===i.options.groups.visibility[t[a]]||!0===i.options.groups.visibility[t[a]]))for(l=0;l<e[t[a]].length;l++)h.push({screen_x:e[t[a]][l].screen_x,screen_end:e[t[a]][l].screen_end,screen_y:e[t[a]][l].screen_y,x:e[t[a]][l].x,end:e[t[a]][l].end,y:e[t[a]][l].y,groupId:t[a],label:e[t[a]][l].label}),c+=1;if(0!==c)for(RC(h).call(h,(function(t,e){return t.screen_x===e.screen_x?t.groupId<e.groupId?-1:1:t.screen_x-e.screen_x})),gI._getDataIntersections(u,h),a=0;a<h.length;a++){var d=null!=(s=i.groups[h[a].groupId]).options.barChart.minWidth?s.options.barChart.minWidth:.1*s.options.barChart.width,p=0;if(void 0===u[r=h[a].screen_x])a+1<h.length&&(n=Math.abs(h[a+1].screen_x-r)),o=gI._getSafeDrawData(n,s,d);else{var f=a+(u[r].amount-u[r].resolved);f<h.length&&(n=Math.abs(h[f].screen_x-r)),o=gI._getSafeDrawData(n,s,d),u[r].resolved+=1,!0===s.options.stack&&!0!==s.options.excludeFromStacking?h[a].screen_y<s.zeroPosition?(p=u[r].accumulatedNegative,u[r].accumulatedNegative+=s.zeroPosition-h[a].screen_y):(p=u[r].accumulatedPositive,u[r].accumulatedPositive+=s.zeroPosition-h[a].screen_y):!0===s.options.barChart.sideBySide&&(o.width=o.width/u[r].amount,o.offset+=u[r].resolved*o.width-.5*o.width*(u[r].amount+1))}var m=o.width,v=h[a].screen_x;if(null!=h[a].screen_end?v+=.5*(m=h[a].screen_end-h[a].screen_x):v+=o.offset,kb(v,h[a].screen_y-p,m,s.zeroPosition-h[a].screen_y,s.className+" vis-bar",i.svgElements,i.svg,s.style),!0===s.options.drawPoints.enabled){var g={screen_x:h[a].screen_x,screen_y:h[a].screen_y-p,x:h[a].x,y:h[a].y,groupId:h[a].groupId,label:h[a].label};mI.draw([g],s,i,o.offset)}}},gI._getDataIntersections=function(t,e){for(var i,n=0;n<e.length;n++)n+1<e.length&&(i=Math.abs(e[n+1].screen_x-e[n].screen_x)),n>0&&(i=Math.min(i,Math.abs(e[n-1].screen_x-e[n].screen_x))),0===i&&(void 0===t[e[n].screen_x]&&(t[e[n].screen_x]={amount:0,resolved:0,accumulatedPositive:0,accumulatedNegative:0}),t[e[n].screen_x].amount+=1)},gI._getSafeDrawData=function(t,e,i){var n,r;return t<e.options.barChart.width&&t>0?(n=t<i?i:t,r=0,"left"===e.options.barChart.align?r-=.5*t:"right"===e.options.barChart.align&&(r+=.5*t)):(n=e.options.barChart.width,r=0,"left"===e.options.barChart.align?r-=.5*e.options.barChart.width:"right"===e.options.barChart.align&&(r+=.5*e.options.barChart.width)),{width:n,offset:r}},gI.getStackedYRange=function(t,e,i,n,r){if(t.length>0){RC(t).call(t,(function(t,e){return t.screen_x===e.screen_x?t.groupId<e.groupId?-1:1:t.screen_x-e.screen_x}));var o={};gI._getDataIntersections(o,t),e[n]=gI._getStackedYRange(o,t),e[n].yAxisOrientation=r,i.push(n)}},gI._getStackedYRange=function(t,e){for(var i,n=e[0].screen_y,r=e[0].screen_y,o=0;o<e.length;o++)void 0===t[i=e[o].screen_x]?(n=n>e[o].screen_y?e[o].screen_y:n,r=r<e[o].screen_y?e[o].screen_y:r):e[o].screen_y<0?t[i].accumulatedNegative+=e[o].screen_y:t[i].accumulatedPositive+=e[o].screen_y;for(var s in t)t.hasOwnProperty(s)&&(n=(n=n>t[s].accumulatedNegative?t[s].accumulatedNegative:n)>t[s].accumulatedPositive?t[s].accumulatedPositive:n,r=(r=r<t[s].accumulatedNegative?t[s].accumulatedNegative:r)<t[s].accumulatedPositive?t[s].accumulatedPositive:r);return{min:n,max:r}},yI.calcPath=function(t,e){if(null!=t&&t.length>0)return 1==e.options.interpolation.enabled?yI._catmullRom(t,e):yI._linear(t)},yI.drawIcon=function(t,e,i,n,r,o){var s,a,l=.5*r,h=bb("rect",o.svgElements,o.svg);h.setAttributeNS(null,"x",e),h.setAttributeNS(null,"y",i-l),h.setAttributeNS(null,"width",n),h.setAttributeNS(null,"height",2*l),h.setAttributeNS(null,"class","vis-outline"),(s=bb("path",o.svgElements,o.svg)).setAttributeNS(null,"class",t.className),void 0!==t.style&&s.setAttributeNS(null,"style",t.style),s.setAttributeNS(null,"d","M"+e+","+i+" L"+(e+n)+","+i),1==t.options.shaded.enabled&&(a=bb("path",o.svgElements,o.svg),"top"==t.options.shaded.orientation?a.setAttributeNS(null,"d","M"+e+", "+(i-l)+"L"+e+","+i+" L"+(e+n)+","+i+" L"+(e+n)+","+(i-l)):a.setAttributeNS(null,"d","M"+e+","+i+" L"+e+","+(i+l)+" L"+(e+n)+","+(i+l)+"L"+(e+n)+","+i),a.setAttributeNS(null,"class",t.className+" vis-icon-fill"),void 0!==t.options.shaded.style&&""!==t.options.shaded.style&&a.setAttributeNS(null,"style",t.options.shaded.style)),1==t.options.drawPoints.enabled&&wb(e+.5*n,i,{style:t.options.drawPoints.style,styles:t.options.drawPoints.styles,size:t.options.drawPoints.size,className:t.className},o.svgElements,o.svg)},yI.drawShading=function(t,e,i,n){if(1==e.options.shaded.enabled){var r,o=Number(n.svg.style.height.replace("px","")),s=bb("path",n.svgElements,n.svg),a="L";1==e.options.interpolation.enabled&&(a="C");var l;l="top"==e.options.shaded.orientation?0:"bottom"==e.options.shaded.orientation?o:Math.min(Math.max(0,e.zeroPosition),o),r="group"==e.options.shaded.orientation&&null!=i&&null!=i?"M"+t[0][0]+","+t[0][1]+" "+this.serializePath(t,a,!1)+" L"+i[i.length-1][0]+","+i[i.length-1][1]+" "+this.serializePath(i,a,!0)+i[0][0]+","+i[0][1]+" Z":"M"+t[0][0]+","+t[0][1]+" "+this.serializePath(t,a,!1)+" V"+l+" H"+t[0][0]+" Z",s.setAttributeNS(null,"class",e.className+" vis-fill"),void 0!==e.options.shaded.style&&s.setAttributeNS(null,"style",e.options.shaded.style),s.setAttributeNS(null,"d",r)}},yI.draw=function(t,e,i){if(null!=t&&null!=t){var n=bb("path",i.svgElements,i.svg);n.setAttributeNS(null,"class",e.className),void 0!==e.style&&n.setAttributeNS(null,"style",e.style);var r="L";1==e.options.interpolation.enabled&&(r="C"),n.setAttributeNS(null,"d","M"+t[0][0]+","+t[0][1]+" "+this.serializePath(t,r,!1))}},yI.serializePath=function(t,e,i){if(t.length<2)return"";var n,r=e;if(i)for(n=t.length-2;n>0;n--)r+=t[n][0]+","+t[n][1]+" ";else for(n=1;n<t.length;n++)r+=t[n][0]+","+t[n][1]+" ";return r},yI._catmullRomUniform=function(t){var e,i,n,r,o,s,a=[];a.push([Math.round(t[0].screen_x),Math.round(t[0].screen_y)]);for(var l=1/6,h=t.length,u=0;u<h-1;u++)e=0==u?t[0]:t[u-1],i=t[u],n=t[u+1],r=u+2<h?t[u+2]:n,o={screen_x:(-e.screen_x+6*i.screen_x+n.screen_x)*l,screen_y:(-e.screen_y+6*i.screen_y+n.screen_y)*l},s={screen_x:(i.screen_x+6*n.screen_x-r.screen_x)*l,screen_y:(i.screen_y+6*n.screen_y-r.screen_y)*l},a.push([o.screen_x,o.screen_y]),a.push([s.screen_x,s.screen_y]),a.push([n.screen_x,n.screen_y]);return a},yI._catmullRom=function(t,e){var i=e.options.interpolation.alpha;if(0==i||void 0===i)return this._catmullRomUniform(t);var n,r,o,s,a,l,h,u,c,d,p,f,m,v,g,y,b,_,w,k=[];k.push([Math.round(t[0].screen_x),Math.round(t[0].screen_y)]);for(var x=t.length,S=0;S<x-1;S++)n=0==S?t[0]:t[S-1],r=t[S],o=t[S+1],s=S+2<x?t[S+2]:o,h=Math.sqrt(Math.pow(n.screen_x-r.screen_x,2)+Math.pow(n.screen_y-r.screen_y,2)),u=Math.sqrt(Math.pow(r.screen_x-o.screen_x,2)+Math.pow(r.screen_y-o.screen_y,2)),c=Math.sqrt(Math.pow(o.screen_x-s.screen_x,2)+Math.pow(o.screen_y-s.screen_y,2)),v=Math.pow(c,i),y=Math.pow(c,2*i),g=Math.pow(u,i),b=Math.pow(u,2*i),w=Math.pow(h,i),d=2*(_=Math.pow(h,2*i))+3*w*g+b,p=2*y+3*v*g+b,(f=3*w*(w+g))>0&&(f=1/f),(m=3*v*(v+g))>0&&(m=1/m),a={screen_x:(-b*n.screen_x+d*r.screen_x+_*o.screen_x)*f,screen_y:(-b*n.screen_y+d*r.screen_y+_*o.screen_y)*f},l={screen_x:(y*r.screen_x+p*o.screen_x-b*s.screen_x)*m,screen_y:(y*r.screen_y+p*o.screen_y-b*s.screen_y)*m},0==a.screen_x&&0==a.screen_y&&(a=r),0==l.screen_x&&0==l.screen_y&&(l=o),k.push([a.screen_x,a.screen_y]),k.push([l.screen_x,l.screen_y]),k.push([o.screen_x,o.screen_y]);return k},yI._linear=function(t){for(var e=[],i=0;i<t.length;i++)e.push([t[i].screen_x,t[i].screen_y]);return e},bI.prototype.setItems=function(t){null!=t?(this.itemsData=t,1==RC(this.options)&&EO.insertSort(this.itemsData,(function(t,e){return t.x>e.x?1:-1}))):this.itemsData=[]},bI.prototype.getItems=function(){return this.itemsData},bI.prototype.setZeroPosition=function(t){this.zeroPosition=t},bI.prototype.setOptions=function(t){void 0!==t&&(EO.selectiveDeepExtend(["sampling","style","sort","yAxisOrientation","barChart","zIndex","excludeFromStacking","excludeFromLegend"],this.options,t),"function"==typeof t.drawPoints&&(t.drawPoints={onRender:t.drawPoints}),EO.mergeOptions(this.options,t,"interpolation"),EO.mergeOptions(this.options,t,"drawPoints"),EO.mergeOptions(this.options,t,"shaded"),t.interpolation&&"object"==kc(t.interpolation)&&t.interpolation.parametrization&&("uniform"==t.interpolation.parametrization?this.options.interpolation.alpha=0:"chordal"==t.interpolation.parametrization?this.options.interpolation.alpha=1:(this.options.interpolation.parametrization="centripetal",this.options.interpolation.alpha=.5)))},bI.prototype.update=function(t){this.group=t,this.content=t.content||"graph",this.className=t.className||this.className||"vis-graph-group"+this.groupsUsingDefaultStyles[0]%10,this.visible=void 0===t.visible||t.visible,this.style=t.style,this.setOptions(t.options)},bI.prototype.getLegend=function(t,e,i,n,r){switch(null!=i&&null!=i||(i={svg:document.createElementNS("http://www.w3.org/2000/svg","svg"),svgElements:{},options:this.options,groups:[this]}),null!=n&&null!=n||(n=0),null!=r&&null!=r||(r=.5*e),this.options.style){case"line":yI.drawIcon(this,n,r,t,e,i);break;case"points":case"point":mI.drawIcon(this,n,r,t,e,i);break;case"bar":gI.drawIcon(this,n,r,t,e,i)}return{icon:i.svg,label:this.content,orientation:this.options.yAxisOrientation}},bI.prototype.getYRange=function(t){for(var e=t[0].y,i=t[0].y,n=0;n<t.length;n++)e=e>t[n].y?t[n].y:e,i=i<t[n].y?t[n].y:i;return{min:e,max:i,yAxisOrientation:this.options.yAxisOrientation}},_I.prototype=new GO,_I.prototype.clear=function(){this.groups={},this.amountOfGroups=0},_I.prototype.addGroup=function(t,e){1!=e.options.excludeFromLegend&&(this.groups.hasOwnProperty(t)||(this.groups[t]=e),this.amountOfGroups+=1)},_I.prototype.updateGroup=function(t,e){this.groups[t]=e},_I.prototype.removeGroup=function(t){this.groups.hasOwnProperty(t)&&(delete this.groups[t],this.amountOfGroups-=1)},_I.prototype._create=function(){this.dom.frame=document.createElement("div"),this.dom.frame.className="vis-legend",this.dom.frame.style.position="absolute",this.dom.frame.style.top="10px",this.dom.frame.style.display="block",this.dom.textArea=document.createElement("div"),this.dom.textArea.className="vis-legend-text",this.dom.textArea.style.position="relative",this.dom.textArea.style.top="0px",this.svg=document.createElementNS("http://www.w3.org/2000/svg","svg"),this.svg.style.position="absolute",this.svg.style.top="0px",this.svg.style.width=this.options.iconSize+5+"px",this.svg.style.height="100%",this.dom.frame.appendChild(this.svg),this.dom.frame.appendChild(this.dom.textArea)},_I.prototype.hide=function(){this.dom.frame.parentNode&&this.dom.frame.parentNode.removeChild(this.dom.frame)},_I.prototype.show=function(){this.dom.frame.parentNode||this.body.dom.center.appendChild(this.dom.frame)},_I.prototype.setOptions=function(t){EO.selectiveDeepExtend(["enabled","orientation","icons","left","right"],this.options,t)},_I.prototype.redraw=function(){var t=0,e=Bd(this.groups);RC(e).call(e,(function(t,e){return t<e?-1:1}));for(var i=0;i<e.length;i++){var n=e[i];1!=this.groups[n].visible||void 0!==this.linegraphOptions.visibility[n]&&1!=this.linegraphOptions.visibility[n]||t++}if(0==this.options[this.side].visible||0==this.amountOfGroups||0==this.options.enabled||0==t)this.hide();else{if(this.show(),"top-left"==this.options[this.side].position||"bottom-left"==this.options[this.side].position?(this.dom.frame.style.left="4px",this.dom.frame.style.textAlign="left",this.dom.textArea.style.textAlign="left",this.dom.textArea.style.left=this.options.iconSize+15+"px",this.dom.textArea.style.right="",this.svg.style.left="0px",this.svg.style.right=""):(this.dom.frame.style.right="4px",this.dom.frame.style.textAlign="right",this.dom.textArea.style.textAlign="right",this.dom.textArea.style.right=this.options.iconSize+15+"px",this.dom.textArea.style.left="",this.svg.style.right="0px",this.svg.style.left=""),"top-left"==this.options[this.side].position||"top-right"==this.options[this.side].position)this.dom.frame.style.top=4-Number(this.body.dom.center.style.top.replace("px",""))+"px",this.dom.frame.style.bottom="";else{var r=this.body.domProps.center.height-this.body.domProps.centerContainer.height;this.dom.frame.style.bottom=4+r+Number(this.body.dom.center.style.top.replace("px",""))+"px",this.dom.frame.style.top=""}0==this.options.icons?(this.dom.frame.style.width=this.dom.textArea.offsetWidth+10+"px",this.dom.textArea.style.right="",this.dom.textArea.style.left="",this.svg.style.width="0px"):(this.dom.frame.style.width=this.options.iconSize+15+this.dom.textArea.offsetWidth+10+"px",this.drawLegendIcons());var o="";for(i=0;i<e.length;i++)n=e[i],1!=this.groups[n].visible||void 0!==this.linegraphOptions.visibility[n]&&1!=this.linegraphOptions.visibility[n]||(o+=this.groups[n].content+"<br />");this.dom.textArea.innerHTML=EO.xss(o),this.dom.textArea.style.lineHeight=.75*this.options.iconSize+this.options.iconSpacing+"px"}},_I.prototype.drawLegendIcons=function(){if(this.dom.frame.parentNode){var t=Bd(this.groups);RC(t).call(t,(function(t,e){return t<e?-1:1})),yb(this.svgElements);var e=window.getComputedStyle(this.dom.frame).paddingTop,i=Number(e.replace("px","")),n=i,r=this.options.iconSize,o=.75*this.options.iconSize,s=i+.5*o+3;this.svg.style.width=r+5+i+"px";for(var a=0;a<t.length;a++){var l=t[a];1!=this.groups[l].visible||void 0!==this.linegraphOptions.visibility[l]&&1!=this.linegraphOptions.visibility[l]||(this.groups[l].getLegend(r,o,this.framework,n,s),s+=o+this.options.iconSpacing)}}};var wI="__ungrouped__";function kI(t,e){this.id=nM(),this.body=t,this.defaultOptions={yAxisOrientation:"left",defaultGroup:"default",sort:!0,sampling:!0,stack:!1,graphHeight:"400px",shaded:{enabled:!1,orientation:"bottom"},style:"line",barChart:{width:50,sideBySide:!1,align:"center"},interpolation:{enabled:!0,parametrization:"centripetal",alpha:.5},drawPoints:{enabled:!0,size:6,style:"square"},dataAxis:{},legend:{},groups:{visibility:{}}},this.options=EO.extend({},this.defaultOptions),this.dom={},this.props={},this.hammer=null,this.groups={},this.abortedGraphUpdate=!1,this.updateSVGheight=!1,this.updateSVGheightOnResize=!1,this.forceGraphUpdate=!0;var i=this;this.itemsData=null,this.groupsData=null,this.itemListeners={add:function(t,e,n){i._onAdd(e.items)},update:function(t,e,n){i._onUpdate(e.items)},remove:function(t,e,n){i._onRemove(e.items)}},this.groupListeners={add:function(t,e,n){i._onAddGroups(e.items)},update:function(t,e,n){i._onUpdateGroups(e.items)},remove:function(t,e,n){i._onRemoveGroups(e.items)}},this.items={},this.selection=[],this.lastStart=this.body.range.start,this.touchParams={},this.svgElements={},this.setOptions(e),this.groupsUsingDefaultStyles=[0],this.body.emitter.on("rangechanged",(function(){i.svg.style.left=EO.option.asSize(-i.props.width),i.forceGraphUpdate=!0,i.redraw.call(i)})),this._create(),this.framework={svg:this.svg,svgElements:this.svgElements,options:this.options,groups:this.groups}}kI.prototype=new GO,kI.prototype._create=function(){var t=document.createElement("div");t.className="vis-line-graph",this.dom.frame=t,this.svg=document.createElementNS("http://www.w3.org/2000/svg","svg"),this.svg.style.position="relative",this.svg.style.height=(""+this.options.graphHeight).replace("px","")+"px",this.svg.style.display="block",t.appendChild(this.svg),this.options.dataAxis.orientation="left",this.yAxisLeft=new fI(this.body,this.options.dataAxis,this.svg,this.options.groups),this.options.dataAxis.orientation="right",this.yAxisRight=new fI(this.body,this.options.dataAxis,this.svg,this.options.groups),delete this.options.dataAxis.orientation,this.legendLeft=new _I(this.body,this.options.legend,"left",this.options.groups),this.legendRight=new _I(this.body,this.options.legend,"right",this.options.groups),this.show()},kI.prototype.setOptions=function(t){t&&(void 0===t.graphHeight&&void 0!==t.height?(this.updateSVGheight=!0,this.updateSVGheightOnResize=!0):void 0!==this.body.domProps.centerContainer.height&&void 0!==t.graphHeight&&Cm((t.graphHeight+"").replace("px",""))<this.body.domProps.centerContainer.height&&(this.updateSVGheight=!0),EO.selectiveDeepExtend(["sampling","defaultGroup","stack","height","graphHeight","yAxisOrientation","style","barChart","dataAxis","sort","groups"],this.options,t),EO.mergeOptions(this.options,t,"interpolation"),EO.mergeOptions(this.options,t,"drawPoints"),EO.mergeOptions(this.options,t,"shaded"),EO.mergeOptions(this.options,t,"legend"),t.interpolation&&"object"==kc(t.interpolation)&&t.interpolation.parametrization&&("uniform"==t.interpolation.parametrization?this.options.interpolation.alpha=0:"chordal"==t.interpolation.parametrization?this.options.interpolation.alpha=1:(this.options.interpolation.parametrization="centripetal",this.options.interpolation.alpha=.5)),this.yAxisLeft&&void 0!==t.dataAxis&&(this.yAxisLeft.setOptions(this.options.dataAxis),this.yAxisRight.setOptions(this.options.dataAxis)),this.legendLeft&&void 0!==t.legend&&(this.legendLeft.setOptions(this.options.legend),this.legendRight.setOptions(this.options.legend)),this.groups.hasOwnProperty(wI)&&this.groups[wI].setOptions(t)),this.dom.frame&&(this.forceGraphUpdate=!0,this.body.emitter.emit("_change",{queue:!0}))},kI.prototype.hide=function(){this.dom.frame.parentNode&&this.dom.frame.parentNode.removeChild(this.dom.frame)},kI.prototype.show=function(){this.dom.frame.parentNode||this.body.dom.center.appendChild(this.dom.frame)},kI.prototype.setItems=function(t){var e,i=this,n=this.itemsData;if(t){if(!xO(t))throw new TypeError("Data must implement the interface of DataSet or DataView");this.itemsData=TO(t)}else this.itemsData=null;if(n&&(kp(EO).call(EO,this.itemListeners,(function(t,e){n.off(e,t)})),n.dispose(),e=n.getIds(),this._onRemove(e)),this.itemsData){var r=this.id;kp(EO).call(EO,this.itemListeners,(function(t,e){i.itemsData.on(e,t,r)})),e=this.itemsData.getIds(),this._onAdd(e)}},kI.prototype.setGroups=function(t){var e,i=this;if(this.groupsData){kp(EO).call(EO,this.groupListeners,(function(t,e){i.groupsData.off(e,t)})),e=this.groupsData.getIds(),this.groupsData=null;for(var n=0;n<e.length;n++)this._removeGroup(e[n])}if(t){if(!xO(t))throw new TypeError("Data must implement the interface of DataSet or DataView");this.groupsData=t}else this.groupsData=null;if(this.groupsData){var r=this.id;kp(EO).call(EO,this.groupListeners,(function(t,e){i.groupsData.on(e,t,r)})),e=this.groupsData.getIds(),this._onAddGroups(e)}},kI.prototype._onUpdate=function(t){this._updateAllGroupData(t)},kI.prototype._onAdd=function(t){this._onUpdate(t)},kI.prototype._onRemove=function(t){this._onUpdate(t)},kI.prototype._onUpdateGroups=function(t){this._updateAllGroupData(null,t)},kI.prototype._onAddGroups=function(t){this._onUpdateGroups(t)},kI.prototype._onRemoveGroups=function(t){for(var e=0;e<t.length;e++)this._removeGroup(t[e]);this.forceGraphUpdate=!0,this.body.emitter.emit("_change",{queue:!0})},kI.prototype._removeGroup=function(t){this.groups.hasOwnProperty(t)&&("right"==this.groups[t].options.yAxisOrientation?(this.yAxisRight.removeGroup(t),this.legendRight.removeGroup(t),this.legendRight.redraw()):(this.yAxisLeft.removeGroup(t),this.legendLeft.removeGroup(t),this.legendLeft.redraw()),delete this.groups[t])},kI.prototype._updateGroup=function(t,e){this.groups.hasOwnProperty(e)?(this.groups[e].update(t),"right"==this.groups[e].options.yAxisOrientation?(this.yAxisRight.updateGroup(e,this.groups[e]),this.legendRight.updateGroup(e,this.groups[e]),this.yAxisLeft.removeGroup(e),this.legendLeft.removeGroup(e)):(this.yAxisLeft.updateGroup(e,this.groups[e]),this.legendLeft.updateGroup(e,this.groups[e]),this.yAxisRight.removeGroup(e),this.legendRight.removeGroup(e))):(this.groups[e]=new bI(t,e,this.options,this.groupsUsingDefaultStyles),"right"==this.groups[e].options.yAxisOrientation?(this.yAxisRight.addGroup(e,this.groups[e]),this.legendRight.addGroup(e,this.groups[e])):(this.yAxisLeft.addGroup(e,this.groups[e]),this.legendLeft.addGroup(e,this.groups[e]))),this.legendLeft.redraw(),this.legendRight.redraw()},kI.prototype._updateAllGroupData=function(t,e){if(null!=this.itemsData){var i={},n=this.itemsData.get(),r=this.itemsData.idProp,o={};t&&jd(t).call(t,(function(t){o[t]=t}));for(var s={},a=0;a<n.length;a++){var l=n[a],h=l.group;null==h&&(h=wI),s.hasOwnProperty(h)?s[h]++:s[h]=1}var u={};if(!e&&t)for(h in this.groups)if(this.groups.hasOwnProperty(h)){var c=(m=this.groups[h]).getItems();i[h]=Vf(c).call(c,(function(t){return u[t[r]]=t[r],t[r]!==o[t[r]]}));var d=s[h];s[h]-=i[h].length,i[h].length<d&&(i[h][d-1]={})}for(a=0;a<n.length;a++)if(null==(h=(l=n[a]).group)&&(h=wI),e||!t||l[r]===o[l[r]]||!u.hasOwnProperty(l[r])){i.hasOwnProperty(h)||(i[h]=new Array(s[h]));var p=EO.bridgeObject(l);p.x=EO.convert(l.x,"Date"),p.end=EO.convert(l.end,"Date"),p.orginalY=l.y,p.y=Number(l.y),p[r]=l[r];var f=i[h].length-s[h]--;i[h][f]=p}for(h in this.groups)this.groups.hasOwnProperty(h)&&(i.hasOwnProperty(h)||(i[h]=new Array(0)));for(h in i)if(i.hasOwnProperty(h))if(0==i[h].length)this.groups.hasOwnProperty(h)&&this._removeGroup(h);else{var m=void 0;null!=this.groupsData&&(m=this.groupsData.get(h)),null==m&&(m={id:h,content:this.options.defaultGroup+h}),this._updateGroup(m,h),this.groups[h].setItems(i[h])}this.forceGraphUpdate=!0,this.body.emitter.emit("_change",{queue:!0})}},kI.prototype.redraw=function(){var t=!1;this.props.width=this.dom.frame.offsetWidth,this.props.height=this.body.domProps.centerContainer.height-this.body.domProps.border.top-this.body.domProps.border.bottom,t=this._isResized()||t;var e,i=this.body.range.end-this.body.range.start,n=i!=this.lastVisibleInterval;if(this.lastVisibleInterval=i,1==t&&(this.svg.style.width=EO.option.asSize(3*this.props.width),this.svg.style.left=EO.option.asSize(-this.props.width),-1==Rm(e=this.options.height+"").call(e,"%")&&1!=this.updateSVGheightOnResize||(this.updateSVGheight=!0)),1==this.updateSVGheight?(this.options.graphHeight!=this.props.height+"px"&&(this.options.graphHeight=this.props.height+"px",this.svg.style.height=this.props.height+"px"),this.updateSVGheight=!1):this.svg.style.height=(""+this.options.graphHeight).replace("px","")+"px",1==t||1==n||1==this.abortedGraphUpdate||1==this.forceGraphUpdate)t=this._updateGraph()||t,this.forceGraphUpdate=!1,this.lastStart=this.body.range.start,this.svg.style.left=-this.props.width+"px";else if(0!=this.lastStart){var r=this.body.range.start-this.lastStart,o=this.body.range.end-this.body.range.start;if(0!=this.props.width){var s=r*(this.props.width/o);this.svg.style.left=-this.props.width-s+"px"}}return this.legendLeft.redraw(),this.legendRight.redraw(),t},kI.prototype._getSortedGroupIds=function(){var t=[];for(var e in this.groups)if(this.groups.hasOwnProperty(e)){var i=this.groups[e];1!=i.visible||void 0!==this.options.groups.visibility[e]&&1!=this.options.groups.visibility[e]||t.push({id:e,zIndex:i.options.zIndex})}EO.insertSort(t,(function(t,e){var i=t.zIndex,n=e.zIndex;return void 0===i&&(i=0),void 0===n&&(n=0),i==n?0:i<n?-1:1}));for(var n=new Array(t.length),r=0;r<t.length;r++)n[r]=t[r].id;return n},kI.prototype._updateGraph=function(){if(vb(this.svgElements),0!=this.props.width&&null!=this.itemsData){var t,e,i={},n=this.body.util.toGlobalTime(-this.body.domProps.root.width),r=this.body.util.toGlobalTime(2*this.body.domProps.root.width),o=this._getSortedGroupIds();if(o.length>0){var s={};for(this._getRelevantData(o,s,n,r),this._applySampling(o,s),e=0;e<o.length;e++)this._convertXcoordinates(s[o[e]]);if(this._getYRanges(o,s,i),1==this._updateYAxis(o,i))return gb(this.svgElements),this.abortedGraphUpdate=!0,!0;this.abortedGraphUpdate=!1;var a=void 0;for(e=0;e<o.length;e++)t=this.groups[o[e]],!0===this.options.stack&&"line"===this.options.style&&(null!=t.options.excludeFromStacking&&t.options.excludeFromStacking||(null!=a&&(this._stack(s[t.id],s[a.id]),1==t.options.shaded.enabled&&"group"!==t.options.shaded.orientation&&("top"==t.options.shaded.orientation&&"group"!==a.options.shaded.orientation?(a.options.shaded.orientation="group",a.options.shaded.groupId=t.id):(t.options.shaded.orientation="group",t.options.shaded.groupId=a.id))),a=t)),this._convertYcoordinates(s[o[e]],t);var l={};for(e=0;e<o.length;e++)if("line"===(t=this.groups[o[e]]).options.style&&1==t.options.shaded.enabled){var h=s[o[e]];if(null==h||0==h.length)continue;if(l.hasOwnProperty(o[e])||(l[o[e]]=yI.calcPath(h,t)),"group"===t.options.shaded.orientation){var u=t.options.shaded.groupId;if(-1===Rm(o).call(o,u)){console.log(t.id+": Unknown shading group target given:"+u);continue}l.hasOwnProperty(u)||(l[u]=yI.calcPath(s[u],this.groups[u])),yI.drawShading(l[o[e]],t,l[u],this.framework)}else yI.drawShading(l[o[e]],t,void 0,this.framework)}for(gI.draw(o,s,this.framework),e=0;e<o.length;e++)if(t=this.groups[o[e]],s[o[e]].length>0)switch(t.options.style){case"line":l.hasOwnProperty(o[e])||(l[o[e]]=yI.calcPath(s[o[e]],t)),yI.draw(l[o[e]],t,this.framework);case"point":case"points":"point"!=t.options.style&&"points"!=t.options.style&&1!=t.options.drawPoints.enabled||mI.draw(s[o[e]],t,this.framework)}}}return gb(this.svgElements),!1},kI.prototype._stack=function(t,e){var i,n,r,o,s;i=0;for(var a=0;a<t.length;a++){o=void 0,s=void 0;for(var l=i;l<e.length;l++){if(e[l].x===t[a].x){o=e[l],s=e[l],i=l;break}if(e[l].x>t[a].x){s=e[l],o=0==l?s:e[l-1],i=l;break}}void 0===s&&(o=e[e.length-1],s=e[e.length-1]),n=s.x-o.x,r=s.y-o.y,t[a].y=0==n?t[a].orginalY+s.y:t[a].orginalY+r/n*(t[a].x-o.x)+o.y}},kI.prototype._getRelevantData=function(t,e,i,n){var r,o,s,a;if(t.length>0)for(o=0;o<t.length;o++){var l=(r=this.groups[t[o]]).getItems();if(1==RC(r.options)){var h=function(t,e){return t.getTime()==e.getTime()?0:t<e?-1:1},u=Math.max(0,EO.binarySearchValue(l,i,"x","before",h)),c=Math.min(l.length,EO.binarySearchValue(l,n,"x","after",h)+1);c<=0&&(c=l.length);var d=new Array(c-u);for(s=u;s<c;s++)a=r.itemsData[s],d[s-u]=a;e[t[o]]=d}else e[t[o]]=r.itemsData}},kI.prototype._applySampling=function(t,e){if(t.length>0)for(var i=0;i<t.length;i++)if(1==this.groups[t[i]].options.sampling){var n=e[t[i]];if(n.length>0){var r,o=n.length,s=o/(this.body.util.toGlobalScreen(n[n.length-1].x)-this.body.util.toGlobalScreen(n[0].x));r=Math.min(Math.ceil(.2*o),Math.max(1,Math.round(s)));for(var a=new Array(o),l=0;l<o;l+=r)a[Math.round(l/r)]=n[l];e[t[i]]=Qp(a).call(a,0,Math.round(o/r))}}},kI.prototype._getYRanges=function(t,e,i){var n,r,o,s,a=[],l=[];if(t.length>0){for(o=0;o<t.length;o++)n=e[t[o]],s=this.groups[t[o]].options,n.length>0&&(r=this.groups[t[o]],!0===s.stack&&"bar"===s.style?"left"===s.yAxisOrientation?a=xd(a).call(a,n):l=xd(l).call(l,n):i[t[o]]=r.getYRange(n,t[o]));gI.getStackedYRange(a,i,t,"__barStackLeft","left"),gI.getStackedYRange(l,i,t,"__barStackRight","right")}},kI.prototype._updateYAxis=function(t,e){var i,n,r=!1,o=!1,s=!1,a=1e9,l=1e9,h=-1e9,u=-1e9;if(t.length>0){for(var c=0;c<t.length;c++){var d=this.groups[t[c]];d&&"right"!=d.options.yAxisOrientation?(o=!0,a=1e9,h=-1e9):d&&d.options.yAxisOrientation&&(s=!0,l=1e9,u=-1e9)}for(c=0;c<t.length;c++)e.hasOwnProperty(t[c])&&!0!==e[t[c]].ignore&&(i=e[t[c]].min,n=e[t[c]].max,"right"!=e[t[c]].yAxisOrientation?(o=!0,a=a>i?i:a,h=h<n?n:h):(s=!0,l=l>i?i:l,u=u<n?n:u));1==o&&this.yAxisLeft.setRange(a,h),1==s&&this.yAxisRight.setRange(l,u)}r=this._toggleAxisVisiblity(o,this.yAxisLeft)||r,r=this._toggleAxisVisiblity(s,this.yAxisRight)||r,1==s&&1==o?(this.yAxisLeft.drawIcons=!0,this.yAxisRight.drawIcons=!0):(this.yAxisLeft.drawIcons=!1,this.yAxisRight.drawIcons=!1),this.yAxisRight.master=!o,this.yAxisRight.masterAxis=this.yAxisLeft,0==this.yAxisRight.master?(this.yAxisLeft.lineOffset=1==s?this.yAxisRight.width:0,r=this.yAxisLeft.redraw()||r,r=this.yAxisRight.redraw()||r):r=this.yAxisRight.redraw()||r;var p=["__barStackLeft","__barStackRight","__lineStackLeft","__lineStackRight"];for(c=0;c<p.length;c++)-1!=Rm(t).call(t,p[c])&&Qp(t).call(t,Rm(t).call(t,p[c]),1);return r},kI.prototype._toggleAxisVisiblity=function(t,e){var i=!1;return 0==t?e.dom.frame.parentNode&&0==e.hidden&&(e.hide(),i=!0):e.dom.frame.parentNode||1!=e.hidden||(e.show(),i=!0),i},kI.prototype._convertXcoordinates=function(t){for(var e=this.body.util.toScreen,i=0;i<t.length;i++)t[i].screen_x=e(t[i].x)+this.props.width,t[i].screen_y=t[i].y,null!=t[i].end?t[i].screen_end=e(t[i].end)+this.props.width:t[i].screen_end=void 0},kI.prototype._convertYcoordinates=function(t,e){var i=this.yAxisLeft,n=Number(this.svg.style.height.replace("px",""));"right"==e.options.yAxisOrientation&&(i=this.yAxisRight);for(var r=0;r<t.length;r++)t[r].screen_y=Math.round(i.convertValue(t[r].y));e.setZeroPosition(Math.min(n,i.convertValue(0)))};var xI="string",SI="boolean",DI="number",CI="date",TI="object",MI="moment",OI={configure:{enabled:{boolean:SI},filter:{boolean:SI,function:"function"},container:{dom:"dom"},__type__:{object:TI,boolean:SI,function:"function"}},alignCurrentTime:{string:xI,undefined:"undefined"},yAxisOrientation:{string:["left","right"]},defaultGroup:{string:xI},sort:{boolean:SI},sampling:{boolean:SI},stack:{boolean:SI},graphHeight:{string:xI,number:DI},shaded:{enabled:{boolean:SI},orientation:{string:["bottom","top","zero","group"]},groupId:{object:TI},__type__:{boolean:SI,object:TI}},style:{string:["line","bar","points"]},barChart:{width:{number:DI},minWidth:{number:DI},sideBySide:{boolean:SI},align:{string:["left","center","right"]},__type__:{object:TI}},interpolation:{enabled:{boolean:SI},parametrization:{string:["centripetal","chordal","uniform"]},alpha:{number:DI},__type__:{object:TI,boolean:SI}},drawPoints:{enabled:{boolean:SI},onRender:{function:"function"},size:{number:DI},style:{string:["square","circle"]},__type__:{object:TI,boolean:SI,function:"function"}},dataAxis:{showMinorLabels:{boolean:SI},showMajorLabels:{boolean:SI},showWeekScale:{boolean:SI},icons:{boolean:SI},width:{string:xI,number:DI},visible:{boolean:SI},alignZeros:{boolean:SI},left:{range:{min:{number:DI,undefined:"undefined"},max:{number:DI,undefined:"undefined"},__type__:{object:TI}},format:{function:"function"},title:{text:{string:xI,number:DI,undefined:"undefined"},style:{string:xI,undefined:"undefined"},__type__:{object:TI}},__type__:{object:TI}},right:{range:{min:{number:DI,undefined:"undefined"},max:{number:DI,undefined:"undefined"},__type__:{object:TI}},format:{function:"function"},title:{text:{string:xI,number:DI,undefined:"undefined"},style:{string:xI,undefined:"undefined"},__type__:{object:TI}},__type__:{object:TI}},__type__:{object:TI}},legend:{enabled:{boolean:SI},icons:{boolean:SI},left:{visible:{boolean:SI},position:{string:["top-right","bottom-right","top-left","bottom-left"]},__type__:{object:TI}},right:{visible:{boolean:SI},position:{string:["top-right","bottom-right","top-left","bottom-left"]},__type__:{object:TI}},__type__:{object:TI,boolean:SI}},groups:{visibility:{any:"any"},__type__:{object:TI}},autoResize:{boolean:SI},throttleRedraw:{number:DI},clickToUse:{boolean:SI},end:{number:DI,date:CI,string:xI,moment:MI},format:{minorLabels:{millisecond:{string:xI,undefined:"undefined"},second:{string:xI,undefined:"undefined"},minute:{string:xI,undefined:"undefined"},hour:{string:xI,undefined:"undefined"},weekday:{string:xI,undefined:"undefined"},day:{string:xI,undefined:"undefined"},week:{string:xI,undefined:"undefined"},month:{string:xI,undefined:"undefined"},quarter:{string:xI,undefined:"undefined"},year:{string:xI,undefined:"undefined"},__type__:{object:TI}},majorLabels:{millisecond:{string:xI,undefined:"undefined"},second:{string:xI,undefined:"undefined"},minute:{string:xI,undefined:"undefined"},hour:{string:xI,undefined:"undefined"},weekday:{string:xI,undefined:"undefined"},day:{string:xI,undefined:"undefined"},week:{string:xI,undefined:"undefined"},month:{string:xI,undefined:"undefined"},quarter:{string:xI,undefined:"undefined"},year:{string:xI,undefined:"undefined"},__type__:{object:TI}},__type__:{object:TI}},moment:{function:"function"},height:{string:xI,number:DI},hiddenDates:{start:{date:CI,number:DI,string:xI,moment:MI},end:{date:CI,number:DI,string:xI,moment:MI},repeat:{string:xI},__type__:{object:TI,array:"array"}},locale:{string:xI},locales:{__any__:{any:"any"},__type__:{object:TI}},max:{date:CI,number:DI,string:xI,moment:MI},maxHeight:{number:DI,string:xI},maxMinorChars:{number:DI},min:{date:CI,number:DI,string:xI,moment:MI},minHeight:{number:DI,string:xI},moveable:{boolean:SI},multiselect:{boolean:SI},orientation:{string:xI},showCurrentTime:{boolean:SI},showMajorLabels:{boolean:SI},showMinorLabels:{boolean:SI},showWeekScale:{boolean:SI},snap:{function:"function",null:"null"},start:{date:CI,number:DI,string:xI,moment:MI},timeAxis:{scale:{string:xI,undefined:"undefined"},step:{number:DI,undefined:"undefined"},__type__:{object:TI}},width:{string:xI,number:DI},zoomable:{boolean:SI},zoomKey:{string:["ctrlKey","altKey","metaKey",""]},zoomMax:{number:DI},zoomMin:{number:DI},zIndex:{number:DI},__type__:{object:TI}},PI={global:{alignCurrentTime:["none","year","month","quarter","week","isoWeek","day","date","hour","minute","second"],sort:!0,sampling:!0,stack:!1,shaded:{enabled:!1,orientation:["zero","top","bottom","group"]},style:["line","bar","points"],barChart:{width:[50,5,100,5],minWidth:[50,5,100,5],sideBySide:!1,align:["left","center","right"]},interpolation:{enabled:!0,parametrization:["centripetal","chordal","uniform"]},drawPoints:{enabled:!0,size:[6,2,30,1],style:["square","circle"]},dataAxis:{showMinorLabels:!0,showMajorLabels:!0,showWeekScale:!1,icons:!1,width:[40,0,200,1],visible:!0,alignZeros:!0,left:{title:{text:"",style:""}},right:{title:{text:"",style:""}}},legend:{enabled:!1,icons:!0,left:{visible:!0,position:["top-right","bottom-right","top-left","bottom-left"]},right:{visible:!0,position:["top-right","bottom-right","top-left","bottom-left"]}},autoResize:!0,clickToUse:!1,end:"",format:{minorLabels:{millisecond:"SSS",second:"s",minute:"HH:mm",hour:"HH:mm",weekday:"ddd D",day:"D",week:"w",month:"MMM",quarter:"[Q]Q",year:"YYYY"},majorLabels:{millisecond:"HH:mm:ss",second:"D MMMM HH:mm",minute:"ddd D MMMM",hour:"ddd D MMMM",weekday:"MMMM YYYY",day:"MMMM YYYY",week:"MMMM YYYY",month:"YYYY",quarter:"YYYY",year:""}},height:"",locale:"",max:"",maxHeight:"",maxMinorChars:[7,0,20,1],min:"",minHeight:"",moveable:!0,orientation:["both","bottom","top"],showCurrentTime:!1,showMajorLabels:!0,showMinorLabels:!0,showWeekScale:!1,start:"",width:"100%",zoomable:!0,zoomKey:["ctrlKey","altKey","metaKey",""],zoomMax:[31536e10,10,31536e10,1],zoomMin:[10,10,31536e10,1],zIndex:0}};function EI(t,e,i,n){var r,o,s,a,l,h,u;if(!Id(i)&&!xO(i)&&i instanceof Object){var c=n;n=i,i=c}n&&n.throttleRedraw&&console.warn('Graph2d option "throttleRedraw" is DEPRICATED and no longer supported. It will be removed in the next MAJOR release.');var d=this;this.defaultOptions={start:null,end:null,autoResize:!0,orientation:{axis:"bottom",item:"bottom"},moment:gM,width:null,height:null,maxHeight:null,minHeight:null},this.options=EO.deepExtend({},this.defaultOptions),this._create(t),this.components=[],this.body={dom:this.dom,domProps:this.props,emitter:{on:hp(r=this.on).call(r,this),off:hp(o=this.off).call(o,this),emit:hp(s=this.emit).call(s,this)},hiddenDates:[],util:{getScale:function(){return d.timeAxis.step.scale},getStep:function(){return d.timeAxis.step.step},toScreen:hp(a=d._toScreen).call(a,d),toGlobalScreen:hp(l=d._toGlobalScreen).call(l,d),toTime:hp(h=d._toTime).call(h,d),toGlobalTime:hp(u=d._toGlobalTime).call(u,d)}},this.range=new pP(this.body),this.components.push(this.range),this.body.range=this.range,this.timeAxis=new kP(this.body),this.components.push(this.timeAxis),this.currentTime=new GP(this.body),this.components.push(this.currentTime),this.linegraph=new kI(this.body),this.components.push(this.linegraph),this.itemsData=null,this.groupsData=null,this.on("tap",(function(t){d.emit("click",d.getEventProperties(t))})),this.on("doubletap",(function(t){d.emit("doubleClick",d.getEventProperties(t))})),this.dom.root.oncontextmenu=function(t){d.emit("contextmenu",d.getEventProperties(t))},this.initialFitDone=!1,this.on("changed",(function(){if(null!=d.itemsData){if(!d.initialFitDone&&!d.options.rollingMode)if(d.initialFitDone=!0,null!=d.options.start||null!=d.options.end){if(null==d.options.start||null==d.options.end)var t=d.getItemRange();var e=null!=d.options.start?d.options.start:t.min,i=null!=d.options.end?d.options.end:t.max;d.setWindow(e,i,{animation:!1})}else d.fit({animation:!1});d.initialDrawDone||!d.initialRangeChangeDone&&(d.options.start||d.options.end)&&!d.options.rollingMode||(d.initialDrawDone=!0,d.dom.root.style.visibility="visible",d.dom.loadingScreen.parentNode.removeChild(d.dom.loadingScreen),d.options.onInitialDrawComplete&&uv((function(){return d.options.onInitialDrawComplete()}),0))}})),n&&this.setOptions(n),i&&this.setGroups(i),e&&this.setItems(e),this._redraw()}EI.prototype=new zP,EI.prototype.setOptions=function(t){!0===$E.validate(t,OI)&&console.log("%cErrors have been found in the supplied options object.",qE),zP.prototype.setOptions.call(this,t)},EI.prototype.setItems=function(t){var e,i=null==this.itemsData;if(e=t?xO(t)?TO(t):TO(new mM(t)):null,this.itemsData&&this.itemsData.dispose(),this.itemsData=e,this.linegraph&&this.linegraph.setItems(null!=e?e.rawDS:null),i)if(null!=this.options.start||null!=this.options.end){var n=null!=this.options.start?this.options.start:null,r=null!=this.options.end?this.options.end:null;this.setWindow(n,r,{animation:!1})}else this.fit({animation:!1})},EI.prototype.setGroups=function(t){var e;e=t?xO(t)?t:new mM(t):null,this.groupsData=e,this.linegraph.setGroups(e)},EI.prototype.getLegend=function(t,e,i){return void 0===e&&(e=15),void 0===i&&(i=15),void 0!==this.linegraph.groups[t]?this.linegraph.groups[t].getLegend(e,i):"cannot find group:'"+t+"'"},EI.prototype.isGroupVisible=function(t){return void 0!==this.linegraph.groups[t]&&this.linegraph.groups[t].visible&&(void 0===this.linegraph.options.groups.visibility[t]||1==this.linegraph.options.groups.visibility[t])},EI.prototype.getDataRange=function(){var t=null,e=null;for(var i in this.linegraph.groups)if(this.linegraph.groups.hasOwnProperty(i)&&1==this.linegraph.groups[i].visible)for(var n=0;n<this.linegraph.groups[i].itemsData.length;n++){var r=this.linegraph.groups[i].itemsData[n],o=EO.convert(r.x,"Date").valueOf();t=null==t||t>o?o:t,e=null==e||e<o?o:e}return{min:null!=t?new Date(t):null,max:null!=e?new Date(e):null}},EI.prototype.getEventProperties=function(t){var e=t.center?t.center.x:t.clientX,i=t.center?t.center.y:t.clientY,n=e-EO.getAbsoluteLeft(this.dom.centerContainer),r=i-EO.getAbsoluteTop(this.dom.centerContainer),o=this._toTime(n),s=BP.customTimeFromTarget(t),a=EO.getTarget(t),l=null;EO.hasParent(a,this.timeAxis.dom.foreground)||this.timeAxis2&&EO.hasParent(a,this.timeAxis2.dom.foreground)?l="axis":EO.hasParent(a,this.linegraph.yAxisLeft.dom.frame)||EO.hasParent(a,this.linegraph.yAxisRight.dom.frame)?l="data-axis":EO.hasParent(a,this.linegraph.legendLeft.dom.frame)||EO.hasParent(a,this.linegraph.legendRight.dom.frame)?l="legend":null!=s?l="custom-time":EO.hasParent(a,this.currentTime.bar)?l="current-time":EO.hasParent(a,this.dom.center)&&(l="background");var h=[],u=this.linegraph.yAxisLeft,c=this.linegraph.yAxisRight;return!u.hidden&&this.itemsData.length>0&&h.push(u.screenToValue(r)),!c.hidden&&this.itemsData.length>0&&h.push(c.screenToValue(r)),{event:t,customTime:s?s.options.id:null,what:l,pageX:t.srcEvent?t.srcEvent.pageX:t.pageX,pageY:t.srcEvent?t.srcEvent.pageY:t.pageY,x:n,y:r,time:o,value:h}},EI.prototype._createConfigurator=function(){return new aI(this,this.dom.container,PI)};var II=xb();gM.locale(II);var LI={Core:zP,DateUtil:dP,Range:pP,stack:bE,TimeStep:_P,components:{items:{Item:SE,BackgroundItem:ME,BoxItem:DE,ClusterItem:jE,PointItem:CE,RangeItem:TE},BackgroundGroup:kE,Component:GO,CurrentTime:GP,CustomTime:BP,DataAxis:fI,DataScale:dI,GraphGroup:bI,Group:wE,ItemSet:VE,Legend:_I,LineGraph:kI,TimeAxis:kP}};t.DOMutil=Sb,t.DataSet=mM,t.DataView=vM,t.Graph2d=EI,t.Hammer=yP,t.Queue=dM,t.Timeline=lI,t.keycharm=SP,t.moment=gM,t.timeline=LI,t.util=mb})),function(t,e){"object"==typeof exports&&"object"==typeof module?module.exports=e():"function"==typeof define&&define.amd?define([],e):"object"==typeof exports?exports.Handlebars=e():t.Handlebars=e()}(this,(function(){return function(t){function e(n){if(i[n])return i[n].exports;var r=i[n]={exports:{},id:n,loaded:!1};return t[n].call(r.exports,r,r.exports,e),r.loaded=!0,r.exports}var i={};return e.m=t,e.c=i,e.p="",e(0)}([function(t,e,i){"use strict";function n(){var t=d();return t.compile=function(e,i){return l.compile(e,i,t)},t.precompile=function(e,i){return l.precompile(e,i,t)},t.AST=s.default,t.Compiler=l.Compiler,t.JavaScriptCompiler=h.default,t.Parser=a.parser,t.parse=a.parse,t.parseWithoutProcessing=a.parseWithoutProcessing,t}var r=i(1).default;e.__esModule=!0;var o=r(i(2)),s=r(i(84)),a=i(85),l=i(90),h=r(i(91)),u=r(i(88)),c=r(i(83)),d=o.default.create,p=n();p.create=n,c.default(p),p.Visitor=u.default,p.default=p,e.default=p,t.exports=e.default},function(t,e){"use strict";e.default=function(t){return t&&t.__esModule?t:{default:t}},e.__esModule=!0},function(t,e,i){"use strict";function n(){var t=new s.HandlebarsEnvironment;return h.extend(t,s),t.SafeString=a.default,t.Exception=l.default,t.Utils=h,t.escapeExpression=h.escapeExpression,t.VM=u,t.template=function(e){return u.template(e,t)},t}var r=i(3).default,o=i(1).default;e.__esModule=!0;var s=r(i(4)),a=o(i(77)),l=o(i(6)),h=r(i(5)),u=r(i(78)),c=o(i(83)),d=n();d.create=n,c.default(d),d.default=d,e.default=d,t.exports=e.default},function(t,e){"use strict";e.default=function(t){if(t&&t.__esModule)return t;var e={};if(null!=t)for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e.default=t,e},e.__esModule=!0},function(t,e,i){"use strict";function n(t,e,i){this.helpers=t||{},this.partials=e||{},this.decorators=i||{},a.registerDefaultHelpers(this),l.registerDefaultDecorators(this)}var r=i(1).default;e.__esModule=!0,e.HandlebarsEnvironment=n;var o=i(5),s=r(i(6)),a=i(10),l=i(70),h=r(i(72)),u=i(73);e.VERSION="4.7.8";e.COMPILER_REVISION=8;e.LAST_COMPATIBLE_COMPILER_REVISION=7;e.REVISION_CHANGES={1:"<= 1.0.rc.2",2:"== 1.0.0-rc.3",3:"== 1.0.0-rc.4",4:"== 1.x.x",5:"== 2.0.0-alpha.x",6:">= 2.0.0-beta.1",7:">= 4.0.0 <4.3.0",8:">= 4.3.0"};var c="[object Object]";n.prototype={constructor:n,logger:h.default,log:h.default.log,registerHelper:function(t,e){if(o.toString.call(t)===c){if(e)throw new s.default("Arg not supported with multiple helpers");o.extend(this.helpers,t)}else this.helpers[t]=e},unregisterHelper:function(t){delete this.helpers[t]},registerPartial:function(t,e){if(o.toString.call(t)===c)o.extend(this.partials,t);else{if(void 0===e)throw new s.default('Attempting to register a partial called "'+t+'" as undefined');this.partials[t]=e}},unregisterPartial:function(t){delete this.partials[t]},registerDecorator:function(t,e){if(o.toString.call(t)===c){if(e)throw new s.default("Arg not supported with multiple decorators");o.extend(this.decorators,t)}else this.decorators[t]=e},unregisterDecorator:function(t){delete this.decorators[t]},resetLoggedPropertyAccesses:function(){u.resetLoggedProperties()}};var d=h.default.log;e.log=d,e.createFrame=o.createFrame,e.logger=h.default},function(t,e){"use strict";function i(t){return r[t]}function n(t){for(var e=1;e<arguments.length;e++)for(var i in arguments[e])Object.prototype.hasOwnProperty.call(arguments[e],i)&&(t[i]=arguments[e][i]);return t}e.__esModule=!0,e.extend=n,e.indexOf=function(t,e){for(var i=0,n=t.length;i<n;i++)if(t[i]===e)return i;return-1},e.escapeExpression=function(t){if("string"!=typeof t){if(t&&t.toHTML)return t.toHTML();if(null==t)return"";if(!t)return t+"";t=""+t}return s.test(t)?t.replace(o,i):t},e.isEmpty=function(t){return!t&&0!==t||!(!h(t)||0!==t.length)},e.createFrame=function(t){var e=n({},t);return e._parent=t,e},e.blockParams=function(t,e){return t.path=e,t},e.appendContextPath=function(t,e){return(t?t+".":"")+e};var r={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#x27;","`":"&#x60;","=":"&#x3D;"},o=/[&<>"'`=]/g,s=/[&<>"'`=]/,a=Object.prototype.toString;e.toString=a;var l=function(t){return"function"==typeof t};l(/x/)&&(e.isFunction=l=function(t){return"function"==typeof t&&"[object Function]"===a.call(t)}),e.isFunction=l;var h=Array.isArray||function(t){return!(!t||"object"!=typeof t)&&"[object Array]"===a.call(t)};e.isArray=h},function(t,e,i){"use strict";function n(t,e){var i=e&&e.loc,s=void 0,a=void 0,l=void 0,h=void 0;i&&(s=i.start.line,a=i.end.line,l=i.start.column,h=i.end.column,t+=" - "+s+":"+l);for(var u=Error.prototype.constructor.call(this,t),c=0;c<o.length;c++)this[o[c]]=u[o[c]];Error.captureStackTrace&&Error.captureStackTrace(this,n);try{i&&(this.lineNumber=s,this.endLineNumber=a,r?(Object.defineProperty(this,"column",{value:l,enumerable:!0}),Object.defineProperty(this,"endColumn",{value:h,enumerable:!0})):(this.column=l,this.endColumn=h))}catch(t){}}var r=i(7).default;e.__esModule=!0;var o=["description","fileName","lineNumber","endLineNumber","message","name","number","stack"];n.prototype=new Error,e.default=n,t.exports=e.default},function(t,e,i){t.exports={default:i(8),__esModule:!0}},function(t,e,i){var n=i(9);t.exports=function(t,e,i){return n.setDesc(t,e,i)}},function(t,e){var i=Object;t.exports={create:i.create,getProto:i.getPrototypeOf,isEnum:{}.propertyIsEnumerable,getDesc:i.getOwnPropertyDescriptor,setDesc:i.defineProperty,setDescs:i.defineProperties,getKeys:i.keys,getNames:i.getOwnPropertyNames,getSymbols:i.getOwnPropertySymbols,each:[].forEach}},function(t,e,i){"use strict";var n=i(1).default;e.__esModule=!0,e.registerDefaultHelpers=function(t){r.default(t),o.default(t),s.default(t),a.default(t),l.default(t),h.default(t),u.default(t)},e.moveHelperToHooks=function(t,e,i){t.helpers[e]&&(t.hooks[e]=t.helpers[e],i||delete t.helpers[e])};var r=n(i(11)),o=n(i(12)),s=n(i(65)),a=n(i(66)),l=n(i(67)),h=n(i(68)),u=n(i(69))},function(t,e,i){"use strict";e.__esModule=!0;var n=i(5);e.default=function(t){t.registerHelper("blockHelperMissing",(function(e,i){var r=i.inverse,o=i.fn;if(!0===e)return o(this);if(!1===e||null==e)return r(this);if(n.isArray(e))return e.length>0?(i.ids&&(i.ids=[i.name]),t.helpers.each(e,i)):r(this);if(i.data&&i.ids){var s=n.createFrame(i.data);s.contextPath=n.appendContextPath(i.data.contextPath,i.name),i={data:s}}return o(e,i)}))},t.exports=e.default},function(t,e,i){"use strict";var n=i(13).default,r=i(43).default,o=i(55).default,s=i(60).default,a=i(1).default;e.__esModule=!0;var l=i(5),h=a(i(6));e.default=function(t){t.registerHelper("each",(function(t,e){function i(e,i,n){p&&(p.key=e,p.index=i,p.first=0===i,p.last=!!n,f&&(p.contextPath=f+e)),d+=a(t[e],{data:p,blockParams:l.blockParams([t[e],e],[f+e,null])})}if(!e)throw new h.default("Must pass iterator to #each");var a=e.fn,u=e.inverse,c=0,d="",p=void 0,f=void 0;if(e.data&&e.ids&&(f=l.appendContextPath(e.data.contextPath,e.ids[0])+"."),l.isFunction(t)&&(t=t.call(this)),e.data&&(p=l.createFrame(e.data)),t&&"object"==typeof t)if(l.isArray(t))for(var m=t.length;c<m;c++)c in t&&i(c,c,c===t.length-1);else if("function"==typeof n&&t[r]){for(var v=[],g=o(t),y=g.next();!y.done;y=g.next())v.push(y.value);for(m=(t=v).length;c<m;c++)i(c,c,c===t.length-1)}else!function(){var e=void 0;s(t).forEach((function(t){void 0!==e&&i(e,c-1),e=t,c++})),void 0!==e&&i(e,c-1,!0)}();return 0===c&&(d=u(this)),d}))},t.exports=e.default},function(t,e,i){t.exports={default:i(14),__esModule:!0}},function(t,e,i){i(15),i(42),t.exports=i(21).Symbol},function(t,e,i){"use strict";var n=i(9),r=i(16),o=i(17),s=i(18),a=i(20),l=i(24),h=i(19),u=i(27),c=i(28),d=i(30),p=i(29),f=i(31),m=i(36),v=i(37),g=i(38),y=i(39),b=i(32),_=i(26),w=n.getDesc,k=n.setDesc,x=n.create,S=m.get,D=r.Symbol,C=r.JSON,T=C&&C.stringify,M=!1,O=p("_hidden"),P=n.isEnum,E=u("symbol-registry"),I=u("symbols"),L="function"==typeof D,A=Object.prototype,N=s&&h((function(){return 7!=x(k({},"a",{get:function(){return k(this,"a",{value:7}).a}})).a}))?function(t,e,i){var n=w(A,e);n&&delete A[e],k(t,e,i),n&&t!==A&&k(A,e,n)}:k,R=function(t){var e=I[t]=x(D.prototype);return e._k=t,s&&M&&N(A,t,{configurable:!0,set:function(e){o(this,O)&&o(this[O],t)&&(this[O][t]=!1),N(this,t,_(1,e))}}),e},F=function(t){return"symbol"==typeof t},j=function(t,e,i){return i&&o(I,e)?(i.enumerable?(o(t,O)&&t[O][e]&&(t[O][e]=!1),i=x(i,{enumerable:_(0,!1)})):(o(t,O)||k(t,O,_(1,{})),t[O][e]=!0),N(t,e,i)):k(t,e,i)},Y=function(t,e){y(t);for(var i,n=v(e=b(e)),r=0,o=n.length;o>r;)j(t,i=n[r++],e[i]);return t},H=function(t,e){return void 0===e?x(t):Y(x(t),e)},B=function(t){var e=P.call(this,t);return!(e||!o(this,t)||!o(I,t)||o(this,O)&&this[O][t])||e},z=function(t,e){var i=w(t=b(t),e);return!i||!o(I,e)||o(t,O)&&t[O][e]||(i.enumerable=!0),i},G=function(t){for(var e,i=S(b(t)),n=[],r=0;i.length>r;)o(I,e=i[r++])||e==O||n.push(e);return n},W=function(t){for(var e,i=S(b(t)),n=[],r=0;i.length>r;)o(I,e=i[r++])&&n.push(I[e]);return n},V=h((function(){var t=D();return"[null]"!=T([t])||"{}"!=T({a:t})||"{}"!=T(Object(t))}));L||(D=function(){if(F(this))throw TypeError("Symbol is not a constructor");return R(d(arguments.length>0?arguments[0]:void 0))},l(D.prototype,"toString",(function(){return this._k})),F=function(t){return t instanceof D},n.create=H,n.isEnum=B,n.getDesc=z,n.setDesc=j,n.setDescs=Y,n.getNames=m.get=G,n.getSymbols=W,s&&!i(41)&&l(A,"propertyIsEnumerable",B,!0));var U={for:function(t){return o(E,t+="")?E[t]:E[t]=D(t)},keyFor:function(t){return f(E,t)},useSetter:function(){M=!0},useSimple:function(){M=!1}};n.each.call("hasInstance,isConcatSpreadable,iterator,match,replace,search,species,split,toPrimitive,toStringTag,unscopables".split(","),(function(t){var e=p(t);U[t]=L?e:R(e)})),M=!0,a(a.G+a.W,{Symbol:D}),a(a.S,"Symbol",U),a(a.S+a.F*!L,"Object",{create:H,defineProperty:j,defineProperties:Y,getOwnPropertyDescriptor:z,getOwnPropertyNames:G,getOwnPropertySymbols:W}),C&&a(a.S+a.F*(!L||V),"JSON",{stringify:function(t){if(void 0!==t&&!F(t)){for(var e,i,n=[t],r=1,o=arguments;o.length>r;)n.push(o[r++]);return"function"==typeof(e=n[1])&&(i=e),!i&&g(e)||(e=function(t,e){if(i&&(e=i.call(this,t,e)),!F(e))return e}),n[1]=e,T.apply(C,n)}}}),c(D,"Symbol"),c(Math,"Math",!0),c(r.JSON,"JSON",!0)},function(t,e){var i=t.exports="undefined"!=typeof window&&window.Math==Math?window:"undefined"!=typeof self&&self.Math==Math?self:Function("return this")();"number"==typeof __g&&(__g=i)},function(t,e){var i={}.hasOwnProperty;t.exports=function(t,e){return i.call(t,e)}},function(t,e,i){t.exports=!i(19)((function(){return 7!=Object.defineProperty({},"a",{get:function(){return 7}}).a}))},function(t,e){t.exports=function(t){try{return!!t()}catch(t){return!0}}},function(t,e,i){var n=i(16),r=i(21),o=i(22),s="prototype",a=function(t,e,i){var l,h,u,c=t&a.F,d=t&a.G,p=t&a.S,f=t&a.P,m=t&a.B,v=t&a.W,g=d?r:r[e]||(r[e]={}),y=d?n:p?n[e]:(n[e]||{})[s];for(l in d&&(i=e),i)(h=!c&&y&&l in y)&&l in g||(u=h?y[l]:i[l],g[l]=d&&"function"!=typeof y[l]?i[l]:m&&h?o(u,n):v&&y[l]==u?function(t){var e=function(e){return this instanceof t?new t(e):t(e)};return e[s]=t[s],e}(u):f&&"function"==typeof u?o(Function.call,u):u,f&&((g[s]||(g[s]={}))[l]=u))};a.F=1,a.G=2,a.S=4,a.P=8,a.B=16,a.W=32,t.exports=a},function(t,e){var i=t.exports={version:"1.2.6"};"number"==typeof __e&&(__e=i)},function(t,e,i){var n=i(23);t.exports=function(t,e,i){if(n(t),void 0===e)return t;switch(i){case 1:return function(i){return t.call(e,i)};case 2:return function(i,n){return t.call(e,i,n)};case 3:return function(i,n,r){return t.call(e,i,n,r)}}return function(){return t.apply(e,arguments)}}},function(t,e){t.exports=function(t){if("function"!=typeof t)throw TypeError(t+" is not a function!");return t}},function(t,e,i){t.exports=i(25)},function(t,e,i){var n=i(9),r=i(26);t.exports=i(18)?function(t,e,i){return n.setDesc(t,e,r(1,i))}:function(t,e,i){return t[e]=i,t}},function(t,e){t.exports=function(t,e){return{enumerable:!(1&t),configurable:!(2&t),writable:!(4&t),value:e}}},function(t,e,i){var n=i(16),r="__core-js_shared__",o=n[r]||(n[r]={});t.exports=function(t){return o[t]||(o[t]={})}},function(t,e,i){var n=i(9).setDesc,r=i(17),o=i(29)("toStringTag");t.exports=function(t,e,i){t&&!r(t=i?t:t.prototype,o)&&n(t,o,{configurable:!0,value:e})}},function(t,e,i){var n=i(27)("wks"),r=i(30),o=i(16).Symbol;t.exports=function(t){return n[t]||(n[t]=o&&o[t]||(o||r)("Symbol."+t))}},function(t,e){var i=0,n=Math.random();t.exports=function(t){return"Symbol(".concat(void 0===t?"":t,")_",(++i+n).toString(36))}},function(t,e,i){var n=i(9),r=i(32);t.exports=function(t,e){for(var i,o=r(t),s=n.getKeys(o),a=s.length,l=0;a>l;)if(o[i=s[l++]]===e)return i}},function(t,e,i){var n=i(33),r=i(35);t.exports=function(t){return n(r(t))}},function(t,e,i){var n=i(34);t.exports=Object("z").propertyIsEnumerable(0)?Object:function(t){return"String"==n(t)?t.split(""):Object(t)}},function(t,e){var i={}.toString;t.exports=function(t){return i.call(t).slice(8,-1)}},function(t,e){t.exports=function(t){if(null==t)throw TypeError("Can't call method on  "+t);return t}},function(t,e,i){var n=i(32),r=i(9).getNames,o={}.toString,s="object"==typeof window&&Object.getOwnPropertyNames?Object.getOwnPropertyNames(window):[];t.exports.get=function(t){return s&&"[object Window]"==o.call(t)?function(t){try{return r(t)}catch(t){return s.slice()}}(t):r(n(t))}},function(t,e,i){var n=i(9);t.exports=function(t){var e=n.getKeys(t),i=n.getSymbols;if(i)for(var r,o=i(t),s=n.isEnum,a=0;o.length>a;)s.call(t,r=o[a++])&&e.push(r);return e}},function(t,e,i){var n=i(34);t.exports=Array.isArray||function(t){return"Array"==n(t)}},function(t,e,i){var n=i(40);t.exports=function(t){if(!n(t))throw TypeError(t+" is not an object!");return t}},function(t,e){t.exports=function(t){return"object"==typeof t?null!==t:"function"==typeof t}},function(t,e){t.exports=!0},function(t,e){},function(t,e,i){t.exports={default:i(44),__esModule:!0}},function(t,e,i){i(45),i(51),t.exports=i(29)("iterator")},function(t,e,i){"use strict";var n=i(46)(!0);i(48)(String,"String",(function(t){this._t=String(t),this._i=0}),(function(){var t,e=this._t,i=this._i;return i>=e.length?{value:void 0,done:!0}:(t=n(e,i),this._i+=t.length,{value:t,done:!1})}))},function(t,e,i){var n=i(47),r=i(35);t.exports=function(t){return function(e,i){var o,s,a=String(r(e)),l=n(i),h=a.length;return l<0||l>=h?t?"":void 0:(o=a.charCodeAt(l))<55296||o>56319||l+1===h||(s=a.charCodeAt(l+1))<56320||s>57343?t?a.charAt(l):o:t?a.slice(l,l+2):s-56320+(o-55296<<10)+65536}}},function(t,e){var i=Math.ceil,n=Math.floor;t.exports=function(t){return isNaN(t=+t)?0:(t>0?n:i)(t)}},function(t,e,i){"use strict";var n=i(41),r=i(20),o=i(24),s=i(25),a=i(17),l=i(49),h=i(50),u=i(28),c=i(9).getProto,d=i(29)("iterator"),p=!([].keys&&"next"in[].keys()),f="@@iterator",m="keys",v="values",g=function(){return this};t.exports=function(t,e,i,y,b,_,w){h(i,e,y);var k,x,S=function(t){if(!p&&t in M)return M[t];switch(t){case m:case v:return function(){return new i(this,t)}}return function(){return new i(this,t)}},D=e+" Iterator",C=b==v,T=!1,M=t.prototype,O=M[d]||M[f]||b&&M[b],P=O||S(b);if(O){var E=c(P.call(new t));u(E,D,!0),!n&&a(M,f)&&s(E,d,g),C&&O.name!==v&&(T=!0,P=function(){return O.call(this)})}if(n&&!w||!p&&!T&&M[d]||s(M,d,P),l[e]=P,l[D]=g,b)if(k={values:C?P:S(v),keys:_?P:S(m),entries:C?S("entries"):P},w)for(x in k)x in M||o(M,x,k[x]);else r(r.P+r.F*(p||T),e,k);return k}},function(t,e){t.exports={}},function(t,e,i){"use strict";var n=i(9),r=i(26),o=i(28),s={};i(25)(s,i(29)("iterator"),(function(){return this})),t.exports=function(t,e,i){t.prototype=n.create(s,{next:r(1,i)}),o(t,e+" Iterator")}},function(t,e,i){i(52);var n=i(49);n.NodeList=n.HTMLCollection=n.Array},function(t,e,i){"use strict";var n=i(53),r=i(54),o=i(49),s=i(32);t.exports=i(48)(Array,"Array",(function(t,e){this._t=s(t),this._i=0,this._k=e}),(function(){var t=this._t,e=this._k,i=this._i++;return!t||i>=t.length?(this._t=void 0,r(1)):r(0,"keys"==e?i:"values"==e?t[i]:[i,t[i]])}),"values"),o.Arguments=o.Array,n("keys"),n("values"),n("entries")},function(t,e){t.exports=function(){}},function(t,e){t.exports=function(t,e){return{value:e,done:!!t}}},function(t,e,i){t.exports={default:i(56),__esModule:!0}},function(t,e,i){i(51),i(45),t.exports=i(57)},function(t,e,i){var n=i(39),r=i(58);t.exports=i(21).getIterator=function(t){var e=r(t);if("function"!=typeof e)throw TypeError(t+" is not iterable!");return n(e.call(t))}},function(t,e,i){var n=i(59),r=i(29)("iterator"),o=i(49);t.exports=i(21).getIteratorMethod=function(t){if(null!=t)return t[r]||t["@@iterator"]||o[n(t)]}},function(t,e,i){var n=i(34),r=i(29)("toStringTag"),o="Arguments"==n(function(){return arguments}());t.exports=function(t){var e,i,s;return void 0===t?"Undefined":null===t?"Null":"string"==typeof(i=(e=Object(t))[r])?i:o?n(e):"Object"==(s=n(e))&&"function"==typeof e.callee?"Arguments":s}},function(t,e,i){t.exports={default:i(61),__esModule:!0}},function(t,e,i){i(62),t.exports=i(21).Object.keys},function(t,e,i){var n=i(63);i(64)("keys",(function(t){return function(e){return t(n(e))}}))},function(t,e,i){var n=i(35);t.exports=function(t){return Object(n(t))}},function(t,e,i){var n=i(20),r=i(21),o=i(19);t.exports=function(t,e){var i=(r.Object||{})[t]||Object[t],s={};s[t]=e(i),n(n.S+n.F*o((function(){i(1)})),"Object",s)}},function(t,e,i){"use strict";var n=i(1).default;e.__esModule=!0;var r=n(i(6));e.default=function(t){t.registerHelper("helperMissing",(function(){if(1!==arguments.length)throw new r.default('Missing helper: "'+arguments[arguments.length-1].name+'"')}))},t.exports=e.default},function(t,e,i){"use strict";var n=i(1).default;e.__esModule=!0;var r=i(5),o=n(i(6));e.default=function(t){t.registerHelper("if",(function(t,e){if(2!=arguments.length)throw new o.default("#if requires exactly one argument");return r.isFunction(t)&&(t=t.call(this)),!e.hash.includeZero&&!t||r.isEmpty(t)?e.inverse(this):e.fn(this)})),t.registerHelper("unless",(function(e,i){if(2!=arguments.length)throw new o.default("#unless requires exactly one argument");return t.helpers.if.call(this,e,{fn:i.inverse,inverse:i.fn,hash:i.hash})}))},t.exports=e.default},function(t,e){"use strict";e.__esModule=!0,e.default=function(t){t.registerHelper("log",(function(){for(var e=[void 0],i=arguments[arguments.length-1],n=0;n<arguments.length-1;n++)e.push(arguments[n]);var r=1;null!=i.hash.level?r=i.hash.level:i.data&&null!=i.data.level&&(r=i.data.level),e[0]=r,t.log.apply(t,e)}))},t.exports=e.default},function(t,e){"use strict";e.__esModule=!0,e.default=function(t){t.registerHelper("lookup",(function(t,e,i){return t?i.lookupProperty(t,e):t}))},t.exports=e.default},function(t,e,i){"use strict";var n=i(1).default;e.__esModule=!0;var r=i(5),o=n(i(6));e.default=function(t){t.registerHelper("with",(function(t,e){if(2!=arguments.length)throw new o.default("#with requires exactly one argument");r.isFunction(t)&&(t=t.call(this));var i=e.fn;if(r.isEmpty(t))return e.inverse(this);var n=e.data;return e.data&&e.ids&&((n=r.createFrame(e.data)).contextPath=r.appendContextPath(e.data.contextPath,e.ids[0])),i(t,{data:n,blockParams:r.blockParams([t],[n&&n.contextPath])})}))},t.exports=e.default},function(t,e,i){"use strict";var n=i(1).default;e.__esModule=!0,e.registerDefaultDecorators=function(t){r.default(t)};var r=n(i(71))},function(t,e,i){"use strict";e.__esModule=!0;var n=i(5);e.default=function(t){t.registerDecorator("inline",(function(t,e,i,r){var o=t;return e.partials||(e.partials={},o=function(r,o){var s=i.partials;i.partials=n.extend({},s,e.partials);var a=t(r,o);return i.partials=s,a}),e.partials[r.args[0]]=r.fn,o}))},t.exports=e.default},function(t,e,i){"use strict";e.__esModule=!0;var n=i(5),r={methodMap:["debug","info","warn","error"],level:"info",lookupLevel:function(t){if("string"==typeof t){var e=n.indexOf(r.methodMap,t.toLowerCase());t=e>=0?e:parseInt(t,10)}return t},log:function(t){if(t=r.lookupLevel(t),"undefined"!=typeof console&&r.lookupLevel(r.level)<=t){var e=r.methodMap[t];console[e]||(e="log");for(var i=arguments.length,n=Array(i>1?i-1:0),o=1;o<i;o++)n[o-1]=arguments[o];console[e].apply(console,n)}}};e.default=r,t.exports=e.default},function(t,e,i){"use strict";function n(t,e){return void 0!==t.whitelist[e]?!0===t.whitelist[e]:void 0!==t.defaultValue?t.defaultValue:(function(t){!0!==h[t]&&(h[t]=!0,l.default.log("error",'Handlebars: Access has been denied to resolve the property "'+t+'" because it is not an "own property" of its parent.\nYou can add a runtime option to disable the check or this warning:\nSee https://handlebarsjs.com/api-reference/runtime-options.html#options-to-control-prototype-access for details'))}(e),!1)}var r=i(74).default,o=i(60).default,s=i(1).default;e.__esModule=!0,e.createProtoAccessControl=function(t){var e=r(null);e.constructor=!1,e.__defineGetter__=!1,e.__defineSetter__=!1,e.__lookupGetter__=!1;var i=r(null);return i.__proto__=!1,{properties:{whitelist:a.createNewLookupObject(i,t.allowedProtoProperties),defaultValue:t.allowProtoPropertiesByDefault},methods:{whitelist:a.createNewLookupObject(e,t.allowedProtoMethods),defaultValue:t.allowProtoMethodsByDefault}}},e.resultIsAllowed=function(t,e,i){return n("function"==typeof t?e.methods:e.properties,i)},e.resetLoggedProperties=function(){o(h).forEach((function(t){delete h[t]}))};var a=i(76),l=s(i(72)),h=r(null)},function(t,e,i){t.exports={default:i(75),__esModule:!0}},function(t,e,i){var n=i(9);t.exports=function(t,e){return n.create(t,e)}},function(t,e,i){"use strict";var n=i(74).default;e.__esModule=!0,e.createNewLookupObject=function(){for(var t=arguments.length,e=Array(t),i=0;i<t;i++)e[i]=arguments[i];return r.extend.apply(void 0,[n(null)].concat(e))};var r=i(5)},function(t,e){"use strict";function i(t){this.string=t}e.__esModule=!0,i.prototype.toString=i.prototype.toHTML=function(){return""+this.string},e.default=i,t.exports=e.default},function(t,e,i){"use strict";function n(t,e,i,n,r,s,a){function l(e){var r=arguments.length<=1||void 0===arguments[1]?{}:arguments[1],o=a;return!a||e==a[0]||e===t.nullContext&&null===a[0]||(o=[e].concat(a)),i(t,e,t.helpers,t.partials,r.data||n,s&&[r.blockParams].concat(s),o)}return(l=o(i,l,t,a,n,s)).program=e,l.depth=a?a.length:0,l.blockParams=r||0,l}function r(){return""}function o(t,e,i,n,r,o){if(t.decorator){var s={};e=t.decorator(e,s,i,n&&n[0],r,o,n),u.extend(e,s)}return e}var s=i(79).default,a=i(60).default,l=i(3).default,h=i(1).default;e.__esModule=!0,e.checkRevision=function(t){var e=t&&t[0]||1,i=d.COMPILER_REVISION;if(!(e>=d.LAST_COMPATIBLE_COMPILER_REVISION&&e<=d.COMPILER_REVISION)){if(e<d.LAST_COMPATIBLE_COMPILER_REVISION){var n=d.REVISION_CHANGES[i],r=d.REVISION_CHANGES[e];throw new c.default("Template was precompiled with an older version of Handlebars than the current runtime. Please update your precompiler to a newer version ("+n+") or downgrade your runtime to an older version ("+r+").")}throw new c.default("Template was precompiled with a newer version of Handlebars than the current runtime. Please update your runtime to a newer version ("+t[1]+").")}},e.template=function(t,e){function i(e){function n(e){return""+t.main(l,e,l.helpers,l.partials,s,h,a)}var r=arguments.length<=1||void 0===arguments[1]?{}:arguments[1],s=r.data;i._setup(r),!r.partial&&t.useData&&(s=function(t,e){return e&&"root"in e||(e=e?d.createFrame(e):{},e.root=t),e}(e,s));var a=void 0,h=t.useBlockParams?[]:void 0;return t.useDepths&&(a=r.depths?e!=r.depths[0]?[e].concat(r.depths):r.depths:[e]),(n=o(t.main,n,l,r.depths||[],s,h))(e,r)}if(!e)throw new c.default("No environment passed to template");if(!t||!t.main)throw new c.default("Unknown template object: "+typeof t);t.main.decorator=t.main_d,e.VM.checkRevision(t.compiler);var r=t.compiler&&7===t.compiler[0],l={strict:function(t,e,i){if(!t||!(e in t))throw new c.default('"'+e+'" not defined in '+t,{loc:i});return l.lookupProperty(t,e)},lookupProperty:function(t,e){var i=t[e];return null==i||Object.prototype.hasOwnProperty.call(t,e)||m.resultIsAllowed(i,l.protoAccessControl,e)?i:void 0},lookup:function(t,e){for(var i=t.length,n=0;n<i;n++){if(null!=(t[n]&&l.lookupProperty(t[n],e)))return t[n][e]}},lambda:function(t,e){return"function"==typeof t?t.call(e):t},escapeExpression:u.escapeExpression,invokePartial:function(i,n,r){r.hash&&(n=u.extend({},n,r.hash),r.ids&&(r.ids[0]=!0)),i=e.VM.resolvePartial.call(this,i,n,r);var o=u.extend({},r,{hooks:this.hooks,protoAccessControl:this.protoAccessControl}),s=e.VM.invokePartial.call(this,i,n,o);if(null==s&&e.compile&&(r.partials[r.name]=e.compile(i,t.compilerOptions,e),s=r.partials[r.name](n,o)),null!=s){if(r.indent){for(var a=s.split("\n"),l=0,h=a.length;l<h&&(a[l]||l+1!==h);l++)a[l]=r.indent+a[l];s=a.join("\n")}return s}throw new c.default("The partial "+r.name+" could not be compiled when running in runtime-only mode")},fn:function(e){var i=t[e];return i.decorator=t[e+"_d"],i},programs:[],program:function(t,e,i,r,o){var s=this.programs[t],a=this.fn(t);return e||o||r||i?s=n(this,t,a,e,i,r,o):s||(s=this.programs[t]=n(this,t,a)),s},data:function(t,e){for(;t&&e--;)t=t._parent;return t},mergeIfNeeded:function(t,e){var i=t||e;return t&&e&&t!==e&&(i=u.extend({},e,t)),i},nullContext:s({}),noop:e.VM.noop,compilerInfo:t.compiler};return i.isTop=!0,i._setup=function(i){if(i.partial)l.protoAccessControl=i.protoAccessControl,l.helpers=i.helpers,l.partials=i.partials,l.decorators=i.decorators,l.hooks=i.hooks;else{var n=u.extend({},e.helpers,i.helpers);(function(t,e){a(t).forEach((function(i){var n=t[i];t[i]=function(t,e){var i=e.lookupProperty;return f.wrapHelper(t,(function(t){return u.extend({lookupProperty:i},t)}))}(n,e)}))})(n,l),l.helpers=n,t.usePartial&&(l.partials=l.mergeIfNeeded(i.partials,e.partials)),(t.usePartial||t.useDecorators)&&(l.decorators=u.extend({},e.decorators,i.decorators)),l.hooks={},l.protoAccessControl=m.createProtoAccessControl(i);var o=i.allowCallsToHelperMissing||r;p.moveHelperToHooks(l,"helperMissing",o),p.moveHelperToHooks(l,"blockHelperMissing",o)}},i._child=function(e,i,r,o){if(t.useBlockParams&&!r)throw new c.default("must pass block params");if(t.useDepths&&!o)throw new c.default("must pass parent depths");return n(l,e,t[e],i,0,r,o)},i},e.wrapProgram=n,e.resolvePartial=function(t,e,i){return t?t.call||i.name||(i.name=t,t=i.partials[t]):t="@partial-block"===i.name?i.data["partial-block"]:i.partials[i.name],t},e.invokePartial=function(t,e,i){var n=i.data&&i.data["partial-block"];i.partial=!0,i.ids&&(i.data.contextPath=i.ids[0]||i.data.contextPath);var o=void 0;if(i.fn&&i.fn!==r&&function(){i.data=d.createFrame(i.data);var t=i.fn;o=i.data["partial-block"]=function(e){var i=arguments.length<=1||void 0===arguments[1]?{}:arguments[1];return i.data=d.createFrame(i.data),i.data["partial-block"]=n,t(e,i)},t.partials&&(i.partials=u.extend({},i.partials,t.partials))}(),void 0===t&&o&&(t=o),void 0===t)throw new c.default("The partial "+i.name+" could not be found");if(t instanceof Function)return t(e,i)},e.noop=r;var u=l(i(5)),c=h(i(6)),d=i(4),p=i(10),f=i(82),m=i(73)},function(t,e,i){t.exports={default:i(80),__esModule:!0}},function(t,e,i){i(81),t.exports=i(21).Object.seal},function(t,e,i){var n=i(40);i(64)("seal",(function(t){return function(e){return t&&n(e)?t(e):e}}))},function(t,e){"use strict";e.__esModule=!0,e.wrapHelper=function(t,e){return"function"!=typeof t?t:function(){return arguments[arguments.length-1]=e(arguments[arguments.length-1]),t.apply(this,arguments)}}},function(t,e){"use strict";e.__esModule=!0,e.default=function(t){"object"!=typeof globalThis&&(Object.prototype.__defineGetter__("__magic__",(function(){return this})),__magic__.globalThis=__magic__,delete Object.prototype.__magic__);var e=globalThis.Handlebars;t.noConflict=function(){return globalThis.Handlebars===t&&(globalThis.Handlebars=e),t}},t.exports=e.default},function(t,e){"use strict";e.__esModule=!0;var i={helpers:{helperExpression:function(t){return"SubExpression"===t.type||("MustacheStatement"===t.type||"BlockStatement"===t.type)&&!!(t.params&&t.params.length||t.hash)},scopedId:function(t){return/^\.|this\b/.test(t.original)},simpleId:function(t){return 1===t.parts.length&&!i.helpers.scopedId(t)&&!t.depth}}};e.default=i,t.exports=e.default},function(t,e,i){"use strict";function n(t,e){return"Program"===t.type?t:(s.default.yy=u,u.locInfo=function(t){return new u.SourceLocation(e&&e.srcName,t)},s.default.parse(t))}var r=i(1).default,o=i(3).default;e.__esModule=!0,e.parseWithoutProcessing=n,e.parse=function(t,e){var i=n(t,e);return new a.default(e).accept(i)};var s=r(i(86)),a=r(i(87)),l=o(i(89)),h=i(5);e.parser=s.default;var u={};h.extend(u,l)},function(t,e){"use strict";e.__esModule=!0;var i=function(){function t(){this.yy={}}var e={trace:function(){},yy:{},symbols_:{error:2,root:3,program:4,EOF:5,program_repetition0:6,statement:7,mustache:8,block:9,rawBlock:10,partial:11,partialBlock:12,content:13,COMMENT:14,CONTENT:15,openRawBlock:16,rawBlock_repetition0:17,END_RAW_BLOCK:18,OPEN_RAW_BLOCK:19,helperName:20,openRawBlock_repetition0:21,openRawBlock_option0:22,CLOSE_RAW_BLOCK:23,openBlock:24,block_option0:25,closeBlock:26,openInverse:27,block_option1:28,OPEN_BLOCK:29,openBlock_repetition0:30,openBlock_option0:31,openBlock_option1:32,CLOSE:33,OPEN_INVERSE:34,openInverse_repetition0:35,openInverse_option0:36,openInverse_option1:37,openInverseChain:38,OPEN_INVERSE_CHAIN:39,openInverseChain_repetition0:40,openInverseChain_option0:41,openInverseChain_option1:42,inverseAndProgram:43,INVERSE:44,inverseChain:45,inverseChain_option0:46,OPEN_ENDBLOCK:47,OPEN:48,mustache_repetition0:49,mustache_option0:50,OPEN_UNESCAPED:51,mustache_repetition1:52,mustache_option1:53,CLOSE_UNESCAPED:54,OPEN_PARTIAL:55,partialName:56,partial_repetition0:57,partial_option0:58,openPartialBlock:59,OPEN_PARTIAL_BLOCK:60,openPartialBlock_repetition0:61,openPartialBlock_option0:62,param:63,sexpr:64,OPEN_SEXPR:65,sexpr_repetition0:66,sexpr_option0:67,CLOSE_SEXPR:68,hash:69,hash_repetition_plus0:70,hashSegment:71,ID:72,EQUALS:73,blockParams:74,OPEN_BLOCK_PARAMS:75,blockParams_repetition_plus0:76,CLOSE_BLOCK_PARAMS:77,path:78,dataName:79,STRING:80,NUMBER:81,BOOLEAN:82,UNDEFINED:83,NULL:84,DATA:85,pathSegments:86,SEP:87,$accept:0,$end:1},terminals_:{2:"error",5:"EOF",14:"COMMENT",15:"CONTENT",18:"END_RAW_BLOCK",19:"OPEN_RAW_BLOCK",23:"CLOSE_RAW_BLOCK",29:"OPEN_BLOCK",33:"CLOSE",34:"OPEN_INVERSE",39:"OPEN_INVERSE_CHAIN",44:"INVERSE",47:"OPEN_ENDBLOCK",48:"OPEN",51:"OPEN_UNESCAPED",54:"CLOSE_UNESCAPED",55:"OPEN_PARTIAL",60:"OPEN_PARTIAL_BLOCK",65:"OPEN_SEXPR",68:"CLOSE_SEXPR",72:"ID",73:"EQUALS",75:"OPEN_BLOCK_PARAMS",77:"CLOSE_BLOCK_PARAMS",80:"STRING",81:"NUMBER",82:"BOOLEAN",83:"UNDEFINED",84:"NULL",85:"DATA",87:"SEP"},productions_:[0,[3,2],[4,1],[7,1],[7,1],[7,1],[7,1],[7,1],[7,1],[7,1],[13,1],[10,3],[16,5],[9,4],[9,4],[24,6],[27,6],[38,6],[43,2],[45,3],[45,1],[26,3],[8,5],[8,5],[11,5],[12,3],[59,5],[63,1],[63,1],[64,5],[69,1],[71,3],[74,3],[20,1],[20,1],[20,1],[20,1],[20,1],[20,1],[20,1],[56,1],[56,1],[79,2],[78,1],[86,3],[86,1],[6,0],[6,2],[17,0],[17,2],[21,0],[21,2],[22,0],[22,1],[25,0],[25,1],[28,0],[28,1],[30,0],[30,2],[31,0],[31,1],[32,0],[32,1],[35,0],[35,2],[36,0],[36,1],[37,0],[37,1],[40,0],[40,2],[41,0],[41,1],[42,0],[42,1],[46,0],[46,1],[49,0],[49,2],[50,0],[50,1],[52,0],[52,2],[53,0],[53,1],[57,0],[57,2],[58,0],[58,1],[61,0],[61,2],[62,0],[62,1],[66,0],[66,2],[67,0],[67,1],[70,1],[70,2],[76,1],[76,2]],performAction:function(t,e,i,n,r,o,s){var a=o.length-1;switch(r){case 1:return o[a-1];case 2:this.$=n.prepareProgram(o[a]);break;case 3:case 4:case 5:case 6:case 7:case 8:case 20:case 27:case 28:case 33:case 34:case 40:case 41:this.$=o[a];break;case 9:this.$={type:"CommentStatement",value:n.stripComment(o[a]),strip:n.stripFlags(o[a],o[a]),loc:n.locInfo(this._$)};break;case 10:this.$={type:"ContentStatement",original:o[a],value:o[a],loc:n.locInfo(this._$)};break;case 11:this.$=n.prepareRawBlock(o[a-2],o[a-1],o[a],this._$);break;case 12:this.$={path:o[a-3],params:o[a-2],hash:o[a-1]};break;case 13:this.$=n.prepareBlock(o[a-3],o[a-2],o[a-1],o[a],!1,this._$);break;case 14:this.$=n.prepareBlock(o[a-3],o[a-2],o[a-1],o[a],!0,this._$);break;case 15:this.$={open:o[a-5],path:o[a-4],params:o[a-3],hash:o[a-2],blockParams:o[a-1],strip:n.stripFlags(o[a-5],o[a])};break;case 16:case 17:this.$={path:o[a-4],params:o[a-3],hash:o[a-2],blockParams:o[a-1],strip:n.stripFlags(o[a-5],o[a])};break;case 18:this.$={strip:n.stripFlags(o[a-1],o[a-1]),program:o[a]};break;case 19:var l=n.prepareBlock(o[a-2],o[a-1],o[a],o[a],!1,this._$),h=n.prepareProgram([l],o[a-1].loc);h.chained=!0,this.$={strip:o[a-2].strip,program:h,chain:!0};break;case 21:this.$={path:o[a-1],strip:n.stripFlags(o[a-2],o[a])};break;case 22:case 23:this.$=n.prepareMustache(o[a-3],o[a-2],o[a-1],o[a-4],n.stripFlags(o[a-4],o[a]),this._$);break;case 24:this.$={type:"PartialStatement",name:o[a-3],params:o[a-2],hash:o[a-1],indent:"",strip:n.stripFlags(o[a-4],o[a]),loc:n.locInfo(this._$)};break;case 25:this.$=n.preparePartialBlock(o[a-2],o[a-1],o[a],this._$);break;case 26:this.$={path:o[a-3],params:o[a-2],hash:o[a-1],strip:n.stripFlags(o[a-4],o[a])};break;case 29:this.$={type:"SubExpression",path:o[a-3],params:o[a-2],hash:o[a-1],loc:n.locInfo(this._$)};break;case 30:this.$={type:"Hash",pairs:o[a],loc:n.locInfo(this._$)};break;case 31:this.$={type:"HashPair",key:n.id(o[a-2]),value:o[a],loc:n.locInfo(this._$)};break;case 32:this.$=n.id(o[a-1]);break;case 35:this.$={type:"StringLiteral",value:o[a],original:o[a],loc:n.locInfo(this._$)};break;case 36:this.$={type:"NumberLiteral",value:Number(o[a]),original:Number(o[a]),loc:n.locInfo(this._$)};break;case 37:this.$={type:"BooleanLiteral",value:"true"===o[a],original:"true"===o[a],loc:n.locInfo(this._$)};break;case 38:this.$={type:"UndefinedLiteral",original:void 0,value:void 0,loc:n.locInfo(this._$)};break;case 39:this.$={type:"NullLiteral",original:null,value:null,loc:n.locInfo(this._$)};break;case 42:this.$=n.preparePath(!0,o[a],this._$);break;case 43:this.$=n.preparePath(!1,o[a],this._$);break;case 44:o[a-2].push({part:n.id(o[a]),original:o[a],separator:o[a-1]}),this.$=o[a-2];break;case 45:this.$=[{part:n.id(o[a]),original:o[a]}];break;case 46:case 48:case 50:case 58:case 64:case 70:case 78:case 82:case 86:case 90:case 94:this.$=[];break;case 47:case 49:case 51:case 59:case 65:case 71:case 79:case 83:case 87:case 91:case 95:case 99:case 101:o[a-1].push(o[a]);break;case 98:case 100:this.$=[o[a]]}},table:[{3:1,4:2,5:[2,46],6:3,14:[2,46],15:[2,46],19:[2,46],29:[2,46],34:[2,46],48:[2,46],51:[2,46],55:[2,46],60:[2,46]},{1:[3]},{5:[1,4]},{5:[2,2],7:5,8:6,9:7,10:8,11:9,12:10,13:11,14:[1,12],15:[1,20],16:17,19:[1,23],24:15,27:16,29:[1,21],34:[1,22],39:[2,2],44:[2,2],47:[2,2],48:[1,13],51:[1,14],55:[1,18],59:19,60:[1,24]},{1:[2,1]},{5:[2,47],14:[2,47],15:[2,47],19:[2,47],29:[2,47],34:[2,47],39:[2,47],44:[2,47],47:[2,47],48:[2,47],51:[2,47],55:[2,47],60:[2,47]},{5:[2,3],14:[2,3],15:[2,3],19:[2,3],29:[2,3],34:[2,3],39:[2,3],44:[2,3],47:[2,3],48:[2,3],51:[2,3],55:[2,3],60:[2,3]},{5:[2,4],14:[2,4],15:[2,4],19:[2,4],29:[2,4],34:[2,4],39:[2,4],44:[2,4],47:[2,4],48:[2,4],51:[2,4],55:[2,4],60:[2,4]},{5:[2,5],14:[2,5],15:[2,5],19:[2,5],29:[2,5],34:[2,5],39:[2,5],44:[2,5],47:[2,5],48:[2,5],51:[2,5],55:[2,5],60:[2,5]},{5:[2,6],14:[2,6],15:[2,6],19:[2,6],29:[2,6],34:[2,6],39:[2,6],44:[2,6],47:[2,6],48:[2,6],51:[2,6],55:[2,6],60:[2,6]},{5:[2,7],14:[2,7],15:[2,7],19:[2,7],29:[2,7],34:[2,7],39:[2,7],44:[2,7],47:[2,7],48:[2,7],51:[2,7],55:[2,7],60:[2,7]},{5:[2,8],14:[2,8],15:[2,8],19:[2,8],29:[2,8],34:[2,8],39:[2,8],44:[2,8],47:[2,8],48:[2,8],51:[2,8],55:[2,8],60:[2,8]},{5:[2,9],14:[2,9],15:[2,9],19:[2,9],29:[2,9],34:[2,9],39:[2,9],44:[2,9],47:[2,9],48:[2,9],51:[2,9],55:[2,9],60:[2,9]},{20:25,72:[1,35],78:26,79:27,80:[1,28],81:[1,29],82:[1,30],83:[1,31],84:[1,32],85:[1,34],86:33},{20:36,72:[1,35],78:26,79:27,80:[1,28],81:[1,29],82:[1,30],83:[1,31],84:[1,32],85:[1,34],86:33},{4:37,6:3,14:[2,46],15:[2,46],19:[2,46],29:[2,46],34:[2,46],39:[2,46],44:[2,46],47:[2,46],48:[2,46],51:[2,46],55:[2,46],60:[2,46]},{4:38,6:3,14:[2,46],15:[2,46],19:[2,46],29:[2,46],34:[2,46],44:[2,46],47:[2,46],48:[2,46],51:[2,46],55:[2,46],60:[2,46]},{15:[2,48],17:39,18:[2,48]},{20:41,56:40,64:42,65:[1,43],72:[1,35],78:26,79:27,80:[1,28],81:[1,29],82:[1,30],83:[1,31],84:[1,32],85:[1,34],86:33},{4:44,6:3,14:[2,46],15:[2,46],19:[2,46],29:[2,46],34:[2,46],47:[2,46],48:[2,46],51:[2,46],55:[2,46],60:[2,46]},{5:[2,10],14:[2,10],15:[2,10],18:[2,10],19:[2,10],29:[2,10],34:[2,10],39:[2,10],44:[2,10],47:[2,10],48:[2,10],51:[2,10],55:[2,10],60:[2,10]},{20:45,72:[1,35],78:26,79:27,80:[1,28],81:[1,29],82:[1,30],83:[1,31],84:[1,32],85:[1,34],86:33},{20:46,72:[1,35],78:26,79:27,80:[1,28],81:[1,29],82:[1,30],83:[1,31],84:[1,32],85:[1,34],86:33},{20:47,72:[1,35],78:26,79:27,80:[1,28],81:[1,29],82:[1,30],83:[1,31],84:[1,32],85:[1,34],86:33},{20:41,56:48,64:42,65:[1,43],72:[1,35],78:26,79:27,80:[1,28],81:[1,29],82:[1,30],83:[1,31],84:[1,32],85:[1,34],86:33},{33:[2,78],49:49,65:[2,78],72:[2,78],80:[2,78],81:[2,78],82:[2,78],83:[2,78],84:[2,78],85:[2,78]},{23:[2,33],33:[2,33],54:[2,33],65:[2,33],68:[2,33],72:[2,33],75:[2,33],80:[2,33],81:[2,33],82:[2,33],83:[2,33],84:[2,33],85:[2,33]},{23:[2,34],33:[2,34],54:[2,34],65:[2,34],68:[2,34],72:[2,34],75:[2,34],80:[2,34],81:[2,34],82:[2,34],83:[2,34],84:[2,34],85:[2,34]},{23:[2,35],33:[2,35],54:[2,35],65:[2,35],68:[2,35],72:[2,35],75:[2,35],80:[2,35],81:[2,35],82:[2,35],83:[2,35],84:[2,35],85:[2,35]},{23:[2,36],33:[2,36],54:[2,36],65:[2,36],68:[2,36],72:[2,36],75:[2,36],80:[2,36],81:[2,36],82:[2,36],83:[2,36],84:[2,36],85:[2,36]},{23:[2,37],33:[2,37],54:[2,37],65:[2,37],68:[2,37],72:[2,37],75:[2,37],80:[2,37],81:[2,37],82:[2,37],83:[2,37],84:[2,37],85:[2,37]},{23:[2,38],33:[2,38],54:[2,38],65:[2,38],68:[2,38],72:[2,38],75:[2,38],80:[2,38],81:[2,38],82:[2,38],83:[2,38],84:[2,38],85:[2,38]},{23:[2,39],33:[2,39],54:[2,39],65:[2,39],68:[2,39],72:[2,39],75:[2,39],80:[2,39],81:[2,39],82:[2,39],83:[2,39],84:[2,39],85:[2,39]},{23:[2,43],33:[2,43],54:[2,43],65:[2,43],68:[2,43],72:[2,43],75:[2,43],80:[2,43],81:[2,43],82:[2,43],83:[2,43],84:[2,43],85:[2,43],87:[1,50]},{72:[1,35],86:51},{23:[2,45],33:[2,45],54:[2,45],65:[2,45],68:[2,45],72:[2,45],75:[2,45],80:[2,45],81:[2,45],82:[2,45],83:[2,45],84:[2,45],85:[2,45],87:[2,45]},{52:52,54:[2,82],65:[2,82],72:[2,82],80:[2,82],81:[2,82],82:[2,82],83:[2,82],84:[2,82],85:[2,82]},{25:53,38:55,39:[1,57],43:56,44:[1,58],45:54,47:[2,54]},{28:59,43:60,44:[1,58],47:[2,56]},{13:62,15:[1,20],18:[1,61]},{33:[2,86],57:63,65:[2,86],72:[2,86],80:[2,86],81:[2,86],82:[2,86],83:[2,86],84:[2,86],85:[2,86]},{33:[2,40],65:[2,40],72:[2,40],80:[2,40],81:[2,40],82:[2,40],83:[2,40],84:[2,40],85:[2,40]},{33:[2,41],65:[2,41],72:[2,41],80:[2,41],81:[2,41],82:[2,41],83:[2,41],84:[2,41],85:[2,41]},{20:64,72:[1,35],78:26,79:27,80:[1,28],81:[1,29],82:[1,30],83:[1,31],84:[1,32],85:[1,34],86:33},{26:65,47:[1,66]},{30:67,33:[2,58],65:[2,58],72:[2,58],75:[2,58],80:[2,58],81:[2,58],82:[2,58],83:[2,58],84:[2,58],85:[2,58]},{33:[2,64],35:68,65:[2,64],72:[2,64],75:[2,64],80:[2,64],81:[2,64],82:[2,64],83:[2,64],84:[2,64],85:[2,64]},{21:69,23:[2,50],65:[2,50],72:[2,50],80:[2,50],81:[2,50],82:[2,50],83:[2,50],84:[2,50],85:[2,50]},{33:[2,90],61:70,65:[2,90],72:[2,90],80:[2,90],81:[2,90],82:[2,90],83:[2,90],84:[2,90],85:[2,90]},{20:74,33:[2,80],50:71,63:72,64:75,65:[1,43],69:73,70:76,71:77,72:[1,78],78:26,79:27,80:[1,28],81:[1,29],82:[1,30],83:[1,31],84:[1,32],85:[1,34],86:33},{72:[1,79]},{23:[2,42],33:[2,42],54:[2,42],65:[2,42],68:[2,42],72:[2,42],75:[2,42],80:[2,42],81:[2,42],82:[2,42],83:[2,42],84:[2,42],85:[2,42],87:[1,50]},{20:74,53:80,54:[2,84],63:81,64:75,65:[1,43],69:82,70:76,71:77,72:[1,78],78:26,79:27,80:[1,28],81:[1,29],82:[1,30],83:[1,31],84:[1,32],85:[1,34],86:33},{26:83,47:[1,66]},{47:[2,55]},{4:84,6:3,14:[2,46],15:[2,46],19:[2,46],29:[2,46],34:[2,46],39:[2,46],44:[2,46],47:[2,46],48:[2,46],51:[2,46],55:[2,46],60:[2,46]},{47:[2,20]},{20:85,72:[1,35],78:26,79:27,80:[1,28],81:[1,29],82:[1,30],83:[1,31],84:[1,32],85:[1,34],86:33},{4:86,6:3,14:[2,46],15:[2,46],19:[2,46],29:[2,46],34:[2,46],47:[2,46],48:[2,46],51:[2,46],55:[2,46],60:[2,46]},{26:87,47:[1,66]},{47:[2,57]},{5:[2,11],14:[2,11],15:[2,11],19:[2,11],29:[2,11],34:[2,11],39:[2,11],44:[2,11],47:[2,11],48:[2,11],51:[2,11],55:[2,11],60:[2,11]},{15:[2,49],18:[2,49]},{20:74,33:[2,88],58:88,63:89,64:75,65:[1,43],69:90,70:76,71:77,72:[1,78],78:26,79:27,80:[1,28],81:[1,29],82:[1,30],83:[1,31],84:[1,32],85:[1,34],86:33},{65:[2,94],66:91,68:[2,94],72:[2,94],80:[2,94],81:[2,94],82:[2,94],83:[2,94],84:[2,94],85:[2,94]},{5:[2,25],14:[2,25],15:[2,25],19:[2,25],29:[2,25],34:[2,25],39:[2,25],44:[2,25],47:[2,25],48:[2,25],51:[2,25],55:[2,25],60:[2,25]},{20:92,72:[1,35],78:26,79:27,80:[1,28],81:[1,29],82:[1,30],83:[1,31],84:[1,32],85:[1,34],86:33},{20:74,31:93,33:[2,60],63:94,64:75,65:[1,43],69:95,70:76,71:77,72:[1,78],75:[2,60],78:26,79:27,80:[1,28],81:[1,29],82:[1,30],83:[1,31],84:[1,32],85:[1,34],86:33},{20:74,33:[2,66],36:96,63:97,64:75,65:[1,43],69:98,70:76,71:77,72:[1,78],75:[2,66],78:26,79:27,80:[1,28],81:[1,29],82:[1,30],83:[1,31],84:[1,32],85:[1,34],86:33},{20:74,22:99,23:[2,52],63:100,64:75,65:[1,43],69:101,70:76,71:77,72:[1,78],78:26,79:27,80:[1,28],81:[1,29],82:[1,30],83:[1,31],84:[1,32],85:[1,34],86:33},{20:74,33:[2,92],62:102,63:103,64:75,65:[1,43],69:104,70:76,71:77,72:[1,78],78:26,79:27,80:[1,28],81:[1,29],82:[1,30],83:[1,31],84:[1,32],85:[1,34],86:33},{33:[1,105]},{33:[2,79],65:[2,79],72:[2,79],80:[2,79],81:[2,79],82:[2,79],83:[2,79],84:[2,79],85:[2,79]},{33:[2,81]},{23:[2,27],33:[2,27],54:[2,27],65:[2,27],68:[2,27],72:[2,27],75:[2,27],80:[2,27],81:[2,27],82:[2,27],83:[2,27],84:[2,27],85:[2,27]},{23:[2,28],33:[2,28],54:[2,28],65:[2,28],68:[2,28],72:[2,28],75:[2,28],80:[2,28],81:[2,28],82:[2,28],83:[2,28],84:[2,28],85:[2,28]},{23:[2,30],33:[2,30],54:[2,30],68:[2,30],71:106,72:[1,107],75:[2,30]},{23:[2,98],33:[2,98],54:[2,98],68:[2,98],72:[2,98],75:[2,98]},{23:[2,45],33:[2,45],54:[2,45],65:[2,45],68:[2,45],72:[2,45],73:[1,108],75:[2,45],80:[2,45],81:[2,45],82:[2,45],83:[2,45],84:[2,45],85:[2,45],87:[2,45]},{23:[2,44],33:[2,44],54:[2,44],65:[2,44],68:[2,44],72:[2,44],75:[2,44],80:[2,44],81:[2,44],82:[2,44],83:[2,44],84:[2,44],85:[2,44],87:[2,44]},{54:[1,109]},{54:[2,83],65:[2,83],72:[2,83],80:[2,83],81:[2,83],82:[2,83],83:[2,83],84:[2,83],85:[2,83]},{54:[2,85]},{5:[2,13],14:[2,13],15:[2,13],19:[2,13],29:[2,13],34:[2,13],39:[2,13],44:[2,13],47:[2,13],48:[2,13],51:[2,13],55:[2,13],60:[2,13]},{38:55,39:[1,57],43:56,44:[1,58],45:111,46:110,47:[2,76]},{33:[2,70],40:112,65:[2,70],72:[2,70],75:[2,70],80:[2,70],81:[2,70],82:[2,70],83:[2,70],84:[2,70],85:[2,70]},{47:[2,18]},{5:[2,14],14:[2,14],15:[2,14],19:[2,14],29:[2,14],34:[2,14],39:[2,14],44:[2,14],47:[2,14],48:[2,14],51:[2,14],55:[2,14],60:[2,14]},{33:[1,113]},{33:[2,87],65:[2,87],72:[2,87],80:[2,87],81:[2,87],82:[2,87],83:[2,87],84:[2,87],85:[2,87]},{33:[2,89]},{20:74,63:115,64:75,65:[1,43],67:114,68:[2,96],69:116,70:76,71:77,72:[1,78],78:26,79:27,80:[1,28],81:[1,29],82:[1,30],83:[1,31],84:[1,32],85:[1,34],86:33},{33:[1,117]},{32:118,33:[2,62],74:119,75:[1,120]},{33:[2,59],65:[2,59],72:[2,59],75:[2,59],80:[2,59],81:[2,59],82:[2,59],83:[2,59],84:[2,59],85:[2,59]},{33:[2,61],75:[2,61]},{33:[2,68],37:121,74:122,75:[1,120]},{33:[2,65],65:[2,65],72:[2,65],75:[2,65],80:[2,65],81:[2,65],82:[2,65],83:[2,65],84:[2,65],85:[2,65]},{33:[2,67],75:[2,67]},{23:[1,123]},{23:[2,51],65:[2,51],72:[2,51],80:[2,51],81:[2,51],82:[2,51],83:[2,51],84:[2,51],85:[2,51]},{23:[2,53]},{33:[1,124]},{33:[2,91],65:[2,91],72:[2,91],80:[2,91],81:[2,91],82:[2,91],83:[2,91],84:[2,91],85:[2,91]},{33:[2,93]},{5:[2,22],14:[2,22],15:[2,22],19:[2,22],29:[2,22],34:[2,22],39:[2,22],44:[2,22],47:[2,22],48:[2,22],51:[2,22],55:[2,22],60:[2,22]},{23:[2,99],33:[2,99],54:[2,99],68:[2,99],72:[2,99],75:[2,99]},{73:[1,108]},{20:74,63:125,64:75,65:[1,43],72:[1,35],78:26,79:27,80:[1,28],81:[1,29],82:[1,30],83:[1,31],84:[1,32],85:[1,34],86:33},{5:[2,23],14:[2,23],15:[2,23],19:[2,23],29:[2,23],34:[2,23],39:[2,23],44:[2,23],47:[2,23],48:[2,23],51:[2,23],55:[2,23],60:[2,23]},{47:[2,19]},{47:[2,77]},{20:74,33:[2,72],41:126,63:127,64:75,65:[1,43],69:128,70:76,71:77,72:[1,78],75:[2,72],78:26,79:27,80:[1,28],81:[1,29],82:[1,30],83:[1,31],84:[1,32],85:[1,34],86:33},{5:[2,24],14:[2,24],15:[2,24],19:[2,24],29:[2,24],34:[2,24],39:[2,24],44:[2,24],47:[2,24],48:[2,24],51:[2,24],55:[2,24],60:[2,24]},{68:[1,129]},{65:[2,95],68:[2,95],72:[2,95],80:[2,95],81:[2,95],82:[2,95],83:[2,95],84:[2,95],85:[2,95]},{68:[2,97]},{5:[2,21],14:[2,21],15:[2,21],19:[2,21],29:[2,21],34:[2,21],39:[2,21],44:[2,21],47:[2,21],48:[2,21],51:[2,21],55:[2,21],60:[2,21]},{33:[1,130]},{33:[2,63]},{72:[1,132],76:131},{33:[1,133]},{33:[2,69]},{15:[2,12],18:[2,12]},{14:[2,26],15:[2,26],19:[2,26],29:[2,26],34:[2,26],47:[2,26],48:[2,26],51:[2,26],55:[2,26],60:[2,26]},{23:[2,31],33:[2,31],54:[2,31],68:[2,31],72:[2,31],75:[2,31]},{33:[2,74],42:134,74:135,75:[1,120]},{33:[2,71],65:[2,71],72:[2,71],75:[2,71],80:[2,71],81:[2,71],82:[2,71],83:[2,71],84:[2,71],85:[2,71]},{33:[2,73],75:[2,73]},{23:[2,29],33:[2,29],54:[2,29],65:[2,29],68:[2,29],72:[2,29],75:[2,29],80:[2,29],81:[2,29],82:[2,29],83:[2,29],84:[2,29],85:[2,29]},{14:[2,15],15:[2,15],19:[2,15],29:[2,15],34:[2,15],39:[2,15],44:[2,15],47:[2,15],48:[2,15],51:[2,15],55:[2,15],60:[2,15]},{72:[1,137],77:[1,136]},{72:[2,100],77:[2,100]},{14:[2,16],15:[2,16],19:[2,16],29:[2,16],34:[2,16],44:[2,16],47:[2,16],48:[2,16],51:[2,16],55:[2,16],60:[2,16]},{33:[1,138]},{33:[2,75]},{33:[2,32]},{72:[2,101],77:[2,101]},{14:[2,17],15:[2,17],19:[2,17],29:[2,17],34:[2,17],39:[2,17],44:[2,17],47:[2,17],48:[2,17],51:[2,17],55:[2,17],60:[2,17]}],defaultActions:{4:[2,1],54:[2,55],56:[2,20],60:[2,57],73:[2,81],82:[2,85],86:[2,18],90:[2,89],101:[2,53],104:[2,93],110:[2,19],111:[2,77],116:[2,97],119:[2,63],122:[2,69],135:[2,75],136:[2,32]},parseError:function(t,e){throw new Error(t)},parse:function(t){function e(){var t;return"number"!=typeof(t=i.lexer.lex()||1)&&(t=i.symbols_[t]||t),t}var i=this,n=[0],r=[null],o=[],s=this.table,a="",l=0,h=0,u=0;this.lexer.setInput(t),this.lexer.yy=this.yy,this.yy.lexer=this.lexer,this.yy.parser=this,void 0===this.lexer.yylloc&&(this.lexer.yylloc={});var c=this.lexer.yylloc;o.push(c);var d=this.lexer.options&&this.lexer.options.ranges;"function"==typeof this.yy.parseError&&(this.parseError=this.yy.parseError);for(var p,f,m,v,g,y,b,_,w,k={};;){if(m=n[n.length-1],this.defaultActions[m]?v=this.defaultActions[m]:(null!=p||(p=e()),v=s[m]&&s[m][p]),void 0===v||!v.length||!v[0]){var x="";if(!u){for(y in w=[],s[m])this.terminals_[y]&&y>2&&w.push("'"+this.terminals_[y]+"'");x=this.lexer.showPosition?"Parse error on line "+(l+1)+":\n"+this.lexer.showPosition()+"\nExpecting "+w.join(", ")+", got '"+(this.terminals_[p]||p)+"'":"Parse error on line "+(l+1)+": Unexpected "+(1==p?"end of input":"'"+(this.terminals_[p]||p)+"'"),this.parseError(x,{text:this.lexer.match,token:this.terminals_[p]||p,line:this.lexer.yylineno,loc:c,expected:w})}}if(v[0]instanceof Array&&v.length>1)throw new Error("Parse Error: multiple actions possible at state: "+m+", token: "+p);switch(v[0]){case 1:n.push(p),r.push(this.lexer.yytext),o.push(this.lexer.yylloc),n.push(v[1]),p=null,f?(p=f,f=null):(h=this.lexer.yyleng,a=this.lexer.yytext,l=this.lexer.yylineno,c=this.lexer.yylloc,u>0&&u--);break;case 2:if(b=this.productions_[v[1]][1],k.$=r[r.length-b],k._$={first_line:o[o.length-(b||1)].first_line,last_line:o[o.length-1].last_line,first_column:o[o.length-(b||1)].first_column,last_column:o[o.length-1].last_column},d&&(k._$.range=[o[o.length-(b||1)].range[0],o[o.length-1].range[1]]),void 0!==(g=this.performAction.call(k,a,h,l,this.yy,v[1],r,o)))return g;b&&(n=n.slice(0,-1*b*2),r=r.slice(0,-1*b),o=o.slice(0,-1*b)),n.push(this.productions_[v[1]][0]),r.push(k.$),o.push(k._$),_=s[n[n.length-2]][n[n.length-1]],n.push(_);break;case 3:return!0}}return!0}},i=function(){var t={EOF:1,parseError:function(t,e){if(!this.yy.parser)throw new Error(t);this.yy.parser.parseError(t,e)},setInput:function(t){return this._input=t,this._more=this._less=this.done=!1,this.yylineno=this.yyleng=0,this.yytext=this.matched=this.match="",this.conditionStack=["INITIAL"],this.yylloc={first_line:1,first_column:0,last_line:1,last_column:0},this.options.ranges&&(this.yylloc.range=[0,0]),this.offset=0,this},input:function(){var t=this._input[0];return this.yytext+=t,this.yyleng++,this.offset++,this.match+=t,this.matched+=t,t.match(/(?:\r\n?|\n).*/g)?(this.yylineno++,this.yylloc.last_line++):this.yylloc.last_column++,this.options.ranges&&this.yylloc.range[1]++,this._input=this._input.slice(1),t},unput:function(t){var e=t.length,i=t.split(/(?:\r\n?|\n)/g);this._input=t+this._input,this.yytext=this.yytext.substr(0,this.yytext.length-e-1),this.offset-=e;var n=this.match.split(/(?:\r\n?|\n)/g);this.match=this.match.substr(0,this.match.length-1),this.matched=this.matched.substr(0,this.matched.length-1),i.length-1&&(this.yylineno-=i.length-1);var r=this.yylloc.range;return this.yylloc={first_line:this.yylloc.first_line,last_line:this.yylineno+1,first_column:this.yylloc.first_column,last_column:i?(i.length===n.length?this.yylloc.first_column:0)+n[n.length-i.length].length-i[0].length:this.yylloc.first_column-e},this.options.ranges&&(this.yylloc.range=[r[0],r[0]+this.yyleng-e]),this},more:function(){return this._more=!0,this},less:function(t){this.unput(this.match.slice(t))},pastInput:function(){var t=this.matched.substr(0,this.matched.length-this.match.length);return(t.length>20?"...":"")+t.substr(-20).replace(/\n/g,"")},upcomingInput:function(){var t=this.match;return t.length<20&&(t+=this._input.substr(0,20-t.length)),(t.substr(0,20)+(t.length>20?"...":"")).replace(/\n/g,"")},showPosition:function(){var t=this.pastInput(),e=new Array(t.length+1).join("-");return t+this.upcomingInput()+"\n"+e+"^"},next:function(){if(this.done)return this.EOF;var t,e,i,n,r;this._input||(this.done=!0),this._more||(this.yytext="",this.match="");for(var o=this._currentRules(),s=0;s<o.length&&(!(i=this._input.match(this.rules[o[s]]))||e&&!(i[0].length>e[0].length)||(e=i,n=s,this.options.flex));s++);return e?((r=e[0].match(/(?:\r\n?|\n).*/g))&&(this.yylineno+=r.length),this.yylloc={first_line:this.yylloc.last_line,last_line:this.yylineno+1,first_column:this.yylloc.last_column,last_column:r?r[r.length-1].length-r[r.length-1].match(/\r?\n?/)[0].length:this.yylloc.last_column+e[0].length},this.yytext+=e[0],this.match+=e[0],this.matches=e,this.yyleng=this.yytext.length,this.options.ranges&&(this.yylloc.range=[this.offset,this.offset+=this.yyleng]),this._more=!1,this._input=this._input.slice(e[0].length),this.matched+=e[0],t=this.performAction.call(this,this.yy,this,o[n],this.conditionStack[this.conditionStack.length-1]),this.done&&this._input&&(this.done=!1),t||void 0):""===this._input?this.EOF:this.parseError("Lexical error on line "+(this.yylineno+1)+". Unrecognized text.\n"+this.showPosition(),{text:"",token:null,line:this.yylineno})},lex:function(){var t=this.next();return void 0!==t?t:this.lex()},begin:function(t){this.conditionStack.push(t)},popState:function(){return this.conditionStack.pop()},_currentRules:function(){return this.conditions[this.conditionStack[this.conditionStack.length-1]].rules},topState:function(){return this.conditionStack[this.conditionStack.length-2]},pushState:function(t){this.begin(t)},options:{},performAction:function(t,e,i,n){function r(t,i){return e.yytext=e.yytext.substring(t,e.yyleng-i+t)}switch(i){case 0:if("\\\\"===e.yytext.slice(-2)?(r(0,1),this.begin("mu")):"\\"===e.yytext.slice(-1)?(r(0,1),this.begin("emu")):this.begin("mu"),e.yytext)return 15;break;case 1:case 5:return 15;case 2:return this.popState(),15;case 3:return this.begin("raw"),15;case 4:return this.popState(),"raw"===this.conditionStack[this.conditionStack.length-1]?15:(r(5,9),"END_RAW_BLOCK");case 6:case 22:return this.popState(),14;case 7:return 65;case 8:return 68;case 9:return 19;case 10:return this.popState(),this.begin("raw"),23;case 11:return 55;case 12:return 60;case 13:return 29;case 14:return 47;case 15:case 16:return this.popState(),44;case 17:return 34;case 18:return 39;case 19:return 51;case 20:case 23:return 48;case 21:this.unput(e.yytext),this.popState(),this.begin("com");break;case 24:return 73;case 25:case 26:case 41:return 72;case 27:return 87;case 28:break;case 29:return this.popState(),54;case 30:return this.popState(),33;case 31:return e.yytext=r(1,2).replace(/\\"/g,'"'),80;case 32:return e.yytext=r(1,2).replace(/\\'/g,"'"),80;case 33:return 85;case 34:case 35:return 82;case 36:return 83;case 37:return 84;case 38:return 81;case 39:return 75;case 40:return 77;case 42:return e.yytext=e.yytext.replace(/\\([\\\]])/g,"$1"),72;case 43:return"INVALID";case 44:return 5}},rules:[/^(?:[^\x00]*?(?=(\{\{)))/,/^(?:[^\x00]+)/,/^(?:[^\x00]{2,}?(?=(\{\{|\\\{\{|\\\\\{\{|$)))/,/^(?:\{\{\{\{(?=[^/]))/,/^(?:\{\{\{\{\/[^\s!"#%-,\.\/;->@\[-\^`\{-~]+(?=[=}\s\/.])\}\}\}\})/,/^(?:[^\x00]+?(?=(\{\{\{\{)))/,/^(?:[\s\S]*?--(~)?\}\})/,/^(?:\()/,/^(?:\))/,/^(?:\{\{\{\{)/,/^(?:\}\}\}\})/,/^(?:\{\{(~)?>)/,/^(?:\{\{(~)?#>)/,/^(?:\{\{(~)?#\*?)/,/^(?:\{\{(~)?\/)/,/^(?:\{\{(~)?\^\s*(~)?\}\})/,/^(?:\{\{(~)?\s*else\s*(~)?\}\})/,/^(?:\{\{(~)?\^)/,/^(?:\{\{(~)?\s*else\b)/,/^(?:\{\{(~)?\{)/,/^(?:\{\{(~)?&)/,/^(?:\{\{(~)?!--)/,/^(?:\{\{(~)?![\s\S]*?\}\})/,/^(?:\{\{(~)?\*?)/,/^(?:=)/,/^(?:\.\.)/,/^(?:\.(?=([=~}\s\/.)|])))/,/^(?:[\/.])/,/^(?:\s+)/,/^(?:\}(~)?\}\})/,/^(?:(~)?\}\})/,/^(?:"(\\["]|[^"])*")/,/^(?:'(\\[']|[^'])*')/,/^(?:@)/,/^(?:true(?=([~}\s)])))/,/^(?:false(?=([~}\s)])))/,/^(?:undefined(?=([~}\s)])))/,/^(?:null(?=([~}\s)])))/,/^(?:-?[0-9]+(?:\.[0-9]+)?(?=([~}\s)])))/,/^(?:as\s+\|)/,/^(?:\|)/,/^(?:([^\s!"#%-,\.\/;->@\[-\^`\{-~]+(?=([=~}\s\/.)|]))))/,/^(?:\[(\\\]|[^\]])*\])/,/^(?:.)/,/^(?:$)/],conditions:{mu:{rules:[7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44],inclusive:!1},emu:{rules:[2],inclusive:!1},com:{rules:[6],inclusive:!1},raw:{rules:[3,4,5],inclusive:!1},INITIAL:{rules:[0,1,44],inclusive:!0}}};return t}();return e.lexer=i,t.prototype=e,e.Parser=t,new t}();e.default=i,t.exports=e.default},function(t,e,i){"use strict";function n(){var t=arguments.length<=0||void 0===arguments[0]?{}:arguments[0];this.options=t}function r(t,e,i){void 0===e&&(e=t.length);var n=t[e-1],r=t[e-2];return n?"ContentStatement"===n.type?(r||!i?/\r?\n\s*?$/:/(^|\r?\n)\s*?$/).test(n.original):void 0:i}function o(t,e,i){void 0===e&&(e=-1);var n=t[e+1],r=t[e+2];return n?"ContentStatement"===n.type?(r||!i?/^\s*?\r?\n/:/^\s*?(\r?\n|$)/).test(n.original):void 0:i}function s(t,e,i){var n=t[null==e?0:e+1];if(n&&"ContentStatement"===n.type&&(i||!n.rightStripped)){var r=n.value;n.value=n.value.replace(i?/^\s+/:/^[ \t]*\r?\n?/,""),n.rightStripped=n.value!==r}}function a(t,e,i){var n=t[null==e?t.length-1:e-1];if(n&&"ContentStatement"===n.type&&(i||!n.leftStripped)){var r=n.value;return n.value=n.value.replace(i?/\s+$/:/[ \t]+$/,""),n.leftStripped=n.value!==r,n.leftStripped}}var l=i(1).default;e.__esModule=!0;var h=l(i(88));n.prototype=new h.default,n.prototype.Program=function(t){var e=!this.options.ignoreStandalone,i=!this.isRootSeen;this.isRootSeen=!0;for(var n=t.body,l=0,h=n.length;l<h;l++){var u=n[l],c=this.accept(u);if(c){var d=r(n,l,i),p=o(n,l,i),f=c.openStandalone&&d,m=c.closeStandalone&&p,v=c.inlineStandalone&&d&&p;c.close&&s(n,l,!0),c.open&&a(n,l,!0),e&&v&&(s(n,l),a(n,l)&&"PartialStatement"===u.type&&(u.indent=/([ \t]+$)/.exec(n[l-1].original)[1])),e&&f&&(s((u.program||u.inverse).body),a(n,l)),e&&m&&(s(n,l),a((u.inverse||u.program).body))}}return t},n.prototype.BlockStatement=n.prototype.DecoratorBlock=n.prototype.PartialBlockStatement=function(t){this.accept(t.program),this.accept(t.inverse);var e=t.program||t.inverse,i=t.program&&t.inverse,n=i,l=i;if(i&&i.chained)for(n=i.body[0].program;l.chained;)l=l.body[l.body.length-1].program;var h={open:t.openStrip.open,close:t.closeStrip.close,openStandalone:o(e.body),closeStandalone:r((n||e).body)};if(t.openStrip.close&&s(e.body,null,!0),i){var u=t.inverseStrip;u.open&&a(e.body,null,!0),u.close&&s(n.body,null,!0),t.closeStrip.open&&a(l.body,null,!0),!this.options.ignoreStandalone&&r(e.body)&&o(n.body)&&(a(e.body),s(n.body))}else t.closeStrip.open&&a(e.body,null,!0);return h},n.prototype.Decorator=n.prototype.MustacheStatement=function(t){return t.strip},n.prototype.PartialStatement=n.prototype.CommentStatement=function(t){var e=t.strip||{};return{inlineStandalone:!0,open:e.open,close:e.close}},e.default=n,t.exports=e.default},function(t,e,i){"use strict";function n(){this.parents=[]}function r(t){this.acceptRequired(t,"path"),this.acceptArray(t.params),this.acceptKey(t,"hash")}function o(t){r.call(this,t),this.acceptKey(t,"program"),this.acceptKey(t,"inverse")}function s(t){this.acceptRequired(t,"name"),this.acceptArray(t.params),this.acceptKey(t,"hash")}var a=i(1).default;e.__esModule=!0;var l=a(i(6));n.prototype={constructor:n,mutating:!1,acceptKey:function(t,e){var i=this.accept(t[e]);if(this.mutating){if(i&&!n.prototype[i.type])throw new l.default('Unexpected node type "'+i.type+'" found when accepting '+e+" on "+t.type);t[e]=i}},acceptRequired:function(t,e){if(this.acceptKey(t,e),!t[e])throw new l.default(t.type+" requires "+e)},acceptArray:function(t){for(var e=0,i=t.length;e<i;e++)this.acceptKey(t,e),t[e]||(t.splice(e,1),e--,i--)},accept:function(t){if(t){if(!this[t.type])throw new l.default("Unknown type: "+t.type,t);this.current&&this.parents.unshift(this.current),this.current=t;var e=this[t.type](t);return this.current=this.parents.shift(),!this.mutating||e?e:!1!==e?t:void 0}},Program:function(t){this.acceptArray(t.body)},MustacheStatement:r,Decorator:r,BlockStatement:o,DecoratorBlock:o,PartialStatement:s,PartialBlockStatement:function(t){s.call(this,t),this.acceptKey(t,"program")},ContentStatement:function(){},CommentStatement:function(){},SubExpression:r,PathExpression:function(){},StringLiteral:function(){},NumberLiteral:function(){},BooleanLiteral:function(){},UndefinedLiteral:function(){},NullLiteral:function(){},Hash:function(t){this.acceptArray(t.pairs)},HashPair:function(t){this.acceptRequired(t,"value")}},e.default=n,t.exports=e.default},function(t,e,i){"use strict";function n(t,e){if(e=e.path?e.path.original:e,t.path.original!==e){var i={loc:t.path.loc};throw new o.default(t.path.original+" doesn't match "+e,i)}}var r=i(1).default;e.__esModule=!0,e.SourceLocation=function(t,e){this.source=t,this.start={line:e.first_line,column:e.first_column},this.end={line:e.last_line,column:e.last_column}},e.id=function(t){return/^\[.*\]$/.test(t)?t.substring(1,t.length-1):t},e.stripFlags=function(t,e){return{open:"~"===t.charAt(2),close:"~"===e.charAt(e.length-3)}},e.stripComment=function(t){return t.replace(/^\{\{~?!-?-?/,"").replace(/-?-?~?\}\}$/,"")},e.preparePath=function(t,e,i){i=this.locInfo(i);for(var n=t?"@":"",r=[],s=0,a=0,l=e.length;a<l;a++){var h=e[a].part,u=e[a].original!==h;if(n+=(e[a].separator||"")+h,u||".."!==h&&"."!==h&&"this"!==h)r.push(h);else{if(r.length>0)throw new o.default("Invalid path: "+n,{loc:i});".."===h&&s++}}return{type:"PathExpression",data:t,depth:s,parts:r,original:n,loc:i}},e.prepareMustache=function(t,e,i,n,r,o){var s=n.charAt(3)||n.charAt(2),a="{"!==s&&"&"!==s;return{type:/\*/.test(n)?"Decorator":"MustacheStatement",path:t,params:e,hash:i,escaped:a,strip:r,loc:this.locInfo(o)}},e.prepareRawBlock=function(t,e,i,r){n(t,i);var o={type:"Program",body:e,strip:{},loc:r=this.locInfo(r)};return{type:"BlockStatement",path:t.path,params:t.params,hash:t.hash,program:o,openStrip:{},inverseStrip:{},closeStrip:{},loc:r}},e.prepareBlock=function(t,e,i,r,s,a){r&&r.path&&n(t,r);var l=/\*/.test(t.open);e.blockParams=t.blockParams;var h=void 0,u=void 0;if(i){if(l)throw new o.default("Unexpected inverse block on decorator",i);i.chain&&(i.program.body[0].closeStrip=r.strip),u=i.strip,h=i.program}return s&&(s=h,h=e,e=s),{type:l?"DecoratorBlock":"BlockStatement",path:t.path,params:t.params,hash:t.hash,program:e,inverse:h,openStrip:t.strip,inverseStrip:u,closeStrip:r&&r.strip,loc:this.locInfo(a)}},e.prepareProgram=function(t,e){if(!e&&t.length){var i=t[0].loc,n=t[t.length-1].loc;i&&n&&(e={source:i.source,start:{line:i.start.line,column:i.start.column},end:{line:n.end.line,column:n.end.column}})}return{type:"Program",body:t,strip:{},loc:e}},e.preparePartialBlock=function(t,e,i,r){return n(t,i),{type:"PartialBlockStatement",name:t.path,params:t.params,hash:t.hash,program:e,openStrip:t.strip,closeStrip:i&&i.strip,loc:this.locInfo(r)}};var o=r(i(6))},function(t,e,i){"use strict";function n(){}function r(t,e){if(t===e)return!0;if(h.isArray(t)&&h.isArray(e)&&t.length===e.length){for(var i=0;i<t.length;i++)if(!r(t[i],e[i]))return!1;return!0}}function o(t){if(!t.path.parts){var e=t.path;t.path={type:"PathExpression",data:!1,depth:0,parts:[e.original+""],original:e.original+"",loc:e.loc}}}var s=i(74).default,a=i(1).default;e.__esModule=!0,e.Compiler=n,e.precompile=function(t,e,i){if(null==t||"string"!=typeof t&&"Program"!==t.type)throw new l.default("You must pass a string or Handlebars AST to Handlebars.precompile. You passed "+t);"data"in(e=e||{})||(e.data=!0),e.compat&&(e.useDepths=!0);var n=i.parse(t,e),r=(new i.Compiler).compile(n,e);return(new i.JavaScriptCompiler).compile(r,e)},e.compile=function(t,e,i){function n(){var n=i.parse(t,e),r=(new i.Compiler).compile(n,e),o=(new i.JavaScriptCompiler).compile(r,e,void 0,!0);return i.template(o)}function r(t,e){return o||(o=n()),o.call(this,t,e)}if(void 0===e&&(e={}),null==t||"string"!=typeof t&&"Program"!==t.type)throw new l.default("You must pass a string or Handlebars AST to Handlebars.compile. You passed "+t);"data"in(e=h.extend({},e))||(e.data=!0),e.compat&&(e.useDepths=!0);var o=void 0;return r._setup=function(t){return o||(o=n()),o._setup(t)},r._child=function(t,e,i,r){return o||(o=n()),o._child(t,e,i,r)},r};var l=a(i(6)),h=i(5),u=a(i(84)),c=[].slice;n.prototype={compiler:n,equals:function(t){var e=this.opcodes.length;if(t.opcodes.length!==e)return!1;for(var i=0;i<e;i++){var n=this.opcodes[i],o=t.opcodes[i];if(n.opcode!==o.opcode||!r(n.args,o.args))return!1}e=this.children.length;for(i=0;i<e;i++)if(!this.children[i].equals(t.children[i]))return!1;return!0},guid:0,compile:function(t,e){return this.sourceNode=[],this.opcodes=[],this.children=[],this.options=e,this.stringParams=e.stringParams,this.trackIds=e.trackIds,e.blockParams=e.blockParams||[],e.knownHelpers=h.extend(s(null),{helperMissing:!0,blockHelperMissing:!0,each:!0,if:!0,unless:!0,with:!0,log:!0,lookup:!0},e.knownHelpers),this.accept(t)},compileProgram:function(t){var e=(new this.compiler).compile(t,this.options),i=this.guid++;return this.usePartial=this.usePartial||e.usePartial,this.children[i]=e,this.useDepths=this.useDepths||e.useDepths,i},accept:function(t){if(!this[t.type])throw new l.default("Unknown type: "+t.type,t);this.sourceNode.unshift(t);var e=this[t.type](t);return this.sourceNode.shift(),e},Program:function(t){this.options.blockParams.unshift(t.blockParams);for(var e=t.body,i=e.length,n=0;n<i;n++)this.accept(e[n]);return this.options.blockParams.shift(),this.isSimple=1===i,this.blockParams=t.blockParams?t.blockParams.length:0,this},BlockStatement:function(t){o(t);var e=t.program,i=t.inverse;e=e&&this.compileProgram(e),i=i&&this.compileProgram(i);var n=this.classifySexpr(t);"helper"===n?this.helperSexpr(t,e,i):"simple"===n?(this.simpleSexpr(t),this.opcode("pushProgram",e),this.opcode("pushProgram",i),this.opcode("emptyHash"),this.opcode("blockValue",t.path.original)):(this.ambiguousSexpr(t,e,i),this.opcode("pushProgram",e),this.opcode("pushProgram",i),this.opcode("emptyHash"),this.opcode("ambiguousBlockValue")),this.opcode("append")},DecoratorBlock:function(t){var e=t.program&&this.compileProgram(t.program),i=this.setupFullMustacheParams(t,e,void 0),n=t.path;this.useDecorators=!0,this.opcode("registerDecorator",i.length,n.original)},PartialStatement:function(t){this.usePartial=!0;var e=t.program;e&&(e=this.compileProgram(t.program));var i=t.params;if(i.length>1)throw new l.default("Unsupported number of partial arguments: "+i.length,t);i.length||(this.options.explicitPartialContext?this.opcode("pushLiteral","undefined"):i.push({type:"PathExpression",parts:[],depth:0}));var n=t.name.original,r="SubExpression"===t.name.type;r&&this.accept(t.name),this.setupFullMustacheParams(t,e,void 0,!0);var o=t.indent||"";this.options.preventIndent&&o&&(this.opcode("appendContent",o),o=""),this.opcode("invokePartial",r,n,o),this.opcode("append")},PartialBlockStatement:function(t){this.PartialStatement(t)},MustacheStatement:function(t){this.SubExpression(t),t.escaped&&!this.options.noEscape?this.opcode("appendEscaped"):this.opcode("append")},Decorator:function(t){this.DecoratorBlock(t)},ContentStatement:function(t){t.value&&this.opcode("appendContent",t.value)},CommentStatement:function(){},SubExpression:function(t){o(t);var e=this.classifySexpr(t);"simple"===e?this.simpleSexpr(t):"helper"===e?this.helperSexpr(t):this.ambiguousSexpr(t)},ambiguousSexpr:function(t,e,i){var n=t.path,r=n.parts[0],o=null!=e||null!=i;this.opcode("getContext",n.depth),this.opcode("pushProgram",e),this.opcode("pushProgram",i),n.strict=!0,this.accept(n),this.opcode("invokeAmbiguous",r,o)},simpleSexpr:function(t){var e=t.path;e.strict=!0,this.accept(e),this.opcode("resolvePossibleLambda")},helperSexpr:function(t,e,i){var n=this.setupFullMustacheParams(t,e,i),r=t.path,o=r.parts[0];if(this.options.knownHelpers[o])this.opcode("invokeKnownHelper",n.length,o);else{if(this.options.knownHelpersOnly)throw new l.default("You specified knownHelpersOnly, but used the unknown helper "+o,t);r.strict=!0,r.falsy=!0,this.accept(r),this.opcode("invokeHelper",n.length,r.original,u.default.helpers.simpleId(r))}},PathExpression:function(t){this.addDepth(t.depth),this.opcode("getContext",t.depth);var e=t.parts[0],i=u.default.helpers.scopedId(t),n=!t.depth&&!i&&this.blockParamIndex(e);n?this.opcode("lookupBlockParam",n,t.parts):e?t.data?(this.options.data=!0,this.opcode("lookupData",t.depth,t.parts,t.strict)):this.opcode("lookupOnContext",t.parts,t.falsy,t.strict,i):this.opcode("pushContext")},StringLiteral:function(t){this.opcode("pushString",t.value)},NumberLiteral:function(t){this.opcode("pushLiteral",t.value)},BooleanLiteral:function(t){this.opcode("pushLiteral",t.value)},UndefinedLiteral:function(){this.opcode("pushLiteral","undefined")},NullLiteral:function(){this.opcode("pushLiteral","null")},Hash:function(t){var e=t.pairs,i=0,n=e.length;for(this.opcode("pushHash");i<n;i++)this.pushParam(e[i].value);for(;i--;)this.opcode("assignToHash",e[i].key);this.opcode("popHash")},opcode:function(t){this.opcodes.push({opcode:t,args:c.call(arguments,1),loc:this.sourceNode[0].loc})},addDepth:function(t){t&&(this.useDepths=!0)},classifySexpr:function(t){var e=u.default.helpers.simpleId(t.path),i=e&&!!this.blockParamIndex(t.path.parts[0]),n=!i&&u.default.helpers.helperExpression(t),r=!i&&(n||e);if(r&&!n){var o=t.path.parts[0],s=this.options;s.knownHelpers[o]?n=!0:s.knownHelpersOnly&&(r=!1)}return n?"helper":r?"ambiguous":"simple"},pushParams:function(t){for(var e=0,i=t.length;e<i;e++)this.pushParam(t[e])},pushParam:function(t){var e=null!=t.value?t.value:t.original||"";if(this.stringParams)e.replace&&(e=e.replace(/^(\.?\.\/)*/g,"").replace(/\//g,".")),t.depth&&this.addDepth(t.depth),this.opcode("getContext",t.depth||0),this.opcode("pushStringParam",e,t.type),"SubExpression"===t.type&&this.accept(t);else{if(this.trackIds){var i=void 0;if(!t.parts||u.default.helpers.scopedId(t)||t.depth||(i=this.blockParamIndex(t.parts[0])),i){var n=t.parts.slice(1).join(".");this.opcode("pushId","BlockParam",i,n)}else(e=t.original||e).replace&&(e=e.replace(/^this(?:\.|$)/,"").replace(/^\.\//,"").replace(/^\.$/,"")),this.opcode("pushId",t.type,e)}this.accept(t)}},setupFullMustacheParams:function(t,e,i,n){var r=t.params;return this.pushParams(r),this.opcode("pushProgram",e),this.opcode("pushProgram",i),t.hash?this.accept(t.hash):this.opcode("emptyHash",n),r},blockParamIndex:function(t){for(var e=0,i=this.options.blockParams.length;e<i;e++){var n=this.options.blockParams[e],r=n&&h.indexOf(n,t);if(n&&r>=0)return[e,r]}}}},function(t,e,i){"use strict";function n(t){this.value=t}function r(){}var o=i(60).default,s=i(1).default;e.__esModule=!0;var a=i(4),l=s(i(6)),h=i(5),u=s(i(92));r.prototype={nameLookup:function(t,e){return this.internalNameLookup(t,e)},depthedLookup:function(t){return[this.aliasable("container.lookup"),"(depths, ",JSON.stringify(t),")"]},compilerInfo:function(){var t=a.COMPILER_REVISION;return[t,a.REVISION_CHANGES[t]]},appendToBuffer:function(t,e,i){return h.isArray(t)||(t=[t]),t=this.source.wrap(t,e),this.environment.isSimple?["return ",t,";"]:i?["buffer += ",t,";"]:(t.appendToBuffer=!0,t)},initializeBuffer:function(){return this.quotedString("")},internalNameLookup:function(t,e){return this.lookupPropertyFunctionIsUsed=!0,["lookupProperty(",t,",",JSON.stringify(e),")"]},lookupPropertyFunctionIsUsed:!1,compile:function(t,e,i,n){this.environment=t,this.options=e,this.stringParams=this.options.stringParams,this.trackIds=this.options.trackIds,this.precompile=!n,this.name=this.environment.name,this.isChild=!!i,this.context=i||{decorators:[],programs:[],environments:[]},this.preamble(),this.stackSlot=0,this.stackVars=[],this.aliases={},this.registers={list:[]},this.hashes=[],this.compileStack=[],this.inlineStack=[],this.blockParams=[],this.compileChildren(t,e),this.useDepths=this.useDepths||t.useDepths||t.useDecorators||this.options.compat,this.useBlockParams=this.useBlockParams||t.useBlockParams;var r=t.opcodes,o=void 0,s=void 0,a=void 0,h=void 0;for(a=0,h=r.length;a<h;a++)o=r[a],this.source.currentLocation=o.loc,s=s||o.loc,this[o.opcode].apply(this,o.args);if(this.source.currentLocation=s,this.pushSource(""),this.stackSlot||this.inlineStack.length||this.compileStack.length)throw new l.default("Compile completed with content left on stack");this.decorators.isEmpty()?this.decorators=void 0:(this.useDecorators=!0,this.decorators.prepend(["var decorators = container.decorators, ",this.lookupPropertyFunctionVarDeclaration(),";\n"]),this.decorators.push("return fn;"),n?this.decorators=Function.apply(this,["fn","props","container","depth0","data","blockParams","depths",this.decorators.merge()]):(this.decorators.prepend("function(fn, props, container, depth0, data, blockParams, depths) {\n"),this.decorators.push("}\n"),this.decorators=this.decorators.merge()));var u=this.createFunctionContext(n);if(this.isChild)return u;var c={compiler:this.compilerInfo(),main:u};this.decorators&&(c.main_d=this.decorators,c.useDecorators=!0);var d=this.context,p=d.programs,f=d.decorators;for(a=0,h=p.length;a<h;a++)p[a]&&(c[a]=p[a],f[a]&&(c[a+"_d"]=f[a],c.useDecorators=!0));return this.environment.usePartial&&(c.usePartial=!0),this.options.data&&(c.useData=!0),this.useDepths&&(c.useDepths=!0),this.useBlockParams&&(c.useBlockParams=!0),this.options.compat&&(c.compat=!0),n?c.compilerOptions=this.options:(c.compiler=JSON.stringify(c.compiler),this.source.currentLocation={start:{line:1,column:0}},c=this.objectLiteral(c),e.srcName?(c=c.toStringWithSourceMap({file:e.destName})).map=c.map&&c.map.toString():c=c.toString()),c},preamble:function(){this.lastContext=0,this.source=new u.default(this.options.srcName),this.decorators=new u.default(this.options.srcName)},createFunctionContext:function(t){var e=this,i="",n=this.stackVars.concat(this.registers.list);n.length>0&&(i+=", "+n.join(", "));var r=0;o(this.aliases).forEach((function(t){var n=e.aliases[t];n.children&&n.referenceCount>1&&(i+=", alias"+ ++r+"="+t,n.children[0]="alias"+r)})),this.lookupPropertyFunctionIsUsed&&(i+=", "+this.lookupPropertyFunctionVarDeclaration());var s=["container","depth0","helpers","partials","data"];(this.useBlockParams||this.useDepths)&&s.push("blockParams"),this.useDepths&&s.push("depths");var a=this.mergeSource(i);return t?(s.push(a),Function.apply(this,s)):this.source.wrap(["function(",s.join(","),") {\n  ",a,"}"])},mergeSource:function(t){var e=this.environment.isSimple,i=!this.forceBuffer,n=void 0,r=void 0,o=void 0,s=void 0;return this.source.each((function(t){t.appendToBuffer?(o?t.prepend("  + "):o=t,s=t):(o&&(r?o.prepend("buffer += "):n=!0,s.add(";"),o=s=void 0),r=!0,e||(i=!1))})),i?o?(o.prepend("return "),s.add(";")):r||this.source.push('return "";'):(t+=", buffer = "+(n?"":this.initializeBuffer()),o?(o.prepend("return buffer + "),s.add(";")):this.source.push("return buffer;")),t&&this.source.prepend("var "+t.substring(2)+(n?"":";\n")),this.source.merge()},lookupPropertyFunctionVarDeclaration:function(){return"\n      lookupProperty = container.lookupProperty || function(parent, propertyName) {\n        if (Object.prototype.hasOwnProperty.call(parent, propertyName)) {\n          return parent[propertyName];\n        }\n        return undefined\n    }\n    ".trim()},blockValue:function(t){var e=this.aliasable("container.hooks.blockHelperMissing"),i=[this.contextName(0)];this.setupHelperArgs(t,0,i);var n=this.popStack();i.splice(1,0,n),this.push(this.source.functionCall(e,"call",i))},ambiguousBlockValue:function(){var t=this.aliasable("container.hooks.blockHelperMissing"),e=[this.contextName(0)];this.setupHelperArgs("",0,e,!0),this.flushInline();var i=this.topStack();e.splice(1,0,i),this.pushSource(["if (!",this.lastHelper,") { ",i," = ",this.source.functionCall(t,"call",e),"}"])},appendContent:function(t){this.pendingContent?t=this.pendingContent+t:this.pendingLocation=this.source.currentLocation,this.pendingContent=t},append:function(){if(this.isInline())this.replaceStack((function(t){return[" != null ? ",t,' : ""']})),this.pushSource(this.appendToBuffer(this.popStack()));else{var t=this.popStack();this.pushSource(["if (",t," != null) { ",this.appendToBuffer(t,void 0,!0)," }"]),this.environment.isSimple&&this.pushSource(["else { ",this.appendToBuffer("''",void 0,!0)," }"])}},appendEscaped:function(){this.pushSource(this.appendToBuffer([this.aliasable("container.escapeExpression"),"(",this.popStack(),")"]))},getContext:function(t){this.lastContext=t},pushContext:function(){this.pushStackLiteral(this.contextName(this.lastContext))},lookupOnContext:function(t,e,i,n){var r=0;n||!this.options.compat||this.lastContext?this.pushContext():this.push(this.depthedLookup(t[r++])),this.resolvePath("context",t,r,e,i)},lookupBlockParam:function(t,e){this.useBlockParams=!0,this.push(["blockParams[",t[0],"][",t[1],"]"]),this.resolvePath("context",e,1)},lookupData:function(t,e,i){t?this.pushStackLiteral("container.data(data, "+t+")"):this.pushStackLiteral("data"),this.resolvePath("data",e,0,!0,i)},resolvePath:function(t,e,i,n,r){var o=this;if(this.options.strict||this.options.assumeObjects)this.push(function(t,e,i,n,r){var o=e.popStack(),s=i.length;for(t&&s--;n<s;n++)o=e.nameLookup(o,i[n],r);return t?[e.aliasable("container.strict"),"(",o,", ",e.quotedString(i[n]),", ",JSON.stringify(e.source.currentLocation)," )"]:o}(this.options.strict&&r,this,e,i,t));else for(var s=e.length;i<s;i++)this.replaceStack((function(r){var s=o.nameLookup(r,e[i],t);return n?[" && ",s]:[" != null ? ",s," : ",r]}))},resolvePossibleLambda:function(){this.push([this.aliasable("container.lambda"),"(",this.popStack(),", ",this.contextName(0),")"])},pushStringParam:function(t,e){this.pushContext(),this.pushString(e),"SubExpression"!==e&&("string"==typeof t?this.pushString(t):this.pushStackLiteral(t))},emptyHash:function(t){this.trackIds&&this.push("{}"),this.stringParams&&(this.push("{}"),this.push("{}")),this.pushStackLiteral(t?"undefined":"{}")},pushHash:function(){this.hash&&this.hashes.push(this.hash),this.hash={values:{},types:[],contexts:[],ids:[]}},popHash:function(){var t=this.hash;this.hash=this.hashes.pop(),this.trackIds&&this.push(this.objectLiteral(t.ids)),this.stringParams&&(this.push(this.objectLiteral(t.contexts)),this.push(this.objectLiteral(t.types))),this.push(this.objectLiteral(t.values))},pushString:function(t){this.pushStackLiteral(this.quotedString(t))},pushLiteral:function(t){this.pushStackLiteral(t)},pushProgram:function(t){null!=t?this.pushStackLiteral(this.programExpression(t)):this.pushStackLiteral(null)},registerDecorator:function(t,e){var i=this.nameLookup("decorators",e,"decorator"),n=this.setupHelperArgs(e,t);this.decorators.push(["fn = ",this.decorators.functionCall(i,"",["fn","props","container",n])," || fn;"])},invokeHelper:function(t,e,i){var n=this.popStack(),r=this.setupHelper(t,e),o=[];i&&o.push(r.name),o.push(n),this.options.strict||o.push(this.aliasable("container.hooks.helperMissing"));var s=["(",this.itemsSeparatedBy(o,"||"),")"],a=this.source.functionCall(s,"call",r.callParams);this.push(a)},itemsSeparatedBy:function(t,e){var i=[];i.push(t[0]);for(var n=1;n<t.length;n++)i.push(e,t[n]);return i},invokeKnownHelper:function(t,e){var i=this.setupHelper(t,e);this.push(this.source.functionCall(i.name,"call",i.callParams))},invokeAmbiguous:function(t,e){this.useRegister("helper");var i=this.popStack();this.emptyHash();var n=this.setupHelper(0,t,e),r=["(","(helper = ",this.lastHelper=this.nameLookup("helpers",t,"helper")," || ",i,")"];this.options.strict||(r[0]="(helper = ",r.push(" != null ? helper : ",this.aliasable("container.hooks.helperMissing"))),this.push(["(",r,n.paramsInit?["),(",n.paramsInit]:[],"),","(typeof helper === ",this.aliasable('"function"')," ? ",this.source.functionCall("helper","call",n.callParams)," : helper))"])},invokePartial:function(t,e,i){var n=[],r=this.setupParams(e,1,n);t&&(e=this.popStack(),delete r.name),i&&(r.indent=JSON.stringify(i)),r.helpers="helpers",r.partials="partials",r.decorators="container.decorators",t?n.unshift(e):n.unshift(this.nameLookup("partials",e,"partial")),this.options.compat&&(r.depths="depths"),r=this.objectLiteral(r),n.push(r),this.push(this.source.functionCall("container.invokePartial","",n))},assignToHash:function(t){var e=this.popStack(),i=void 0,n=void 0,r=void 0;this.trackIds&&(r=this.popStack()),this.stringParams&&(n=this.popStack(),i=this.popStack());var o=this.hash;i&&(o.contexts[t]=i),n&&(o.types[t]=n),r&&(o.ids[t]=r),o.values[t]=e},pushId:function(t,e,i){"BlockParam"===t?this.pushStackLiteral("blockParams["+e[0]+"].path["+e[1]+"]"+(i?" + "+JSON.stringify("."+i):"")):"PathExpression"===t?this.pushString(e):"SubExpression"===t?this.pushStackLiteral("true"):this.pushStackLiteral("null")},compiler:r,compileChildren:function(t,e){for(var i=t.children,n=void 0,r=void 0,o=0,s=i.length;o<s;o++){n=i[o],r=new this.compiler;var a=this.matchExistingProgram(n);if(null==a){this.context.programs.push("");var l=this.context.programs.length;n.index=l,n.name="program"+l,this.context.programs[l]=r.compile(n,e,this.context,!this.precompile),this.context.decorators[l]=r.decorators,this.context.environments[l]=n,this.useDepths=this.useDepths||r.useDepths,this.useBlockParams=this.useBlockParams||r.useBlockParams,n.useDepths=this.useDepths,n.useBlockParams=this.useBlockParams}else n.index=a.index,n.name="program"+a.index,this.useDepths=this.useDepths||a.useDepths,this.useBlockParams=this.useBlockParams||a.useBlockParams}},matchExistingProgram:function(t){for(var e=0,i=this.context.environments.length;e<i;e++){var n=this.context.environments[e];if(n&&n.equals(t))return n}},programExpression:function(t){var e=this.environment.children[t],i=[e.index,"data",e.blockParams];return(this.useBlockParams||this.useDepths)&&i.push("blockParams"),this.useDepths&&i.push("depths"),"container.program("+i.join(", ")+")"},useRegister:function(t){this.registers[t]||(this.registers[t]=!0,this.registers.list.push(t))},push:function(t){return t instanceof n||(t=this.source.wrap(t)),this.inlineStack.push(t),t},pushStackLiteral:function(t){this.push(new n(t))},pushSource:function(t){this.pendingContent&&(this.source.push(this.appendToBuffer(this.source.quotedString(this.pendingContent),this.pendingLocation)),this.pendingContent=void 0),t&&this.source.push(t)},replaceStack:function(t){var e=["("],i=void 0,r=void 0,o=void 0;if(!this.isInline())throw new l.default("replaceStack on non-inline");var s=this.popStack(!0);if(s instanceof n)e=["(",i=[s.value]],o=!0;else{r=!0;var a=this.incrStack();e=["((",this.push(a)," = ",s,")"],i=this.topStack()}var h=t.call(this,i);o||this.popStack(),r&&this.stackSlot--,this.push(e.concat(h,")"))},incrStack:function(){return this.stackSlot++,this.stackSlot>this.stackVars.length&&this.stackVars.push("stack"+this.stackSlot),this.topStackName()},topStackName:function(){return"stack"+this.stackSlot},flushInline:function(){var t=this.inlineStack;this.inlineStack=[];for(var e=0,i=t.length;e<i;e++){var r=t[e];if(r instanceof n)this.compileStack.push(r);else{var o=this.incrStack();this.pushSource([o," = ",r,";"]),this.compileStack.push(o)}}},isInline:function(){return this.inlineStack.length},popStack:function(t){var e=this.isInline(),i=(e?this.inlineStack:this.compileStack).pop();if(!t&&i instanceof n)return i.value;if(!e){if(!this.stackSlot)throw new l.default("Invalid stack pop");this.stackSlot--}return i},topStack:function(){var t=this.isInline()?this.inlineStack:this.compileStack,e=t[t.length-1];return e instanceof n?e.value:e},contextName:function(t){return this.useDepths&&t?"depths["+t+"]":"depth"+t},quotedString:function(t){return this.source.quotedString(t)},objectLiteral:function(t){return this.source.objectLiteral(t)},aliasable:function(t){var e=this.aliases[t];return e?(e.referenceCount++,e):((e=this.aliases[t]=this.source.wrap(t)).aliasable=!0,e.referenceCount=1,e)},setupHelper:function(t,e,i){var n=[];return{params:n,paramsInit:this.setupHelperArgs(e,t,n,i),name:this.nameLookup("helpers",e,"helper"),callParams:[this.aliasable(this.contextName(0)+" != null ? "+this.contextName(0)+" : (container.nullContext || {})")].concat(n)}},setupParams:function(t,e,i){var n={},r=[],o=[],s=[],a=!i,l=void 0;a&&(i=[]),n.name=this.quotedString(t),n.hash=this.popStack(),this.trackIds&&(n.hashIds=this.popStack()),this.stringParams&&(n.hashTypes=this.popStack(),n.hashContexts=this.popStack());var h=this.popStack(),u=this.popStack();(u||h)&&(n.fn=u||"container.noop",n.inverse=h||"container.noop");for(var c=e;c--;)l=this.popStack(),i[c]=l,this.trackIds&&(s[c]=this.popStack()),this.stringParams&&(o[c]=this.popStack(),r[c]=this.popStack());return a&&(n.args=this.source.generateArray(i)),this.trackIds&&(n.ids=this.source.generateArray(s)),this.stringParams&&(n.types=this.source.generateArray(o),n.contexts=this.source.generateArray(r)),this.options.data&&(n.data="data"),this.useBlockParams&&(n.blockParams="blockParams"),n},setupHelperArgs:function(t,e,i,n){var r=this.setupParams(t,e,i);return r.loc=JSON.stringify(this.source.currentLocation),r=this.objectLiteral(r),n?(this.useRegister("options"),i.push("options"),["options=",r]):i?(i.push(r),""):r}},function(){for(var t="break else new var case finally return void catch for switch while continue function this with default if throw delete in try do instanceof typeof abstract enum int short boolean export interface static byte extends long super char final native synchronized class float package throws const goto private transient debugger implements protected volatile double import public let yield await null true false".split(" "),e=r.RESERVED_WORDS={},i=0,n=t.length;i<n;i++)e[t[i]]=!0}(),r.isValidJavaScriptVariableName=function(t){return!r.RESERVED_WORDS[t]&&/^[a-zA-Z_$][0-9a-zA-Z_$]*$/.test(t)},e.default=r,t.exports=e.default},function(t,e,i){"use strict";function n(t,e,i){if(s.isArray(t)){for(var n=[],r=0,o=t.length;r<o;r++)n.push(e.wrap(t[r],i));return n}return"boolean"==typeof t||"number"==typeof t?t+"":t}function r(t){this.srcFile=t,this.source=[]}var o=i(60).default;e.__esModule=!0;var s=i(5),a=void 0;a||(a=function(t,e,i,n){this.src="",n&&this.add(n)},a.prototype={add:function(t){s.isArray(t)&&(t=t.join("")),this.src+=t},prepend:function(t){s.isArray(t)&&(t=t.join("")),this.src=t+this.src},toStringWithSourceMap:function(){return{code:this.toString()}},toString:function(){return this.src}}),r.prototype={isEmpty:function(){return!this.source.length},prepend:function(t,e){this.source.unshift(this.wrap(t,e))},push:function(t,e){this.source.push(this.wrap(t,e))},merge:function(){var t=this.empty();return this.each((function(e){t.add(["  ",e,"\n"])})),t},each:function(t){for(var e=0,i=this.source.length;e<i;e++)t(this.source[e])},empty:function(){var t=this.currentLocation||{start:{}};return new a(t.start.line,t.start.column,this.srcFile)},wrap:function(t){var e=arguments.length<=1||void 0===arguments[1]?this.currentLocation||{start:{}}:arguments[1];return t instanceof a?t:(t=n(t,this,e),new a(e.start.line,e.start.column,this.srcFile,t))},functionCall:function(t,e,i){return i=this.generateList(i),this.wrap([t,e?"."+e+"(":"(",i,")"])},quotedString:function(t){return'"'+(t+"").replace(/\\/g,"\\\\").replace(/"/g,'\\"').replace(/\n/g,"\\n").replace(/\r/g,"\\r").replace(/\u2028/g,"\\u2028").replace(/\u2029/g,"\\u2029")+'"'},objectLiteral:function(t){var e=this,i=[];o(t).forEach((function(r){var o=n(t[r],e);"undefined"!==o&&i.push([e.quotedString(r),":",o])}));var r=this.generateList(i);return r.prepend("{"),r.add("}"),r},generateList:function(t){for(var e=this.empty(),i=0,r=t.length;i<r;i++)i&&e.add(","),e.add(n(t[i],this));return e},generateArray:function(t){var e=this.generateList(t);return e.prepend("["),e.add("]"),e}},e.default=r,t.exports=e.default}])}));