/*! DataTables 1.13.7
 * ©2008-2023 SpryMedia Ltd - datatables.net/license
 */
/**
 * @summary     DataTables
 * @description Paginate, search and order HTML tables
 * @version     1.13.7
 * @author      SpryMedia Ltd
 * @contact     www.datatables.net
 * @copyright   SpryMedia Ltd.
 *
 * This source file is free software, available under the following license:
 *   MIT license - https://datatables.net/license
 *
 * This source file is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the license files for details.
 *
 * For details please refer to: https://www.datatables.net
 */
!function(A){"use strict";if("function"==typeof define&&define.amd)define(["jquery"],(function(t){return A(t,window,document)}));else if("object"==typeof exports){var t=require("jquery");if("undefined"!=typeof window)return A(t,window,window.document);module.exports=function(e,n){return e||(e=window),n||(n=t(e)),A(n,e,e.document)}}else window.DataTable=A(jQuery,window,document)}((function(A,t,e,n){"use strict";var r,i,o,s,a=function(t,e){if(a.factory(t,e))return a;if(this instanceof a)return A(t).DataTable(e);e=t,this.$=function(A,t){return this.api(!0).$(A,t)},this._=function(A,t){return this.api(!0).rows(A,t).data()},this.api=function(A){return new i(A?at(this[r.iApiIndex]):this)},this.fnAddData=function(t,e){var r=this.api(!0),i=Array.isArray(t)&&(Array.isArray(t[0])||A.isPlainObject(t[0]))?r.rows.add(t):r.row.add(t);return(e===n||e)&&r.draw(),i.flatten().toArray()},this.fnAdjustColumnSizing=function(A){var t=this.api(!0).columns.adjust(),e=t.settings()[0],r=e.oScroll;A===n||A?t.draw(!1):""===r.sX&&""===r.sY||JA(e)},this.fnClearTable=function(A){var t=this.api(!0).clear();(A===n||A)&&t.draw()},this.fnClose=function(A){this.api(!0).row(A).child.hide()},this.fnDeleteRow=function(A,t,e){var r=this.api(!0),i=r.rows(A),o=i.settings()[0],s=o.aoData[i[0][0]];return i.remove(),t&&t.call(this,o,s),(e===n||e)&&r.draw(),s},this.fnDestroy=function(A){this.api(!0).destroy(A)},this.fnDraw=function(A){this.api(!0).draw(A)},this.fnFilter=function(A,t,e,r,i,o){var s=this.api(!0);null===t||t===n?s.search(A,e,r,o):s.column(t).search(A,e,r,o),s.draw()},this.fnGetData=function(A,t){var e=this.api(!0);if(A!==n){var r=A.nodeName?A.nodeName.toLowerCase():"";return t!==n||"td"==r||"th"==r?e.cell(A,t).data():e.row(A).data()||null}return e.data().toArray()},this.fnGetNodes=function(A){var t=this.api(!0);return A!==n?t.row(A).node():t.rows().nodes().flatten().toArray()},this.fnGetPosition=function(A){var t=this.api(!0),e=A.nodeName.toUpperCase();if("TR"==e)return t.row(A).index();if("TD"==e||"TH"==e){var n=t.cell(A).index();return[n.row,n.columnVisible,n.column]}return null},this.fnIsOpen=function(A){return this.api(!0).row(A).child.isShown()},this.fnOpen=function(A,t,e){return this.api(!0).row(A).child(t,e).show().child()[0]},this.fnPageChange=function(A,t){var e=this.api(!0).page(A);(t===n||t)&&e.draw(!1)},this.fnSetColumnVis=function(A,t,e){var r=this.api(!0).column(A).visible(t);(e===n||e)&&r.columns.adjust().draw()},this.fnSettings=function(){return at(this[r.iApiIndex])},this.fnSort=function(A){this.api(!0).order(A).draw()},this.fnSortListener=function(A,t,e){this.api(!0).order.listener(A,t,e)},this.fnUpdate=function(A,t,e,r,i){var o=this.api(!0);return e===n||null===e?o.row(t).data(A):o.cell(t,e).data(A),(i===n||i)&&o.columns.adjust(),(r===n||r)&&o.draw(),0},this.fnVersionCheck=r.fnVersionCheck;var o=this,s=e===n,c=this.length;for(var B in s&&(e={}),this.oApi=this.internal=r.internal,a.ext.internal)B&&(this[B]=Kt(B));return this.each((function(){var t,r=c>1?gt({},e,!0):e,i=0,B=this.getAttribute("id"),g=!1,l=a.defaults,u=A(this);if("table"==this.nodeName.toLowerCase()){U(l),S(l.column),Y(l,l,!0),Y(l.column,l.column,!0),Y(l,A.extend(r,u.data()),!0);var w=a.settings;for(i=0,t=w.length;i<t;i++){var h=w[i];if(h.nTable==this||h.nTHead&&h.nTHead.parentNode==this||h.nTFoot&&h.nTFoot.parentNode==this){var E=r.bRetrieve!==n?r.bRetrieve:l.bRetrieve,f=r.bDestroy!==n?r.bDestroy:l.bDestroy;if(s||E)return h.oInstance;if(f){h.oInstance.fnDestroy();break}return void ct(h,0,"Cannot reinitialise DataTable",3)}if(h.sTableId==this.id){w.splice(i,1);break}}null!==B&&""!==B||(B="DataTables_Table_"+a.ext._unique++,this.id=B);var Q=A.extend(!0,{},a.models.oSettings,{sDestroyWidth:u[0].style.width,sInstance:B,sTableId:B});Q.nTable=this,Q.oApi=o.internal,Q.oInit=r,w.push(Q),Q.oInstance=1===o.length?o:u.dataTable(),U(r),b(r.oLanguage),r.aLengthMenu&&!r.iDisplayLength&&(r.iDisplayLength=Array.isArray(r.aLengthMenu[0])?r.aLengthMenu[0][0]:r.aLengthMenu[0]),r=gt(A.extend(!0,{},l),r),Bt(Q.oFeatures,r,["bPaginate","bLengthChange","bFilter","bSort","bSortMulti","bInfo","bProcessing","bAutoWidth","bSortClasses","bServerSide","bDeferRender"]),Bt(Q,r,["asStripeClasses","ajax","fnServerData","fnFormatNumber","sServerMethod","aaSorting","aaSortingFixed","aLengthMenu","sPaginationType","sAjaxSource","sAjaxDataProp","iStateDuration","sDom","bSortCellsTop","iTabIndex","fnStateLoadCallback","fnStateSaveCallback","renderer","searchDelay","rowId",["iCookieDuration","iStateDuration"],["oSearch","oPreviousSearch"],["aoSearchCols","aoPreSearchCols"],["iDisplayLength","_iDisplayLength"]]),Bt(Q.oScroll,r,[["sScrollX","sX"],["sScrollXInner","sXInner"],["sScrollY","sY"],["bScrollCollapse","bCollapse"]]),Bt(Q.oLanguage,r,"fnInfoCallback"),ut(Q,"aoDrawCallback",r.fnDrawCallback,"user"),ut(Q,"aoServerParams",r.fnServerParams,"user"),ut(Q,"aoStateSaveParams",r.fnStateSaveParams,"user"),ut(Q,"aoStateLoadParams",r.fnStateLoadParams,"user"),ut(Q,"aoStateLoaded",r.fnStateLoaded,"user"),ut(Q,"aoRowCallback",r.fnRowCallback,"user"),ut(Q,"aoRowCreatedCallback",r.fnCreatedRow,"user"),ut(Q,"aoHeaderCallback",r.fnHeaderCallback,"user"),ut(Q,"aoFooterCallback",r.fnFooterCallback,"user"),ut(Q,"aoInitComplete",r.fnInitComplete,"user"),ut(Q,"aoPreDrawCallback",r.fnPreDrawCallback,"user"),Q.rowIdFn=q(r.rowId),x(Q);var d=Q.oClasses;if(A.extend(d,a.ext.classes,r.oClasses),u.addClass(d.sTable),Q.iInitDisplayStart===n&&(Q.iInitDisplayStart=r.iDisplayStart,Q._iDisplayStart=r.iDisplayStart),null!==r.iDeferLoading){Q.bDeferLoading=!0;var C=Array.isArray(r.iDeferLoading);Q._iRecordsDisplay=C?r.iDeferLoading[0]:r.iDeferLoading,Q._iRecordsTotal=C?r.iDeferLoading[1]:r.iDeferLoading}var M=Q.oLanguage;A.extend(!0,M,r.oLanguage),M.sUrl?(A.ajax({dataType:"json",url:M.sUrl,success:function(t){Y(l.oLanguage,t),b(t),A.extend(!0,M,t,Q.oInit.oLanguage),wt(Q,null,"i18n",[Q]),xA(Q)},error:function(){xA(Q)}}),g=!0):wt(Q,null,"i18n",[Q]),null===r.asStripeClasses&&(Q.asStripeClasses=[d.sStripeOdd,d.sStripeEven]);var I=Q.asStripeClasses,p=u.children("tbody").find("tr").eq(0);-1!==A.inArray(!0,A.map(I,(function(A,t){return p.hasClass(A)})))&&(A("tbody tr",this).removeClass(I.join(" ")),Q.asDestroyStripes=I.slice());var D,y=[],v=this.getElementsByTagName("thead");if(0!==v.length&&(lA(Q.aoHeader,v[0]),y=uA(Q)),null===r.aoColumns)for(D=[],i=0,t=y.length;i<t;i++)D.push(null);else D=r.aoColumns;for(i=0,t=D.length;i<t;i++)P(Q,y?y[i]:null);if(j(Q,r.aoColumnDefs,D,(function(A,t){N(Q,A,t)})),p.length){var m=function(A,t){return null!==A.getAttribute("data-"+t)?t:null};A(p[0]).children("th, td").each((function(A,t){var e=Q.aoColumns[A];if(e||ct(Q,0,"Incorrect column count",18),e.mData===A){var r=m(t,"sort")||m(t,"order"),i=m(t,"filter")||m(t,"search");null===r&&null===i||(e.mData={_:A+".display",sort:null!==r?A+".@data-"+r:n,type:null!==r?A+".@data-"+r:n,filter:null!==i?A+".@data-"+i:n},e._isArrayHost=!0,N(Q,A))}}))}var F=Q.oFeatures,z=function(){if(r.aaSorting===n){var e=Q.aaSorting;for(i=0,t=e.length;i<t;i++)e[i][1]=Q.aoColumns[i].asSorting[0]}nt(Q),F.bSort&&ut(Q,"aoDrawCallback",(function(){if(Q.bSorted){var t=qA(Q),e={};A.each(t,(function(A,t){e[t.src]=t.dir})),wt(Q,null,"order",[Q,t,e]),At(Q)}})),ut(Q,"aoDrawCallback",(function(){(Q.bSorted||"ssp"===ft(Q)||F.bDeferRender)&&nt(Q)}),"sc");var o=u.children("caption").each((function(){this._captionSide=A(this).css("caption-side")})),s=u.children("thead");0===s.length&&(s=A("<thead/>").appendTo(u)),Q.nTHead=s[0];var a=u.children("tbody");0===a.length&&(a=A("<tbody/>").insertAfter(s)),Q.nTBody=a[0];var c=u.children("tfoot");if(0===c.length&&o.length>0&&(""!==Q.oScroll.sX||""!==Q.oScroll.sY)&&(c=A("<tfoot/>").appendTo(u)),0===c.length||0===c.children().length?u.addClass(d.sNoFooter):c.length>0&&(Q.nTFoot=c[0],lA(Q.aoFooter,Q.nTFoot)),r.aaData)for(i=0;i<r.aaData.length;i++)O(Q,r.aaData[i]);else(Q.bDeferLoading||"dom"==ft(Q))&&W(Q,A(Q.nTBody).children("tr"));Q.aiDisplay=Q.aiDisplayMaster.slice(),Q.bInitialised=!0,!1===g&&xA(Q)};ut(Q,"aoDrawCallback",it,"state_save"),r.bStateSave?(F.bStateSave=!0,ot(Q,r,z)):z()}else ct(null,0,"Non-table node initialisation ("+this.nodeName+")",2)})),o=null,this},c={},B=/[\r\n\u2028]/g,g=/<.*?>/g,l=/^\d{2,4}[\.\/\-]\d{1,2}[\.\/\-]\d{1,2}([T ]{1}\d{1,2}[:\.]\d{2}([\.:]\d{2})?)?$/,u=new RegExp("(\\"+["/",".","*","+","?","|","(",")","[","]","{","}","\\","$","^","-"].join("|\\")+")","g"),w=/['\u00A0,$£€¥%\u2009\u202F\u20BD\u20a9\u20BArfkɃΞ]/gi,h=function(A){return!A||!0===A||"-"===A},E=function(A){var t=parseInt(A,10);return!isNaN(t)&&isFinite(A)?t:null},f=function(A,t){return c[t]||(c[t]=new RegExp(yA(t),"g")),"string"==typeof A&&"."!==t?A.replace(/\./g,"").replace(c[t],"."):A},Q=function(A,t,e){var n=typeof A,r="string"===n;return"number"===n||"bigint"===n||(!!h(A)||(t&&r&&(A=f(A,t)),e&&r&&(A=A.replace(w,"")),!isNaN(parseFloat(A))&&isFinite(A)))},d=function(A,t,e){if(h(A))return!0;var n=function(A){return h(A)||"string"==typeof A}(A);return n&&!!Q(D(A),t,e)||null},C=function(A,t,e){var r=[],i=0,o=A.length;if(e!==n)for(;i<o;i++)A[i]&&A[i][t]&&r.push(A[i][t][e]);else for(;i<o;i++)A[i]&&r.push(A[i][t]);return r},M=function(A,t,e,r){var i=[],o=0,s=t.length;if(r!==n)for(;o<s;o++)A[t[o]][e]&&i.push(A[t[o]][e][r]);else for(;o<s;o++)i.push(A[t[o]][e]);return i},I=function(A,t){var e,r=[];t===n?(t=0,e=A):(e=t,t=A);for(var i=t;i<e;i++)r.push(i);return r},p=function(A){for(var t=[],e=0,n=A.length;e<n;e++)A[e]&&t.push(A[e]);return t},D=function(A){return A.replace(g,"").replace(/<script/i,"")},y=function(A){if(function(A){if(A.length<2)return!0;for(var t=A.slice().sort(),e=t[0],n=1,r=t.length;n<r;n++){if(t[n]===e)return!1;e=t[n]}return!0}(A))return A.slice();var t,e,n,r=[],i=A.length,o=0;A:for(e=0;e<i;e++){for(t=A[e],n=0;n<o;n++)if(r[n]===t)continue A;r.push(t),o++}return r},v=function(A,t){if(Array.isArray(t))for(var e=0;e<t.length;e++)v(A,t[e]);else A.push(t);return A},m=function(A,t){return t===n&&(t=0),-1!==this.indexOf(A,t)};function F(t){var e,n,r={};A.each(t,(function(A,i){(e=A.match(/^([^A-Z]+?)([A-Z])/))&&-1!=="a aa ai ao as b fn i m o s ".indexOf(e[1]+" ")&&(n=A.replace(e[0],e[2].toLowerCase()),r[n]=A,"o"===e[1]&&F(t[A]))})),t._hungarianMap=r}function Y(t,e,r){var i;t._hungarianMap||F(t),A.each(e,(function(o,s){(i=t._hungarianMap[o])===n||!r&&e[i]!==n||("o"===i.charAt(0)?(e[i]||(e[i]={}),A.extend(!0,e[i],e[o]),Y(t[i],e[i],r)):e[i]=e[o])}))}function b(A){var t=a.defaults.oLanguage,e=t.sDecimal;if(e&&Nt(e),A){var n=A.sZeroRecords;!A.sEmptyTable&&n&&"No data available in table"===t.sEmptyTable&&Bt(A,A,"sZeroRecords","sEmptyTable"),!A.sLoadingRecords&&n&&"Loading..."===t.sLoadingRecords&&Bt(A,A,"sZeroRecords","sLoadingRecords"),A.sInfoThousands&&(A.sThousands=A.sInfoThousands);var r=A.sDecimal;r&&e!==r&&Nt(r)}}Array.isArray||(Array.isArray=function(A){return"[object Array]"===Object.prototype.toString.call(A)}),Array.prototype.includes||(Array.prototype.includes=m),String.prototype.trim||(String.prototype.trim=function(){return this.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,"")}),String.prototype.includes||(String.prototype.includes=m),a.util={throttle:function(A,t){var e,r,i=t!==n?t:200;return function(){var t=this,o=+new Date,s=arguments;e&&o<e+i?(clearTimeout(r),r=setTimeout((function(){e=n,A.apply(t,s)}),i)):(e=o,A.apply(t,s))}},escapeRegex:function(A){return A.replace(u,"\\$1")},set:function(t){if(A.isPlainObject(t))return a.util.set(t._);if(null===t)return function(){};if("function"==typeof t)return function(A,e,n){t(A,"set",e,n)};if("string"!=typeof t||-1===t.indexOf(".")&&-1===t.indexOf("[")&&-1===t.indexOf("("))return function(A,e){A[t]=e};var e=function(A,t,r){for(var i,o,s,a,c,B=_(r),g=B[B.length-1],l=0,u=B.length-1;l<u;l++){if("__proto__"===B[l]||"constructor"===B[l])throw new Error("Cannot set prototype values");if(o=B[l].match(X),s=B[l].match(Z),o){if(B[l]=B[l].replace(X,""),A[B[l]]=[],(i=B.slice()).splice(0,l+1),c=i.join("."),Array.isArray(t))for(var w=0,h=t.length;w<h;w++)e(a={},t[w],c),A[B[l]].push(a);else A[B[l]]=t;return}s&&(B[l]=B[l].replace(Z,""),A=A[B[l]](t)),null!==A[B[l]]&&A[B[l]]!==n||(A[B[l]]={}),A=A[B[l]]}g.match(Z)?A=A[g.replace(Z,"")](t):A[g.replace(X,"")]=t};return function(A,n){return e(A,n,t)}},get:function(t){if(A.isPlainObject(t)){var e={};return A.each(t,(function(A,t){t&&(e[A]=a.util.get(t))})),function(A,t,r,i){var o=e[t]||e._;return o!==n?o(A,t,r,i):A}}if(null===t)return function(A){return A};if("function"==typeof t)return function(A,e,n,r){return t(A,e,n,r)};if("string"!=typeof t||-1===t.indexOf(".")&&-1===t.indexOf("[")&&-1===t.indexOf("("))return function(A,e){return A[t]};var r=function(A,t,e){var i,o,s,a;if(""!==e)for(var c=_(e),B=0,g=c.length;B<g;B++){if(i=c[B].match(X),o=c[B].match(Z),i){if(c[B]=c[B].replace(X,""),""!==c[B]&&(A=A[c[B]]),s=[],c.splice(0,B+1),a=c.join("."),Array.isArray(A))for(var l=0,u=A.length;l<u;l++)s.push(r(A[l],t,a));var w=i[0].substring(1,i[0].length-1);A=""===w?s:s.join(w);break}if(o)c[B]=c[B].replace(Z,""),A=A[c[B]]();else{if(null===A||null===A[c[B]])return null;if(A===n||A[c[B]]===n)return n;A=A[c[B]]}}return A};return function(A,e){return r(A,e,t)}}};var z=function(A,t,e){A[t]!==n&&(A[e]=A[t])};function U(A){z(A,"ordering","bSort"),z(A,"orderMulti","bSortMulti"),z(A,"orderClasses","bSortClasses"),z(A,"orderCellsTop","bSortCellsTop"),z(A,"order","aaSorting"),z(A,"orderFixed","aaSortingFixed"),z(A,"paging","bPaginate"),z(A,"pagingType","sPaginationType"),z(A,"pageLength","iDisplayLength"),z(A,"searching","bFilter"),"boolean"==typeof A.sScrollX&&(A.sScrollX=A.sScrollX?"100%":""),"boolean"==typeof A.scrollX&&(A.scrollX=A.scrollX?"100%":"");var t=A.aoSearchCols;if(t)for(var e=0,n=t.length;e<n;e++)t[e]&&Y(a.models.oSearch,t[e])}function S(A){z(A,"orderable","bSortable"),z(A,"orderData","aDataSort"),z(A,"orderSequence","asSorting"),z(A,"orderDataType","sortDataType");var t=A.aDataSort;"number"!=typeof t||Array.isArray(t)||(A.aDataSort=[t])}function x(e){if(!a.__browser){var n={};a.__browser=n;var r=A("<div/>").css({position:"fixed",top:0,left:-1*A(t).scrollLeft(),height:1,width:1,overflow:"hidden"}).append(A("<div/>").css({position:"absolute",top:1,left:1,width:100,overflow:"scroll"}).append(A("<div/>").css({width:"100%",height:10}))).appendTo("body"),i=r.children(),o=i.children();n.barWidth=i[0].offsetWidth-i[0].clientWidth,n.bScrollOversize=100===o[0].offsetWidth&&100!==i[0].clientWidth,n.bScrollbarLeft=1!==Math.round(o.offset().left),n.bBounding=!!r[0].getBoundingClientRect().width,r.remove()}A.extend(e.oBrowser,a.__browser),e.oScroll.iBarWidth=a.__browser.barWidth}function T(A,t,e,r,i,o){var s,a=r,c=!1;for(e!==n&&(s=e,c=!0);a!==i;)A.hasOwnProperty(a)&&(s=c?t(s,A[a],a,A):A[a],c=!0,a+=o);return s}function P(t,n){var r=a.defaults.column,i=t.aoColumns.length,o=A.extend({},a.models.oColumn,r,{nTh:n||e.createElement("th"),sTitle:r.sTitle?r.sTitle:n?n.innerHTML:"",aDataSort:r.aDataSort?r.aDataSort:[i],mData:r.mData?r.mData:i,idx:i});t.aoColumns.push(o);var s=t.aoPreSearchCols;s[i]=A.extend({},a.models.oSearch,s[i]),N(t,i,A(n).data())}function N(t,e,r){var i=t.aoColumns[e],o=t.oClasses,s=A(i.nTh);if(!i.sWidthOrig){i.sWidthOrig=s.attr("width")||null;var c=(s.attr("style")||"").match(/width:\s*(\d+[pxem%]+)/);c&&(i.sWidthOrig=c[1])}if(r!==n&&null!==r){S(r),Y(a.defaults.column,r,!0),r.mDataProp===n||r.mData||(r.mData=r.mDataProp),r.sType&&(i._sManualType=r.sType),r.className&&!r.sClass&&(r.sClass=r.className),r.sClass&&s.addClass(r.sClass);var B=i.sClass;A.extend(i,r),Bt(i,r,"sWidth","sWidthOrig"),B!==i.sClass&&(i.sClass=B+" "+i.sClass),r.iDataSort!==n&&(i.aDataSort=[r.iDataSort]),Bt(i,r,"aDataSort"),i.ariaTitle||(i.ariaTitle=s.attr("aria-label"))}var g=i.mData,l=q(g),u=i.mRender?q(i.mRender):null,w=function(A){return"string"==typeof A&&-1!==A.indexOf("@")};i._bAttrSrc=A.isPlainObject(g)&&(w(g.sort)||w(g.type)||w(g.filter)),i._setter=null,i.fnGetData=function(A,t,e){var r=l(A,t,n,e);return u&&t?u(r,t,A,e):r},i.fnSetData=function(A,t,e){return $(g)(A,t,e)},"number"==typeof g||i._isArrayHost||(t._rowReadObject=!0),t.oFeatures.bSort||(i.bSortable=!1,s.addClass(o.sSortableNone));var h=-1!==A.inArray("asc",i.asSorting),E=-1!==A.inArray("desc",i.asSorting);i.bSortable&&(h||E)?h&&!E?(i.sSortingClass=o.sSortableAsc,i.sSortingClassJUI=o.sSortJUIAscAllowed):!h&&E?(i.sSortingClass=o.sSortableDesc,i.sSortingClassJUI=o.sSortJUIDescAllowed):(i.sSortingClass=o.sSortable,i.sSortingClassJUI=o.sSortJUI):(i.sSortingClass=o.sSortableNone,i.sSortingClassJUI="")}function R(A){if(!1!==A.oFeatures.bAutoWidth){var t=A.aoColumns;WA(A);for(var e=0,n=t.length;e<n;e++)t[e].nTh.style.width=t[e].sWidth}var r=A.oScroll;""===r.sY&&""===r.sX||JA(A),wt(A,null,"column-sizing",[A])}function G(A,t){var e=L(A,"bVisible");return"number"==typeof e[t]?e[t]:null}function H(t,e){var n=L(t,"bVisible"),r=A.inArray(e,n);return-1!==r?r:null}function k(t){var e=0;return A.each(t.aoColumns,(function(t,n){n.bVisible&&"none"!==A(n.nTh).css("display")&&e++})),e}function L(t,e){var n=[];return A.map(t.aoColumns,(function(A,t){A[e]&&n.push(t)})),n}function J(A){var t,e,r,i,o,s,c,B,g,l=A.aoColumns,u=A.aoData,w=a.ext.type.detect;for(t=0,e=l.length;t<e;t++)if(g=[],!(c=l[t]).sType&&c._sManualType)c.sType=c._sManualType;else if(!c.sType){for(r=0,i=w.length;r<i;r++){for(o=0,s=u.length;o<s&&(g[o]===n&&(g[o]=K(A,o,t,"type")),(B=w[r](g[o],A))||r===w.length-1)&&("html"!==B||h(g[o]));o++);if(B){c.sType=B;break}}c.sType||(c.sType="string")}}function j(t,e,r,i){var o,s,a,c,B,g,l,u=t.aoColumns;if(e)for(o=e.length-1;o>=0;o--){var w=(l=e[o]).target!==n?l.target:l.targets!==n?l.targets:l.aTargets;for(Array.isArray(w)||(w=[w]),a=0,c=w.length;a<c;a++)if("number"==typeof w[a]&&w[a]>=0){for(;u.length<=w[a];)P(t);i(w[a],l)}else if("number"==typeof w[a]&&w[a]<0)i(u.length+w[a],l);else if("string"==typeof w[a])for(B=0,g=u.length;B<g;B++)("_all"==w[a]||A(u[B].nTh).hasClass(w[a]))&&i(B,l)}if(r)for(o=0,s=r.length;o<s;o++)i(o,r[o])}function O(t,e,r,i){var o=t.aoData.length,s=A.extend(!0,{},a.models.oRow,{src:r?"dom":"data",idx:o});s._aData=e,t.aoData.push(s);for(var c=t.aoColumns,B=0,g=c.length;B<g;B++)c[B].sType=null;t.aiDisplayMaster.push(o);var l=t.rowIdFn(e);return l!==n&&(t.aIds[l]=s),!r&&t.oFeatures.bDeferRender||iA(t,o,r,i),o}function W(t,e){var n;return e instanceof A||(e=A(e)),e.map((function(A,e){return n=rA(t,e),O(t,n.data,e,n.cells)}))}function K(A,t,e,r){"search"===r?r="filter":"order"===r&&(r="sort");var i=A.iDraw,o=A.aoColumns[e],s=A.aoData[t]._aData,c=o.sDefaultContent,B=o.fnGetData(s,r,{settings:A,row:t,col:e});if(B===n)return A.iDrawError!=i&&null===c&&(ct(A,0,"Requested unknown parameter "+("function"==typeof o.mData?"{function}":"'"+o.mData+"'")+" for row "+t+", column "+e,4),A.iDrawError=i),c;if(B!==s&&null!==B||null===c||r===n){if("function"==typeof B)return B.call(s)}else B=c;if(null===B&&"display"===r)return"";if("filter"===r){var g=a.ext.type.search;g[o.sType]&&(B=g[o.sType](B))}return B}function V(A,t,e,n){var r=A.aoColumns[e],i=A.aoData[t]._aData;r.fnSetData(i,n,{settings:A,row:t,col:e})}var X=/\[.*?\]$/,Z=/\(\)$/;function _(t){return A.map(t.match(/(\\.|[^\.])+/g)||[""],(function(A){return A.replace(/\\\./g,".")}))}var q=a.util.get,$=a.util.set;function AA(A){return C(A.aoData,"_aData")}function tA(A){A.aoData.length=0,A.aiDisplayMaster.length=0,A.aiDisplay.length=0,A.aIds={}}function eA(A,t,e){for(var r=-1,i=0,o=A.length;i<o;i++)A[i]==t?r=i:A[i]>t&&A[i]--;-1!=r&&e===n&&A.splice(r,1)}function nA(A,t,e,r){var i,o,s=A.aoData[t],a=function(e,n){for(;e.childNodes.length;)e.removeChild(e.firstChild);e.innerHTML=K(A,t,n,"display")};if("dom"!==e&&(e&&"auto"!==e||"dom"!==s.src)){var c=s.anCells;if(c)if(r!==n)a(c[r],r);else for(i=0,o=c.length;i<o;i++)a(c[i],i)}else s._aData=rA(A,s,r,r===n?n:s._aData).data;s._aSortData=null,s._aFilterData=null;var B=A.aoColumns;if(r!==n)B[r].sType=null;else{for(i=0,o=B.length;i<o;i++)B[i].sType=null;oA(A,s)}}function rA(A,t,e,r){var i,o,s,a=[],c=t.firstChild,B=0,g=A.aoColumns,l=A._rowReadObject;r=r!==n?r:l?{}:[];var u=function(A,t){if("string"==typeof A){var e=A.indexOf("@");if(-1!==e){var n=A.substring(e+1);$(A)(r,t.getAttribute(n))}}},w=function(A){e!==n&&e!==B||(o=g[B],s=A.innerHTML.trim(),o&&o._bAttrSrc?($(o.mData._)(r,s),u(o.mData.sort,A),u(o.mData.type,A),u(o.mData.filter,A)):l?(o._setter||(o._setter=$(o.mData)),o._setter(r,s)):r[B]=s);B++};if(c)for(;c;)"TD"!=(i=c.nodeName.toUpperCase())&&"TH"!=i||(w(c),a.push(c)),c=c.nextSibling;else for(var h=0,E=(a=t.anCells).length;h<E;h++)w(a[h]);var f=t.firstChild?t:t.nTr;if(f){var Q=f.getAttribute("id");Q&&$(A.rowId)(r,Q)}return{data:r,cells:a}}function iA(t,n,r,i){var o,s,a,c,B,g,l=t.aoData[n],u=l._aData,w=[];if(null===l.nTr){for(o=r||e.createElement("tr"),l.nTr=o,l.anCells=w,o._DT_RowIndex=n,oA(t,l),c=0,B=t.aoColumns.length;c<B;c++)a=t.aoColumns[c],(s=(g=!r)?e.createElement(a.sCellType):i[c])||ct(t,0,"Incorrect column count",18),s._DT_CellIndex={row:n,column:c},w.push(s),!g&&(!a.mRender&&a.mData===c||A.isPlainObject(a.mData)&&a.mData._===c+".display")||(s.innerHTML=K(t,n,c,"display")),a.sClass&&(s.className+=" "+a.sClass),a.bVisible&&!r?o.appendChild(s):!a.bVisible&&r&&s.parentNode.removeChild(s),a.fnCreatedCell&&a.fnCreatedCell.call(t.oInstance,s,K(t,n,c),u,n,c);wt(t,"aoRowCreatedCallback",null,[o,u,n,w])}}function oA(t,e){var n=e.nTr,r=e._aData;if(n){var i=t.rowIdFn(r);if(i&&(n.id=i),r.DT_RowClass){var o=r.DT_RowClass.split(" ");e.__rowc=e.__rowc?y(e.__rowc.concat(o)):o,A(n).removeClass(e.__rowc.join(" ")).addClass(r.DT_RowClass)}r.DT_RowAttr&&A(n).attr(r.DT_RowAttr),r.DT_RowData&&A(n).data(r.DT_RowData)}}function sA(t){var e,n,r,i,o,s=t.nTHead,a=t.nTFoot,c=0===A("th, td",s).length,B=t.oClasses,g=t.aoColumns;for(c&&(i=A("<tr/>").appendTo(s)),e=0,n=g.length;e<n;e++)o=g[e],r=A(o.nTh).addClass(o.sClass),c&&r.appendTo(i),t.oFeatures.bSort&&(r.addClass(o.sSortingClass),!1!==o.bSortable&&(r.attr("tabindex",t.iTabIndex).attr("aria-controls",t.sTableId),et(t,o.nTh,e))),o.sTitle!=r[0].innerHTML&&r.html(o.sTitle),Et(t,"header")(t,r,o,B);if(c&&lA(t.aoHeader,s),A(s).children("tr").children("th, td").addClass(B.sHeaderTH),A(a).children("tr").children("th, td").addClass(B.sFooterTH),null!==a){var l=t.aoFooter[0];for(e=0,n=l.length;e<n;e++)(o=g[e])?(o.nTf=l[e].cell,o.sClass&&A(o.nTf).addClass(o.sClass)):ct(t,0,"Incorrect column count",18)}}function aA(t,e,r){var i,o,s,a,c,B,g,l,u,w=[],h=[],E=t.aoColumns.length;if(e){for(r===n&&(r=!1),i=0,o=e.length;i<o;i++){for(w[i]=e[i].slice(),w[i].nTr=e[i].nTr,s=E-1;s>=0;s--)t.aoColumns[s].bVisible||r||w[i].splice(s,1);h.push([])}for(i=0,o=w.length;i<o;i++){if(g=w[i].nTr)for(;B=g.firstChild;)g.removeChild(B);for(s=0,a=w[i].length;s<a;s++)if(l=1,u=1,h[i][s]===n){for(g.appendChild(w[i][s].cell),h[i][s]=1;w[i+l]!==n&&w[i][s].cell==w[i+l][s].cell;)h[i+l][s]=1,l++;for(;w[i][s+u]!==n&&w[i][s].cell==w[i][s+u].cell;){for(c=0;c<l;c++)h[i+c][s+u]=1;u++}A(w[i][s].cell).attr("rowspan",l).attr("colspan",u)}}}}function cA(t,e){!function(A){var t="ssp"==ft(A),e=A.iInitDisplayStart;e!==n&&-1!==e&&(A._iDisplayStart=t?e:e>=A.fnRecordsDisplay()?0:e,A.iInitDisplayStart=-1)}(t);var r=wt(t,"aoPreDrawCallback","preDraw",[t]);if(-1===A.inArray(!1,r)){var i=[],o=0,s=t.asStripeClasses,a=s.length,c=t.oLanguage,B="ssp"==ft(t),g=t.aiDisplay,l=t._iDisplayStart,u=t.fnDisplayEnd();if(t.bDrawing=!0,t.bDeferLoading)t.bDeferLoading=!1,t.iDraw++,kA(t,!1);else if(B){if(!t.bDestroying&&!e)return void hA(t)}else t.iDraw++;if(0!==g.length)for(var w=B?0:l,h=B?t.aoData.length:u,E=w;E<h;E++){var f=g[E],Q=t.aoData[f];null===Q.nTr&&iA(t,f);var d=Q.nTr;if(0!==a){var C=s[o%a];Q._sRowStripe!=C&&(A(d).removeClass(Q._sRowStripe).addClass(C),Q._sRowStripe=C)}wt(t,"aoRowCallback",null,[d,Q._aData,o,E,f]),i.push(d),o++}else{var M=c.sZeroRecords;1==t.iDraw&&"ajax"==ft(t)?M=c.sLoadingRecords:c.sEmptyTable&&0===t.fnRecordsTotal()&&(M=c.sEmptyTable),i[0]=A("<tr/>",{class:a?s[0]:""}).append(A("<td />",{valign:"top",colSpan:k(t),class:t.oClasses.sRowEmpty}).html(M))[0]}wt(t,"aoHeaderCallback","header",[A(t.nTHead).children("tr")[0],AA(t),l,u,g]),wt(t,"aoFooterCallback","footer",[A(t.nTFoot).children("tr")[0],AA(t),l,u,g]);var I=A(t.nTBody);I.children().detach(),I.append(A(i)),wt(t,"aoDrawCallback","draw",[t]),t.bSorted=!1,t.bFiltered=!1,t.bDrawing=!1}else kA(t,!1)}function BA(A,t){var e=A.oFeatures,n=e.bSort,r=e.bFilter;n&&$A(A),r?CA(A,A.oPreviousSearch):A.aiDisplay=A.aiDisplayMaster.slice(),!0!==t&&(A._iDisplayStart=0),A._drawHold=t,cA(A),A._drawHold=!1}function gA(t){var e=t.oClasses,n=A(t.nTable),r=A("<div/>").insertBefore(n),i=t.oFeatures,o=A("<div/>",{id:t.sTableId+"_wrapper",class:e.sWrapper+(t.nTFoot?"":" "+e.sNoFooter)});t.nHolding=r[0],t.nTableWrapper=o[0],t.nTableReinsertBefore=t.nTable.nextSibling;for(var s,c,B,g,l,u,w=t.sDom.split(""),h=0;h<w.length;h++){if(s=null,"<"==(c=w[h])){if(B=A("<div/>")[0],"'"==(g=w[h+1])||'"'==g){for(l="",u=2;w[h+u]!=g;)l+=w[h+u],u++;if("H"==l?l=e.sJUIHeader:"F"==l&&(l=e.sJUIFooter),-1!=l.indexOf(".")){var E=l.split(".");B.id=E[0].substr(1,E[0].length-1),B.className=E[1]}else"#"==l.charAt(0)?B.id=l.substr(1,l.length-1):B.className=l;h+=u}o.append(B),o=A(B)}else if(">"==c)o=o.parent();else if("l"==c&&i.bPaginate&&i.bLengthChange)s=NA(t);else if("f"==c&&i.bFilter)s=dA(t);else if("r"==c&&i.bProcessing)s=HA(t);else if("t"==c)s=LA(t);else if("i"==c&&i.bInfo)s=zA(t);else if("p"==c&&i.bPaginate)s=RA(t);else if(0!==a.ext.feature.length)for(var f=a.ext.feature,Q=0,d=f.length;Q<d;Q++)if(c==f[Q].cFeature){s=f[Q].fnInit(t);break}if(s){var C=t.aanFeatures;C[c]||(C[c]=[]),C[c].push(s),o.append(s)}}r.replaceWith(o),t.nHolding=null}function lA(t,e){var n,r,i,o,s,a,c,B,g,l,u=A(e).children("tr"),w=function(A,t,e){for(var n=A[t];n[e];)e++;return e};for(t.splice(0,t.length),i=0,a=u.length;i<a;i++)t.push([]);for(i=0,a=u.length;i<a;i++)for(0,r=(n=u[i]).firstChild;r;){if("TD"==r.nodeName.toUpperCase()||"TH"==r.nodeName.toUpperCase())for(B=(B=1*r.getAttribute("colspan"))&&0!==B&&1!==B?B:1,g=(g=1*r.getAttribute("rowspan"))&&0!==g&&1!==g?g:1,c=w(t,i,0),l=1===B,s=0;s<B;s++)for(o=0;o<g;o++)t[i+o][c+s]={cell:r,unique:l},t[i+o].nTr=n;r=r.nextSibling}}function uA(A,t,e){var n=[];e||(e=A.aoHeader,t&&lA(e=[],t));for(var r=0,i=e.length;r<i;r++)for(var o=0,s=e[r].length;o<s;o++)!e[r][o].unique||n[o]&&A.bSortCellsTop||(n[o]=e[r][o].cell);return n}function wA(t,e,n){if(wt(t,"aoServerParams","serverParams",[e]),e&&Array.isArray(e)){var r={},i=/(.*?)\[\]$/;A.each(e,(function(A,t){var e=t.name.match(i);if(e){var n=e[0];r[n]||(r[n]=[]),r[n].push(t.value)}else r[t.name]=t.value})),e=r}var o,s=t.ajax,a=t.oInstance,c=function(A){var e=t.jqXHR?t.jqXHR.status:null;(null===A||"number"==typeof e&&204==e)&&QA(t,A={},[]);var r=A.error||A.sError;r&&ct(t,0,r),t.json=A,wt(t,null,"xhr",[t,A,t.jqXHR]),n(A)};if(A.isPlainObject(s)&&s.data){var B="function"==typeof(o=s.data)?o(e,t):o;e="function"==typeof o&&B?B:A.extend(!0,e,B),delete s.data}var g={data:e,success:c,dataType:"json",cache:!1,type:t.sServerMethod,error:function(e,n,r){var i=wt(t,null,"xhr",[t,null,t.jqXHR]);-1===A.inArray(!0,i)&&("parsererror"==n?ct(t,0,"Invalid JSON response",1):4===e.readyState&&ct(t,0,"Ajax error",7)),kA(t,!1)}};t.oAjaxData=e,wt(t,null,"preXhr",[t,e]),t.fnServerData?t.fnServerData.call(a,t.sAjaxSource,A.map(e,(function(A,t){return{name:t,value:A}})),c,t):t.sAjaxSource||"string"==typeof s?t.jqXHR=A.ajax(A.extend(g,{url:s||t.sAjaxSource})):"function"==typeof s?t.jqXHR=s.call(a,e,c,t):(t.jqXHR=A.ajax(A.extend(g,s)),s.data=o)}function hA(A){A.iDraw++,kA(A,!0);var t=A._drawHold;wA(A,EA(A),(function(e){A._drawHold=t,fA(A,e),A._drawHold=!1}))}function EA(t){var e,n,r,i,o=t.aoColumns,s=o.length,c=t.oFeatures,B=t.oPreviousSearch,g=t.aoPreSearchCols,l=[],u=qA(t),w=t._iDisplayStart,h=!1!==c.bPaginate?t._iDisplayLength:-1,E=function(A,t){l.push({name:A,value:t})};E("sEcho",t.iDraw),E("iColumns",s),E("sColumns",C(o,"sName").join(",")),E("iDisplayStart",w),E("iDisplayLength",h);var f={draw:t.iDraw,columns:[],order:[],start:w,length:h,search:{value:B.sSearch,regex:B.bRegex}};for(e=0;e<s;e++)r=o[e],i=g[e],n="function"==typeof r.mData?"function":r.mData,f.columns.push({data:n,name:r.sName,searchable:r.bSearchable,orderable:r.bSortable,search:{value:i.sSearch,regex:i.bRegex}}),E("mDataProp_"+e,n),c.bFilter&&(E("sSearch_"+e,i.sSearch),E("bRegex_"+e,i.bRegex),E("bSearchable_"+e,r.bSearchable)),c.bSort&&E("bSortable_"+e,r.bSortable);c.bFilter&&(E("sSearch",B.sSearch),E("bRegex",B.bRegex)),c.bSort&&(A.each(u,(function(A,t){f.order.push({column:t.col,dir:t.dir}),E("iSortCol_"+A,t.col),E("sSortDir_"+A,t.dir)})),E("iSortingCols",u.length));var Q=a.ext.legacy.ajax;return null===Q?t.sAjaxSource?l:f:Q?l:f}function fA(A,t){var e=function(A,e){return t[A]!==n?t[A]:t[e]},r=QA(A,t),i=e("sEcho","draw"),o=e("iTotalRecords","recordsTotal"),s=e("iTotalDisplayRecords","recordsFiltered");if(i!==n){if(1*i<A.iDraw)return;A.iDraw=1*i}r||(r=[]),tA(A),A._iRecordsTotal=parseInt(o,10),A._iRecordsDisplay=parseInt(s,10);for(var a=0,c=r.length;a<c;a++)O(A,r[a]);A.aiDisplay=A.aiDisplayMaster.slice(),cA(A,!0),A._bInitComplete||TA(A,t),kA(A,!1)}function QA(t,e,r){var i=A.isPlainObject(t.ajax)&&t.ajax.dataSrc!==n?t.ajax.dataSrc:t.sAjaxDataProp;if(!r)return"data"===i?e.aaData||e[i]:""!==i?q(i)(e):e;$(i)(e,r)}function dA(t){var n=t.oClasses,r=t.sTableId,i=t.oLanguage,o=t.oPreviousSearch,s=t.aanFeatures,a='<input type="search" class="'+n.sFilterInput+'"/>',c=i.sSearch;c=c.match(/_INPUT_/)?c.replace("_INPUT_",a):c+a;var B=A("<div/>",{id:s.f?null:r+"_filter",class:n.sFilter}).append(A("<label/>").append(c)),g=function(A){s.f;var e=this.value?this.value:"";o.return&&"Enter"!==A.key||e!=o.sSearch&&(CA(t,{sSearch:e,bRegex:o.bRegex,bSmart:o.bSmart,bCaseInsensitive:o.bCaseInsensitive,return:o.return}),t._iDisplayStart=0,cA(t))},l=null!==t.searchDelay?t.searchDelay:"ssp"===ft(t)?400:0,u=A("input",B).val(o.sSearch).attr("placeholder",i.sSearchPlaceholder).on("keyup.DT search.DT input.DT paste.DT cut.DT",l?KA(g,l):g).on("mouseup.DT",(function(A){setTimeout((function(){g.call(u[0],A)}),10)})).on("keypress.DT",(function(A){if(13==A.keyCode)return!1})).attr("aria-controls",r);return A(t.nTable).on("search.dt.DT",(function(A,n){if(t===n)try{u[0]!==e.activeElement&&u.val(o.sSearch)}catch(A){}})),B[0]}function CA(A,t,e){var r=A.oPreviousSearch,i=A.aoPreSearchCols,o=function(A){r.sSearch=A.sSearch,r.bRegex=A.bRegex,r.bSmart=A.bSmart,r.bCaseInsensitive=A.bCaseInsensitive,r.return=A.return},s=function(A){return A.bEscapeRegex!==n?!A.bEscapeRegex:A.bRegex};if(J(A),"ssp"!=ft(A)){pA(A,t.sSearch,e,s(t),t.bSmart,t.bCaseInsensitive),o(t);for(var a=0;a<i.length;a++)IA(A,i[a].sSearch,a,s(i[a]),i[a].bSmart,i[a].bCaseInsensitive);MA(A)}else o(t);A.bFiltered=!0,wt(A,null,"search",[A])}function MA(t){for(var e,n,r=a.ext.search,i=t.aiDisplay,o=0,s=r.length;o<s;o++){for(var c=[],B=0,g=i.length;B<g;B++)n=i[B],e=t.aoData[n],r[o](t,e._aFilterData,n,e._aData,B)&&c.push(n);i.length=0,A.merge(i,c)}}function IA(A,t,e,n,r,i){if(""!==t){for(var o,s=[],a=A.aiDisplay,c=DA(t,n,r,i),B=0;B<a.length;B++)o=A.aoData[a[B]]._aFilterData[e],c.test(o)&&s.push(a[B]);A.aiDisplay=s}}function pA(A,t,e,n,r,i){var o,s,c,B=DA(t,n,r,i),g=A.oPreviousSearch.sSearch,l=A.aiDisplayMaster,u=[];if(0!==a.ext.search.length&&(e=!0),s=FA(A),t.length<=0)A.aiDisplay=l.slice();else{for((s||e||n||g.length>t.length||0!==t.indexOf(g)||A.bSorted)&&(A.aiDisplay=l.slice()),o=A.aiDisplay,c=0;c<o.length;c++)B.test(A.aoData[o[c]]._sFilterRow)&&u.push(o[c]);A.aiDisplay=u}}function DA(t,e,n,r){if(t=e?t:yA(t),n){var i=A.map(t.match(/["\u201C][^"\u201D]+["\u201D]|[^ ]+/g)||[""],(function(A){if('"'===A.charAt(0)){var t=A.match(/^"(.*)"$/);A=t?t[1]:A}else if("“"===A.charAt(0)){t=A.match(/^\u201C(.*)\u201D$/);A=t?t[1]:A}return A.replace('"',"")}));t="^(?=.*?"+i.join(")(?=.*?")+").*$"}return new RegExp(t,r?"i":"")}var yA=a.util.escapeRegex,vA=A("<div>")[0],mA=vA.textContent!==n;function FA(A){var t,e,n,r,i,o,s,a=A.aoColumns,c=!1;for(t=0,n=A.aoData.length;t<n;t++)if(!(s=A.aoData[t])._aFilterData){for(i=[],e=0,r=a.length;e<r;e++)a[e].bSearchable?(null===(o=K(A,t,e,"filter"))&&(o=""),"string"!=typeof o&&o.toString&&(o=o.toString())):o="",o.indexOf&&-1!==o.indexOf("&")&&(vA.innerHTML=o,o=mA?vA.textContent:vA.innerText),o.replace&&(o=o.replace(/[\r\n\u2028]/g,"")),i.push(o);s._aFilterData=i,s._sFilterRow=i.join("  "),c=!0}return c}function YA(A){return{search:A.sSearch,smart:A.bSmart,regex:A.bRegex,caseInsensitive:A.bCaseInsensitive}}function bA(A){return{sSearch:A.search,bSmart:A.smart,bRegex:A.regex,bCaseInsensitive:A.caseInsensitive}}function zA(t){var e=t.sTableId,n=t.aanFeatures.i,r=A("<div/>",{class:t.oClasses.sInfo,id:n?null:e+"_info"});return n||(t.aoDrawCallback.push({fn:UA,sName:"information"}),r.attr("role","status").attr("aria-live","polite"),A(t.nTable).attr("aria-describedby",e+"_info")),r[0]}function UA(t){var e=t.aanFeatures.i;if(0!==e.length){var n=t.oLanguage,r=t._iDisplayStart+1,i=t.fnDisplayEnd(),o=t.fnRecordsTotal(),s=t.fnRecordsDisplay(),a=s?n.sInfo:n.sInfoEmpty;s!==o&&(a+=" "+n.sInfoFiltered),a=SA(t,a+=n.sInfoPostFix);var c=n.fnInfoCallback;null!==c&&(a=c.call(t.oInstance,t,r,i,o,s,a)),A(e).html(a)}}function SA(A,t){var e=A.fnFormatNumber,n=A._iDisplayStart+1,r=A._iDisplayLength,i=A.fnRecordsDisplay(),o=-1===r;return t.replace(/_START_/g,e.call(A,n)).replace(/_END_/g,e.call(A,A.fnDisplayEnd())).replace(/_MAX_/g,e.call(A,A.fnRecordsTotal())).replace(/_TOTAL_/g,e.call(A,i)).replace(/_PAGE_/g,e.call(A,o?1:Math.ceil(n/r))).replace(/_PAGES_/g,e.call(A,o?1:Math.ceil(i/r)))}function xA(A){var t,e,n,r=A.iInitDisplayStart,i=A.aoColumns,o=A.oFeatures,s=A.bDeferLoading;if(A.bInitialised){for(gA(A),sA(A),aA(A,A.aoHeader),aA(A,A.aoFooter),kA(A,!0),o.bAutoWidth&&WA(A),t=0,e=i.length;t<e;t++)(n=i[t]).sWidth&&(n.nTh.style.width=_A(n.sWidth));wt(A,null,"preInit",[A]),BA(A);var a=ft(A);("ssp"!=a||s)&&("ajax"==a?wA(A,[],(function(e){var n=QA(A,e);for(t=0;t<n.length;t++)O(A,n[t]);A.iInitDisplayStart=r,BA(A),kA(A,!1),TA(A,e)})):(kA(A,!1),TA(A)))}else setTimeout((function(){xA(A)}),200)}function TA(A,t){A._bInitComplete=!0,(t||A.oInit.aaData)&&R(A),wt(A,null,"plugin-init",[A,t]),wt(A,"aoInitComplete","init",[A,t])}function PA(A,t){var e=parseInt(t,10);A._iDisplayLength=e,ht(A),wt(A,null,"length",[A,e])}function NA(t){for(var e=t.oClasses,n=t.sTableId,r=t.aLengthMenu,i=Array.isArray(r[0]),o=i?r[0]:r,s=i?r[1]:r,a=A("<select/>",{name:n+"_length","aria-controls":n,class:e.sLengthSelect}),c=0,B=o.length;c<B;c++)a[0][c]=new Option("number"==typeof s[c]?t.fnFormatNumber(s[c]):s[c],o[c]);var g=A("<div><label/></div>").addClass(e.sLength);return t.aanFeatures.l||(g[0].id=n+"_length"),g.children().append(t.oLanguage.sLengthMenu.replace("_MENU_",a[0].outerHTML)),A("select",g).val(t._iDisplayLength).on("change.DT",(function(e){PA(t,A(this).val()),cA(t)})),A(t.nTable).on("length.dt.DT",(function(e,n,r){t===n&&A("select",g).val(r)})),g[0]}function RA(t){var e=t.sPaginationType,n=a.ext.pager[e],r="function"==typeof n,i=function(A){cA(A)},o=A("<div/>").addClass(t.oClasses.sPaging+e)[0],s=t.aanFeatures;return r||n.fnInit(t,o,i),s.p||(o.id=t.sTableId+"_paginate",t.aoDrawCallback.push({fn:function(A){if(r){var t,e,o=A._iDisplayStart,a=A._iDisplayLength,c=A.fnRecordsDisplay(),B=-1===a,g=B?0:Math.ceil(o/a),l=B?1:Math.ceil(c/a),u=n(g,l);for(t=0,e=s.p.length;t<e;t++)Et(A,"pageButton")(A,s.p[t],t,u,g,l)}else n.fnUpdate(A,i)},sName:"pagination"})),o}function GA(A,t,e){var n=A._iDisplayStart,r=A._iDisplayLength,i=A.fnRecordsDisplay();0===i||-1===r?n=0:"number"==typeof t?(n=t*r)>i&&(n=0):"first"==t?n=0:"previous"==t?(n=r>=0?n-r:0)<0&&(n=0):"next"==t?n+r<i&&(n+=r):"last"==t?n=Math.floor((i-1)/r)*r:ct(A,0,"Unknown paging action: "+t,5);var o=A._iDisplayStart!==n;return A._iDisplayStart=n,o?(wt(A,null,"page",[A]),e&&cA(A)):wt(A,null,"page-nc",[A]),o}function HA(t){return A("<div/>",{id:t.aanFeatures.r?null:t.sTableId+"_processing",class:t.oClasses.sProcessing,role:"status"}).html(t.oLanguage.sProcessing).append("<div><div></div><div></div><div></div><div></div></div>").insertBefore(t.nTable)[0]}function kA(t,e){t.oFeatures.bProcessing&&A(t.aanFeatures.r).css("display",e?"block":"none"),wt(t,null,"processing",[t,e])}function LA(t){var e=A(t.nTable),n=t.oScroll;if(""===n.sX&&""===n.sY)return t.nTable;var r=n.sX,i=n.sY,o=t.oClasses,s=e.children("caption"),a=s.length?s[0]._captionSide:null,c=A(e[0].cloneNode(!1)),B=A(e[0].cloneNode(!1)),g=e.children("tfoot"),l="<div/>",u=function(A){return A?_A(A):null};g.length||(g=null);var w=A(l,{class:o.sScrollWrapper}).append(A(l,{class:o.sScrollHead}).css({overflow:"hidden",position:"relative",border:0,width:r?u(r):"100%"}).append(A(l,{class:o.sScrollHeadInner}).css({"box-sizing":"content-box",width:n.sXInner||"100%"}).append(c.removeAttr("id").css("margin-left",0).append("top"===a?s:null).append(e.children("thead"))))).append(A(l,{class:o.sScrollBody}).css({position:"relative",overflow:"auto",width:u(r)}).append(e));g&&w.append(A(l,{class:o.sScrollFoot}).css({overflow:"hidden",border:0,width:r?u(r):"100%"}).append(A(l,{class:o.sScrollFootInner}).append(B.removeAttr("id").css("margin-left",0).append("bottom"===a?s:null).append(e.children("tfoot")))));var h=w.children(),E=h[0],f=h[1],Q=g?h[2]:null;return r&&A(f).on("scroll.DT",(function(A){var t=this.scrollLeft;E.scrollLeft=t,g&&(Q.scrollLeft=t)})),A(f).css("max-height",i),n.bCollapse||A(f).css("height",i),t.nScrollHead=E,t.nScrollBody=f,t.nScrollFoot=Q,t.aoDrawCallback.push({fn:JA,sName:"scrolling"}),w[0]}function JA(e){var r,i,o,s,a,c,B,g,l,u=e.oScroll,w=u.sX,h=u.sXInner,E=u.sY,f=u.iBarWidth,Q=A(e.nScrollHead),d=Q[0].style,M=Q.children("div"),I=M[0].style,p=M.children("table"),D=e.nScrollBody,y=A(D),v=D.style,m=A(e.nScrollFoot).children("div"),F=m.children("table"),Y=A(e.nTHead),b=A(e.nTable),z=b[0],U=z.style,S=e.nTFoot?A(e.nTFoot):null,x=e.oBrowser,T=x.bScrollOversize,P=(C(e.aoColumns,"nTh"),[]),N=[],H=[],k=[],L=function(A){var t=A.style;t.paddingTop="0",t.paddingBottom="0",t.borderTopWidth="0",t.borderBottomWidth="0",t.height=0},J=D.scrollHeight>D.clientHeight;if(e.scrollBarVis!==J&&e.scrollBarVis!==n)return e.scrollBarVis=J,void R(e);e.scrollBarVis=J,b.children("thead, tfoot").remove(),S&&(c=S.clone().prependTo(b),i=S.find("tr"),s=c.find("tr"),c.find("[id]").removeAttr("id")),a=Y.clone().prependTo(b),r=Y.find("tr"),o=a.find("tr"),a.find("th, td").removeAttr("tabindex"),a.find("[id]").removeAttr("id"),w||(v.width="100%",Q[0].style.width="100%"),A.each(uA(e,a),(function(A,t){B=G(e,A),t.style.width=e.aoColumns[B].sWidth})),S&&jA((function(A){A.style.width=""}),s),l=b.outerWidth(),""===w?(U.width="100%",T&&(b.find("tbody").height()>D.offsetHeight||"scroll"==y.css("overflow-y"))&&(U.width=_A(b.outerWidth()-f)),l=b.outerWidth()):""!==h&&(U.width=_A(h),l=b.outerWidth()),jA(L,o),jA((function(e){var n=t.getComputedStyle?t.getComputedStyle(e).width:_A(A(e).width());H.push(e.innerHTML),P.push(n)}),o),jA((function(A,t){A.style.width=P[t]}),r),A(o).css("height",0),S&&(jA(L,s),jA((function(t){k.push(t.innerHTML),N.push(_A(A(t).css("width")))}),s),jA((function(A,t){A.style.width=N[t]}),i),A(s).height(0)),jA((function(A,t){A.innerHTML='<div class="dataTables_sizing">'+H[t]+"</div>",A.childNodes[0].style.height="0",A.childNodes[0].style.overflow="hidden",A.style.width=P[t]}),o),S&&jA((function(A,t){A.innerHTML='<div class="dataTables_sizing">'+k[t]+"</div>",A.childNodes[0].style.height="0",A.childNodes[0].style.overflow="hidden",A.style.width=N[t]}),s),Math.round(b.outerWidth())<Math.round(l)?(g=D.scrollHeight>D.offsetHeight||"scroll"==y.css("overflow-y")?l+f:l,T&&(D.scrollHeight>D.offsetHeight||"scroll"==y.css("overflow-y"))&&(U.width=_A(g-f)),""!==w&&""===h||ct(e,1,"Possible column misalignment",6)):g="100%",v.width=_A(g),d.width=_A(g),S&&(e.nScrollFoot.style.width=_A(g)),E||T&&(v.height=_A(z.offsetHeight+f));var j=b.outerWidth();p[0].style.width=_A(j),I.width=_A(j);var O=b.height()>D.clientHeight||"scroll"==y.css("overflow-y"),W="padding"+(x.bScrollbarLeft?"Left":"Right");I[W]=O?f+"px":"0px",S&&(F[0].style.width=_A(j),m[0].style.width=_A(j),m[0].style[W]=O?f+"px":"0px"),b.children("colgroup").insertBefore(b.children("thead")),y.trigger("scroll"),!e.bSorted&&!e.bFiltered||e._drawHold||(D.scrollTop=0)}function jA(A,t,e){for(var n,r,i=0,o=0,s=t.length;o<s;){for(n=t[o].firstChild,r=e?e[o].firstChild:null;n;)1===n.nodeType&&(e?A(n,r,i):A(n,i),i++),n=n.nextSibling,r=e?r.nextSibling:null;o++}}var OA=/<.*?>/g;function WA(e){var n,r,i,o=e.nTable,s=e.aoColumns,a=e.oScroll,c=a.sY,B=a.sX,g=a.sXInner,l=s.length,u=L(e,"bVisible"),w=A("th",e.nTHead),h=o.getAttribute("width"),E=o.parentNode,f=!1,Q=e.oBrowser,d=Q.bScrollOversize,M=o.style.width;M&&-1!==M.indexOf("%")&&(h=M);var I=VA(C(s,"sWidthOrig"),E);for(n=0;n<u.length;n++)null!==(r=s[u[n]]).sWidth&&(r.sWidth=I[n],f=!0);if(d||!f&&!B&&!c&&l==k(e)&&l==w.length)for(n=0;n<l;n++){var p=G(e,n);null!==p&&(s[p].sWidth=_A(w.eq(n).width()))}else{var D=A(o).clone().css("visibility","hidden").removeAttr("id");D.find("tbody tr").remove();var y=A("<tr/>").appendTo(D.find("tbody"));for(D.find("thead, tfoot").remove(),D.append(A(e.nTHead).clone()).append(A(e.nTFoot).clone()),D.find("tfoot th, tfoot td").css("width",""),w=uA(e,D.find("thead")[0]),n=0;n<u.length;n++)r=s[u[n]],w[n].style.width=null!==r.sWidthOrig&&""!==r.sWidthOrig?_A(r.sWidthOrig):"",r.sWidthOrig&&B&&A(w[n]).append(A("<div/>").css({width:r.sWidthOrig,margin:0,padding:0,border:0,height:1}));if(e.aoData.length)for(n=0;n<u.length;n++)r=s[i=u[n]],A(XA(e,i)).clone(!1).append(r.sContentPadding).appendTo(y);A("[name]",D).removeAttr("name");var v=A("<div/>").css(B||c?{position:"absolute",top:0,left:0,height:1,right:0,overflow:"hidden"}:{}).append(D).appendTo(E);B&&g?D.width(g):B?(D.css("width","auto"),D.removeAttr("width"),D.width()<E.clientWidth&&h&&D.width(E.clientWidth)):c?D.width(E.clientWidth):h&&D.width(h);var m=0;for(n=0;n<u.length;n++){var F=A(w[n]),Y=F.outerWidth()-F.width(),b=Q.bBounding?Math.ceil(w[n].getBoundingClientRect().width):F.outerWidth();m+=b,s[u[n]].sWidth=_A(b-Y)}o.style.width=_A(m),v.remove()}if(h&&(o.style.width=_A(h)),(h||B)&&!e._reszEvt){var z=function(){A(t).on("resize.DT-"+e.sInstance,KA((function(){R(e)})))};d?setTimeout(z,1e3):z(),e._reszEvt=!0}}var KA=a.util.throttle;function VA(t,n){for(var r=[],i=[],o=0;o<t.length;o++)t[o]?r.push(A("<div/>").css("width",_A(t[o])).appendTo(n||e.body)):r.push(null);for(o=0;o<t.length;o++)i.push(r[o]?r[o][0].offsetWidth:null);return A(r).remove(),i}function XA(t,e){var n=ZA(t,e);if(n<0)return null;var r=t.aoData[n];return r.nTr?r.anCells[e]:A("<td/>").html(K(t,n,e,"display"))[0]}function ZA(A,t){for(var e,n=-1,r=-1,i=0,o=A.aoData.length;i<o;i++)(e=(e=(e=K(A,i,t,"display")+"").replace(OA,"")).replace(/&nbsp;/g," ")).length>n&&(n=e.length,r=i);return r}function _A(A){return null===A?"0px":"number"==typeof A?A<0?"0px":A+"px":A.match(/\d$/)?A+"px":A}function qA(t){var e,r,i,o,s,c,B,g=[],l=t.aoColumns,u=t.aaSortingFixed,w=A.isPlainObject(u),h=[],E=function(t){t.length&&!Array.isArray(t[0])?h.push(t):A.merge(h,t)};for(Array.isArray(u)&&E(u),w&&u.pre&&E(u.pre),E(t.aaSorting),w&&u.post&&E(u.post),e=0;e<h.length;e++)for(r=0,i=(o=l[B=h[e][0]].aDataSort).length;r<i;r++)c=l[s=o[r]].sType||"string",h[e]._idx===n&&(h[e]._idx=A.inArray(h[e][1],l[s].asSorting)),g.push({src:B,col:s,dir:h[e][1],index:h[e]._idx,type:c,formatter:a.ext.type.order[c+"-pre"]});return g}function $A(A){var t,e,n,r,i,o=[],s=a.ext.type.order,c=A.aoData,B=(A.aoColumns,0),g=A.aiDisplayMaster;for(J(A),t=0,e=(i=qA(A)).length;t<e;t++)(r=i[t]).formatter&&B++,rt(A,r.col);if("ssp"!=ft(A)&&0!==i.length){for(t=0,n=g.length;t<n;t++)o[g[t]]=t;B===i.length?g.sort((function(A,t){var e,n,r,s,a,B=i.length,g=c[A]._aSortData,l=c[t]._aSortData;for(r=0;r<B;r++)if(0!==(s=(e=g[(a=i[r]).col])<(n=l[a.col])?-1:e>n?1:0))return"asc"===a.dir?s:-s;return(e=o[A])<(n=o[t])?-1:e>n?1:0})):g.sort((function(A,t){var e,n,r,a,B,g=i.length,l=c[A]._aSortData,u=c[t]._aSortData;for(r=0;r<g;r++)if(e=l[(B=i[r]).col],n=u[B.col],0!==(a=(s[B.type+"-"+B.dir]||s["string-"+B.dir])(e,n)))return a;return(e=o[A])<(n=o[t])?-1:e>n?1:0}))}A.bSorted=!0}function At(A){for(var t,e,n=A.aoColumns,r=qA(A),i=A.oLanguage.oAria,o=0,s=n.length;o<s;o++){var a=n[o],c=a.asSorting,B=a.ariaTitle||a.sTitle.replace(/<.*?>/g,""),g=a.nTh;g.removeAttribute("aria-sort"),a.bSortable?(r.length>0&&r[0].col==o?(g.setAttribute("aria-sort","asc"==r[0].dir?"ascending":"descending"),e=c[r[0].index+1]||c[0]):e=c[0],t=B+("asc"===e?i.sSortAscending:i.sSortDescending)):t=B,g.setAttribute("aria-label",t)}}function tt(t,e,r,i){var o,s=t.aoColumns[e],a=t.aaSorting,c=s.asSorting,B=function(t,e){var r=t._idx;return r===n&&(r=A.inArray(t[1],c)),r+1<c.length?r+1:e?null:0};if("number"==typeof a[0]&&(a=t.aaSorting=[a]),r&&t.oFeatures.bSortMulti){var g=A.inArray(e,C(a,"0"));-1!==g?(null===(o=B(a[g],!0))&&1===a.length&&(o=0),null===o?a.splice(g,1):(a[g][1]=c[o],a[g]._idx=o)):(a.push([e,c[0],0]),a[a.length-1]._idx=0)}else a.length&&a[0][0]==e?(o=B(a[0]),a.length=1,a[0][1]=c[o],a[0]._idx=o):(a.length=0,a.push([e,c[0]]),a[0]._idx=0);BA(t),"function"==typeof i&&i(t)}function et(A,t,e,n){var r=A.aoColumns[e];lt(t,{},(function(t){!1!==r.bSortable&&(A.oFeatures.bProcessing?(kA(A,!0),setTimeout((function(){tt(A,e,t.shiftKey,n),"ssp"!==ft(A)&&kA(A,!1)}),0)):tt(A,e,t.shiftKey,n))}))}function nt(t){var e,n,r,i=t.aLastSort,o=t.oClasses.sSortColumn,s=qA(t),a=t.oFeatures;if(a.bSort&&a.bSortClasses){for(e=0,n=i.length;e<n;e++)r=i[e].src,A(C(t.aoData,"anCells",r)).removeClass(o+(e<2?e+1:3));for(e=0,n=s.length;e<n;e++)r=s[e].src,A(C(t.aoData,"anCells",r)).addClass(o+(e<2?e+1:3))}t.aLastSort=s}function rt(A,t){var e,n,r,i=A.aoColumns[t],o=a.ext.order[i.sSortDataType];o&&(e=o.call(A.oInstance,A,t,H(A,t)));for(var s=a.ext.type.order[i.sType+"-pre"],c=0,B=A.aoData.length;c<B;c++)(n=A.aoData[c])._aSortData||(n._aSortData=[]),n._aSortData[t]&&!o||(r=o?e[c]:K(A,c,t,"sort"),n._aSortData[t]=s?s(r):r)}function it(t){if(!t._bLoadingState){var e={time:+new Date,start:t._iDisplayStart,length:t._iDisplayLength,order:A.extend(!0,[],t.aaSorting),search:YA(t.oPreviousSearch),columns:A.map(t.aoColumns,(function(A,e){return{visible:A.bVisible,search:YA(t.aoPreSearchCols[e])}}))};t.oSavedState=e,wt(t,"aoStateSaveParams","stateSaveParams",[t,e]),t.oFeatures.bStateSave&&!t.bDestroying&&t.fnStateSaveCallback.call(t.oInstance,t,e)}}function ot(A,t,e){if(A.oFeatures.bStateSave){var r=A.fnStateLoadCallback.call(A.oInstance,A,(function(t){st(A,t,e)}));return r!==n&&st(A,r,e),!0}e()}function st(t,e,r){var i,o,s=t.aoColumns;t._bLoadingState=!0;var c=t._bInitComplete?new a.Api(t):null;if(!e||!e.time)return t._bLoadingState=!1,void r();var B=wt(t,"aoStateLoadParams","stateLoadParams",[t,e]);if(-1!==A.inArray(!1,B))return t._bLoadingState=!1,void r();var g=t.iStateDuration;if(g>0&&e.time<+new Date-1e3*g)return t._bLoadingState=!1,void r();if(e.columns&&s.length!==e.columns.length)return t._bLoadingState=!1,void r();if(t.oLoadedState=A.extend(!0,{},e),e.length!==n&&(c?c.page.len(e.length):t._iDisplayLength=e.length),e.start!==n&&(null===c?(t._iDisplayStart=e.start,t.iInitDisplayStart=e.start):GA(t,e.start/t._iDisplayLength)),e.order!==n&&(t.aaSorting=[],A.each(e.order,(function(A,e){t.aaSorting.push(e[0]>=s.length?[0,e[1]]:e)}))),e.search!==n&&A.extend(t.oPreviousSearch,bA(e.search)),e.columns){for(i=0,o=e.columns.length;i<o;i++){var l=e.columns[i];l.visible!==n&&(c?c.column(i).visible(l.visible,!1):s[i].bVisible=l.visible),l.search!==n&&A.extend(t.aoPreSearchCols[i],bA(l.search))}c&&c.columns.adjust()}t._bLoadingState=!1,wt(t,"aoStateLoaded","stateLoaded",[t,e]),r()}function at(t){var e=a.settings,n=A.inArray(t,C(e,"nTable"));return-1!==n?e[n]:null}function ct(A,e,n,r){if(n="DataTables warning: "+(A?"table id="+A.sTableId+" - ":"")+n,r&&(n+=". For more information about this error, please see https://datatables.net/tn/"+r),e)t.console&&console.log&&console.log(n);else{var i=a.ext,o=i.sErrMode||i.errMode;if(A&&wt(A,null,"error",[A,r,n]),"alert"==o)alert(n);else{if("throw"==o)throw new Error(n);"function"==typeof o&&o(A,r,n)}}}function Bt(t,e,r,i){Array.isArray(r)?A.each(r,(function(A,n){Array.isArray(n)?Bt(t,e,n[0],n[1]):Bt(t,e,n)})):(i===n&&(i=r),e[r]!==n&&(t[i]=e[r]))}function gt(t,e,n){var r;for(var i in e)e.hasOwnProperty(i)&&(r=e[i],A.isPlainObject(r)?(A.isPlainObject(t[i])||(t[i]={}),A.extend(!0,t[i],r)):n&&"data"!==i&&"aaData"!==i&&Array.isArray(r)?t[i]=r.slice():t[i]=r);return t}function lt(t,e,n){A(t).on("click.DT",e,(function(e){A(t).trigger("blur"),n(e)})).on("keypress.DT",e,(function(A){13===A.which&&(A.preventDefault(),n(A))})).on("selectstart.DT",(function(){return!1}))}function ut(A,t,e,n){e&&A[t].push({fn:e,sName:n})}function wt(t,e,n,r){var i=[];if(e&&(i=A.map(t[e].slice().reverse(),(function(A,e){return A.fn.apply(t.oInstance,r)}))),null!==n){var o=A.Event(n+".dt"),s=A(t.nTable);s.trigger(o,r),0===s.parents("body").length&&A("body").trigger(o,r),i.push(o.result)}return i}function ht(A){var t=A._iDisplayStart,e=A.fnDisplayEnd(),n=A._iDisplayLength;t>=e&&(t=e-n),t-=t%n,(-1===n||t<0)&&(t=0),A._iDisplayStart=t}function Et(t,e){var n=t.renderer,r=a.ext.renderer[e];return A.isPlainObject(n)&&n[e]?r[n[e]]||r._:"string"==typeof n&&r[n]||r._}function ft(A){return A.oFeatures.bServerSide?"ssp":A.ajax||A.sAjaxSource?"ajax":"dom"}var Qt=[],dt=Array.prototype;i=function(t,e){if(!(this instanceof i))return new i(t,e);var n=[],r=function(t){var e=function(t){var e,n,r=a.settings,i=A.map(r,(function(A,t){return A.nTable}));return t?t.nTable&&t.oApi?[t]:t.nodeName&&"table"===t.nodeName.toLowerCase()?-1!==(e=A.inArray(t,i))?[r[e]]:null:t&&"function"==typeof t.settings?t.settings().toArray():("string"==typeof t?n=A(t):t instanceof A&&(n=t),n?n.map((function(t){return-1!==(e=A.inArray(this,i))?r[e]:null})).toArray():void 0):[]}(t);e&&n.push.apply(n,e)};if(Array.isArray(t))for(var o=0,s=t.length;o<s;o++)r(t[o]);else r(t);this.context=y(n),e&&A.merge(this,e),this.selector={rows:null,cols:null,opts:null},i.extend(this,this,Qt)},a.Api=i,A.extend(i.prototype,{any:function(){return 0!==this.count()},concat:dt.concat,context:[],count:function(){return this.flatten().length},each:function(A){for(var t=0,e=this.length;t<e;t++)A.call(this,this[t],t,this);return this},eq:function(A){var t=this.context;return t.length>A?new i(t[A],this[A]):null},filter:function(A){var t=[];if(dt.filter)t=dt.filter.call(this,A,this);else for(var e=0,n=this.length;e<n;e++)A.call(this,this[e],e,this)&&t.push(this[e]);return new i(this.context,t)},flatten:function(){var A=[];return new i(this.context,A.concat.apply(A,this.toArray()))},join:dt.join,indexOf:dt.indexOf||function(A,t){for(var e=t||0,n=this.length;e<n;e++)if(this[e]===A)return e;return-1},iterator:function(A,t,e,r){var o,s,a,c,B,g,l,u,w=[],h=this.context,E=this.selector;for("string"==typeof A&&(r=e,e=t,t=A,A=!1),s=0,a=h.length;s<a;s++){var f=new i(h[s]);if("table"===t)(o=e.call(f,h[s],s))!==n&&w.push(o);else if("columns"===t||"rows"===t)(o=e.call(f,h[s],this[s],s))!==n&&w.push(o);else if("column"===t||"column-rows"===t||"row"===t||"cell"===t)for(l=this[s],"column-rows"===t&&(g=yt(h[s],E.opts)),c=0,B=l.length;c<B;c++)u=l[c],(o="cell"===t?e.call(f,h[s],u.row,u.column,s,c):e.call(f,h[s],u,s,c,g))!==n&&w.push(o)}if(w.length||r){var Q=new i(h,A?w.concat.apply([],w):w),d=Q.selector;return d.rows=E.rows,d.cols=E.cols,d.opts=E.opts,Q}return this},lastIndexOf:dt.lastIndexOf||function(A,t){return this.indexOf.apply(this.toArray.reverse(),arguments)},length:0,map:function(A){var t=[];if(dt.map)t=dt.map.call(this,A,this);else for(var e=0,n=this.length;e<n;e++)t.push(A.call(this,this[e],e));return new i(this.context,t)},pluck:function(A){var t=a.util.get(A);return this.map((function(A){return t(A)}))},pop:dt.pop,push:dt.push,reduce:dt.reduce||function(A,t){return T(this,A,t,0,this.length,1)},reduceRight:dt.reduceRight||function(A,t){return T(this,A,t,this.length-1,-1,-1)},reverse:dt.reverse,selector:null,shift:dt.shift,slice:function(){return new i(this.context,this)},sort:dt.sort,splice:dt.splice,toArray:function(){return dt.slice.call(this)},to$:function(){return A(this)},toJQuery:function(){return A(this)},unique:function(){return new i(this.context,y(this))},unshift:dt.unshift}),i.extend=function(A,t,e){if(e.length&&t&&(t instanceof i||t.__dt_wrapper)){var n,r,o,s=function(A,t,e){return function(){var n=t.apply(A,arguments);return i.extend(n,n,e.methodExt),n}};for(n=0,r=e.length;n<r;n++)t[(o=e[n]).name]="function"===o.type?s(A,o.val,o):"object"===o.type?{}:o.val,t[o.name].__dt_wrapper=!0,i.extend(A,t[o.name],o.propExt)}},i.register=o=function(t,e){if(Array.isArray(t))for(var n=0,r=t.length;n<r;n++)i.register(t[n],e);else{var o,s,a,c,B=t.split("."),g=Qt,l=function(A,t){for(var e=0,n=A.length;e<n;e++)if(A[e].name===t)return A[e];return null};for(o=0,s=B.length;o<s;o++){var u=l(g,a=(c=-1!==B[o].indexOf("()"))?B[o].replace("()",""):B[o]);u||(u={name:a,val:{},methodExt:[],propExt:[],type:"object"},g.push(u)),o===s-1?(u.val=e,u.type="function"==typeof e?"function":A.isPlainObject(e)?"object":"other"):g=c?u.methodExt:u.propExt}}},i.registerPlural=s=function(A,t,e){i.register(A,e),i.register(t,(function(){var A=e.apply(this,arguments);return A===this?this:A instanceof i?A.length?Array.isArray(A[0])?new i(A.context,A[0]):A[0]:n:A}))};var Ct=function(t,e){if(Array.isArray(t))return A.map(t,(function(A){return Ct(A,e)}));if("number"==typeof t)return[e[t]];var n=A.map(e,(function(A,t){return A.nTable}));return A(n).filter(t).map((function(t){var r=A.inArray(this,n);return e[r]})).toArray()};o("tables()",(function(A){return A!==n&&null!==A?new i(Ct(A,this.context)):this})),o("table()",(function(A){var t=this.tables(A),e=t.context;return e.length?new i(e[0]):t})),s("tables().nodes()","table().node()",(function(){return this.iterator("table",(function(A){return A.nTable}),1)})),s("tables().body()","table().body()",(function(){return this.iterator("table",(function(A){return A.nTBody}),1)})),s("tables().header()","table().header()",(function(){return this.iterator("table",(function(A){return A.nTHead}),1)})),s("tables().footer()","table().footer()",(function(){return this.iterator("table",(function(A){return A.nTFoot}),1)})),s("tables().containers()","table().container()",(function(){return this.iterator("table",(function(A){return A.nTableWrapper}),1)})),o("draw()",(function(A){return this.iterator("table",(function(t){"page"===A?cA(t):("string"==typeof A&&(A="full-hold"!==A),BA(t,!1===A))}))})),o("page()",(function(A){return A===n?this.page.info().page:this.iterator("table",(function(t){GA(t,A)}))})),o("page.info()",(function(A){if(0===this.context.length)return n;var t=this.context[0],e=t._iDisplayStart,r=t.oFeatures.bPaginate?t._iDisplayLength:-1,i=t.fnRecordsDisplay(),o=-1===r;return{page:o?0:Math.floor(e/r),pages:o?1:Math.ceil(i/r),start:e,end:t.fnDisplayEnd(),length:r,recordsTotal:t.fnRecordsTotal(),recordsDisplay:i,serverSide:"ssp"===ft(t)}})),o("page.len()",(function(A){return A===n?0!==this.context.length?this.context[0]._iDisplayLength:n:this.iterator("table",(function(t){PA(t,A)}))}));var Mt=function(A,t,e){if(e){var n=new i(A);n.one("draw",(function(){e(n.ajax.json())}))}if("ssp"==ft(A))BA(A,t);else{kA(A,!0);var r=A.jqXHR;r&&4!==r.readyState&&r.abort(),wA(A,[],(function(e){tA(A);for(var n=QA(A,e),r=0,i=n.length;r<i;r++)O(A,n[r]);BA(A,t),kA(A,!1)}))}};o("ajax.json()",(function(){var A=this.context;if(A.length>0)return A[0].json})),o("ajax.params()",(function(){var A=this.context;if(A.length>0)return A[0].oAjaxData})),o("ajax.reload()",(function(A,t){return this.iterator("table",(function(e){Mt(e,!1===t,A)}))})),o("ajax.url()",(function(t){var e=this.context;return t===n?0===e.length?n:(e=e[0]).ajax?A.isPlainObject(e.ajax)?e.ajax.url:e.ajax:e.sAjaxSource:this.iterator("table",(function(e){A.isPlainObject(e.ajax)?e.ajax.url=t:e.ajax=t}))})),o("ajax.url().load()",(function(A,t){return this.iterator("table",(function(e){Mt(e,!1===t,A)}))}));var It=function(A,t,e,i,o){var s,a,c,B,g,l,u=[],w=typeof t;for(t&&"string"!==w&&"function"!==w&&t.length!==n||(t=[t]),c=0,B=t.length;c<B;c++)for(g=0,l=(a=t[c]&&t[c].split&&!t[c].match(/[\[\(:]/)?t[c].split(","):[t[c]]).length;g<l;g++)(s=e("string"==typeof a[g]?a[g].trim():a[g]))&&s.length&&(u=u.concat(s));var h=r.selector[A];if(h.length)for(c=0,B=h.length;c<B;c++)u=h[c](i,o,u);return y(u)},pt=function(t){return t||(t={}),t.filter&&t.search===n&&(t.search=t.filter),A.extend({search:"none",order:"current",page:"all"},t)},Dt=function(A){for(var t=0,e=A.length;t<e;t++)if(A[t].length>0)return A[0]=A[t],A[0].length=1,A.length=1,A.context=[A.context[t]],A;return A.length=0,A},yt=function(t,e){var n,r=[],i=t.aiDisplay,o=t.aiDisplayMaster,s=e.search,a=e.order,c=e.page;if("ssp"==ft(t))return"removed"===s?[]:I(0,o.length);if("current"==c)for(g=t._iDisplayStart,l=t.fnDisplayEnd();g<l;g++)r.push(i[g]);else if("current"==a||"applied"==a){if("none"==s)r=o.slice();else if("applied"==s)r=i.slice();else if("removed"==s){for(var B={},g=0,l=i.length;g<l;g++)B[i[g]]=null;r=A.map(o,(function(A){return B.hasOwnProperty(A)?null:A}))}}else if("index"==a||"original"==a)for(g=0,l=t.aoData.length;g<l;g++)("none"==s||-1===(n=A.inArray(g,i))&&"removed"==s||n>=0&&"applied"==s)&&r.push(g);return r};o("rows()",(function(t,e){t===n?t="":A.isPlainObject(t)&&(e=t,t=""),e=pt(e);var r=this.iterator("table",(function(r){return function(t,e,r){var i;return It("row",e,(function(e){var o=E(e),s=t.aoData;if(null!==o&&!r)return[o];if(i||(i=yt(t,r)),null!==o&&-1!==A.inArray(o,i))return[o];if(null===e||e===n||""===e)return i;if("function"==typeof e)return A.map(i,(function(A){var t=s[A];return e(A,t._aData,t.nTr)?A:null}));if(e.nodeName){var a=e._DT_RowIndex,c=e._DT_CellIndex;if(a!==n)return s[a]&&s[a].nTr===e?[a]:[];if(c)return s[c.row]&&s[c.row].nTr===e.parentNode?[c.row]:[];var B=A(e).closest("*[data-dt-row]");return B.length?[B.data("dt-row")]:[]}if("string"==typeof e&&"#"===e.charAt(0)){var g=t.aIds[e.replace(/^#/,"")];if(g!==n)return[g.idx]}var l=p(M(t.aoData,i,"nTr"));return A(l).filter(e).map((function(){return this._DT_RowIndex})).toArray()}),t,r)}(r,t,e)}),1);return r.selector.rows=t,r.selector.opts=e,r})),o("rows().nodes()",(function(){return this.iterator("row",(function(A,t){return A.aoData[t].nTr||n}),1)})),o("rows().data()",(function(){return this.iterator(!0,"rows",(function(A,t){return M(A.aoData,t,"_aData")}),1)})),s("rows().cache()","row().cache()",(function(A){return this.iterator("row",(function(t,e){var n=t.aoData[e];return"search"===A?n._aFilterData:n._aSortData}),1)})),s("rows().invalidate()","row().invalidate()",(function(A){return this.iterator("row",(function(t,e){nA(t,e,A)}))})),s("rows().indexes()","row().index()",(function(){return this.iterator("row",(function(A,t){return t}),1)})),s("rows().ids()","row().id()",(function(A){for(var t=[],e=this.context,n=0,r=e.length;n<r;n++)for(var o=0,s=this[n].length;o<s;o++){var a=e[n].rowIdFn(e[n].aoData[this[n][o]]._aData);t.push((!0===A?"#":"")+a)}return new i(e,t)})),s("rows().remove()","row().remove()",(function(){var A=this;return this.iterator("row",(function(t,e,r){var i,o,s,a,c,B,g=t.aoData,l=g[e];for(g.splice(e,1),i=0,o=g.length;i<o;i++)if(B=(c=g[i]).anCells,null!==c.nTr&&(c.nTr._DT_RowIndex=i),null!==B)for(s=0,a=B.length;s<a;s++)B[s]._DT_CellIndex.row=i;eA(t.aiDisplayMaster,e),eA(t.aiDisplay,e),eA(A[r],e,!1),t._iRecordsDisplay>0&&t._iRecordsDisplay--,ht(t);var u=t.rowIdFn(l._aData);u!==n&&delete t.aIds[u]})),this.iterator("table",(function(A){for(var t=0,e=A.aoData.length;t<e;t++)A.aoData[t].idx=t})),this})),o("rows.add()",(function(t){var e=this.iterator("table",(function(A){var e,n,r,i=[];for(n=0,r=t.length;n<r;n++)(e=t[n]).nodeName&&"TR"===e.nodeName.toUpperCase()?i.push(W(A,e)[0]):i.push(O(A,e));return i}),1),n=this.rows(-1);return n.pop(),A.merge(n,e),n})),o("row()",(function(A,t){return Dt(this.rows(A,t))})),o("row().data()",(function(A){var t=this.context;if(A===n)return t.length&&this.length?t[0].aoData[this[0]]._aData:n;var e=t[0].aoData[this[0]];return e._aData=A,Array.isArray(A)&&e.nTr&&e.nTr.id&&$(t[0].rowId)(A,e.nTr.id),nA(t[0],this[0],"data"),this})),o("row().node()",(function(){var A=this.context;return A.length&&this.length&&A[0].aoData[this[0]].nTr||null})),o("row.add()",(function(t){t instanceof A&&t.length&&(t=t[0]);var e=this.iterator("table",(function(A){return t.nodeName&&"TR"===t.nodeName.toUpperCase()?W(A,t)[0]:O(A,t)}));return this.row(e[0])})),A(e).on("plugin-init.dt",(function(t,e){var n=new i(e),r="on-plugin-init",o="stateSaveParams."+r,s="destroy. "+r;n.on(o,(function(A,t,e){for(var n=t.rowIdFn,r=t.aoData,i=[],o=0;o<r.length;o++)r[o]._detailsShow&&i.push("#"+n(r[o]._aData));e.childRows=i})),n.on(s,(function(){n.off(o+" "+s)}));var a=n.state.loaded();a&&a.childRows&&n.rows(A.map(a.childRows,(function(A){return A.replace(/:/g,"\\:")}))).every((function(){wt(e,null,"requestChild",[this])}))}));var vt=a.util.throttle((function(A){it(A[0])}),500),mt=function(t,e){var r=t.context;if(r.length){var i=r[0].aoData[e!==n?e:t[0]];i&&i._details&&(i._details.remove(),i._detailsShow=n,i._details=n,A(i.nTr).removeClass("dt-hasChild"),vt(r))}},Ft=function(t,e){var n=t.context;if(n.length&&t.length){var r=n[0].aoData[t[0]];r._details&&(r._detailsShow=e,e?(r._details.insertAfter(r.nTr),A(r.nTr).addClass("dt-hasChild")):(r._details.detach(),A(r.nTr).removeClass("dt-hasChild")),wt(n[0],null,"childRow",[e,t.row(t[0])]),Yt(n[0]),vt(n))}},Yt=function(A){var t=new i(A),e=".dt.DT_details",n="draw"+e,r="column-sizing"+e,o="destroy"+e,s=A.aoData;t.off(n+" "+r+" "+o),C(s,"_details").length>0&&(t.on(n,(function(e,n){A===n&&t.rows({page:"current"}).eq(0).each((function(A){var t=s[A];t._detailsShow&&t._details.insertAfter(t.nTr)}))})),t.on(r,(function(t,e,n,r){if(A===e)for(var i,o=k(e),a=0,c=s.length;a<c;a++)(i=s[a])._details&&i._details.children("td[colspan]").attr("colspan",o)})),t.on(o,(function(e,n){if(A===n)for(var r=0,i=s.length;r<i;r++)s[r]._details&&mt(t,r)})))},bt="row().child",zt=bt+"()";o(zt,(function(t,e){var r=this.context;return t===n?r.length&&this.length?r[0].aoData[this[0]]._details:n:(!0===t?this.child.show():!1===t?mt(this):r.length&&this.length&&function(t,e,n,r){var i=[],o=function(e,n){if(Array.isArray(e)||e instanceof A)for(var r=0,s=e.length;r<s;r++)o(e[r],n);else if(e.nodeName&&"tr"===e.nodeName.toLowerCase())i.push(e);else{var a=A("<tr><td></td></tr>").addClass(n);A("td",a).addClass(n).html(e)[0].colSpan=k(t),i.push(a[0])}};o(n,r),e._details&&e._details.detach(),e._details=A(i),e._detailsShow&&e._details.insertAfter(e.nTr)}(r[0],r[0].aoData[this[0]],t,e),this)})),o([bt+".show()",zt+".show()"],(function(A){return Ft(this,!0),this})),o([bt+".hide()",zt+".hide()"],(function(){return Ft(this,!1),this})),o([bt+".remove()",zt+".remove()"],(function(){return mt(this),this})),o(bt+".isShown()",(function(){var A=this.context;return A.length&&this.length&&A[0].aoData[this[0]]._detailsShow||!1}));var Ut=/^([^:]+):(name|visIdx|visible)$/,St=function(A,t,e,n,r){for(var i=[],o=0,s=r.length;o<s;o++)i.push(K(A,r[o],t));return i};o("columns()",(function(t,e){t===n?t="":A.isPlainObject(t)&&(e=t,t=""),e=pt(e);var r=this.iterator("table",(function(n){return function(t,e,n){var r=t.aoColumns,i=C(r,"sName"),o=C(r,"nTh");return It("column",e,(function(e){var s=E(e);if(""===e)return I(r.length);if(null!==s)return[s>=0?s:r.length+s];if("function"==typeof e){var a=yt(t,n);return A.map(r,(function(A,n){return e(n,St(t,n,0,0,a),o[n])?n:null}))}var c="string"==typeof e?e.match(Ut):"";if(c)switch(c[2]){case"visIdx":case"visible":var B=parseInt(c[1],10);if(B<0){var g=A.map(r,(function(A,t){return A.bVisible?t:null}));return[g[g.length+B]]}return[G(t,B)];case"name":return A.map(i,(function(A,t){return A===c[1]?t:null}));default:return[]}if(e.nodeName&&e._DT_CellIndex)return[e._DT_CellIndex.column];var l=A(o).filter(e).map((function(){return A.inArray(this,o)})).toArray();if(l.length||!e.nodeName)return l;var u=A(e).closest("*[data-dt-column]");return u.length?[u.data("dt-column")]:[]}),t,n)}(n,t,e)}),1);return r.selector.cols=t,r.selector.opts=e,r})),s("columns().header()","column().header()",(function(A,t){return this.iterator("column",(function(A,t){return A.aoColumns[t].nTh}),1)})),s("columns().footer()","column().footer()",(function(A,t){return this.iterator("column",(function(A,t){return A.aoColumns[t].nTf}),1)})),s("columns().data()","column().data()",(function(){return this.iterator("column-rows",St,1)})),s("columns().dataSrc()","column().dataSrc()",(function(){return this.iterator("column",(function(A,t){return A.aoColumns[t].mData}),1)})),s("columns().cache()","column().cache()",(function(A){return this.iterator("column-rows",(function(t,e,n,r,i){return M(t.aoData,i,"search"===A?"_aFilterData":"_aSortData",e)}),1)})),s("columns().nodes()","column().nodes()",(function(){return this.iterator("column-rows",(function(A,t,e,n,r){return M(A.aoData,r,"anCells",t)}),1)})),s("columns().visible()","column().visible()",(function(t,e){var r=this,i=this.iterator("column",(function(e,r){if(t===n)return e.aoColumns[r].bVisible;!function(t,e,r){var i,o,s,a,c=t.aoColumns,B=c[e],g=t.aoData;if(r===n)return B.bVisible;if(B.bVisible!==r){if(r){var l=A.inArray(!0,C(c,"bVisible"),e+1);for(o=0,s=g.length;o<s;o++)a=g[o].nTr,i=g[o].anCells,a&&a.insertBefore(i[e],i[l]||null)}else A(C(t.aoData,"anCells",e)).detach();B.bVisible=r}}(e,r,t)}));return t!==n&&this.iterator("table",(function(i){aA(i,i.aoHeader),aA(i,i.aoFooter),i.aiDisplay.length||A(i.nTBody).find("td[colspan]").attr("colspan",k(i)),it(i),r.iterator("column",(function(A,n){wt(A,null,"column-visibility",[A,n,t,e])})),(e===n||e)&&r.columns.adjust()})),i})),s("columns().indexes()","column().index()",(function(A){return this.iterator("column",(function(t,e){return"visible"===A?H(t,e):e}),1)})),o("columns.adjust()",(function(){return this.iterator("table",(function(A){R(A)}),1)})),o("column.index()",(function(A,t){if(0!==this.context.length){var e=this.context[0];if("fromVisible"===A||"toData"===A)return G(e,t);if("fromData"===A||"toVisible"===A)return H(e,t)}})),o("column()",(function(A,t){return Dt(this.columns(A,t))}));o("cells()",(function(t,e,r){if(A.isPlainObject(t)&&(t.row===n?(r=t,t=null):(r=e,e=null)),A.isPlainObject(e)&&(r=e,e=null),null===e||e===n)return this.iterator("table",(function(e){return function(t,e,r){var i,o,s,a,c,B,g,l=t.aoData,u=yt(t,r),w=p(M(l,u,"anCells")),h=A(v([],w)),E=t.aoColumns.length;return It("cell",e,(function(e){var r="function"==typeof e;if(null===e||e===n||r){for(o=[],s=0,a=u.length;s<a;s++)for(i=u[s],c=0;c<E;c++)B={row:i,column:c},r?(g=l[i],e(B,K(t,i,c),g.anCells?g.anCells[c]:null)&&o.push(B)):o.push(B);return o}if(A.isPlainObject(e))return e.column!==n&&e.row!==n&&-1!==A.inArray(e.row,u)?[e]:[];var w=h.filter(e).map((function(A,t){return{row:t._DT_CellIndex.row,column:t._DT_CellIndex.column}})).toArray();return w.length||!e.nodeName?w:(g=A(e).closest("*[data-dt-row]")).length?[{row:g.data("dt-row"),column:g.data("dt-column")}]:[]}),t,r)}(e,t,pt(r))}));var i,o,s,a,c=r?{page:r.page,order:r.order,search:r.search}:{},B=this.columns(e,c),g=this.rows(t,c),l=this.iterator("table",(function(A,t){var e=[];for(i=0,o=g[t].length;i<o;i++)for(s=0,a=B[t].length;s<a;s++)e.push({row:g[t][i],column:B[t][s]});return e}),1),u=r&&r.selected?this.cells(l,r):l;return A.extend(u.selector,{cols:e,rows:t,opts:r}),u})),s("cells().nodes()","cell().node()",(function(){return this.iterator("cell",(function(A,t,e){var r=A.aoData[t];return r&&r.anCells?r.anCells[e]:n}),1)})),o("cells().data()",(function(){return this.iterator("cell",(function(A,t,e){return K(A,t,e)}),1)})),s("cells().cache()","cell().cache()",(function(A){return A="search"===A?"_aFilterData":"_aSortData",this.iterator("cell",(function(t,e,n){return t.aoData[e][A][n]}),1)})),s("cells().render()","cell().render()",(function(A){return this.iterator("cell",(function(t,e,n){return K(t,e,n,A)}),1)})),s("cells().indexes()","cell().index()",(function(){return this.iterator("cell",(function(A,t,e){return{row:t,column:e,columnVisible:H(A,e)}}),1)})),s("cells().invalidate()","cell().invalidate()",(function(A){return this.iterator("cell",(function(t,e,n){nA(t,e,A,n)}))})),o("cell()",(function(A,t,e){return Dt(this.cells(A,t,e))})),o("cell().data()",(function(A){var t=this.context,e=this[0];return A===n?t.length&&e.length?K(t[0],e[0].row,e[0].column):n:(V(t[0],e[0].row,e[0].column,A),nA(t[0],e[0].row,"data",e[0].column),this)})),o("order()",(function(A,t){var e=this.context;return A===n?0!==e.length?e[0].aaSorting:n:("number"==typeof A?A=[[A,t]]:A.length&&!Array.isArray(A[0])&&(A=Array.prototype.slice.call(arguments)),this.iterator("table",(function(t){t.aaSorting=A.slice()})))})),o("order.listener()",(function(A,t,e){return this.iterator("table",(function(n){et(n,A,t,e)}))})),o("order.fixed()",(function(t){if(!t){var e=this.context,r=e.length?e[0].aaSortingFixed:n;return Array.isArray(r)?{pre:r}:r}return this.iterator("table",(function(e){e.aaSortingFixed=A.extend(!0,{},t)}))})),o(["columns().order()","column().order()"],(function(t){var e=this;return this.iterator("table",(function(n,r){var i=[];A.each(e[r],(function(A,e){i.push([e,t])})),n.aaSorting=i}))})),o("search()",(function(t,e,r,i){var o=this.context;return t===n?0!==o.length?o[0].oPreviousSearch.sSearch:n:this.iterator("table",(function(n){n.oFeatures.bFilter&&CA(n,A.extend({},n.oPreviousSearch,{sSearch:t+"",bRegex:null!==e&&e,bSmart:null===r||r,bCaseInsensitive:null===i||i}),1)}))})),s("columns().search()","column().search()",(function(t,e,r,i){return this.iterator("column",(function(o,s){var a=o.aoPreSearchCols;if(t===n)return a[s].sSearch;o.oFeatures.bFilter&&(A.extend(a[s],{sSearch:t+"",bRegex:null!==e&&e,bSmart:null===r||r,bCaseInsensitive:null===i||i}),CA(o,o.oPreviousSearch,1))}))})),o("state()",(function(){return this.context.length?this.context[0].oSavedState:null})),o("state.clear()",(function(){return this.iterator("table",(function(A){A.fnStateSaveCallback.call(A.oInstance,A,{})}))})),o("state.loaded()",(function(){return this.context.length?this.context[0].oLoadedState:null})),o("state.save()",(function(){return this.iterator("table",(function(A){it(A)}))})),a.use=function(n,r){"lib"===r||n.fn?A=n:"win"==r||n.document?(t=n,e=n.document):"datetime"!==r&&"DateTime"!==n.type||(a.DateTime=n)},a.factory=function(n,r){var i=!1;return n&&n.document&&(t=n,e=n.document),r&&r.fn&&r.fn.jquery&&(A=r,i=!0),i},a.versionCheck=a.fnVersionCheck=function(A){for(var t,e,n=a.version.split("."),r=A.split("."),i=0,o=r.length;i<o;i++)if((t=parseInt(n[i],10)||0)!==(e=parseInt(r[i],10)||0))return t>e;return!0},a.isDataTable=a.fnIsDataTable=function(t){var e=A(t).get(0),n=!1;return t instanceof a.Api||(A.each(a.settings,(function(t,r){var i=r.nScrollHead?A("table",r.nScrollHead)[0]:null,o=r.nScrollFoot?A("table",r.nScrollFoot)[0]:null;r.nTable!==e&&i!==e&&o!==e||(n=!0)})),n)},a.tables=a.fnTables=function(t){var e=!1;A.isPlainObject(t)&&(e=t.api,t=t.visible);var n=A.map(a.settings,(function(e){if(!t||t&&A(e.nTable).is(":visible"))return e.nTable}));return e?new i(n):n},a.camelToHungarian=Y,o("$()",(function(t,e){var n=this.rows(e).nodes(),r=A(n);return A([].concat(r.filter(t).toArray(),r.find(t).toArray()))})),A.each(["on","one","off"],(function(t,e){o(e+"()",(function(){var t=Array.prototype.slice.call(arguments);t[0]=A.map(t[0].split(/\s/),(function(A){return A.match(/\.dt\b/)?A:A+".dt"})).join(" ");var n=A(this.tables().nodes());return n[e].apply(n,t),this}))})),o("clear()",(function(){return this.iterator("table",(function(A){tA(A)}))})),o("settings()",(function(){return new i(this.context,this.context)})),o("init()",(function(){var A=this.context;return A.length?A[0].oInit:null})),o("data()",(function(){return this.iterator("table",(function(A){return C(A.aoData,"_aData")})).flatten()})),o("destroy()",(function(e){return e=e||!1,this.iterator("table",(function(n){var r,o=n.oClasses,s=n.nTable,c=n.nTBody,B=n.nTHead,g=n.nTFoot,l=A(s),u=A(c),w=A(n.nTableWrapper),h=A.map(n.aoData,(function(A){return A.nTr}));n.bDestroying=!0,wt(n,"aoDestroyCallback","destroy",[n]),e||new i(n).columns().visible(!0),w.off(".DT").find(":not(tbody *)").off(".DT"),A(t).off(".DT-"+n.sInstance),s!=B.parentNode&&(l.children("thead").detach(),l.append(B)),g&&s!=g.parentNode&&(l.children("tfoot").detach(),l.append(g)),n.aaSorting=[],n.aaSortingFixed=[],nt(n),A(h).removeClass(n.asStripeClasses.join(" ")),A("th, td",B).removeClass(o.sSortable+" "+o.sSortableAsc+" "+o.sSortableDesc+" "+o.sSortableNone),u.children().detach(),u.append(h);var E=n.nTableWrapper.parentNode,f=e?"remove":"detach";l[f](),w[f](),!e&&E&&(E.insertBefore(s,n.nTableReinsertBefore),l.css("width",n.sDestroyWidth).removeClass(o.sTable),(r=n.asDestroyStripes.length)&&u.children().each((function(t){A(this).addClass(n.asDestroyStripes[t%r])})));var Q=A.inArray(n,a.settings);-1!==Q&&a.settings.splice(Q,1)}))})),A.each(["column","row","cell"],(function(A,t){o(t+"s().every()",(function(A){var e=this.selector.opts,r=this;return this.iterator(t,(function(i,o,s,a,c){A.call(r[t](o,"cell"===t?s:e,"cell"===t?e:n),o,s,a,c)}))}))})),o("i18n()",(function(t,e,r){var i=this.context[0],o=q(t)(i.oLanguage);return o===n&&(o=e),r!==n&&A.isPlainObject(o)&&(o=o[r]!==n?o[r]:o._),"string"==typeof o?o.replace("%d",r):o})),a.version="1.13.7",a.settings=[],a.models={},a.models.oSearch={bCaseInsensitive:!0,sSearch:"",bRegex:!1,bSmart:!0,return:!1},a.models.oRow={nTr:null,anCells:null,_aData:[],_aSortData:null,_aFilterData:null,_sFilterRow:null,_sRowStripe:"",src:null,idx:-1},a.models.oColumn={idx:null,aDataSort:null,asSorting:null,bSearchable:null,bSortable:null,bVisible:null,_sManualType:null,_bAttrSrc:!1,fnCreatedCell:null,fnGetData:null,fnSetData:null,mData:null,mRender:null,nTh:null,nTf:null,sClass:null,sContentPadding:null,sDefaultContent:null,sName:null,sSortDataType:"std",sSortingClass:null,sSortingClassJUI:null,sTitle:null,sType:null,sWidth:null,sWidthOrig:null},a.defaults={aaData:null,aaSorting:[[0,"asc"]],aaSortingFixed:[],ajax:null,aLengthMenu:[10,25,50,100],aoColumns:null,aoColumnDefs:null,aoSearchCols:[],asStripeClasses:null,bAutoWidth:!0,bDeferRender:!1,bDestroy:!1,bFilter:!0,bInfo:!0,bLengthChange:!0,bPaginate:!0,bProcessing:!1,bRetrieve:!1,bScrollCollapse:!1,bServerSide:!1,bSort:!0,bSortMulti:!0,bSortCellsTop:!1,bSortClasses:!0,bStateSave:!1,fnCreatedRow:null,fnDrawCallback:null,fnFooterCallback:null,fnFormatNumber:function(A){return A.toString().replace(/\B(?=(\d{3})+(?!\d))/g,this.oLanguage.sThousands)},fnHeaderCallback:null,fnInfoCallback:null,fnInitComplete:null,fnPreDrawCallback:null,fnRowCallback:null,fnServerData:null,fnServerParams:null,fnStateLoadCallback:function(A){try{return JSON.parse((-1===A.iStateDuration?sessionStorage:localStorage).getItem("DataTables_"+A.sInstance+"_"+location.pathname))}catch(A){return{}}},fnStateLoadParams:null,fnStateLoaded:null,fnStateSaveCallback:function(A,t){try{(-1===A.iStateDuration?sessionStorage:localStorage).setItem("DataTables_"+A.sInstance+"_"+location.pathname,JSON.stringify(t))}catch(A){}},fnStateSaveParams:null,iStateDuration:7200,iDeferLoading:null,iDisplayLength:10,iDisplayStart:0,iTabIndex:0,oClasses:{},oLanguage:{oAria:{sSortAscending:": activate to sort column ascending",sSortDescending:": activate to sort column descending"},oPaginate:{sFirst:"First",sLast:"Last",sNext:"Next",sPrevious:"Previous"},sEmptyTable:"No data available in table",sInfo:"Showing _START_ to _END_ of _TOTAL_ entries",sInfoEmpty:"Showing 0 to 0 of 0 entries",sInfoFiltered:"(filtered from _MAX_ total entries)",sInfoPostFix:"",sDecimal:"",sThousands:",",sLengthMenu:"Show _MENU_ entries",sLoadingRecords:"Loading...",sProcessing:"",sSearch:"Search:",sSearchPlaceholder:"",sUrl:"",sZeroRecords:"No matching records found"},oSearch:A.extend({},a.models.oSearch),sAjaxDataProp:"data",sAjaxSource:null,sDom:"lfrtip",searchDelay:null,sPaginationType:"simple_numbers",sScrollX:"",sScrollXInner:"",sScrollY:"",sServerMethod:"GET",renderer:null,rowId:"DT_RowId"},F(a.defaults),a.defaults.column={aDataSort:null,iDataSort:-1,asSorting:["asc","desc"],bSearchable:!0,bSortable:!0,bVisible:!0,fnCreatedCell:null,mData:null,mRender:null,sCellType:"td",sClass:"",sContentPadding:"",sDefaultContent:null,sName:"",sSortDataType:"std",sTitle:null,sType:null,sWidth:null},F(a.defaults.column),a.models.oSettings={oFeatures:{bAutoWidth:null,bDeferRender:null,bFilter:null,bInfo:null,bLengthChange:null,bPaginate:null,bProcessing:null,bServerSide:null,bSort:null,bSortMulti:null,bSortClasses:null,bStateSave:null},oScroll:{bCollapse:null,iBarWidth:0,sX:null,sXInner:null,sY:null},oLanguage:{fnInfoCallback:null},oBrowser:{bScrollOversize:!1,bScrollbarLeft:!1,bBounding:!1,barWidth:0},ajax:null,aanFeatures:[],aoData:[],aiDisplay:[],aiDisplayMaster:[],aIds:{},aoColumns:[],aoHeader:[],aoFooter:[],oPreviousSearch:{},aoPreSearchCols:[],aaSorting:null,aaSortingFixed:[],asStripeClasses:null,asDestroyStripes:[],sDestroyWidth:0,aoRowCallback:[],aoHeaderCallback:[],aoFooterCallback:[],aoDrawCallback:[],aoRowCreatedCallback:[],aoPreDrawCallback:[],aoInitComplete:[],aoStateSaveParams:[],aoStateLoadParams:[],aoStateLoaded:[],sTableId:"",nTable:null,nTHead:null,nTFoot:null,nTBody:null,nTableWrapper:null,bDeferLoading:!1,bInitialised:!1,aoOpenRows:[],sDom:null,searchDelay:null,sPaginationType:"two_button",iStateDuration:0,aoStateSave:[],aoStateLoad:[],oSavedState:null,oLoadedState:null,sAjaxSource:null,sAjaxDataProp:null,jqXHR:null,json:n,oAjaxData:n,fnServerData:null,aoServerParams:[],sServerMethod:null,fnFormatNumber:null,aLengthMenu:null,iDraw:0,bDrawing:!1,iDrawError:-1,_iDisplayLength:10,_iDisplayStart:0,_iRecordsTotal:0,_iRecordsDisplay:0,oClasses:{},bFiltered:!1,bSorted:!1,bSortCellsTop:null,oInit:null,aoDestroyCallback:[],fnRecordsTotal:function(){return"ssp"==ft(this)?1*this._iRecordsTotal:this.aiDisplayMaster.length},fnRecordsDisplay:function(){return"ssp"==ft(this)?1*this._iRecordsDisplay:this.aiDisplay.length},fnDisplayEnd:function(){var A=this._iDisplayLength,t=this._iDisplayStart,e=t+A,n=this.aiDisplay.length,r=this.oFeatures,i=r.bPaginate;return r.bServerSide?!1===i||-1===A?t+n:Math.min(t+A,this._iRecordsDisplay):!i||e>n||-1===A?n:e},oInstance:null,sInstance:null,iTabIndex:0,nScrollHead:null,nScrollFoot:null,aLastSort:[],oPlugins:{},rowIdFn:null,rowId:null},a.ext=r={buttons:{},classes:{},builder:"-source-",errMode:"alert",feature:[],search:[],selector:{cell:[],column:[],row:[]},internal:{},legacy:{ajax:null},pager:{},renderer:{pageButton:{},header:{}},order:{},type:{detect:[],search:{},order:{}},_unique:0,fnVersionCheck:a.fnVersionCheck,iApiIndex:0,oJUIClasses:{},sVersion:a.version},A.extend(r,{afnFiltering:r.search,aTypes:r.type.detect,ofnSearch:r.type.search,oSort:r.type.order,afnSortData:r.order,aoFeatures:r.feature,oApi:r.internal,oStdClasses:r.classes,oPagination:r.pager}),A.extend(a.ext.classes,{sTable:"dataTable",sNoFooter:"no-footer",sPageButton:"paginate_button",sPageButtonActive:"current",sPageButtonDisabled:"disabled",sStripeOdd:"odd",sStripeEven:"even",sRowEmpty:"dataTables_empty",sWrapper:"dataTables_wrapper",sFilter:"dataTables_filter",sInfo:"dataTables_info",sPaging:"dataTables_paginate paging_",sLength:"dataTables_length",sProcessing:"dataTables_processing",sSortAsc:"sorting_asc",sSortDesc:"sorting_desc",sSortable:"sorting",sSortableAsc:"sorting_desc_disabled",sSortableDesc:"sorting_asc_disabled",sSortableNone:"sorting_disabled",sSortColumn:"sorting_",sFilterInput:"",sLengthSelect:"",sScrollWrapper:"dataTables_scroll",sScrollHead:"dataTables_scrollHead",sScrollHeadInner:"dataTables_scrollHeadInner",sScrollBody:"dataTables_scrollBody",sScrollFoot:"dataTables_scrollFoot",sScrollFootInner:"dataTables_scrollFootInner",sHeaderTH:"",sFooterTH:"",sSortJUIAsc:"",sSortJUIDesc:"",sSortJUI:"",sSortJUIAscAllowed:"",sSortJUIDescAllowed:"",sSortJUIWrapper:"",sSortIcon:"",sJUIHeader:"",sJUIFooter:""});var xt=a.ext.pager;function Tt(A,t){var e=[],n=xt.numbers_length,r=Math.floor(n/2);return t<=n?e=I(0,t):A<=r?((e=I(0,n-2)).push("ellipsis"),e.push(t-1)):A>=t-1-r?((e=I(t-(n-2),t)).splice(0,0,"ellipsis"),e.splice(0,0,0)):((e=I(A-r+2,A+r-1)).push("ellipsis"),e.push(t-1),e.splice(0,0,"ellipsis"),e.splice(0,0,0)),e.DT_el="span",e}A.extend(xt,{simple:function(A,t){return["previous","next"]},full:function(A,t){return["first","previous","next","last"]},numbers:function(A,t){return[Tt(A,t)]},simple_numbers:function(A,t){return["previous",Tt(A,t),"next"]},full_numbers:function(A,t){return["first","previous",Tt(A,t),"next","last"]},first_last_numbers:function(A,t){return["first",Tt(A,t),"last"]},_numbers:Tt,numbers_length:7}),A.extend(!0,a.ext.renderer,{pageButton:{_:function(t,r,i,o,s,a){var c,B,g,l=t.oClasses,u=t.oLanguage.oPaginate,w=t.oLanguage.oAria.paginate||{},h=function(e,n){var r,o,g,E=l.sPageButtonDisabled,f=function(A){GA(t,A.data.action,!0)};for(r=0,o=n.length;r<o;r++)if(g=n[r],Array.isArray(g)){var Q=A("<"+(g.DT_el||"div")+"/>").appendTo(e);h(Q,g)}else{var d=!1;switch(c=null,B=g,g){case"ellipsis":e.append('<span class="ellipsis">&#x2026;</span>');break;case"first":c=u.sFirst,0===s&&(d=!0);break;case"previous":c=u.sPrevious,0===s&&(d=!0);break;case"next":c=u.sNext,0!==a&&s!==a-1||(d=!0);break;case"last":c=u.sLast,0!==a&&s!==a-1||(d=!0);break;default:c=t.fnFormatNumber(g+1),B=s===g?l.sPageButtonActive:""}if(null!==c){var C=t.oInit.pagingTag||"a";d&&(B+=" "+E),lt(A("<"+C+">",{class:l.sPageButton+" "+B,"aria-controls":t.sTableId,"aria-disabled":d?"true":null,"aria-label":w[g],role:"link","aria-current":B===l.sPageButtonActive?"page":null,"data-dt-idx":g,tabindex:d?-1:t.iTabIndex,id:0===i&&"string"==typeof g?t.sTableId+"_"+g:null}).html(c).appendTo(e),{action:g},f)}}};try{g=A(r).find(e.activeElement).data("dt-idx")}catch(A){}h(A(r).empty(),o),g!==n&&A(r).find("[data-dt-idx="+g+"]").trigger("focus")}}}),A.extend(a.ext.type.detect,[function(A,t){var e=t.oLanguage.sDecimal;return Q(A,e)?"num"+e:null},function(A,t){if(A&&!(A instanceof Date)&&!l.test(A))return null;var e=Date.parse(A);return null!==e&&!isNaN(e)||h(A)?"date":null},function(A,t){var e=t.oLanguage.sDecimal;return Q(A,e,!0)?"num-fmt"+e:null},function(A,t){var e=t.oLanguage.sDecimal;return d(A,e)?"html-num"+e:null},function(A,t){var e=t.oLanguage.sDecimal;return d(A,e,!0)?"html-num-fmt"+e:null},function(A,t){return h(A)||"string"==typeof A&&-1!==A.indexOf("<")?"html":null}]),A.extend(a.ext.type.search,{html:function(A){return h(A)?A:"string"==typeof A?A.replace(B," ").replace(g,""):""},string:function(A){return h(A)?A:"string"==typeof A?A.replace(B," "):A}});var Pt=function(A,t,e,n){if(0!==A&&(!A||"-"===A))return-1/0;var r=typeof A;return"number"===r||"bigint"===r?A:(t&&(A=f(A,t)),A.replace&&(e&&(A=A.replace(e,"")),n&&(A=A.replace(n,""))),1*A)};function Nt(t){A.each({num:function(A){return Pt(A,t)},"num-fmt":function(A){return Pt(A,t,w)},"html-num":function(A){return Pt(A,t,g)},"html-num-fmt":function(A){return Pt(A,t,g,w)}},(function(A,e){r.type.order[A+t+"-pre"]=e,A.match(/^html\-/)&&(r.type.search[A+t]=r.type.search.html)}))}A.extend(r.type.order,{"date-pre":function(A){var t=Date.parse(A);return isNaN(t)?-1/0:t},"html-pre":function(A){return h(A)?"":A.replace?A.replace(/<.*?>/g,"").toLowerCase():A+""},"string-pre":function(A){return h(A)?"":"string"==typeof A?A.toLowerCase():A.toString?A.toString():""},"string-asc":function(A,t){return A<t?-1:A>t?1:0},"string-desc":function(A,t){return A<t?1:A>t?-1:0}}),Nt(""),A.extend(!0,a.ext.renderer,{header:{_:function(t,e,n,r){A(t.nTable).on("order.dt.DT",(function(A,i,o,s){if(t===i){var a=n.idx;e.removeClass(r.sSortAsc+" "+r.sSortDesc).addClass("asc"==s[a]?r.sSortAsc:"desc"==s[a]?r.sSortDesc:n.sSortingClass)}}))},jqueryui:function(t,e,n,r){A("<div/>").addClass(r.sSortJUIWrapper).append(e.contents()).append(A("<span/>").addClass(r.sSortIcon+" "+n.sSortingClassJUI)).appendTo(e),A(t.nTable).on("order.dt.DT",(function(A,i,o,s){if(t===i){var a=n.idx;e.removeClass(r.sSortAsc+" "+r.sSortDesc).addClass("asc"==s[a]?r.sSortAsc:"desc"==s[a]?r.sSortDesc:n.sSortingClass),e.find("span."+r.sSortIcon).removeClass(r.sSortJUIAsc+" "+r.sSortJUIDesc+" "+r.sSortJUI+" "+r.sSortJUIAscAllowed+" "+r.sSortJUIDescAllowed).addClass("asc"==s[a]?r.sSortJUIAsc:"desc"==s[a]?r.sSortJUIDesc:n.sSortingClassJUI)}}))}}});var Rt=function(A){return Array.isArray(A)&&(A=A.join(",")),"string"==typeof A?A.replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;").replace(/"/g,"&quot;"):A};function Gt(A,e,n,r,i){return t.moment?A[e](i):t.luxon?A[n](i):r?A[r](i):A}var Ht=!1;function kt(A,e,n){var r;if(t.moment){if(!(r=t.moment.utc(A,e,n,!0)).isValid())return null}else if(t.luxon){if(!(r=e&&"string"==typeof A?t.luxon.DateTime.fromFormat(A,e):t.luxon.DateTime.fromISO(A)).isValid)return null;r.setLocale(n)}else e?(Ht||alert("DataTables warning: Formatted date without Moment.js or Luxon - https://datatables.net/tn/17"),Ht=!0):r=new Date(A);return r}function Lt(A){return function(t,e,r,i){0===arguments.length?(r="en",e=null,t=null):1===arguments.length?(r="en",e=t,t=null):2===arguments.length&&(r=e,e=t,t=null);var o="datetime-"+e;return a.ext.type.order[o]||(a.ext.type.detect.unshift((function(A){return A===o&&o})),a.ext.type.order[o+"-asc"]=function(A,t){var e=A.valueOf(),n=t.valueOf();return e===n?0:e<n?-1:1},a.ext.type.order[o+"-desc"]=function(A,t){var e=A.valueOf(),n=t.valueOf();return e===n?0:e>n?-1:1}),function(s,a){if(null===s||s===n)if("--now"===i){var c=new Date;s=new Date(Date.UTC(c.getFullYear(),c.getMonth(),c.getDate(),c.getHours(),c.getMinutes(),c.getSeconds()))}else s="";if("type"===a)return o;if(""===s)return"sort"!==a?"":kt("0000-01-01 00:00:00",null,r);if(null!==e&&t===e&&"sort"!==a&&"type"!==a&&!(s instanceof Date))return s;var B=kt(s,t,r);if(null===B)return s;if("sort"===a)return B;var g=null===e?Gt(B,"toDate","toJSDate","")[A]():Gt(B,"format","toFormat","toISOString",e);return"display"===a?Rt(g):g}}}var Jt=",",jt=".";if(t.Intl!==n)try{for(var Ot=(new Intl.NumberFormat).formatToParts(100000.1),Wt=0;Wt<Ot.length;Wt++)"group"===Ot[Wt].type?Jt=Ot[Wt].value:"decimal"===Ot[Wt].type&&(jt=Ot[Wt].value)}catch(A){}function Kt(A){return function(){var t=[at(this[a.ext.iApiIndex])].concat(Array.prototype.slice.call(arguments));return a.ext.internal[A].apply(this,t)}}return a.datetime=function(A,t){var e="datetime-detect-"+A;t||(t="en"),a.ext.type.order[e]||(a.ext.type.detect.unshift((function(n){var r=kt(n,A,t);return!(""!==n&&!r)&&e})),a.ext.type.order[e+"-pre"]=function(e){return kt(e,A,t)||0})},a.render={date:Lt("toLocaleDateString"),datetime:Lt("toLocaleString"),time:Lt("toLocaleTimeString"),number:function(A,t,e,r,i){return null!==A&&A!==n||(A=Jt),null!==t&&t!==n||(t=jt),{display:function(n){if("number"!=typeof n&&"string"!=typeof n)return n;if(""===n||null===n)return n;var o=n<0?"-":"",s=parseFloat(n);if(isNaN(s))return Rt(n);s=s.toFixed(e),n=Math.abs(s);var a=parseInt(n,10),c=e?t+(n-a).toFixed(e).substring(2):"";return 0===a&&0===parseFloat(c)&&(o=""),o+(r||"")+a.toString().replace(/\B(?=(\d{3})+(?!\d))/g,A)+c+(i||"")}}},text:function(){return{display:Rt,filter:Rt}}},A.extend(a.ext.internal,{_fnExternApiFunc:Kt,_fnBuildAjax:wA,_fnAjaxUpdate:hA,_fnAjaxParameters:EA,_fnAjaxUpdateDraw:fA,_fnAjaxDataSrc:QA,_fnAddColumn:P,_fnColumnOptions:N,_fnAdjustColumnSizing:R,_fnVisibleToColumnIndex:G,_fnColumnIndexToVisible:H,_fnVisbleColumns:k,_fnGetColumns:L,_fnColumnTypes:J,_fnApplyColumnDefs:j,_fnHungarianMap:F,_fnCamelToHungarian:Y,_fnLanguageCompat:b,_fnBrowserDetect:x,_fnAddData:O,_fnAddTr:W,_fnNodeToDataIndex:function(A,t){return t._DT_RowIndex!==n?t._DT_RowIndex:null},_fnNodeToColumnIndex:function(t,e,n){return A.inArray(n,t.aoData[e].anCells)},_fnGetCellData:K,_fnSetCellData:V,_fnSplitObjNotation:_,_fnGetObjectDataFn:q,_fnSetObjectDataFn:$,_fnGetDataMaster:AA,_fnClearTable:tA,_fnDeleteIndex:eA,_fnInvalidate:nA,_fnGetRowElements:rA,_fnCreateTr:iA,_fnBuildHead:sA,_fnDrawHead:aA,_fnDraw:cA,_fnReDraw:BA,_fnAddOptionsHtml:gA,_fnDetectHeader:lA,_fnGetUniqueThs:uA,_fnFeatureHtmlFilter:dA,_fnFilterComplete:CA,_fnFilterCustom:MA,_fnFilterColumn:IA,_fnFilter:pA,_fnFilterCreateSearch:DA,_fnEscapeRegex:yA,_fnFilterData:FA,_fnFeatureHtmlInfo:zA,_fnUpdateInfo:UA,_fnInfoMacros:SA,_fnInitialise:xA,_fnInitComplete:TA,_fnLengthChange:PA,_fnFeatureHtmlLength:NA,_fnFeatureHtmlPaginate:RA,_fnPageChange:GA,_fnFeatureHtmlProcessing:HA,_fnProcessingDisplay:kA,_fnFeatureHtmlTable:LA,_fnScrollDraw:JA,_fnApplyToChildren:jA,_fnCalculateColumnWidths:WA,_fnThrottle:KA,_fnConvertToWidth:VA,_fnGetWidestNode:XA,_fnGetMaxLenString:ZA,_fnStringToCss:_A,_fnSortFlatten:qA,_fnSort:$A,_fnSortAria:At,_fnSortListener:tt,_fnSortAttachListener:et,_fnSortingClasses:nt,_fnSortData:rt,_fnSaveState:it,_fnLoadState:ot,_fnImplementState:st,_fnSettingsFromNode:at,_fnLog:ct,_fnMap:Bt,_fnBindAction:lt,_fnCallbackReg:ut,_fnCallbackFire:wt,_fnLengthOverflow:ht,_fnRenderer:Et,_fnDataSource:ft,_fnRowAttributes:oA,_fnExtend:gt,_fnCalculateEnd:function(){}}),A.fn.dataTable=a,a.$=A,A.fn.dataTableSettings=a.settings,A.fn.dataTableExt=a.ext,A.fn.DataTable=function(t){return A(this).dataTable(t).api()},A.each(a,(function(t,e){A.fn.DataTable[t]=e})),a})),
/*! DataTables Bootstrap 5 integration
 * 2020 SpryMedia Ltd - datatables.net/license
 */
function(A){if("function"==typeof define&&define.amd)define(["jquery","datatables.net"],(function(t){return A(t,window,document)}));else if("object"==typeof exports){var t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net")(A,t)};"undefined"==typeof window?module.exports=function(n,r){return n||(n=window),r||(r=t(n)),e(n,r),A(r,n,n.document)}:(e(window,t),module.exports=A(t,window,window.document))}else A(jQuery,window,document)}((function(A,t,e,n){"use strict";var r=A.fn.dataTable;return A.extend(!0,r.defaults,{dom:"<'row'<'col-sm-12 col-md-6'l><'col-sm-12 col-md-6'f>><'row dt-row'<'col-sm-12'tr>><'row'<'col-sm-12 col-md-5'i><'col-sm-12 col-md-7'p>>",renderer:"bootstrap"}),A.extend(r.ext.classes,{sWrapper:"dataTables_wrapper dt-bootstrap5",sFilterInput:"form-control form-control-sm",sLengthSelect:"form-select form-select-sm",sProcessing:"dataTables_processing card",sPageButton:"paginate_button page-item"}),r.ext.renderer.pageButton.bootstrap=function(t,i,o,s,a,c){var B,g,l,u=new r.Api(t),w=t.oClasses,h=t.oLanguage.oPaginate,E=t.oLanguage.oAria.paginate||{},f=function(e,n){var r,i,s,l,Q=function(t){t.preventDefault(),A(t.currentTarget).hasClass("disabled")||u.page()==t.data.action||u.page(t.data.action).draw("page")};for(r=0,i=n.length;r<i;r++)if(l=n[r],Array.isArray(l))f(e,l);else{switch(B="",g="",l){case"ellipsis":B="&#x2026;",g="disabled";break;case"first":B=h.sFirst,g=l+(a>0?"":" disabled");break;case"previous":B=h.sPrevious,g=l+(a>0?"":" disabled");break;case"next":B=h.sNext,g=l+(a<c-1?"":" disabled");break;case"last":B=h.sLast,g=l+(a<c-1?"":" disabled");break;default:B=l+1,g=a===l?"active":""}if(B){var d=-1!==g.indexOf("disabled");s=A("<li>",{class:w.sPageButton+" "+g,id:0===o&&"string"==typeof l?t.sTableId+"_"+l:null}).append(A("<a>",{href:d?null:"#","aria-controls":t.sTableId,"aria-disabled":d?"true":null,"aria-label":E[l],role:"link","aria-current":"active"===g?"page":null,"data-dt-idx":l,tabindex:d?-1:t.iTabIndex,class:"page-link"}).html(B)).appendTo(e),t.oApi._fnBindAction(s,{action:l},Q)}}},Q=A(i);try{l=Q.find(e.activeElement).data("dt-idx")}catch(A){}var d=Q.children("ul.pagination");d.length?d.empty():d=Q.html("<ul/>").children("ul").addClass("pagination"),f(d,s),l!==n&&Q.find("[data-dt-idx="+l+"]").trigger("focus")},r}));var defaults={language:{info:"Showing _START_ to _END_ of _TOTAL_ records",infoEmpty:"Showing no records",lengthMenu:"_MENU_",processing:'<span class="spinner-border w-15px h-15px text-muted align-middle me-2"></span> <span class="text-gray-600">Loading...</span>',paginate:{first:'<i class="first"></i>',last:'<i class="last"></i>',next:'<i class="next"></i>',previous:'<i class="previous"></i>'}}};$.extend(!0,$.fn.dataTable.defaults,defaults),
/*! DataTables Bootstrap 4 integration
 * ©2011-2017 SpryMedia Ltd - datatables.net/license
 */
function(A){"function"==typeof define&&define.amd?define(["jquery","datatables.net"],(function(t){return A(t,window,document)})):"object"==typeof exports?module.exports=function(t,e){return t||(t=window),e&&e.fn.dataTable||(e=require("datatables.net")(t,e).$),A(e,t,t.document)}:A(jQuery,window,document)}((function(A,t,e,n){"use strict";var r=A.fn.dataTable;return A.extend(!0,r.defaults,{dom:"<'table-responsive'tr><'row'<'col-sm-12 col-md-5 d-flex align-items-center justify-content-center justify-content-md-start'li><'col-sm-12 col-md-7 d-flex align-items-center justify-content-center justify-content-md-end'p>>",renderer:"bootstrap"}),A.extend(r.ext.classes,{sWrapper:"dataTables_wrapper dt-bootstrap4",sFilterInput:"form-control form-control-sm form-control-solid",sLengthSelect:"form-select form-select-sm form-select-solid",sProcessing:"dataTables_processing",sPageButton:"paginate_button page-item"}),r.ext.renderer.pageButton.bootstrap=function(t,i,o,s,a,c){var B,g,l,u=new r.Api(t),w=t.oClasses,h=t.oLanguage.oPaginate,E=t.oLanguage.oAria.paginate||{},f=0,Q=function(e,n){var r,i,s,l,d=function(t){t.preventDefault(),A(t.currentTarget).hasClass("disabled")||u.page()==t.data.action||u.page(t.data.action).draw("page")};for(r=0,i=n.length;r<i;r++)if(l=n[r],Array.isArray(l))Q(e,l);else{switch(B="",g="",l){case"ellipsis":B="&#x2026;",g="disabled";break;case"first":B=h.sFirst,g=l+(a>0?"":" disabled");break;case"previous":B=h.sPrevious,g=l+(a>0?"":" disabled");break;case"next":B=h.sNext,g=l+(a<c-1?"":" disabled");break;case"last":B=h.sLast,g=l+(a<c-1?"":" disabled");break;default:B=l+1,g=a===l?"active":""}B&&(s=A("<li>",{class:w.sPageButton+" "+g,id:0===o&&"string"==typeof l?t.sTableId+"_"+l:null}).append(A("<a>",{href:"#","aria-controls":t.sTableId,"aria-label":E[l],"data-dt-idx":f,tabindex:t.iTabIndex,class:"page-link"}).html(B)).appendTo(e),t.oApi._fnBindAction(s,{action:l},d),f++)}};try{l=A(i).find(e.activeElement).data("dt-idx")}catch(A){}Q(A(i).empty().html('<ul class="pagination"/>').children("ul"),s),l!==n&&A(i).find("[data-dt-idx="+l+"]").trigger("focus")},r})),function(A){"object"==typeof exports&&"undefined"!=typeof module?module.exports=A():"function"==typeof define&&define.amd?define([],A):("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:this).JSZip=A()}((function(){return function A(t,e,n){function r(o,s){if(!e[o]){if(!t[o]){var a="function"==typeof require&&require;if(!s&&a)return a(o,!0);if(i)return i(o,!0);var c=new Error("Cannot find module '"+o+"'");throw c.code="MODULE_NOT_FOUND",c}var B=e[o]={exports:{}};t[o][0].call(B.exports,(function(A){return r(t[o][1][A]||A)}),B,B.exports,A,t,e,n)}return e[o].exports}for(var i="function"==typeof require&&require,o=0;o<n.length;o++)r(n[o]);return r}({1:[function(A,t,e){"use strict";var n=A("./utils"),r=A("./support"),i="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";e.encode=function(A){for(var t,e,r,o,s,a,c,B=[],g=0,l=A.length,u=l,w="string"!==n.getTypeOf(A);g<A.length;)u=l-g,r=w?(t=A[g++],e=g<l?A[g++]:0,g<l?A[g++]:0):(t=A.charCodeAt(g++),e=g<l?A.charCodeAt(g++):0,g<l?A.charCodeAt(g++):0),o=t>>2,s=(3&t)<<4|e>>4,a=1<u?(15&e)<<2|r>>6:64,c=2<u?63&r:64,B.push(i.charAt(o)+i.charAt(s)+i.charAt(a)+i.charAt(c));return B.join("")},e.decode=function(A){var t,e,n,o,s,a,c=0,B=0,g="data:";if(A.substr(0,5)===g)throw new Error("Invalid base64 input, it looks like a data url.");var l,u=3*(A=A.replace(/[^A-Za-z0-9+/=]/g,"")).length/4;if(A.charAt(A.length-1)===i.charAt(64)&&u--,A.charAt(A.length-2)===i.charAt(64)&&u--,u%1!=0)throw new Error("Invalid base64 input, bad content length.");for(l=r.uint8array?new Uint8Array(0|u):new Array(0|u);c<A.length;)t=i.indexOf(A.charAt(c++))<<2|(o=i.indexOf(A.charAt(c++)))>>4,e=(15&o)<<4|(s=i.indexOf(A.charAt(c++)))>>2,n=(3&s)<<6|(a=i.indexOf(A.charAt(c++))),l[B++]=t,64!==s&&(l[B++]=e),64!==a&&(l[B++]=n);return l}},{"./support":30,"./utils":32}],2:[function(A,t,e){"use strict";var n=A("./external"),r=A("./stream/DataWorker"),i=A("./stream/Crc32Probe"),o=A("./stream/DataLengthProbe");function s(A,t,e,n,r){this.compressedSize=A,this.uncompressedSize=t,this.crc32=e,this.compression=n,this.compressedContent=r}s.prototype={getContentWorker:function(){var A=new r(n.Promise.resolve(this.compressedContent)).pipe(this.compression.uncompressWorker()).pipe(new o("data_length")),t=this;return A.on("end",(function(){if(this.streamInfo.data_length!==t.uncompressedSize)throw new Error("Bug : uncompressed data size mismatch")})),A},getCompressedWorker:function(){return new r(n.Promise.resolve(this.compressedContent)).withStreamInfo("compressedSize",this.compressedSize).withStreamInfo("uncompressedSize",this.uncompressedSize).withStreamInfo("crc32",this.crc32).withStreamInfo("compression",this.compression)}},s.createWorkerFrom=function(A,t,e){return A.pipe(new i).pipe(new o("uncompressedSize")).pipe(t.compressWorker(e)).pipe(new o("compressedSize")).withStreamInfo("compression",t)},t.exports=s},{"./external":6,"./stream/Crc32Probe":25,"./stream/DataLengthProbe":26,"./stream/DataWorker":27}],3:[function(A,t,e){"use strict";var n=A("./stream/GenericWorker");e.STORE={magic:"\0\0",compressWorker:function(){return new n("STORE compression")},uncompressWorker:function(){return new n("STORE decompression")}},e.DEFLATE=A("./flate")},{"./flate":7,"./stream/GenericWorker":28}],4:[function(A,t,e){"use strict";var n=A("./utils"),r=function(){for(var A,t=[],e=0;e<256;e++){A=e;for(var n=0;n<8;n++)A=1&A?3988292384^A>>>1:A>>>1;t[e]=A}return t}();t.exports=function(A,t){return void 0!==A&&A.length?"string"!==n.getTypeOf(A)?function(A,t,e,n){var i=r,o=0+e;A^=-1;for(var s=0;s<o;s++)A=A>>>8^i[255&(A^t[s])];return-1^A}(0|t,A,A.length):function(A,t,e,n){var i=r,o=0+e;A^=-1;for(var s=0;s<o;s++)A=A>>>8^i[255&(A^t.charCodeAt(s))];return-1^A}(0|t,A,A.length):0}},{"./utils":32}],5:[function(A,t,e){"use strict";e.base64=!1,e.binary=!1,e.dir=!1,e.createFolders=!0,e.date=null,e.compression=null,e.compressionOptions=null,e.comment=null,e.unixPermissions=null,e.dosPermissions=null},{}],6:[function(A,t,e){"use strict";var n;n="undefined"!=typeof Promise?Promise:A("lie"),t.exports={Promise:n}},{lie:37}],7:[function(A,t,e){"use strict";var n="undefined"!=typeof Uint8Array&&"undefined"!=typeof Uint16Array&&"undefined"!=typeof Uint32Array,r=A("pako"),i=A("./utils"),o=A("./stream/GenericWorker"),s=n?"uint8array":"array";function a(A,t){o.call(this,"FlateWorker/"+A),this._pako=null,this._pakoAction=A,this._pakoOptions=t,this.meta={}}e.magic="\b\0",i.inherits(a,o),a.prototype.processChunk=function(A){this.meta=A.meta,null===this._pako&&this._createPako(),this._pako.push(i.transformTo(s,A.data),!1)},a.prototype.flush=function(){o.prototype.flush.call(this),null===this._pako&&this._createPako(),this._pako.push([],!0)},a.prototype.cleanUp=function(){o.prototype.cleanUp.call(this),this._pako=null},a.prototype._createPako=function(){this._pako=new r[this._pakoAction]({raw:!0,level:this._pakoOptions.level||-1});var A=this;this._pako.onData=function(t){A.push({data:t,meta:A.meta})}},e.compressWorker=function(A){return new a("Deflate",A)},e.uncompressWorker=function(){return new a("Inflate",{})}},{"./stream/GenericWorker":28,"./utils":32,pako:38}],8:[function(A,t,e){"use strict";function n(A,t){var e,n="";for(e=0;e<t;e++)n+=String.fromCharCode(255&A),A>>>=8;return n}function r(A,t,e,r,o,B){var g,l,u=A.file,w=A.compression,h=B!==s.utf8encode,E=i.transformTo("string",B(u.name)),f=i.transformTo("string",s.utf8encode(u.name)),Q=u.comment,d=i.transformTo("string",B(Q)),C=i.transformTo("string",s.utf8encode(Q)),M=f.length!==u.name.length,I=C.length!==Q.length,p="",D="",y="",v=u.dir,m=u.date,F={crc32:0,compressedSize:0,uncompressedSize:0};t&&!e||(F.crc32=A.crc32,F.compressedSize=A.compressedSize,F.uncompressedSize=A.uncompressedSize);var Y=0;t&&(Y|=8),h||!M&&!I||(Y|=2048);var b=0,z=0;v&&(b|=16),"UNIX"===o?(z=798,b|=function(A,t){var e=A;return A||(e=t?16893:33204),(65535&e)<<16}(u.unixPermissions,v)):(z=20,b|=function(A){return 63&(A||0)}(u.dosPermissions)),g=m.getUTCHours(),g<<=6,g|=m.getUTCMinutes(),g<<=5,g|=m.getUTCSeconds()/2,l=m.getUTCFullYear()-1980,l<<=4,l|=m.getUTCMonth()+1,l<<=5,l|=m.getUTCDate(),M&&(D=n(1,1)+n(a(E),4)+f,p+="up"+n(D.length,2)+D),I&&(y=n(1,1)+n(a(d),4)+C,p+="uc"+n(y.length,2)+y);var U="";return U+="\n\0",U+=n(Y,2),U+=w.magic,U+=n(g,2),U+=n(l,2),U+=n(F.crc32,4),U+=n(F.compressedSize,4),U+=n(F.uncompressedSize,4),U+=n(E.length,2),U+=n(p.length,2),{fileRecord:c.LOCAL_FILE_HEADER+U+E+p,dirRecord:c.CENTRAL_FILE_HEADER+n(z,2)+U+n(d.length,2)+"\0\0\0\0"+n(b,4)+n(r,4)+E+p+d}}var i=A("../utils"),o=A("../stream/GenericWorker"),s=A("../utf8"),a=A("../crc32"),c=A("../signature");function B(A,t,e,n){o.call(this,"ZipFileWorker"),this.bytesWritten=0,this.zipComment=t,this.zipPlatform=e,this.encodeFileName=n,this.streamFiles=A,this.accumulate=!1,this.contentBuffer=[],this.dirRecords=[],this.currentSourceOffset=0,this.entriesCount=0,this.currentFile=null,this._sources=[]}i.inherits(B,o),B.prototype.push=function(A){var t=A.meta.percent||0,e=this.entriesCount,n=this._sources.length;this.accumulate?this.contentBuffer.push(A):(this.bytesWritten+=A.data.length,o.prototype.push.call(this,{data:A.data,meta:{currentFile:this.currentFile,percent:e?(t+100*(e-n-1))/e:100}}))},B.prototype.openedSource=function(A){this.currentSourceOffset=this.bytesWritten,this.currentFile=A.file.name;var t=this.streamFiles&&!A.file.dir;if(t){var e=r(A,t,!1,this.currentSourceOffset,this.zipPlatform,this.encodeFileName);this.push({data:e.fileRecord,meta:{percent:0}})}else this.accumulate=!0},B.prototype.closedSource=function(A){this.accumulate=!1;var t=this.streamFiles&&!A.file.dir,e=r(A,t,!0,this.currentSourceOffset,this.zipPlatform,this.encodeFileName);if(this.dirRecords.push(e.dirRecord),t)this.push({data:function(A){return c.DATA_DESCRIPTOR+n(A.crc32,4)+n(A.compressedSize,4)+n(A.uncompressedSize,4)}(A),meta:{percent:100}});else for(this.push({data:e.fileRecord,meta:{percent:0}});this.contentBuffer.length;)this.push(this.contentBuffer.shift());this.currentFile=null},B.prototype.flush=function(){for(var A=this.bytesWritten,t=0;t<this.dirRecords.length;t++)this.push({data:this.dirRecords[t],meta:{percent:100}});var e=this.bytesWritten-A,r=function(A,t,e,r,o){var s=i.transformTo("string",o(r));return c.CENTRAL_DIRECTORY_END+"\0\0\0\0"+n(A,2)+n(A,2)+n(t,4)+n(e,4)+n(s.length,2)+s}(this.dirRecords.length,e,A,this.zipComment,this.encodeFileName);this.push({data:r,meta:{percent:100}})},B.prototype.prepareNextSource=function(){this.previous=this._sources.shift(),this.openedSource(this.previous.streamInfo),this.isPaused?this.previous.pause():this.previous.resume()},B.prototype.registerPrevious=function(A){this._sources.push(A);var t=this;return A.on("data",(function(A){t.processChunk(A)})),A.on("end",(function(){t.closedSource(t.previous.streamInfo),t._sources.length?t.prepareNextSource():t.end()})),A.on("error",(function(A){t.error(A)})),this},B.prototype.resume=function(){return!!o.prototype.resume.call(this)&&(!this.previous&&this._sources.length?(this.prepareNextSource(),!0):this.previous||this._sources.length||this.generatedError?void 0:(this.end(),!0))},B.prototype.error=function(A){var t=this._sources;if(!o.prototype.error.call(this,A))return!1;for(var e=0;e<t.length;e++)try{t[e].error(A)}catch(A){}return!0},B.prototype.lock=function(){o.prototype.lock.call(this);for(var A=this._sources,t=0;t<A.length;t++)A[t].lock()},t.exports=B},{"../crc32":4,"../signature":23,"../stream/GenericWorker":28,"../utf8":31,"../utils":32}],9:[function(A,t,e){"use strict";var n=A("../compressions"),r=A("./ZipFileWorker");e.generateWorker=function(A,t,e){var i=new r(t.streamFiles,e,t.platform,t.encodeFileName),o=0;try{A.forEach((function(A,e){o++;var r=function(A,t){var e=A||t,r=n[e];if(!r)throw new Error(e+" is not a valid compression method !");return r}(e.options.compression,t.compression),s=e.options.compressionOptions||t.compressionOptions||{},a=e.dir,c=e.date;e._compressWorker(r,s).withStreamInfo("file",{name:A,dir:a,date:c,comment:e.comment||"",unixPermissions:e.unixPermissions,dosPermissions:e.dosPermissions}).pipe(i)})),i.entriesCount=o}catch(A){i.error(A)}return i}},{"../compressions":3,"./ZipFileWorker":8}],10:[function(A,t,e){"use strict";function n(){if(!(this instanceof n))return new n;if(arguments.length)throw new Error("The constructor with parameters has been removed in JSZip 3.0, please check the upgrade guide.");this.files=Object.create(null),this.comment=null,this.root="",this.clone=function(){var A=new n;for(var t in this)"function"!=typeof this[t]&&(A[t]=this[t]);return A}}(n.prototype=A("./object")).loadAsync=A("./load"),n.support=A("./support"),n.defaults=A("./defaults"),n.version="3.10.1",n.loadAsync=function(A,t){return(new n).loadAsync(A,t)},n.external=A("./external"),t.exports=n},{"./defaults":5,"./external":6,"./load":11,"./object":15,"./support":30}],11:[function(A,t,e){"use strict";var n=A("./utils"),r=A("./external"),i=A("./utf8"),o=A("./zipEntries"),s=A("./stream/Crc32Probe"),a=A("./nodejsUtils");function c(A){return new r.Promise((function(t,e){var n=A.decompressed.getContentWorker().pipe(new s);n.on("error",(function(A){e(A)})).on("end",(function(){n.streamInfo.crc32!==A.decompressed.crc32?e(new Error("Corrupted zip : CRC32 mismatch")):t()})).resume()}))}t.exports=function(A,t){var e=this;return t=n.extend(t||{},{base64:!1,checkCRC32:!1,optimizedBinaryString:!1,createFolders:!1,decodeFileName:i.utf8decode}),a.isNode&&a.isStream(A)?r.Promise.reject(new Error("JSZip can't accept a stream when loading a zip file.")):n.prepareContent("the loaded zip file",A,!0,t.optimizedBinaryString,t.base64).then((function(A){var e=new o(t);return e.load(A),e})).then((function(A){var e=[r.Promise.resolve(A)],n=A.files;if(t.checkCRC32)for(var i=0;i<n.length;i++)e.push(c(n[i]));return r.Promise.all(e)})).then((function(A){for(var r=A.shift(),i=r.files,o=0;o<i.length;o++){var s=i[o],a=s.fileNameStr,c=n.resolve(s.fileNameStr);e.file(c,s.decompressed,{binary:!0,optimizedBinaryString:!0,date:s.date,dir:s.dir,comment:s.fileCommentStr.length?s.fileCommentStr:null,unixPermissions:s.unixPermissions,dosPermissions:s.dosPermissions,createFolders:t.createFolders}),s.dir||(e.file(c).unsafeOriginalName=a)}return r.zipComment.length&&(e.comment=r.zipComment),e}))}},{"./external":6,"./nodejsUtils":14,"./stream/Crc32Probe":25,"./utf8":31,"./utils":32,"./zipEntries":33}],12:[function(A,t,e){"use strict";var n=A("../utils"),r=A("../stream/GenericWorker");function i(A,t){r.call(this,"Nodejs stream input adapter for "+A),this._upstreamEnded=!1,this._bindStream(t)}n.inherits(i,r),i.prototype._bindStream=function(A){var t=this;(this._stream=A).pause(),A.on("data",(function(A){t.push({data:A,meta:{percent:0}})})).on("error",(function(A){t.isPaused?this.generatedError=A:t.error(A)})).on("end",(function(){t.isPaused?t._upstreamEnded=!0:t.end()}))},i.prototype.pause=function(){return!!r.prototype.pause.call(this)&&(this._stream.pause(),!0)},i.prototype.resume=function(){return!!r.prototype.resume.call(this)&&(this._upstreamEnded?this.end():this._stream.resume(),!0)},t.exports=i},{"../stream/GenericWorker":28,"../utils":32}],13:[function(A,t,e){"use strict";var n=A("readable-stream").Readable;function r(A,t,e){n.call(this,t),this._helper=A;var r=this;A.on("data",(function(A,t){r.push(A)||r._helper.pause(),e&&e(t)})).on("error",(function(A){r.emit("error",A)})).on("end",(function(){r.push(null)}))}A("../utils").inherits(r,n),r.prototype._read=function(){this._helper.resume()},t.exports=r},{"../utils":32,"readable-stream":16}],14:[function(A,t,e){"use strict";t.exports={isNode:"undefined"!=typeof Buffer,newBufferFrom:function(A,t){if(Buffer.from&&Buffer.from!==Uint8Array.from)return Buffer.from(A,t);if("number"==typeof A)throw new Error('The "data" argument must not be a number');return new Buffer(A,t)},allocBuffer:function(A){if(Buffer.alloc)return Buffer.alloc(A);var t=new Buffer(A);return t.fill(0),t},isBuffer:function(A){return Buffer.isBuffer(A)},isStream:function(A){return A&&"function"==typeof A.on&&"function"==typeof A.pause&&"function"==typeof A.resume}}},{}],15:[function(A,t,e){"use strict";function n(A,t,e){var n,r=i.getTypeOf(t),s=i.extend(e||{},a);s.date=s.date||new Date,null!==s.compression&&(s.compression=s.compression.toUpperCase()),"string"==typeof s.unixPermissions&&(s.unixPermissions=parseInt(s.unixPermissions,8)),s.unixPermissions&&16384&s.unixPermissions&&(s.dir=!0),s.dosPermissions&&16&s.dosPermissions&&(s.dir=!0),s.dir&&(A=h(A)),s.createFolders&&(n=w(A))&&E.call(this,n,!0);var g="string"===r&&!1===s.binary&&!1===s.base64;e&&void 0!==e.binary||(s.binary=!g),(t instanceof c&&0===t.uncompressedSize||s.dir||!t||0===t.length)&&(s.base64=!1,s.binary=!0,t="",s.compression="STORE",r="string");var f;f=t instanceof c||t instanceof o?t:l.isNode&&l.isStream(t)?new u(A,t):i.prepareContent(A,t,s.binary,s.optimizedBinaryString,s.base64);var Q=new B(A,f,s);this.files[A]=Q}var r=A("./utf8"),i=A("./utils"),o=A("./stream/GenericWorker"),s=A("./stream/StreamHelper"),a=A("./defaults"),c=A("./compressedObject"),B=A("./zipObject"),g=A("./generate"),l=A("./nodejsUtils"),u=A("./nodejs/NodejsStreamInputAdapter"),w=function(A){"/"===A.slice(-1)&&(A=A.substring(0,A.length-1));var t=A.lastIndexOf("/");return 0<t?A.substring(0,t):""},h=function(A){return"/"!==A.slice(-1)&&(A+="/"),A},E=function(A,t){return t=void 0!==t?t:a.createFolders,A=h(A),this.files[A]||n.call(this,A,null,{dir:!0,createFolders:t}),this.files[A]};function f(A){return"[object RegExp]"===Object.prototype.toString.call(A)}var Q={load:function(){throw new Error("This method has been removed in JSZip 3.0, please check the upgrade guide.")},forEach:function(A){var t,e,n;for(t in this.files)n=this.files[t],(e=t.slice(this.root.length,t.length))&&t.slice(0,this.root.length)===this.root&&A(e,n)},filter:function(A){var t=[];return this.forEach((function(e,n){A(e,n)&&t.push(n)})),t},file:function(A,t,e){if(1!==arguments.length)return A=this.root+A,n.call(this,A,t,e),this;if(f(A)){var r=A;return this.filter((function(A,t){return!t.dir&&r.test(A)}))}var i=this.files[this.root+A];return i&&!i.dir?i:null},folder:function(A){if(!A)return this;if(f(A))return this.filter((function(t,e){return e.dir&&A.test(t)}));var t=this.root+A,e=E.call(this,t),n=this.clone();return n.root=e.name,n},remove:function(A){A=this.root+A;var t=this.files[A];if(t||("/"!==A.slice(-1)&&(A+="/"),t=this.files[A]),t&&!t.dir)delete this.files[A];else for(var e=this.filter((function(t,e){return e.name.slice(0,A.length)===A})),n=0;n<e.length;n++)delete this.files[e[n].name];return this},generate:function(){throw new Error("This method has been removed in JSZip 3.0, please check the upgrade guide.")},generateInternalStream:function(A){var t,e={};try{if((e=i.extend(A||{},{streamFiles:!1,compression:"STORE",compressionOptions:null,type:"",platform:"DOS",comment:null,mimeType:"application/zip",encodeFileName:r.utf8encode})).type=e.type.toLowerCase(),e.compression=e.compression.toUpperCase(),"binarystring"===e.type&&(e.type="string"),!e.type)throw new Error("No output type specified.");i.checkSupport(e.type),"darwin"!==e.platform&&"freebsd"!==e.platform&&"linux"!==e.platform&&"sunos"!==e.platform||(e.platform="UNIX"),"win32"===e.platform&&(e.platform="DOS");var n=e.comment||this.comment||"";t=g.generateWorker(this,e,n)}catch(A){(t=new o("error")).error(A)}return new s(t,e.type||"string",e.mimeType)},generateAsync:function(A,t){return this.generateInternalStream(A).accumulate(t)},generateNodeStream:function(A,t){return(A=A||{}).type||(A.type="nodebuffer"),this.generateInternalStream(A).toNodejsStream(t)}};t.exports=Q},{"./compressedObject":2,"./defaults":5,"./generate":9,"./nodejs/NodejsStreamInputAdapter":12,"./nodejsUtils":14,"./stream/GenericWorker":28,"./stream/StreamHelper":29,"./utf8":31,"./utils":32,"./zipObject":35}],16:[function(A,t,e){"use strict";t.exports=A("stream")},{stream:void 0}],17:[function(A,t,e){"use strict";var n=A("./DataReader");function r(A){n.call(this,A);for(var t=0;t<this.data.length;t++)A[t]=255&A[t]}A("../utils").inherits(r,n),r.prototype.byteAt=function(A){return this.data[this.zero+A]},r.prototype.lastIndexOfSignature=function(A){for(var t=A.charCodeAt(0),e=A.charCodeAt(1),n=A.charCodeAt(2),r=A.charCodeAt(3),i=this.length-4;0<=i;--i)if(this.data[i]===t&&this.data[i+1]===e&&this.data[i+2]===n&&this.data[i+3]===r)return i-this.zero;return-1},r.prototype.readAndCheckSignature=function(A){var t=A.charCodeAt(0),e=A.charCodeAt(1),n=A.charCodeAt(2),r=A.charCodeAt(3),i=this.readData(4);return t===i[0]&&e===i[1]&&n===i[2]&&r===i[3]},r.prototype.readData=function(A){if(this.checkOffset(A),0===A)return[];var t=this.data.slice(this.zero+this.index,this.zero+this.index+A);return this.index+=A,t},t.exports=r},{"../utils":32,"./DataReader":18}],18:[function(A,t,e){"use strict";var n=A("../utils");function r(A){this.data=A,this.length=A.length,this.index=0,this.zero=0}r.prototype={checkOffset:function(A){this.checkIndex(this.index+A)},checkIndex:function(A){if(this.length<this.zero+A||A<0)throw new Error("End of data reached (data length = "+this.length+", asked index = "+A+"). Corrupted zip ?")},setIndex:function(A){this.checkIndex(A),this.index=A},skip:function(A){this.setIndex(this.index+A)},byteAt:function(){},readInt:function(A){var t,e=0;for(this.checkOffset(A),t=this.index+A-1;t>=this.index;t--)e=(e<<8)+this.byteAt(t);return this.index+=A,e},readString:function(A){return n.transformTo("string",this.readData(A))},readData:function(){},lastIndexOfSignature:function(){},readAndCheckSignature:function(){},readDate:function(){var A=this.readInt(4);return new Date(Date.UTC(1980+(A>>25&127),(A>>21&15)-1,A>>16&31,A>>11&31,A>>5&63,(31&A)<<1))}},t.exports=r},{"../utils":32}],19:[function(A,t,e){"use strict";var n=A("./Uint8ArrayReader");function r(A){n.call(this,A)}A("../utils").inherits(r,n),r.prototype.readData=function(A){this.checkOffset(A);var t=this.data.slice(this.zero+this.index,this.zero+this.index+A);return this.index+=A,t},t.exports=r},{"../utils":32,"./Uint8ArrayReader":21}],20:[function(A,t,e){"use strict";var n=A("./DataReader");function r(A){n.call(this,A)}A("../utils").inherits(r,n),r.prototype.byteAt=function(A){return this.data.charCodeAt(this.zero+A)},r.prototype.lastIndexOfSignature=function(A){return this.data.lastIndexOf(A)-this.zero},r.prototype.readAndCheckSignature=function(A){return A===this.readData(4)},r.prototype.readData=function(A){this.checkOffset(A);var t=this.data.slice(this.zero+this.index,this.zero+this.index+A);return this.index+=A,t},t.exports=r},{"../utils":32,"./DataReader":18}],21:[function(A,t,e){"use strict";var n=A("./ArrayReader");function r(A){n.call(this,A)}A("../utils").inherits(r,n),r.prototype.readData=function(A){if(this.checkOffset(A),0===A)return new Uint8Array(0);var t=this.data.subarray(this.zero+this.index,this.zero+this.index+A);return this.index+=A,t},t.exports=r},{"../utils":32,"./ArrayReader":17}],22:[function(A,t,e){"use strict";var n=A("../utils"),r=A("../support"),i=A("./ArrayReader"),o=A("./StringReader"),s=A("./NodeBufferReader"),a=A("./Uint8ArrayReader");t.exports=function(A){var t=n.getTypeOf(A);return n.checkSupport(t),"string"!==t||r.uint8array?"nodebuffer"===t?new s(A):r.uint8array?new a(n.transformTo("uint8array",A)):new i(n.transformTo("array",A)):new o(A)}},{"../support":30,"../utils":32,"./ArrayReader":17,"./NodeBufferReader":19,"./StringReader":20,"./Uint8ArrayReader":21}],23:[function(A,t,e){"use strict";e.LOCAL_FILE_HEADER="PK",e.CENTRAL_FILE_HEADER="PK",e.CENTRAL_DIRECTORY_END="PK",e.ZIP64_CENTRAL_DIRECTORY_LOCATOR="PK",e.ZIP64_CENTRAL_DIRECTORY_END="PK",e.DATA_DESCRIPTOR="PK\b"},{}],24:[function(A,t,e){"use strict";var n=A("./GenericWorker"),r=A("../utils");function i(A){n.call(this,"ConvertWorker to "+A),this.destType=A}r.inherits(i,n),i.prototype.processChunk=function(A){this.push({data:r.transformTo(this.destType,A.data),meta:A.meta})},t.exports=i},{"../utils":32,"./GenericWorker":28}],25:[function(A,t,e){"use strict";var n=A("./GenericWorker"),r=A("../crc32");function i(){n.call(this,"Crc32Probe"),this.withStreamInfo("crc32",0)}A("../utils").inherits(i,n),i.prototype.processChunk=function(A){this.streamInfo.crc32=r(A.data,this.streamInfo.crc32||0),this.push(A)},t.exports=i},{"../crc32":4,"../utils":32,"./GenericWorker":28}],26:[function(A,t,e){"use strict";var n=A("../utils"),r=A("./GenericWorker");function i(A){r.call(this,"DataLengthProbe for "+A),this.propName=A,this.withStreamInfo(A,0)}n.inherits(i,r),i.prototype.processChunk=function(A){if(A){var t=this.streamInfo[this.propName]||0;this.streamInfo[this.propName]=t+A.data.length}r.prototype.processChunk.call(this,A)},t.exports=i},{"../utils":32,"./GenericWorker":28}],27:[function(A,t,e){"use strict";var n=A("../utils"),r=A("./GenericWorker");function i(A){r.call(this,"DataWorker");var t=this;this.dataIsReady=!1,this.index=0,this.max=0,this.data=null,this.type="",this._tickScheduled=!1,A.then((function(A){t.dataIsReady=!0,t.data=A,t.max=A&&A.length||0,t.type=n.getTypeOf(A),t.isPaused||t._tickAndRepeat()}),(function(A){t.error(A)}))}n.inherits(i,r),i.prototype.cleanUp=function(){r.prototype.cleanUp.call(this),this.data=null},i.prototype.resume=function(){return!!r.prototype.resume.call(this)&&(!this._tickScheduled&&this.dataIsReady&&(this._tickScheduled=!0,n.delay(this._tickAndRepeat,[],this)),!0)},i.prototype._tickAndRepeat=function(){this._tickScheduled=!1,this.isPaused||this.isFinished||(this._tick(),this.isFinished||(n.delay(this._tickAndRepeat,[],this),this._tickScheduled=!0))},i.prototype._tick=function(){if(this.isPaused||this.isFinished)return!1;var A=null,t=Math.min(this.max,this.index+16384);if(this.index>=this.max)return this.end();switch(this.type){case"string":A=this.data.substring(this.index,t);break;case"uint8array":A=this.data.subarray(this.index,t);break;case"array":case"nodebuffer":A=this.data.slice(this.index,t)}return this.index=t,this.push({data:A,meta:{percent:this.max?this.index/this.max*100:0}})},t.exports=i},{"../utils":32,"./GenericWorker":28}],28:[function(A,t,e){"use strict";function n(A){this.name=A||"default",this.streamInfo={},this.generatedError=null,this.extraStreamInfo={},this.isPaused=!0,this.isFinished=!1,this.isLocked=!1,this._listeners={data:[],end:[],error:[]},this.previous=null}n.prototype={push:function(A){this.emit("data",A)},end:function(){if(this.isFinished)return!1;this.flush();try{this.emit("end"),this.cleanUp(),this.isFinished=!0}catch(A){this.emit("error",A)}return!0},error:function(A){return!this.isFinished&&(this.isPaused?this.generatedError=A:(this.isFinished=!0,this.emit("error",A),this.previous&&this.previous.error(A),this.cleanUp()),!0)},on:function(A,t){return this._listeners[A].push(t),this},cleanUp:function(){this.streamInfo=this.generatedError=this.extraStreamInfo=null,this._listeners=[]},emit:function(A,t){if(this._listeners[A])for(var e=0;e<this._listeners[A].length;e++)this._listeners[A][e].call(this,t)},pipe:function(A){return A.registerPrevious(this)},registerPrevious:function(A){if(this.isLocked)throw new Error("The stream '"+this+"' has already been used.");this.streamInfo=A.streamInfo,this.mergeStreamInfo(),this.previous=A;var t=this;return A.on("data",(function(A){t.processChunk(A)})),A.on("end",(function(){t.end()})),A.on("error",(function(A){t.error(A)})),this},pause:function(){return!this.isPaused&&!this.isFinished&&(this.isPaused=!0,this.previous&&this.previous.pause(),!0)},resume:function(){if(!this.isPaused||this.isFinished)return!1;var A=this.isPaused=!1;return this.generatedError&&(this.error(this.generatedError),A=!0),this.previous&&this.previous.resume(),!A},flush:function(){},processChunk:function(A){this.push(A)},withStreamInfo:function(A,t){return this.extraStreamInfo[A]=t,this.mergeStreamInfo(),this},mergeStreamInfo:function(){for(var A in this.extraStreamInfo)Object.prototype.hasOwnProperty.call(this.extraStreamInfo,A)&&(this.streamInfo[A]=this.extraStreamInfo[A])},lock:function(){if(this.isLocked)throw new Error("The stream '"+this+"' has already been used.");this.isLocked=!0,this.previous&&this.previous.lock()},toString:function(){var A="Worker "+this.name;return this.previous?this.previous+" -> "+A:A}},t.exports=n},{}],29:[function(A,t,e){"use strict";var n=A("../utils"),r=A("./ConvertWorker"),i=A("./GenericWorker"),o=A("../base64"),s=A("../support"),a=A("../external"),c=null;if(s.nodestream)try{c=A("../nodejs/NodejsStreamOutputAdapter")}catch(A){}function B(A,t,e){var o=t;switch(t){case"blob":case"arraybuffer":o="uint8array";break;case"base64":o="string"}try{this._internalType=o,this._outputType=t,this._mimeType=e,n.checkSupport(o),this._worker=A.pipe(new r(o)),A.lock()}catch(A){this._worker=new i("error"),this._worker.error(A)}}B.prototype={accumulate:function(A){return function(A,t){return new a.Promise((function(e,r){var i=[],s=A._internalType,a=A._outputType,c=A._mimeType;A.on("data",(function(A,e){i.push(A),t&&t(e)})).on("error",(function(A){i=[],r(A)})).on("end",(function(){try{var A=function(A,t,e){switch(A){case"blob":return n.newBlob(n.transformTo("arraybuffer",t),e);case"base64":return o.encode(t);default:return n.transformTo(A,t)}}(a,function(A,t){var e,n=0,r=null,i=0;for(e=0;e<t.length;e++)i+=t[e].length;switch(A){case"string":return t.join("");case"array":return Array.prototype.concat.apply([],t);case"uint8array":for(r=new Uint8Array(i),e=0;e<t.length;e++)r.set(t[e],n),n+=t[e].length;return r;case"nodebuffer":return Buffer.concat(t);default:throw new Error("concat : unsupported type '"+A+"'")}}(s,i),c);e(A)}catch(A){r(A)}i=[]})).resume()}))}(this,A)},on:function(A,t){var e=this;return"data"===A?this._worker.on(A,(function(A){t.call(e,A.data,A.meta)})):this._worker.on(A,(function(){n.delay(t,arguments,e)})),this},resume:function(){return n.delay(this._worker.resume,[],this._worker),this},pause:function(){return this._worker.pause(),this},toNodejsStream:function(A){if(n.checkSupport("nodestream"),"nodebuffer"!==this._outputType)throw new Error(this._outputType+" is not supported by this method");return new c(this,{objectMode:"nodebuffer"!==this._outputType},A)}},t.exports=B},{"../base64":1,"../external":6,"../nodejs/NodejsStreamOutputAdapter":13,"../support":30,"../utils":32,"./ConvertWorker":24,"./GenericWorker":28}],30:[function(A,t,e){"use strict";if(e.base64=!0,e.array=!0,e.string=!0,e.arraybuffer="undefined"!=typeof ArrayBuffer&&"undefined"!=typeof Uint8Array,e.nodebuffer="undefined"!=typeof Buffer,e.uint8array="undefined"!=typeof Uint8Array,"undefined"==typeof ArrayBuffer)e.blob=!1;else{var n=new ArrayBuffer(0);try{e.blob=0===new Blob([n],{type:"application/zip"}).size}catch(A){try{var r=new(self.BlobBuilder||self.WebKitBlobBuilder||self.MozBlobBuilder||self.MSBlobBuilder);r.append(n),e.blob=0===r.getBlob("application/zip").size}catch(A){e.blob=!1}}}try{e.nodestream=!!A("readable-stream").Readable}catch(A){e.nodestream=!1}},{"readable-stream":16}],31:[function(A,t,e){"use strict";for(var n=A("./utils"),r=A("./support"),i=A("./nodejsUtils"),o=A("./stream/GenericWorker"),s=new Array(256),a=0;a<256;a++)s[a]=252<=a?6:248<=a?5:240<=a?4:224<=a?3:192<=a?2:1;function c(){o.call(this,"utf-8 decode"),this.leftOver=null}function B(){o.call(this,"utf-8 encode")}s[254]=s[254]=1,e.utf8encode=function(A){return r.nodebuffer?i.newBufferFrom(A,"utf-8"):function(A){var t,e,n,i,o,s=A.length,a=0;for(i=0;i<s;i++)55296==(64512&(e=A.charCodeAt(i)))&&i+1<s&&56320==(64512&(n=A.charCodeAt(i+1)))&&(e=65536+(e-55296<<10)+(n-56320),i++),a+=e<128?1:e<2048?2:e<65536?3:4;for(t=r.uint8array?new Uint8Array(a):new Array(a),i=o=0;o<a;i++)55296==(64512&(e=A.charCodeAt(i)))&&i+1<s&&56320==(64512&(n=A.charCodeAt(i+1)))&&(e=65536+(e-55296<<10)+(n-56320),i++),e<128?t[o++]=e:(e<2048?t[o++]=192|e>>>6:(e<65536?t[o++]=224|e>>>12:(t[o++]=240|e>>>18,t[o++]=128|e>>>12&63),t[o++]=128|e>>>6&63),t[o++]=128|63&e);return t}(A)},e.utf8decode=function(A){return r.nodebuffer?n.transformTo("nodebuffer",A).toString("utf-8"):function(A){var t,e,r,i,o=A.length,a=new Array(2*o);for(t=e=0;t<o;)if((r=A[t++])<128)a[e++]=r;else if(4<(i=s[r]))a[e++]=65533,t+=i-1;else{for(r&=2===i?31:3===i?15:7;1<i&&t<o;)r=r<<6|63&A[t++],i--;1<i?a[e++]=65533:r<65536?a[e++]=r:(r-=65536,a[e++]=55296|r>>10&1023,a[e++]=56320|1023&r)}return a.length!==e&&(a.subarray?a=a.subarray(0,e):a.length=e),n.applyFromCharCode(a)}(A=n.transformTo(r.uint8array?"uint8array":"array",A))},n.inherits(c,o),c.prototype.processChunk=function(A){var t=n.transformTo(r.uint8array?"uint8array":"array",A.data);if(this.leftOver&&this.leftOver.length){if(r.uint8array){var i=t;(t=new Uint8Array(i.length+this.leftOver.length)).set(this.leftOver,0),t.set(i,this.leftOver.length)}else t=this.leftOver.concat(t);this.leftOver=null}var o=function(A,t){var e;for((t=t||A.length)>A.length&&(t=A.length),e=t-1;0<=e&&128==(192&A[e]);)e--;return e<0||0===e?t:e+s[A[e]]>t?e:t}(t),a=t;o!==t.length&&(r.uint8array?(a=t.subarray(0,o),this.leftOver=t.subarray(o,t.length)):(a=t.slice(0,o),this.leftOver=t.slice(o,t.length))),this.push({data:e.utf8decode(a),meta:A.meta})},c.prototype.flush=function(){this.leftOver&&this.leftOver.length&&(this.push({data:e.utf8decode(this.leftOver),meta:{}}),this.leftOver=null)},e.Utf8DecodeWorker=c,n.inherits(B,o),B.prototype.processChunk=function(A){this.push({data:e.utf8encode(A.data),meta:A.meta})},e.Utf8EncodeWorker=B},{"./nodejsUtils":14,"./stream/GenericWorker":28,"./support":30,"./utils":32}],32:[function(A,t,e){"use strict";var n=A("./support"),r=A("./base64"),i=A("./nodejsUtils"),o=A("./external");function s(A){return A}function a(A,t){for(var e=0;e<A.length;++e)t[e]=255&A.charCodeAt(e);return t}A("setimmediate"),e.newBlob=function(A,t){e.checkSupport("blob");try{return new Blob([A],{type:t})}catch(e){try{var n=new(self.BlobBuilder||self.WebKitBlobBuilder||self.MozBlobBuilder||self.MSBlobBuilder);return n.append(A),n.getBlob(t)}catch(A){throw new Error("Bug : can't construct the Blob.")}}};var c={stringifyByChunk:function(A,t,e){var n=[],r=0,i=A.length;if(i<=e)return String.fromCharCode.apply(null,A);for(;r<i;)"array"===t||"nodebuffer"===t?n.push(String.fromCharCode.apply(null,A.slice(r,Math.min(r+e,i)))):n.push(String.fromCharCode.apply(null,A.subarray(r,Math.min(r+e,i)))),r+=e;return n.join("")},stringifyByChar:function(A){for(var t="",e=0;e<A.length;e++)t+=String.fromCharCode(A[e]);return t},applyCanBeUsed:{uint8array:function(){try{return n.uint8array&&1===String.fromCharCode.apply(null,new Uint8Array(1)).length}catch(A){return!1}}(),nodebuffer:function(){try{return n.nodebuffer&&1===String.fromCharCode.apply(null,i.allocBuffer(1)).length}catch(A){return!1}}()}};function B(A){var t=65536,n=e.getTypeOf(A),r=!0;if("uint8array"===n?r=c.applyCanBeUsed.uint8array:"nodebuffer"===n&&(r=c.applyCanBeUsed.nodebuffer),r)for(;1<t;)try{return c.stringifyByChunk(A,n,t)}catch(A){t=Math.floor(t/2)}return c.stringifyByChar(A)}function g(A,t){for(var e=0;e<A.length;e++)t[e]=A[e];return t}e.applyFromCharCode=B;var l={};l.string={string:s,array:function(A){return a(A,new Array(A.length))},arraybuffer:function(A){return l.string.uint8array(A).buffer},uint8array:function(A){return a(A,new Uint8Array(A.length))},nodebuffer:function(A){return a(A,i.allocBuffer(A.length))}},l.array={string:B,array:s,arraybuffer:function(A){return new Uint8Array(A).buffer},uint8array:function(A){return new Uint8Array(A)},nodebuffer:function(A){return i.newBufferFrom(A)}},l.arraybuffer={string:function(A){return B(new Uint8Array(A))},array:function(A){return g(new Uint8Array(A),new Array(A.byteLength))},arraybuffer:s,uint8array:function(A){return new Uint8Array(A)},nodebuffer:function(A){return i.newBufferFrom(new Uint8Array(A))}},l.uint8array={string:B,array:function(A){return g(A,new Array(A.length))},arraybuffer:function(A){return A.buffer},uint8array:s,nodebuffer:function(A){return i.newBufferFrom(A)}},l.nodebuffer={string:B,array:function(A){return g(A,new Array(A.length))},arraybuffer:function(A){return l.nodebuffer.uint8array(A).buffer},uint8array:function(A){return g(A,new Uint8Array(A.length))},nodebuffer:s},e.transformTo=function(A,t){if(t=t||"",!A)return t;e.checkSupport(A);var n=e.getTypeOf(t);return l[n][A](t)},e.resolve=function(A){for(var t=A.split("/"),e=[],n=0;n<t.length;n++){var r=t[n];"."===r||""===r&&0!==n&&n!==t.length-1||(".."===r?e.pop():e.push(r))}return e.join("/")},e.getTypeOf=function(A){return"string"==typeof A?"string":"[object Array]"===Object.prototype.toString.call(A)?"array":n.nodebuffer&&i.isBuffer(A)?"nodebuffer":n.uint8array&&A instanceof Uint8Array?"uint8array":n.arraybuffer&&A instanceof ArrayBuffer?"arraybuffer":void 0},e.checkSupport=function(A){if(!n[A.toLowerCase()])throw new Error(A+" is not supported by this platform")},e.MAX_VALUE_16BITS=65535,e.MAX_VALUE_32BITS=-1,e.pretty=function(A){var t,e,n="";for(e=0;e<(A||"").length;e++)n+="\\x"+((t=A.charCodeAt(e))<16?"0":"")+t.toString(16).toUpperCase();return n},e.delay=function(A,t,e){setImmediate((function(){A.apply(e||null,t||[])}))},e.inherits=function(A,t){function e(){}e.prototype=t.prototype,A.prototype=new e},e.extend=function(){var A,t,e={};for(A=0;A<arguments.length;A++)for(t in arguments[A])Object.prototype.hasOwnProperty.call(arguments[A],t)&&void 0===e[t]&&(e[t]=arguments[A][t]);return e},e.prepareContent=function(A,t,i,s,c){return o.Promise.resolve(t).then((function(A){return n.blob&&(A instanceof Blob||-1!==["[object File]","[object Blob]"].indexOf(Object.prototype.toString.call(A)))&&"undefined"!=typeof FileReader?new o.Promise((function(t,e){var n=new FileReader;n.onload=function(A){t(A.target.result)},n.onerror=function(A){e(A.target.error)},n.readAsArrayBuffer(A)})):A})).then((function(t){var B=e.getTypeOf(t);return B?("arraybuffer"===B?t=e.transformTo("uint8array",t):"string"===B&&(c?t=r.decode(t):i&&!0!==s&&(t=function(A){return a(A,n.uint8array?new Uint8Array(A.length):new Array(A.length))}(t))),t):o.Promise.reject(new Error("Can't read the data of '"+A+"'. Is it in a supported JavaScript type (String, Blob, ArrayBuffer, etc) ?"))}))}},{"./base64":1,"./external":6,"./nodejsUtils":14,"./support":30,setimmediate:54}],33:[function(A,t,e){"use strict";var n=A("./reader/readerFor"),r=A("./utils"),i=A("./signature"),o=A("./zipEntry"),s=A("./support");function a(A){this.files=[],this.loadOptions=A}a.prototype={checkSignature:function(A){if(!this.reader.readAndCheckSignature(A)){this.reader.index-=4;var t=this.reader.readString(4);throw new Error("Corrupted zip or bug: unexpected signature ("+r.pretty(t)+", expected "+r.pretty(A)+")")}},isSignature:function(A,t){var e=this.reader.index;this.reader.setIndex(A);var n=this.reader.readString(4)===t;return this.reader.setIndex(e),n},readBlockEndOfCentral:function(){this.diskNumber=this.reader.readInt(2),this.diskWithCentralDirStart=this.reader.readInt(2),this.centralDirRecordsOnThisDisk=this.reader.readInt(2),this.centralDirRecords=this.reader.readInt(2),this.centralDirSize=this.reader.readInt(4),this.centralDirOffset=this.reader.readInt(4),this.zipCommentLength=this.reader.readInt(2);var A=this.reader.readData(this.zipCommentLength),t=s.uint8array?"uint8array":"array",e=r.transformTo(t,A);this.zipComment=this.loadOptions.decodeFileName(e)},readBlockZip64EndOfCentral:function(){this.zip64EndOfCentralSize=this.reader.readInt(8),this.reader.skip(4),this.diskNumber=this.reader.readInt(4),this.diskWithCentralDirStart=this.reader.readInt(4),this.centralDirRecordsOnThisDisk=this.reader.readInt(8),this.centralDirRecords=this.reader.readInt(8),this.centralDirSize=this.reader.readInt(8),this.centralDirOffset=this.reader.readInt(8),this.zip64ExtensibleData={};for(var A,t,e,n=this.zip64EndOfCentralSize-44;0<n;)A=this.reader.readInt(2),t=this.reader.readInt(4),e=this.reader.readData(t),this.zip64ExtensibleData[A]={id:A,length:t,value:e}},readBlockZip64EndOfCentralLocator:function(){if(this.diskWithZip64CentralDirStart=this.reader.readInt(4),this.relativeOffsetEndOfZip64CentralDir=this.reader.readInt(8),this.disksCount=this.reader.readInt(4),1<this.disksCount)throw new Error("Multi-volumes zip are not supported")},readLocalFiles:function(){var A,t;for(A=0;A<this.files.length;A++)t=this.files[A],this.reader.setIndex(t.localHeaderOffset),this.checkSignature(i.LOCAL_FILE_HEADER),t.readLocalPart(this.reader),t.handleUTF8(),t.processAttributes()},readCentralDir:function(){var A;for(this.reader.setIndex(this.centralDirOffset);this.reader.readAndCheckSignature(i.CENTRAL_FILE_HEADER);)(A=new o({zip64:this.zip64},this.loadOptions)).readCentralPart(this.reader),this.files.push(A);if(this.centralDirRecords!==this.files.length&&0!==this.centralDirRecords&&0===this.files.length)throw new Error("Corrupted zip or bug: expected "+this.centralDirRecords+" records in central dir, got "+this.files.length)},readEndOfCentral:function(){var A=this.reader.lastIndexOfSignature(i.CENTRAL_DIRECTORY_END);if(A<0)throw this.isSignature(0,i.LOCAL_FILE_HEADER)?new Error("Corrupted zip: can't find end of central directory"):new Error("Can't find end of central directory : is this a zip file ? If it is, see https://stuk.github.io/jszip/documentation/howto/read_zip.html");this.reader.setIndex(A);var t=A;if(this.checkSignature(i.CENTRAL_DIRECTORY_END),this.readBlockEndOfCentral(),this.diskNumber===r.MAX_VALUE_16BITS||this.diskWithCentralDirStart===r.MAX_VALUE_16BITS||this.centralDirRecordsOnThisDisk===r.MAX_VALUE_16BITS||this.centralDirRecords===r.MAX_VALUE_16BITS||this.centralDirSize===r.MAX_VALUE_32BITS||this.centralDirOffset===r.MAX_VALUE_32BITS){if(this.zip64=!0,(A=this.reader.lastIndexOfSignature(i.ZIP64_CENTRAL_DIRECTORY_LOCATOR))<0)throw new Error("Corrupted zip: can't find the ZIP64 end of central directory locator");if(this.reader.setIndex(A),this.checkSignature(i.ZIP64_CENTRAL_DIRECTORY_LOCATOR),this.readBlockZip64EndOfCentralLocator(),!this.isSignature(this.relativeOffsetEndOfZip64CentralDir,i.ZIP64_CENTRAL_DIRECTORY_END)&&(this.relativeOffsetEndOfZip64CentralDir=this.reader.lastIndexOfSignature(i.ZIP64_CENTRAL_DIRECTORY_END),this.relativeOffsetEndOfZip64CentralDir<0))throw new Error("Corrupted zip: can't find the ZIP64 end of central directory");this.reader.setIndex(this.relativeOffsetEndOfZip64CentralDir),this.checkSignature(i.ZIP64_CENTRAL_DIRECTORY_END),this.readBlockZip64EndOfCentral()}var e=this.centralDirOffset+this.centralDirSize;this.zip64&&(e+=20,e+=12+this.zip64EndOfCentralSize);var n=t-e;if(0<n)this.isSignature(t,i.CENTRAL_FILE_HEADER)||(this.reader.zero=n);else if(n<0)throw new Error("Corrupted zip: missing "+Math.abs(n)+" bytes.")},prepareReader:function(A){this.reader=n(A)},load:function(A){this.prepareReader(A),this.readEndOfCentral(),this.readCentralDir(),this.readLocalFiles()}},t.exports=a},{"./reader/readerFor":22,"./signature":23,"./support":30,"./utils":32,"./zipEntry":34}],34:[function(A,t,e){"use strict";var n=A("./reader/readerFor"),r=A("./utils"),i=A("./compressedObject"),o=A("./crc32"),s=A("./utf8"),a=A("./compressions"),c=A("./support");function B(A,t){this.options=A,this.loadOptions=t}B.prototype={isEncrypted:function(){return 1==(1&this.bitFlag)},useUTF8:function(){return 2048==(2048&this.bitFlag)},readLocalPart:function(A){var t,e;if(A.skip(22),this.fileNameLength=A.readInt(2),e=A.readInt(2),this.fileName=A.readData(this.fileNameLength),A.skip(e),-1===this.compressedSize||-1===this.uncompressedSize)throw new Error("Bug or corrupted zip : didn't get enough information from the central directory (compressedSize === -1 || uncompressedSize === -1)");if(null===(t=function(A){for(var t in a)if(Object.prototype.hasOwnProperty.call(a,t)&&a[t].magic===A)return a[t];return null}(this.compressionMethod)))throw new Error("Corrupted zip : compression "+r.pretty(this.compressionMethod)+" unknown (inner file : "+r.transformTo("string",this.fileName)+")");this.decompressed=new i(this.compressedSize,this.uncompressedSize,this.crc32,t,A.readData(this.compressedSize))},readCentralPart:function(A){this.versionMadeBy=A.readInt(2),A.skip(2),this.bitFlag=A.readInt(2),this.compressionMethod=A.readString(2),this.date=A.readDate(),this.crc32=A.readInt(4),this.compressedSize=A.readInt(4),this.uncompressedSize=A.readInt(4);var t=A.readInt(2);if(this.extraFieldsLength=A.readInt(2),this.fileCommentLength=A.readInt(2),this.diskNumberStart=A.readInt(2),this.internalFileAttributes=A.readInt(2),this.externalFileAttributes=A.readInt(4),this.localHeaderOffset=A.readInt(4),this.isEncrypted())throw new Error("Encrypted zip are not supported");A.skip(t),this.readExtraFields(A),this.parseZIP64ExtraField(A),this.fileComment=A.readData(this.fileCommentLength)},processAttributes:function(){this.unixPermissions=null,this.dosPermissions=null;var A=this.versionMadeBy>>8;this.dir=!!(16&this.externalFileAttributes),0==A&&(this.dosPermissions=63&this.externalFileAttributes),3==A&&(this.unixPermissions=this.externalFileAttributes>>16&65535),this.dir||"/"!==this.fileNameStr.slice(-1)||(this.dir=!0)},parseZIP64ExtraField:function(){if(this.extraFields[1]){var A=n(this.extraFields[1].value);this.uncompressedSize===r.MAX_VALUE_32BITS&&(this.uncompressedSize=A.readInt(8)),this.compressedSize===r.MAX_VALUE_32BITS&&(this.compressedSize=A.readInt(8)),this.localHeaderOffset===r.MAX_VALUE_32BITS&&(this.localHeaderOffset=A.readInt(8)),this.diskNumberStart===r.MAX_VALUE_32BITS&&(this.diskNumberStart=A.readInt(4))}},readExtraFields:function(A){var t,e,n,r=A.index+this.extraFieldsLength;for(this.extraFields||(this.extraFields={});A.index+4<r;)t=A.readInt(2),e=A.readInt(2),n=A.readData(e),this.extraFields[t]={id:t,length:e,value:n};A.setIndex(r)},handleUTF8:function(){var A=c.uint8array?"uint8array":"array";if(this.useUTF8())this.fileNameStr=s.utf8decode(this.fileName),this.fileCommentStr=s.utf8decode(this.fileComment);else{var t=this.findExtraFieldUnicodePath();if(null!==t)this.fileNameStr=t;else{var e=r.transformTo(A,this.fileName);this.fileNameStr=this.loadOptions.decodeFileName(e)}var n=this.findExtraFieldUnicodeComment();if(null!==n)this.fileCommentStr=n;else{var i=r.transformTo(A,this.fileComment);this.fileCommentStr=this.loadOptions.decodeFileName(i)}}},findExtraFieldUnicodePath:function(){var A=this.extraFields[28789];if(A){var t=n(A.value);return 1!==t.readInt(1)||o(this.fileName)!==t.readInt(4)?null:s.utf8decode(t.readData(A.length-5))}return null},findExtraFieldUnicodeComment:function(){var A=this.extraFields[25461];if(A){var t=n(A.value);return 1!==t.readInt(1)||o(this.fileComment)!==t.readInt(4)?null:s.utf8decode(t.readData(A.length-5))}return null}},t.exports=B},{"./compressedObject":2,"./compressions":3,"./crc32":4,"./reader/readerFor":22,"./support":30,"./utf8":31,"./utils":32}],35:[function(A,t,e){"use strict";function n(A,t,e){this.name=A,this.dir=e.dir,this.date=e.date,this.comment=e.comment,this.unixPermissions=e.unixPermissions,this.dosPermissions=e.dosPermissions,this._data=t,this._dataBinary=e.binary,this.options={compression:e.compression,compressionOptions:e.compressionOptions}}var r=A("./stream/StreamHelper"),i=A("./stream/DataWorker"),o=A("./utf8"),s=A("./compressedObject"),a=A("./stream/GenericWorker");n.prototype={internalStream:function(A){var t=null,e="string";try{if(!A)throw new Error("No output type specified.");var n="string"===(e=A.toLowerCase())||"text"===e;"binarystring"!==e&&"text"!==e||(e="string"),t=this._decompressWorker();var i=!this._dataBinary;i&&!n&&(t=t.pipe(new o.Utf8EncodeWorker)),!i&&n&&(t=t.pipe(new o.Utf8DecodeWorker))}catch(A){(t=new a("error")).error(A)}return new r(t,e,"")},async:function(A,t){return this.internalStream(A).accumulate(t)},nodeStream:function(A,t){return this.internalStream(A||"nodebuffer").toNodejsStream(t)},_compressWorker:function(A,t){if(this._data instanceof s&&this._data.compression.magic===A.magic)return this._data.getCompressedWorker();var e=this._decompressWorker();return this._dataBinary||(e=e.pipe(new o.Utf8EncodeWorker)),s.createWorkerFrom(e,A,t)},_decompressWorker:function(){return this._data instanceof s?this._data.getContentWorker():this._data instanceof a?this._data:new i(this._data)}};for(var c=["asText","asBinary","asNodeBuffer","asUint8Array","asArrayBuffer"],B=function(){throw new Error("This method has been removed in JSZip 3.0, please check the upgrade guide.")},g=0;g<c.length;g++)n.prototype[c[g]]=B;t.exports=n},{"./compressedObject":2,"./stream/DataWorker":27,"./stream/GenericWorker":28,"./stream/StreamHelper":29,"./utf8":31}],36:[function(A,t,e){(function(A){"use strict";var e,n,r=A.MutationObserver||A.WebKitMutationObserver;if(r){var i=0,o=new r(B),s=A.document.createTextNode("");o.observe(s,{characterData:!0}),e=function(){s.data=i=++i%2}}else if(A.setImmediate||void 0===A.MessageChannel)e="document"in A&&"onreadystatechange"in A.document.createElement("script")?function(){var t=A.document.createElement("script");t.onreadystatechange=function(){B(),t.onreadystatechange=null,t.parentNode.removeChild(t),t=null},A.document.documentElement.appendChild(t)}:function(){setTimeout(B,0)};else{var a=new A.MessageChannel;a.port1.onmessage=B,e=function(){a.port2.postMessage(0)}}var c=[];function B(){var A,t;n=!0;for(var e=c.length;e;){for(t=c,c=[],A=-1;++A<e;)t[A]();e=c.length}n=!1}t.exports=function(A){1!==c.push(A)||n||e()}}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{}],37:[function(A,t,e){"use strict";var n=A("immediate");function r(){}var i={},o=["REJECTED"],s=["FULFILLED"],a=["PENDING"];function c(A){if("function"!=typeof A)throw new TypeError("resolver must be a function");this.state=a,this.queue=[],this.outcome=void 0,A!==r&&u(this,A)}function B(A,t,e){this.promise=A,"function"==typeof t&&(this.onFulfilled=t,this.callFulfilled=this.otherCallFulfilled),"function"==typeof e&&(this.onRejected=e,this.callRejected=this.otherCallRejected)}function g(A,t,e){n((function(){var n;try{n=t(e)}catch(n){return i.reject(A,n)}n===A?i.reject(A,new TypeError("Cannot resolve promise with itself")):i.resolve(A,n)}))}function l(A){var t=A&&A.then;if(A&&("object"==typeof A||"function"==typeof A)&&"function"==typeof t)return function(){t.apply(A,arguments)}}function u(A,t){var e=!1;function n(t){e||(e=!0,i.reject(A,t))}function r(t){e||(e=!0,i.resolve(A,t))}var o=w((function(){t(r,n)}));"error"===o.status&&n(o.value)}function w(A,t){var e={};try{e.value=A(t),e.status="success"}catch(A){e.status="error",e.value=A}return e}(t.exports=c).prototype.finally=function(A){if("function"!=typeof A)return this;var t=this.constructor;return this.then((function(e){return t.resolve(A()).then((function(){return e}))}),(function(e){return t.resolve(A()).then((function(){throw e}))}))},c.prototype.catch=function(A){return this.then(null,A)},c.prototype.then=function(A,t){if("function"!=typeof A&&this.state===s||"function"!=typeof t&&this.state===o)return this;var e=new this.constructor(r);return this.state!==a?g(e,this.state===s?A:t,this.outcome):this.queue.push(new B(e,A,t)),e},B.prototype.callFulfilled=function(A){i.resolve(this.promise,A)},B.prototype.otherCallFulfilled=function(A){g(this.promise,this.onFulfilled,A)},B.prototype.callRejected=function(A){i.reject(this.promise,A)},B.prototype.otherCallRejected=function(A){g(this.promise,this.onRejected,A)},i.resolve=function(A,t){var e=w(l,t);if("error"===e.status)return i.reject(A,e.value);var n=e.value;if(n)u(A,n);else{A.state=s,A.outcome=t;for(var r=-1,o=A.queue.length;++r<o;)A.queue[r].callFulfilled(t)}return A},i.reject=function(A,t){A.state=o,A.outcome=t;for(var e=-1,n=A.queue.length;++e<n;)A.queue[e].callRejected(t);return A},c.resolve=function(A){return A instanceof this?A:i.resolve(new this(r),A)},c.reject=function(A){var t=new this(r);return i.reject(t,A)},c.all=function(A){var t=this;if("[object Array]"!==Object.prototype.toString.call(A))return this.reject(new TypeError("must be an array"));var e=A.length,n=!1;if(!e)return this.resolve([]);for(var o=new Array(e),s=0,a=-1,c=new this(r);++a<e;)B(A[a],a);return c;function B(A,r){t.resolve(A).then((function(A){o[r]=A,++s!==e||n||(n=!0,i.resolve(c,o))}),(function(A){n||(n=!0,i.reject(c,A))}))}},c.race=function(A){if("[object Array]"!==Object.prototype.toString.call(A))return this.reject(new TypeError("must be an array"));var t=A.length,e=!1;if(!t)return this.resolve([]);for(var n,o=-1,s=new this(r);++o<t;)n=A[o],this.resolve(n).then((function(A){e||(e=!0,i.resolve(s,A))}),(function(A){e||(e=!0,i.reject(s,A))}));return s}},{immediate:36}],38:[function(A,t,e){"use strict";var n={};(0,A("./lib/utils/common").assign)(n,A("./lib/deflate"),A("./lib/inflate"),A("./lib/zlib/constants")),t.exports=n},{"./lib/deflate":39,"./lib/inflate":40,"./lib/utils/common":41,"./lib/zlib/constants":44}],39:[function(A,t,e){"use strict";var n=A("./zlib/deflate"),r=A("./utils/common"),i=A("./utils/strings"),o=A("./zlib/messages"),s=A("./zlib/zstream"),a=Object.prototype.toString,c=0,B=-1,g=0,l=8;function u(A){if(!(this instanceof u))return new u(A);this.options=r.assign({level:B,method:l,chunkSize:16384,windowBits:15,memLevel:8,strategy:g,to:""},A||{});var t=this.options;t.raw&&0<t.windowBits?t.windowBits=-t.windowBits:t.gzip&&0<t.windowBits&&t.windowBits<16&&(t.windowBits+=16),this.err=0,this.msg="",this.ended=!1,this.chunks=[],this.strm=new s,this.strm.avail_out=0;var e=n.deflateInit2(this.strm,t.level,t.method,t.windowBits,t.memLevel,t.strategy);if(e!==c)throw new Error(o[e]);if(t.header&&n.deflateSetHeader(this.strm,t.header),t.dictionary){var w;if(w="string"==typeof t.dictionary?i.string2buf(t.dictionary):"[object ArrayBuffer]"===a.call(t.dictionary)?new Uint8Array(t.dictionary):t.dictionary,(e=n.deflateSetDictionary(this.strm,w))!==c)throw new Error(o[e]);this._dict_set=!0}}function w(A,t){var e=new u(t);if(e.push(A,!0),e.err)throw e.msg||o[e.err];return e.result}u.prototype.push=function(A,t){var e,o,s=this.strm,B=this.options.chunkSize;if(this.ended)return!1;o=t===~~t?t:!0===t?4:0,"string"==typeof A?s.input=i.string2buf(A):"[object ArrayBuffer]"===a.call(A)?s.input=new Uint8Array(A):s.input=A,s.next_in=0,s.avail_in=s.input.length;do{if(0===s.avail_out&&(s.output=new r.Buf8(B),s.next_out=0,s.avail_out=B),1!==(e=n.deflate(s,o))&&e!==c)return this.onEnd(e),!(this.ended=!0);0!==s.avail_out&&(0!==s.avail_in||4!==o&&2!==o)||("string"===this.options.to?this.onData(i.buf2binstring(r.shrinkBuf(s.output,s.next_out))):this.onData(r.shrinkBuf(s.output,s.next_out)))}while((0<s.avail_in||0===s.avail_out)&&1!==e);return 4===o?(e=n.deflateEnd(this.strm),this.onEnd(e),this.ended=!0,e===c):2!==o||(this.onEnd(c),!(s.avail_out=0))},u.prototype.onData=function(A){this.chunks.push(A)},u.prototype.onEnd=function(A){A===c&&("string"===this.options.to?this.result=this.chunks.join(""):this.result=r.flattenChunks(this.chunks)),this.chunks=[],this.err=A,this.msg=this.strm.msg},e.Deflate=u,e.deflate=w,e.deflateRaw=function(A,t){return(t=t||{}).raw=!0,w(A,t)},e.gzip=function(A,t){return(t=t||{}).gzip=!0,w(A,t)}},{"./utils/common":41,"./utils/strings":42,"./zlib/deflate":46,"./zlib/messages":51,"./zlib/zstream":53}],40:[function(A,t,e){"use strict";var n=A("./zlib/inflate"),r=A("./utils/common"),i=A("./utils/strings"),o=A("./zlib/constants"),s=A("./zlib/messages"),a=A("./zlib/zstream"),c=A("./zlib/gzheader"),B=Object.prototype.toString;function g(A){if(!(this instanceof g))return new g(A);this.options=r.assign({chunkSize:16384,windowBits:0,to:""},A||{});var t=this.options;t.raw&&0<=t.windowBits&&t.windowBits<16&&(t.windowBits=-t.windowBits,0===t.windowBits&&(t.windowBits=-15)),!(0<=t.windowBits&&t.windowBits<16)||A&&A.windowBits||(t.windowBits+=32),15<t.windowBits&&t.windowBits<48&&0==(15&t.windowBits)&&(t.windowBits|=15),this.err=0,this.msg="",this.ended=!1,this.chunks=[],this.strm=new a,this.strm.avail_out=0;var e=n.inflateInit2(this.strm,t.windowBits);if(e!==o.Z_OK)throw new Error(s[e]);this.header=new c,n.inflateGetHeader(this.strm,this.header)}function l(A,t){var e=new g(t);if(e.push(A,!0),e.err)throw e.msg||s[e.err];return e.result}g.prototype.push=function(A,t){var e,s,a,c,g,l,u=this.strm,w=this.options.chunkSize,h=this.options.dictionary,E=!1;if(this.ended)return!1;s=t===~~t?t:!0===t?o.Z_FINISH:o.Z_NO_FLUSH,"string"==typeof A?u.input=i.binstring2buf(A):"[object ArrayBuffer]"===B.call(A)?u.input=new Uint8Array(A):u.input=A,u.next_in=0,u.avail_in=u.input.length;do{if(0===u.avail_out&&(u.output=new r.Buf8(w),u.next_out=0,u.avail_out=w),(e=n.inflate(u,o.Z_NO_FLUSH))===o.Z_NEED_DICT&&h&&(l="string"==typeof h?i.string2buf(h):"[object ArrayBuffer]"===B.call(h)?new Uint8Array(h):h,e=n.inflateSetDictionary(this.strm,l)),e===o.Z_BUF_ERROR&&!0===E&&(e=o.Z_OK,E=!1),e!==o.Z_STREAM_END&&e!==o.Z_OK)return this.onEnd(e),!(this.ended=!0);u.next_out&&(0!==u.avail_out&&e!==o.Z_STREAM_END&&(0!==u.avail_in||s!==o.Z_FINISH&&s!==o.Z_SYNC_FLUSH)||("string"===this.options.to?(a=i.utf8border(u.output,u.next_out),c=u.next_out-a,g=i.buf2string(u.output,a),u.next_out=c,u.avail_out=w-c,c&&r.arraySet(u.output,u.output,a,c,0),this.onData(g)):this.onData(r.shrinkBuf(u.output,u.next_out)))),0===u.avail_in&&0===u.avail_out&&(E=!0)}while((0<u.avail_in||0===u.avail_out)&&e!==o.Z_STREAM_END);return e===o.Z_STREAM_END&&(s=o.Z_FINISH),s===o.Z_FINISH?(e=n.inflateEnd(this.strm),this.onEnd(e),this.ended=!0,e===o.Z_OK):s!==o.Z_SYNC_FLUSH||(this.onEnd(o.Z_OK),!(u.avail_out=0))},g.prototype.onData=function(A){this.chunks.push(A)},g.prototype.onEnd=function(A){A===o.Z_OK&&("string"===this.options.to?this.result=this.chunks.join(""):this.result=r.flattenChunks(this.chunks)),this.chunks=[],this.err=A,this.msg=this.strm.msg},e.Inflate=g,e.inflate=l,e.inflateRaw=function(A,t){return(t=t||{}).raw=!0,l(A,t)},e.ungzip=l},{"./utils/common":41,"./utils/strings":42,"./zlib/constants":44,"./zlib/gzheader":47,"./zlib/inflate":49,"./zlib/messages":51,"./zlib/zstream":53}],41:[function(A,t,e){"use strict";var n="undefined"!=typeof Uint8Array&&"undefined"!=typeof Uint16Array&&"undefined"!=typeof Int32Array;e.assign=function(A){for(var t=Array.prototype.slice.call(arguments,1);t.length;){var e=t.shift();if(e){if("object"!=typeof e)throw new TypeError(e+"must be non-object");for(var n in e)e.hasOwnProperty(n)&&(A[n]=e[n])}}return A},e.shrinkBuf=function(A,t){return A.length===t?A:A.subarray?A.subarray(0,t):(A.length=t,A)};var r={arraySet:function(A,t,e,n,r){if(t.subarray&&A.subarray)A.set(t.subarray(e,e+n),r);else for(var i=0;i<n;i++)A[r+i]=t[e+i]},flattenChunks:function(A){var t,e,n,r,i,o;for(t=n=0,e=A.length;t<e;t++)n+=A[t].length;for(o=new Uint8Array(n),t=r=0,e=A.length;t<e;t++)i=A[t],o.set(i,r),r+=i.length;return o}},i={arraySet:function(A,t,e,n,r){for(var i=0;i<n;i++)A[r+i]=t[e+i]},flattenChunks:function(A){return[].concat.apply([],A)}};e.setTyped=function(A){A?(e.Buf8=Uint8Array,e.Buf16=Uint16Array,e.Buf32=Int32Array,e.assign(e,r)):(e.Buf8=Array,e.Buf16=Array,e.Buf32=Array,e.assign(e,i))},e.setTyped(n)},{}],42:[function(A,t,e){"use strict";var n=A("./common"),r=!0,i=!0;try{String.fromCharCode.apply(null,[0])}catch(A){r=!1}try{String.fromCharCode.apply(null,new Uint8Array(1))}catch(A){i=!1}for(var o=new n.Buf8(256),s=0;s<256;s++)o[s]=252<=s?6:248<=s?5:240<=s?4:224<=s?3:192<=s?2:1;function a(A,t){if(t<65537&&(A.subarray&&i||!A.subarray&&r))return String.fromCharCode.apply(null,n.shrinkBuf(A,t));for(var e="",o=0;o<t;o++)e+=String.fromCharCode(A[o]);return e}o[254]=o[254]=1,e.string2buf=function(A){var t,e,r,i,o,s=A.length,a=0;for(i=0;i<s;i++)55296==(64512&(e=A.charCodeAt(i)))&&i+1<s&&56320==(64512&(r=A.charCodeAt(i+1)))&&(e=65536+(e-55296<<10)+(r-56320),i++),a+=e<128?1:e<2048?2:e<65536?3:4;for(t=new n.Buf8(a),i=o=0;o<a;i++)55296==(64512&(e=A.charCodeAt(i)))&&i+1<s&&56320==(64512&(r=A.charCodeAt(i+1)))&&(e=65536+(e-55296<<10)+(r-56320),i++),e<128?t[o++]=e:(e<2048?t[o++]=192|e>>>6:(e<65536?t[o++]=224|e>>>12:(t[o++]=240|e>>>18,t[o++]=128|e>>>12&63),t[o++]=128|e>>>6&63),t[o++]=128|63&e);return t},e.buf2binstring=function(A){return a(A,A.length)},e.binstring2buf=function(A){for(var t=new n.Buf8(A.length),e=0,r=t.length;e<r;e++)t[e]=A.charCodeAt(e);return t},e.buf2string=function(A,t){var e,n,r,i,s=t||A.length,c=new Array(2*s);for(e=n=0;e<s;)if((r=A[e++])<128)c[n++]=r;else if(4<(i=o[r]))c[n++]=65533,e+=i-1;else{for(r&=2===i?31:3===i?15:7;1<i&&e<s;)r=r<<6|63&A[e++],i--;1<i?c[n++]=65533:r<65536?c[n++]=r:(r-=65536,c[n++]=55296|r>>10&1023,c[n++]=56320|1023&r)}return a(c,n)},e.utf8border=function(A,t){var e;for((t=t||A.length)>A.length&&(t=A.length),e=t-1;0<=e&&128==(192&A[e]);)e--;return e<0||0===e?t:e+o[A[e]]>t?e:t}},{"./common":41}],43:[function(A,t,e){"use strict";t.exports=function(A,t,e,n){for(var r=65535&A|0,i=A>>>16&65535|0,o=0;0!==e;){for(e-=o=2e3<e?2e3:e;i=i+(r=r+t[n++]|0)|0,--o;);r%=65521,i%=65521}return r|i<<16|0}},{}],44:[function(A,t,e){"use strict";t.exports={Z_NO_FLUSH:0,Z_PARTIAL_FLUSH:1,Z_SYNC_FLUSH:2,Z_FULL_FLUSH:3,Z_FINISH:4,Z_BLOCK:5,Z_TREES:6,Z_OK:0,Z_STREAM_END:1,Z_NEED_DICT:2,Z_ERRNO:-1,Z_STREAM_ERROR:-2,Z_DATA_ERROR:-3,Z_BUF_ERROR:-5,Z_NO_COMPRESSION:0,Z_BEST_SPEED:1,Z_BEST_COMPRESSION:9,Z_DEFAULT_COMPRESSION:-1,Z_FILTERED:1,Z_HUFFMAN_ONLY:2,Z_RLE:3,Z_FIXED:4,Z_DEFAULT_STRATEGY:0,Z_BINARY:0,Z_TEXT:1,Z_UNKNOWN:2,Z_DEFLATED:8}},{}],45:[function(A,t,e){"use strict";var n=function(){for(var A,t=[],e=0;e<256;e++){A=e;for(var n=0;n<8;n++)A=1&A?3988292384^A>>>1:A>>>1;t[e]=A}return t}();t.exports=function(A,t,e,r){var i=n,o=r+e;A^=-1;for(var s=r;s<o;s++)A=A>>>8^i[255&(A^t[s])];return-1^A}},{}],46:[function(A,t,e){"use strict";var n,r=A("../utils/common"),i=A("./trees"),o=A("./adler32"),s=A("./crc32"),a=A("./messages"),c=0,B=0,g=-2,l=2,u=8,w=286,h=30,E=19,f=2*w+1,Q=15,d=3,C=258,M=C+d+1,I=42,p=113;function D(A,t){return A.msg=a[t],t}function y(A){return(A<<1)-(4<A?9:0)}function v(A){for(var t=A.length;0<=--t;)A[t]=0}function m(A){var t=A.state,e=t.pending;e>A.avail_out&&(e=A.avail_out),0!==e&&(r.arraySet(A.output,t.pending_buf,t.pending_out,e,A.next_out),A.next_out+=e,t.pending_out+=e,A.total_out+=e,A.avail_out-=e,t.pending-=e,0===t.pending&&(t.pending_out=0))}function F(A,t){i._tr_flush_block(A,0<=A.block_start?A.block_start:-1,A.strstart-A.block_start,t),A.block_start=A.strstart,m(A.strm)}function Y(A,t){A.pending_buf[A.pending++]=t}function b(A,t){A.pending_buf[A.pending++]=t>>>8&255,A.pending_buf[A.pending++]=255&t}function z(A,t){var e,n,r=A.max_chain_length,i=A.strstart,o=A.prev_length,s=A.nice_match,a=A.strstart>A.w_size-M?A.strstart-(A.w_size-M):0,c=A.window,B=A.w_mask,g=A.prev,l=A.strstart+C,u=c[i+o-1],w=c[i+o];A.prev_length>=A.good_match&&(r>>=2),s>A.lookahead&&(s=A.lookahead);do{if(c[(e=t)+o]===w&&c[e+o-1]===u&&c[e]===c[i]&&c[++e]===c[i+1]){i+=2,e++;do{}while(c[++i]===c[++e]&&c[++i]===c[++e]&&c[++i]===c[++e]&&c[++i]===c[++e]&&c[++i]===c[++e]&&c[++i]===c[++e]&&c[++i]===c[++e]&&c[++i]===c[++e]&&i<l);if(n=C-(l-i),i=l-C,o<n){if(A.match_start=t,s<=(o=n))break;u=c[i+o-1],w=c[i+o]}}}while((t=g[t&B])>a&&0!=--r);return o<=A.lookahead?o:A.lookahead}function U(A){var t,e,n,i,a,c,B,g,l,u,w=A.w_size;do{if(i=A.window_size-A.lookahead-A.strstart,A.strstart>=w+(w-M)){for(r.arraySet(A.window,A.window,w,w,0),A.match_start-=w,A.strstart-=w,A.block_start-=w,t=e=A.hash_size;n=A.head[--t],A.head[t]=w<=n?n-w:0,--e;);for(t=e=w;n=A.prev[--t],A.prev[t]=w<=n?n-w:0,--e;);i+=w}if(0===A.strm.avail_in)break;if(c=A.strm,B=A.window,g=A.strstart+A.lookahead,u=void 0,(l=i)<(u=c.avail_in)&&(u=l),e=0===u?0:(c.avail_in-=u,r.arraySet(B,c.input,c.next_in,u,g),1===c.state.wrap?c.adler=o(c.adler,B,u,g):2===c.state.wrap&&(c.adler=s(c.adler,B,u,g)),c.next_in+=u,c.total_in+=u,u),A.lookahead+=e,A.lookahead+A.insert>=d)for(a=A.strstart-A.insert,A.ins_h=A.window[a],A.ins_h=(A.ins_h<<A.hash_shift^A.window[a+1])&A.hash_mask;A.insert&&(A.ins_h=(A.ins_h<<A.hash_shift^A.window[a+d-1])&A.hash_mask,A.prev[a&A.w_mask]=A.head[A.ins_h],A.head[A.ins_h]=a,a++,A.insert--,!(A.lookahead+A.insert<d)););}while(A.lookahead<M&&0!==A.strm.avail_in)}function S(A,t){for(var e,n;;){if(A.lookahead<M){if(U(A),A.lookahead<M&&t===c)return 1;if(0===A.lookahead)break}if(e=0,A.lookahead>=d&&(A.ins_h=(A.ins_h<<A.hash_shift^A.window[A.strstart+d-1])&A.hash_mask,e=A.prev[A.strstart&A.w_mask]=A.head[A.ins_h],A.head[A.ins_h]=A.strstart),0!==e&&A.strstart-e<=A.w_size-M&&(A.match_length=z(A,e)),A.match_length>=d)if(n=i._tr_tally(A,A.strstart-A.match_start,A.match_length-d),A.lookahead-=A.match_length,A.match_length<=A.max_lazy_match&&A.lookahead>=d){for(A.match_length--;A.strstart++,A.ins_h=(A.ins_h<<A.hash_shift^A.window[A.strstart+d-1])&A.hash_mask,e=A.prev[A.strstart&A.w_mask]=A.head[A.ins_h],A.head[A.ins_h]=A.strstart,0!=--A.match_length;);A.strstart++}else A.strstart+=A.match_length,A.match_length=0,A.ins_h=A.window[A.strstart],A.ins_h=(A.ins_h<<A.hash_shift^A.window[A.strstart+1])&A.hash_mask;else n=i._tr_tally(A,0,A.window[A.strstart]),A.lookahead--,A.strstart++;if(n&&(F(A,!1),0===A.strm.avail_out))return 1}return A.insert=A.strstart<d-1?A.strstart:d-1,4===t?(F(A,!0),0===A.strm.avail_out?3:4):A.last_lit&&(F(A,!1),0===A.strm.avail_out)?1:2}function x(A,t){for(var e,n,r;;){if(A.lookahead<M){if(U(A),A.lookahead<M&&t===c)return 1;if(0===A.lookahead)break}if(e=0,A.lookahead>=d&&(A.ins_h=(A.ins_h<<A.hash_shift^A.window[A.strstart+d-1])&A.hash_mask,e=A.prev[A.strstart&A.w_mask]=A.head[A.ins_h],A.head[A.ins_h]=A.strstart),A.prev_length=A.match_length,A.prev_match=A.match_start,A.match_length=d-1,0!==e&&A.prev_length<A.max_lazy_match&&A.strstart-e<=A.w_size-M&&(A.match_length=z(A,e),A.match_length<=5&&(1===A.strategy||A.match_length===d&&4096<A.strstart-A.match_start)&&(A.match_length=d-1)),A.prev_length>=d&&A.match_length<=A.prev_length){for(r=A.strstart+A.lookahead-d,n=i._tr_tally(A,A.strstart-1-A.prev_match,A.prev_length-d),A.lookahead-=A.prev_length-1,A.prev_length-=2;++A.strstart<=r&&(A.ins_h=(A.ins_h<<A.hash_shift^A.window[A.strstart+d-1])&A.hash_mask,e=A.prev[A.strstart&A.w_mask]=A.head[A.ins_h],A.head[A.ins_h]=A.strstart),0!=--A.prev_length;);if(A.match_available=0,A.match_length=d-1,A.strstart++,n&&(F(A,!1),0===A.strm.avail_out))return 1}else if(A.match_available){if((n=i._tr_tally(A,0,A.window[A.strstart-1]))&&F(A,!1),A.strstart++,A.lookahead--,0===A.strm.avail_out)return 1}else A.match_available=1,A.strstart++,A.lookahead--}return A.match_available&&(n=i._tr_tally(A,0,A.window[A.strstart-1]),A.match_available=0),A.insert=A.strstart<d-1?A.strstart:d-1,4===t?(F(A,!0),0===A.strm.avail_out?3:4):A.last_lit&&(F(A,!1),0===A.strm.avail_out)?1:2}function T(A,t,e,n,r){this.good_length=A,this.max_lazy=t,this.nice_length=e,this.max_chain=n,this.func=r}function P(){this.strm=null,this.status=0,this.pending_buf=null,this.pending_buf_size=0,this.pending_out=0,this.pending=0,this.wrap=0,this.gzhead=null,this.gzindex=0,this.method=u,this.last_flush=-1,this.w_size=0,this.w_bits=0,this.w_mask=0,this.window=null,this.window_size=0,this.prev=null,this.head=null,this.ins_h=0,this.hash_size=0,this.hash_bits=0,this.hash_mask=0,this.hash_shift=0,this.block_start=0,this.match_length=0,this.prev_match=0,this.match_available=0,this.strstart=0,this.match_start=0,this.lookahead=0,this.prev_length=0,this.max_chain_length=0,this.max_lazy_match=0,this.level=0,this.strategy=0,this.good_match=0,this.nice_match=0,this.dyn_ltree=new r.Buf16(2*f),this.dyn_dtree=new r.Buf16(2*(2*h+1)),this.bl_tree=new r.Buf16(2*(2*E+1)),v(this.dyn_ltree),v(this.dyn_dtree),v(this.bl_tree),this.l_desc=null,this.d_desc=null,this.bl_desc=null,this.bl_count=new r.Buf16(Q+1),this.heap=new r.Buf16(2*w+1),v(this.heap),this.heap_len=0,this.heap_max=0,this.depth=new r.Buf16(2*w+1),v(this.depth),this.l_buf=0,this.lit_bufsize=0,this.last_lit=0,this.d_buf=0,this.opt_len=0,this.static_len=0,this.matches=0,this.insert=0,this.bi_buf=0,this.bi_valid=0}function N(A){var t;return A&&A.state?(A.total_in=A.total_out=0,A.data_type=l,(t=A.state).pending=0,t.pending_out=0,t.wrap<0&&(t.wrap=-t.wrap),t.status=t.wrap?I:p,A.adler=2===t.wrap?0:1,t.last_flush=c,i._tr_init(t),B):D(A,g)}function R(A){var t=N(A);return t===B&&function(A){A.window_size=2*A.w_size,v(A.head),A.max_lazy_match=n[A.level].max_lazy,A.good_match=n[A.level].good_length,A.nice_match=n[A.level].nice_length,A.max_chain_length=n[A.level].max_chain,A.strstart=0,A.block_start=0,A.lookahead=0,A.insert=0,A.match_length=A.prev_length=d-1,A.match_available=0,A.ins_h=0}(A.state),t}function G(A,t,e,n,i,o){if(!A)return g;var s=1;if(-1===t&&(t=6),n<0?(s=0,n=-n):15<n&&(s=2,n-=16),i<1||9<i||e!==u||n<8||15<n||t<0||9<t||o<0||4<o)return D(A,g);8===n&&(n=9);var a=new P;return(A.state=a).strm=A,a.wrap=s,a.gzhead=null,a.w_bits=n,a.w_size=1<<a.w_bits,a.w_mask=a.w_size-1,a.hash_bits=i+7,a.hash_size=1<<a.hash_bits,a.hash_mask=a.hash_size-1,a.hash_shift=~~((a.hash_bits+d-1)/d),a.window=new r.Buf8(2*a.w_size),a.head=new r.Buf16(a.hash_size),a.prev=new r.Buf16(a.w_size),a.lit_bufsize=1<<i+6,a.pending_buf_size=4*a.lit_bufsize,a.pending_buf=new r.Buf8(a.pending_buf_size),a.d_buf=1*a.lit_bufsize,a.l_buf=3*a.lit_bufsize,a.level=t,a.strategy=o,a.method=e,R(A)}n=[new T(0,0,0,0,(function(A,t){var e=65535;for(e>A.pending_buf_size-5&&(e=A.pending_buf_size-5);;){if(A.lookahead<=1){if(U(A),0===A.lookahead&&t===c)return 1;if(0===A.lookahead)break}A.strstart+=A.lookahead,A.lookahead=0;var n=A.block_start+e;if((0===A.strstart||A.strstart>=n)&&(A.lookahead=A.strstart-n,A.strstart=n,F(A,!1),0===A.strm.avail_out))return 1;if(A.strstart-A.block_start>=A.w_size-M&&(F(A,!1),0===A.strm.avail_out))return 1}return A.insert=0,4===t?(F(A,!0),0===A.strm.avail_out?3:4):(A.strstart>A.block_start&&(F(A,!1),A.strm.avail_out),1)})),new T(4,4,8,4,S),new T(4,5,16,8,S),new T(4,6,32,32,S),new T(4,4,16,16,x),new T(8,16,32,32,x),new T(8,16,128,128,x),new T(8,32,128,256,x),new T(32,128,258,1024,x),new T(32,258,258,4096,x)],e.deflateInit=function(A,t){return G(A,t,u,15,8,0)},e.deflateInit2=G,e.deflateReset=R,e.deflateResetKeep=N,e.deflateSetHeader=function(A,t){return A&&A.state?2!==A.state.wrap?g:(A.state.gzhead=t,B):g},e.deflate=function(A,t){var e,r,o,a;if(!A||!A.state||5<t||t<0)return A?D(A,g):g;if(r=A.state,!A.output||!A.input&&0!==A.avail_in||666===r.status&&4!==t)return D(A,0===A.avail_out?-5:g);if(r.strm=A,e=r.last_flush,r.last_flush=t,r.status===I)if(2===r.wrap)A.adler=0,Y(r,31),Y(r,139),Y(r,8),r.gzhead?(Y(r,(r.gzhead.text?1:0)+(r.gzhead.hcrc?2:0)+(r.gzhead.extra?4:0)+(r.gzhead.name?8:0)+(r.gzhead.comment?16:0)),Y(r,255&r.gzhead.time),Y(r,r.gzhead.time>>8&255),Y(r,r.gzhead.time>>16&255),Y(r,r.gzhead.time>>24&255),Y(r,9===r.level?2:2<=r.strategy||r.level<2?4:0),Y(r,255&r.gzhead.os),r.gzhead.extra&&r.gzhead.extra.length&&(Y(r,255&r.gzhead.extra.length),Y(r,r.gzhead.extra.length>>8&255)),r.gzhead.hcrc&&(A.adler=s(A.adler,r.pending_buf,r.pending,0)),r.gzindex=0,r.status=69):(Y(r,0),Y(r,0),Y(r,0),Y(r,0),Y(r,0),Y(r,9===r.level?2:2<=r.strategy||r.level<2?4:0),Y(r,3),r.status=p);else{var l=u+(r.w_bits-8<<4)<<8;l|=(2<=r.strategy||r.level<2?0:r.level<6?1:6===r.level?2:3)<<6,0!==r.strstart&&(l|=32),l+=31-l%31,r.status=p,b(r,l),0!==r.strstart&&(b(r,A.adler>>>16),b(r,65535&A.adler)),A.adler=1}if(69===r.status)if(r.gzhead.extra){for(o=r.pending;r.gzindex<(65535&r.gzhead.extra.length)&&(r.pending!==r.pending_buf_size||(r.gzhead.hcrc&&r.pending>o&&(A.adler=s(A.adler,r.pending_buf,r.pending-o,o)),m(A),o=r.pending,r.pending!==r.pending_buf_size));)Y(r,255&r.gzhead.extra[r.gzindex]),r.gzindex++;r.gzhead.hcrc&&r.pending>o&&(A.adler=s(A.adler,r.pending_buf,r.pending-o,o)),r.gzindex===r.gzhead.extra.length&&(r.gzindex=0,r.status=73)}else r.status=73;if(73===r.status)if(r.gzhead.name){o=r.pending;do{if(r.pending===r.pending_buf_size&&(r.gzhead.hcrc&&r.pending>o&&(A.adler=s(A.adler,r.pending_buf,r.pending-o,o)),m(A),o=r.pending,r.pending===r.pending_buf_size)){a=1;break}a=r.gzindex<r.gzhead.name.length?255&r.gzhead.name.charCodeAt(r.gzindex++):0,Y(r,a)}while(0!==a);r.gzhead.hcrc&&r.pending>o&&(A.adler=s(A.adler,r.pending_buf,r.pending-o,o)),0===a&&(r.gzindex=0,r.status=91)}else r.status=91;if(91===r.status)if(r.gzhead.comment){o=r.pending;do{if(r.pending===r.pending_buf_size&&(r.gzhead.hcrc&&r.pending>o&&(A.adler=s(A.adler,r.pending_buf,r.pending-o,o)),m(A),o=r.pending,r.pending===r.pending_buf_size)){a=1;break}a=r.gzindex<r.gzhead.comment.length?255&r.gzhead.comment.charCodeAt(r.gzindex++):0,Y(r,a)}while(0!==a);r.gzhead.hcrc&&r.pending>o&&(A.adler=s(A.adler,r.pending_buf,r.pending-o,o)),0===a&&(r.status=103)}else r.status=103;if(103===r.status&&(r.gzhead.hcrc?(r.pending+2>r.pending_buf_size&&m(A),r.pending+2<=r.pending_buf_size&&(Y(r,255&A.adler),Y(r,A.adler>>8&255),A.adler=0,r.status=p)):r.status=p),0!==r.pending){if(m(A),0===A.avail_out)return r.last_flush=-1,B}else if(0===A.avail_in&&y(t)<=y(e)&&4!==t)return D(A,-5);if(666===r.status&&0!==A.avail_in)return D(A,-5);if(0!==A.avail_in||0!==r.lookahead||t!==c&&666!==r.status){var w=2===r.strategy?function(A,t){for(var e;;){if(0===A.lookahead&&(U(A),0===A.lookahead)){if(t===c)return 1;break}if(A.match_length=0,e=i._tr_tally(A,0,A.window[A.strstart]),A.lookahead--,A.strstart++,e&&(F(A,!1),0===A.strm.avail_out))return 1}return A.insert=0,4===t?(F(A,!0),0===A.strm.avail_out?3:4):A.last_lit&&(F(A,!1),0===A.strm.avail_out)?1:2}(r,t):3===r.strategy?function(A,t){for(var e,n,r,o,s=A.window;;){if(A.lookahead<=C){if(U(A),A.lookahead<=C&&t===c)return 1;if(0===A.lookahead)break}if(A.match_length=0,A.lookahead>=d&&0<A.strstart&&(n=s[r=A.strstart-1])===s[++r]&&n===s[++r]&&n===s[++r]){o=A.strstart+C;do{}while(n===s[++r]&&n===s[++r]&&n===s[++r]&&n===s[++r]&&n===s[++r]&&n===s[++r]&&n===s[++r]&&n===s[++r]&&r<o);A.match_length=C-(o-r),A.match_length>A.lookahead&&(A.match_length=A.lookahead)}if(A.match_length>=d?(e=i._tr_tally(A,1,A.match_length-d),A.lookahead-=A.match_length,A.strstart+=A.match_length,A.match_length=0):(e=i._tr_tally(A,0,A.window[A.strstart]),A.lookahead--,A.strstart++),e&&(F(A,!1),0===A.strm.avail_out))return 1}return A.insert=0,4===t?(F(A,!0),0===A.strm.avail_out?3:4):A.last_lit&&(F(A,!1),0===A.strm.avail_out)?1:2}(r,t):n[r.level].func(r,t);if(3!==w&&4!==w||(r.status=666),1===w||3===w)return 0===A.avail_out&&(r.last_flush=-1),B;if(2===w&&(1===t?i._tr_align(r):5!==t&&(i._tr_stored_block(r,0,0,!1),3===t&&(v(r.head),0===r.lookahead&&(r.strstart=0,r.block_start=0,r.insert=0))),m(A),0===A.avail_out))return r.last_flush=-1,B}return 4!==t?B:r.wrap<=0?1:(2===r.wrap?(Y(r,255&A.adler),Y(r,A.adler>>8&255),Y(r,A.adler>>16&255),Y(r,A.adler>>24&255),Y(r,255&A.total_in),Y(r,A.total_in>>8&255),Y(r,A.total_in>>16&255),Y(r,A.total_in>>24&255)):(b(r,A.adler>>>16),b(r,65535&A.adler)),m(A),0<r.wrap&&(r.wrap=-r.wrap),0!==r.pending?B:1)},e.deflateEnd=function(A){var t;return A&&A.state?(t=A.state.status)!==I&&69!==t&&73!==t&&91!==t&&103!==t&&t!==p&&666!==t?D(A,g):(A.state=null,t===p?D(A,-3):B):g},e.deflateSetDictionary=function(A,t){var e,n,i,s,a,c,l,u,w=t.length;if(!A||!A.state)return g;if(2===(s=(e=A.state).wrap)||1===s&&e.status!==I||e.lookahead)return g;for(1===s&&(A.adler=o(A.adler,t,w,0)),e.wrap=0,w>=e.w_size&&(0===s&&(v(e.head),e.strstart=0,e.block_start=0,e.insert=0),u=new r.Buf8(e.w_size),r.arraySet(u,t,w-e.w_size,e.w_size,0),t=u,w=e.w_size),a=A.avail_in,c=A.next_in,l=A.input,A.avail_in=w,A.next_in=0,A.input=t,U(e);e.lookahead>=d;){for(n=e.strstart,i=e.lookahead-(d-1);e.ins_h=(e.ins_h<<e.hash_shift^e.window[n+d-1])&e.hash_mask,e.prev[n&e.w_mask]=e.head[e.ins_h],e.head[e.ins_h]=n,n++,--i;);e.strstart=n,e.lookahead=d-1,U(e)}return e.strstart+=e.lookahead,e.block_start=e.strstart,e.insert=e.lookahead,e.lookahead=0,e.match_length=e.prev_length=d-1,e.match_available=0,A.next_in=c,A.input=l,A.avail_in=a,e.wrap=s,B},e.deflateInfo="pako deflate (from Nodeca project)"},{"../utils/common":41,"./adler32":43,"./crc32":45,"./messages":51,"./trees":52}],47:[function(A,t,e){"use strict";t.exports=function(){this.text=0,this.time=0,this.xflags=0,this.os=0,this.extra=null,this.extra_len=0,this.name="",this.comment="",this.hcrc=0,this.done=!1}},{}],48:[function(A,t,e){"use strict";t.exports=function(A,t){var e,n,r,i,o,s,a,c,B,g,l,u,w,h,E,f,Q,d,C,M,I,p,D,y,v;e=A.state,n=A.next_in,y=A.input,r=n+(A.avail_in-5),i=A.next_out,v=A.output,o=i-(t-A.avail_out),s=i+(A.avail_out-257),a=e.dmax,c=e.wsize,B=e.whave,g=e.wnext,l=e.window,u=e.hold,w=e.bits,h=e.lencode,E=e.distcode,f=(1<<e.lenbits)-1,Q=(1<<e.distbits)-1;A:do{w<15&&(u+=y[n++]<<w,w+=8,u+=y[n++]<<w,w+=8),d=h[u&f];t:for(;;){if(u>>>=C=d>>>24,w-=C,0==(C=d>>>16&255))v[i++]=65535&d;else{if(!(16&C)){if(0==(64&C)){d=h[(65535&d)+(u&(1<<C)-1)];continue t}if(32&C){e.mode=12;break A}A.msg="invalid literal/length code",e.mode=30;break A}M=65535&d,(C&=15)&&(w<C&&(u+=y[n++]<<w,w+=8),M+=u&(1<<C)-1,u>>>=C,w-=C),w<15&&(u+=y[n++]<<w,w+=8,u+=y[n++]<<w,w+=8),d=E[u&Q];e:for(;;){if(u>>>=C=d>>>24,w-=C,!(16&(C=d>>>16&255))){if(0==(64&C)){d=E[(65535&d)+(u&(1<<C)-1)];continue e}A.msg="invalid distance code",e.mode=30;break A}if(I=65535&d,w<(C&=15)&&(u+=y[n++]<<w,(w+=8)<C&&(u+=y[n++]<<w,w+=8)),a<(I+=u&(1<<C)-1)){A.msg="invalid distance too far back",e.mode=30;break A}if(u>>>=C,w-=C,(C=i-o)<I){if(B<(C=I-C)&&e.sane){A.msg="invalid distance too far back",e.mode=30;break A}if(D=l,(p=0)===g){if(p+=c-C,C<M){for(M-=C;v[i++]=l[p++],--C;);p=i-I,D=v}}else if(g<C){if(p+=c+g-C,(C-=g)<M){for(M-=C;v[i++]=l[p++],--C;);if(p=0,g<M){for(M-=C=g;v[i++]=l[p++],--C;);p=i-I,D=v}}}else if(p+=g-C,C<M){for(M-=C;v[i++]=l[p++],--C;);p=i-I,D=v}for(;2<M;)v[i++]=D[p++],v[i++]=D[p++],v[i++]=D[p++],M-=3;M&&(v[i++]=D[p++],1<M&&(v[i++]=D[p++]))}else{for(p=i-I;v[i++]=v[p++],v[i++]=v[p++],v[i++]=v[p++],2<(M-=3););M&&(v[i++]=v[p++],1<M&&(v[i++]=v[p++]))}break}}break}}while(n<r&&i<s);n-=M=w>>3,u&=(1<<(w-=M<<3))-1,A.next_in=n,A.next_out=i,A.avail_in=n<r?r-n+5:5-(n-r),A.avail_out=i<s?s-i+257:257-(i-s),e.hold=u,e.bits=w}},{}],49:[function(A,t,e){"use strict";var n=A("../utils/common"),r=A("./adler32"),i=A("./crc32"),o=A("./inffast"),s=A("./inftrees"),a=0,c=-2,B=1,g=852,l=592;function u(A){return(A>>>24&255)+(A>>>8&65280)+((65280&A)<<8)+((255&A)<<24)}function w(){this.mode=0,this.last=!1,this.wrap=0,this.havedict=!1,this.flags=0,this.dmax=0,this.check=0,this.total=0,this.head=null,this.wbits=0,this.wsize=0,this.whave=0,this.wnext=0,this.window=null,this.hold=0,this.bits=0,this.length=0,this.offset=0,this.extra=0,this.lencode=null,this.distcode=null,this.lenbits=0,this.distbits=0,this.ncode=0,this.nlen=0,this.ndist=0,this.have=0,this.next=null,this.lens=new n.Buf16(320),this.work=new n.Buf16(288),this.lendyn=null,this.distdyn=null,this.sane=0,this.back=0,this.was=0}function h(A){var t;return A&&A.state?(t=A.state,A.total_in=A.total_out=t.total=0,A.msg="",t.wrap&&(A.adler=1&t.wrap),t.mode=B,t.last=0,t.havedict=0,t.dmax=32768,t.head=null,t.hold=0,t.bits=0,t.lencode=t.lendyn=new n.Buf32(g),t.distcode=t.distdyn=new n.Buf32(l),t.sane=1,t.back=-1,a):c}function E(A){var t;return A&&A.state?((t=A.state).wsize=0,t.whave=0,t.wnext=0,h(A)):c}function f(A,t){var e,n;return A&&A.state?(n=A.state,t<0?(e=0,t=-t):(e=1+(t>>4),t<48&&(t&=15)),t&&(t<8||15<t)?c:(null!==n.window&&n.wbits!==t&&(n.window=null),n.wrap=e,n.wbits=t,E(A))):c}function Q(A,t){var e,n;return A?(n=new w,(A.state=n).window=null,(e=f(A,t))!==a&&(A.state=null),e):c}var d,C,M=!0;function I(A){if(M){var t;for(d=new n.Buf32(512),C=new n.Buf32(32),t=0;t<144;)A.lens[t++]=8;for(;t<256;)A.lens[t++]=9;for(;t<280;)A.lens[t++]=7;for(;t<288;)A.lens[t++]=8;for(s(1,A.lens,0,288,d,0,A.work,{bits:9}),t=0;t<32;)A.lens[t++]=5;s(2,A.lens,0,32,C,0,A.work,{bits:5}),M=!1}A.lencode=d,A.lenbits=9,A.distcode=C,A.distbits=5}function p(A,t,e,r){var i,o=A.state;return null===o.window&&(o.wsize=1<<o.wbits,o.wnext=0,o.whave=0,o.window=new n.Buf8(o.wsize)),r>=o.wsize?(n.arraySet(o.window,t,e-o.wsize,o.wsize,0),o.wnext=0,o.whave=o.wsize):(r<(i=o.wsize-o.wnext)&&(i=r),n.arraySet(o.window,t,e-r,i,o.wnext),(r-=i)?(n.arraySet(o.window,t,e-r,r,0),o.wnext=r,o.whave=o.wsize):(o.wnext+=i,o.wnext===o.wsize&&(o.wnext=0),o.whave<o.wsize&&(o.whave+=i))),0}e.inflateReset=E,e.inflateReset2=f,e.inflateResetKeep=h,e.inflateInit=function(A){return Q(A,15)},e.inflateInit2=Q,e.inflate=function(A,t){var e,g,l,w,h,E,f,Q,d,C,M,D,y,v,m,F,Y,b,z,U,S,x,T,P,N=0,R=new n.Buf8(4),G=[16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15];if(!A||!A.state||!A.output||!A.input&&0!==A.avail_in)return c;12===(e=A.state).mode&&(e.mode=13),h=A.next_out,l=A.output,f=A.avail_out,w=A.next_in,g=A.input,E=A.avail_in,Q=e.hold,d=e.bits,C=E,M=f,x=a;A:for(;;)switch(e.mode){case B:if(0===e.wrap){e.mode=13;break}for(;d<16;){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}if(2&e.wrap&&35615===Q){R[e.check=0]=255&Q,R[1]=Q>>>8&255,e.check=i(e.check,R,2,0),d=Q=0,e.mode=2;break}if(e.flags=0,e.head&&(e.head.done=!1),!(1&e.wrap)||(((255&Q)<<8)+(Q>>8))%31){A.msg="incorrect header check",e.mode=30;break}if(8!=(15&Q)){A.msg="unknown compression method",e.mode=30;break}if(d-=4,S=8+(15&(Q>>>=4)),0===e.wbits)e.wbits=S;else if(S>e.wbits){A.msg="invalid window size",e.mode=30;break}e.dmax=1<<S,A.adler=e.check=1,e.mode=512&Q?10:12,d=Q=0;break;case 2:for(;d<16;){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}if(e.flags=Q,8!=(255&e.flags)){A.msg="unknown compression method",e.mode=30;break}if(57344&e.flags){A.msg="unknown header flags set",e.mode=30;break}e.head&&(e.head.text=Q>>8&1),512&e.flags&&(R[0]=255&Q,R[1]=Q>>>8&255,e.check=i(e.check,R,2,0)),d=Q=0,e.mode=3;case 3:for(;d<32;){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}e.head&&(e.head.time=Q),512&e.flags&&(R[0]=255&Q,R[1]=Q>>>8&255,R[2]=Q>>>16&255,R[3]=Q>>>24&255,e.check=i(e.check,R,4,0)),d=Q=0,e.mode=4;case 4:for(;d<16;){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}e.head&&(e.head.xflags=255&Q,e.head.os=Q>>8),512&e.flags&&(R[0]=255&Q,R[1]=Q>>>8&255,e.check=i(e.check,R,2,0)),d=Q=0,e.mode=5;case 5:if(1024&e.flags){for(;d<16;){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}e.length=Q,e.head&&(e.head.extra_len=Q),512&e.flags&&(R[0]=255&Q,R[1]=Q>>>8&255,e.check=i(e.check,R,2,0)),d=Q=0}else e.head&&(e.head.extra=null);e.mode=6;case 6:if(1024&e.flags&&(E<(D=e.length)&&(D=E),D&&(e.head&&(S=e.head.extra_len-e.length,e.head.extra||(e.head.extra=new Array(e.head.extra_len)),n.arraySet(e.head.extra,g,w,D,S)),512&e.flags&&(e.check=i(e.check,g,D,w)),E-=D,w+=D,e.length-=D),e.length))break A;e.length=0,e.mode=7;case 7:if(2048&e.flags){if(0===E)break A;for(D=0;S=g[w+D++],e.head&&S&&e.length<65536&&(e.head.name+=String.fromCharCode(S)),S&&D<E;);if(512&e.flags&&(e.check=i(e.check,g,D,w)),E-=D,w+=D,S)break A}else e.head&&(e.head.name=null);e.length=0,e.mode=8;case 8:if(4096&e.flags){if(0===E)break A;for(D=0;S=g[w+D++],e.head&&S&&e.length<65536&&(e.head.comment+=String.fromCharCode(S)),S&&D<E;);if(512&e.flags&&(e.check=i(e.check,g,D,w)),E-=D,w+=D,S)break A}else e.head&&(e.head.comment=null);e.mode=9;case 9:if(512&e.flags){for(;d<16;){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}if(Q!==(65535&e.check)){A.msg="header crc mismatch",e.mode=30;break}d=Q=0}e.head&&(e.head.hcrc=e.flags>>9&1,e.head.done=!0),A.adler=e.check=0,e.mode=12;break;case 10:for(;d<32;){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}A.adler=e.check=u(Q),d=Q=0,e.mode=11;case 11:if(0===e.havedict)return A.next_out=h,A.avail_out=f,A.next_in=w,A.avail_in=E,e.hold=Q,e.bits=d,2;A.adler=e.check=1,e.mode=12;case 12:if(5===t||6===t)break A;case 13:if(e.last){Q>>>=7&d,d-=7&d,e.mode=27;break}for(;d<3;){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}switch(e.last=1&Q,d-=1,3&(Q>>>=1)){case 0:e.mode=14;break;case 1:if(I(e),e.mode=20,6!==t)break;Q>>>=2,d-=2;break A;case 2:e.mode=17;break;case 3:A.msg="invalid block type",e.mode=30}Q>>>=2,d-=2;break;case 14:for(Q>>>=7&d,d-=7&d;d<32;){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}if((65535&Q)!=(Q>>>16^65535)){A.msg="invalid stored block lengths",e.mode=30;break}if(e.length=65535&Q,d=Q=0,e.mode=15,6===t)break A;case 15:e.mode=16;case 16:if(D=e.length){if(E<D&&(D=E),f<D&&(D=f),0===D)break A;n.arraySet(l,g,w,D,h),E-=D,w+=D,f-=D,h+=D,e.length-=D;break}e.mode=12;break;case 17:for(;d<14;){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}if(e.nlen=257+(31&Q),Q>>>=5,d-=5,e.ndist=1+(31&Q),Q>>>=5,d-=5,e.ncode=4+(15&Q),Q>>>=4,d-=4,286<e.nlen||30<e.ndist){A.msg="too many length or distance symbols",e.mode=30;break}e.have=0,e.mode=18;case 18:for(;e.have<e.ncode;){for(;d<3;){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}e.lens[G[e.have++]]=7&Q,Q>>>=3,d-=3}for(;e.have<19;)e.lens[G[e.have++]]=0;if(e.lencode=e.lendyn,e.lenbits=7,T={bits:e.lenbits},x=s(0,e.lens,0,19,e.lencode,0,e.work,T),e.lenbits=T.bits,x){A.msg="invalid code lengths set",e.mode=30;break}e.have=0,e.mode=19;case 19:for(;e.have<e.nlen+e.ndist;){for(;F=(N=e.lencode[Q&(1<<e.lenbits)-1])>>>16&255,Y=65535&N,!((m=N>>>24)<=d);){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}if(Y<16)Q>>>=m,d-=m,e.lens[e.have++]=Y;else{if(16===Y){for(P=m+2;d<P;){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}if(Q>>>=m,d-=m,0===e.have){A.msg="invalid bit length repeat",e.mode=30;break}S=e.lens[e.have-1],D=3+(3&Q),Q>>>=2,d-=2}else if(17===Y){for(P=m+3;d<P;){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}d-=m,S=0,D=3+(7&(Q>>>=m)),Q>>>=3,d-=3}else{for(P=m+7;d<P;){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}d-=m,S=0,D=11+(127&(Q>>>=m)),Q>>>=7,d-=7}if(e.have+D>e.nlen+e.ndist){A.msg="invalid bit length repeat",e.mode=30;break}for(;D--;)e.lens[e.have++]=S}}if(30===e.mode)break;if(0===e.lens[256]){A.msg="invalid code -- missing end-of-block",e.mode=30;break}if(e.lenbits=9,T={bits:e.lenbits},x=s(1,e.lens,0,e.nlen,e.lencode,0,e.work,T),e.lenbits=T.bits,x){A.msg="invalid literal/lengths set",e.mode=30;break}if(e.distbits=6,e.distcode=e.distdyn,T={bits:e.distbits},x=s(2,e.lens,e.nlen,e.ndist,e.distcode,0,e.work,T),e.distbits=T.bits,x){A.msg="invalid distances set",e.mode=30;break}if(e.mode=20,6===t)break A;case 20:e.mode=21;case 21:if(6<=E&&258<=f){A.next_out=h,A.avail_out=f,A.next_in=w,A.avail_in=E,e.hold=Q,e.bits=d,o(A,M),h=A.next_out,l=A.output,f=A.avail_out,w=A.next_in,g=A.input,E=A.avail_in,Q=e.hold,d=e.bits,12===e.mode&&(e.back=-1);break}for(e.back=0;F=(N=e.lencode[Q&(1<<e.lenbits)-1])>>>16&255,Y=65535&N,!((m=N>>>24)<=d);){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}if(F&&0==(240&F)){for(b=m,z=F,U=Y;F=(N=e.lencode[U+((Q&(1<<b+z)-1)>>b)])>>>16&255,Y=65535&N,!(b+(m=N>>>24)<=d);){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}Q>>>=b,d-=b,e.back+=b}if(Q>>>=m,d-=m,e.back+=m,e.length=Y,0===F){e.mode=26;break}if(32&F){e.back=-1,e.mode=12;break}if(64&F){A.msg="invalid literal/length code",e.mode=30;break}e.extra=15&F,e.mode=22;case 22:if(e.extra){for(P=e.extra;d<P;){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}e.length+=Q&(1<<e.extra)-1,Q>>>=e.extra,d-=e.extra,e.back+=e.extra}e.was=e.length,e.mode=23;case 23:for(;F=(N=e.distcode[Q&(1<<e.distbits)-1])>>>16&255,Y=65535&N,!((m=N>>>24)<=d);){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}if(0==(240&F)){for(b=m,z=F,U=Y;F=(N=e.distcode[U+((Q&(1<<b+z)-1)>>b)])>>>16&255,Y=65535&N,!(b+(m=N>>>24)<=d);){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}Q>>>=b,d-=b,e.back+=b}if(Q>>>=m,d-=m,e.back+=m,64&F){A.msg="invalid distance code",e.mode=30;break}e.offset=Y,e.extra=15&F,e.mode=24;case 24:if(e.extra){for(P=e.extra;d<P;){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}e.offset+=Q&(1<<e.extra)-1,Q>>>=e.extra,d-=e.extra,e.back+=e.extra}if(e.offset>e.dmax){A.msg="invalid distance too far back",e.mode=30;break}e.mode=25;case 25:if(0===f)break A;if(D=M-f,e.offset>D){if((D=e.offset-D)>e.whave&&e.sane){A.msg="invalid distance too far back",e.mode=30;break}y=D>e.wnext?(D-=e.wnext,e.wsize-D):e.wnext-D,D>e.length&&(D=e.length),v=e.window}else v=l,y=h-e.offset,D=e.length;for(f<D&&(D=f),f-=D,e.length-=D;l[h++]=v[y++],--D;);0===e.length&&(e.mode=21);break;case 26:if(0===f)break A;l[h++]=e.length,f--,e.mode=21;break;case 27:if(e.wrap){for(;d<32;){if(0===E)break A;E--,Q|=g[w++]<<d,d+=8}if(M-=f,A.total_out+=M,e.total+=M,M&&(A.adler=e.check=e.flags?i(e.check,l,M,h-M):r(e.check,l,M,h-M)),M=f,(e.flags?Q:u(Q))!==e.check){A.msg="incorrect data check",e.mode=30;break}d=Q=0}e.mode=28;case 28:if(e.wrap&&e.flags){for(;d<32;){if(0===E)break A;E--,Q+=g[w++]<<d,d+=8}if(Q!==(4294967295&e.total)){A.msg="incorrect length check",e.mode=30;break}d=Q=0}e.mode=29;case 29:x=1;break A;case 30:x=-3;break A;case 31:return-4;default:return c}return A.next_out=h,A.avail_out=f,A.next_in=w,A.avail_in=E,e.hold=Q,e.bits=d,(e.wsize||M!==A.avail_out&&e.mode<30&&(e.mode<27||4!==t))&&p(A,A.output,A.next_out,M-A.avail_out)?(e.mode=31,-4):(C-=A.avail_in,M-=A.avail_out,A.total_in+=C,A.total_out+=M,e.total+=M,e.wrap&&M&&(A.adler=e.check=e.flags?i(e.check,l,M,A.next_out-M):r(e.check,l,M,A.next_out-M)),A.data_type=e.bits+(e.last?64:0)+(12===e.mode?128:0)+(20===e.mode||15===e.mode?256:0),(0==C&&0===M||4===t)&&x===a&&(x=-5),x)},e.inflateEnd=function(A){if(!A||!A.state)return c;var t=A.state;return t.window&&(t.window=null),A.state=null,a},e.inflateGetHeader=function(A,t){var e;return A&&A.state?0==(2&(e=A.state).wrap)?c:((e.head=t).done=!1,a):c},e.inflateSetDictionary=function(A,t){var e,n=t.length;return A&&A.state?0!==(e=A.state).wrap&&11!==e.mode?c:11===e.mode&&r(1,t,n,0)!==e.check?-3:p(A,t,n,n)?(e.mode=31,-4):(e.havedict=1,a):c},e.inflateInfo="pako inflate (from Nodeca project)"},{"../utils/common":41,"./adler32":43,"./crc32":45,"./inffast":48,"./inftrees":50}],50:[function(A,t,e){"use strict";var n=A("../utils/common"),r=[3,4,5,6,7,8,9,10,11,13,15,17,19,23,27,31,35,43,51,59,67,83,99,115,131,163,195,227,258,0,0],i=[16,16,16,16,16,16,16,16,17,17,17,17,18,18,18,18,19,19,19,19,20,20,20,20,21,21,21,21,16,72,78],o=[1,2,3,4,5,7,9,13,17,25,33,49,65,97,129,193,257,385,513,769,1025,1537,2049,3073,4097,6145,8193,12289,16385,24577,0,0],s=[16,16,16,16,17,17,18,18,19,19,20,20,21,21,22,22,23,23,24,24,25,25,26,26,27,27,28,28,29,29,64,64];t.exports=function(A,t,e,a,c,B,g,l){var u,w,h,E,f,Q,d,C,M,I=l.bits,p=0,D=0,y=0,v=0,m=0,F=0,Y=0,b=0,z=0,U=0,S=null,x=0,T=new n.Buf16(16),P=new n.Buf16(16),N=null,R=0;for(p=0;p<=15;p++)T[p]=0;for(D=0;D<a;D++)T[t[e+D]]++;for(m=I,v=15;1<=v&&0===T[v];v--);if(v<m&&(m=v),0===v)return c[B++]=20971520,c[B++]=20971520,l.bits=1,0;for(y=1;y<v&&0===T[y];y++);for(m<y&&(m=y),p=b=1;p<=15;p++)if(b<<=1,(b-=T[p])<0)return-1;if(0<b&&(0===A||1!==v))return-1;for(P[1]=0,p=1;p<15;p++)P[p+1]=P[p]+T[p];for(D=0;D<a;D++)0!==t[e+D]&&(g[P[t[e+D]]++]=D);if(Q=0===A?(S=N=g,19):1===A?(S=r,x-=257,N=i,R-=257,256):(S=o,N=s,-1),p=y,f=B,Y=D=U=0,h=-1,E=(z=1<<(F=m))-1,1===A&&852<z||2===A&&592<z)return 1;for(;;){for(d=p-Y,M=g[D]<Q?(C=0,g[D]):g[D]>Q?(C=N[R+g[D]],S[x+g[D]]):(C=96,0),u=1<<p-Y,y=w=1<<F;c[f+(U>>Y)+(w-=u)]=d<<24|C<<16|M|0,0!==w;);for(u=1<<p-1;U&u;)u>>=1;if(0!==u?(U&=u-1,U+=u):U=0,D++,0==--T[p]){if(p===v)break;p=t[e+g[D]]}if(m<p&&(U&E)!==h){for(0===Y&&(Y=m),f+=y,b=1<<(F=p-Y);F+Y<v&&!((b-=T[F+Y])<=0);)F++,b<<=1;if(z+=1<<F,1===A&&852<z||2===A&&592<z)return 1;c[h=U&E]=m<<24|F<<16|f-B|0}}return 0!==U&&(c[f+U]=p-Y<<24|64<<16|0),l.bits=m,0}},{"../utils/common":41}],51:[function(A,t,e){"use strict";t.exports={2:"need dictionary",1:"stream end",0:"","-1":"file error","-2":"stream error","-3":"data error","-4":"insufficient memory","-5":"buffer error","-6":"incompatible version"}},{}],52:[function(A,t,e){"use strict";var n=A("../utils/common");function r(A){for(var t=A.length;0<=--t;)A[t]=0}var i=256,o=286,s=30,a=15,c=16,B=[0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,0],g=[0,0,0,0,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13],l=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,7],u=[16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15],w=new Array(576);r(w);var h=new Array(60);r(h);var E=new Array(512);r(E);var f=new Array(256);r(f);var Q=new Array(29);r(Q);var d,C,M,I=new Array(s);function p(A,t,e,n,r){this.static_tree=A,this.extra_bits=t,this.extra_base=e,this.elems=n,this.max_length=r,this.has_stree=A&&A.length}function D(A,t){this.dyn_tree=A,this.max_code=0,this.stat_desc=t}function y(A){return A<256?E[A]:E[256+(A>>>7)]}function v(A,t){A.pending_buf[A.pending++]=255&t,A.pending_buf[A.pending++]=t>>>8&255}function m(A,t,e){A.bi_valid>c-e?(A.bi_buf|=t<<A.bi_valid&65535,v(A,A.bi_buf),A.bi_buf=t>>c-A.bi_valid,A.bi_valid+=e-c):(A.bi_buf|=t<<A.bi_valid&65535,A.bi_valid+=e)}function F(A,t,e){m(A,e[2*t],e[2*t+1])}function Y(A,t){for(var e=0;e|=1&A,A>>>=1,e<<=1,0<--t;);return e>>>1}function b(A,t,e){var n,r,i=new Array(a+1),o=0;for(n=1;n<=a;n++)i[n]=o=o+e[n-1]<<1;for(r=0;r<=t;r++){var s=A[2*r+1];0!==s&&(A[2*r]=Y(i[s]++,s))}}function z(A){var t;for(t=0;t<o;t++)A.dyn_ltree[2*t]=0;for(t=0;t<s;t++)A.dyn_dtree[2*t]=0;for(t=0;t<19;t++)A.bl_tree[2*t]=0;A.dyn_ltree[512]=1,A.opt_len=A.static_len=0,A.last_lit=A.matches=0}function U(A){8<A.bi_valid?v(A,A.bi_buf):0<A.bi_valid&&(A.pending_buf[A.pending++]=A.bi_buf),A.bi_buf=0,A.bi_valid=0}function S(A,t,e,n){var r=2*t,i=2*e;return A[r]<A[i]||A[r]===A[i]&&n[t]<=n[e]}function x(A,t,e){for(var n=A.heap[e],r=e<<1;r<=A.heap_len&&(r<A.heap_len&&S(t,A.heap[r+1],A.heap[r],A.depth)&&r++,!S(t,n,A.heap[r],A.depth));)A.heap[e]=A.heap[r],e=r,r<<=1;A.heap[e]=n}function T(A,t,e){var n,r,o,s,a=0;if(0!==A.last_lit)for(;n=A.pending_buf[A.d_buf+2*a]<<8|A.pending_buf[A.d_buf+2*a+1],r=A.pending_buf[A.l_buf+a],a++,0===n?F(A,r,t):(F(A,(o=f[r])+i+1,t),0!==(s=B[o])&&m(A,r-=Q[o],s),F(A,o=y(--n),e),0!==(s=g[o])&&m(A,n-=I[o],s)),a<A.last_lit;);F(A,256,t)}function P(A,t){var e,n,r,i=t.dyn_tree,o=t.stat_desc.static_tree,s=t.stat_desc.has_stree,c=t.stat_desc.elems,B=-1;for(A.heap_len=0,A.heap_max=573,e=0;e<c;e++)0!==i[2*e]?(A.heap[++A.heap_len]=B=e,A.depth[e]=0):i[2*e+1]=0;for(;A.heap_len<2;)i[2*(r=A.heap[++A.heap_len]=B<2?++B:0)]=1,A.depth[r]=0,A.opt_len--,s&&(A.static_len-=o[2*r+1]);for(t.max_code=B,e=A.heap_len>>1;1<=e;e--)x(A,i,e);for(r=c;e=A.heap[1],A.heap[1]=A.heap[A.heap_len--],x(A,i,1),n=A.heap[1],A.heap[--A.heap_max]=e,A.heap[--A.heap_max]=n,i[2*r]=i[2*e]+i[2*n],A.depth[r]=(A.depth[e]>=A.depth[n]?A.depth[e]:A.depth[n])+1,i[2*e+1]=i[2*n+1]=r,A.heap[1]=r++,x(A,i,1),2<=A.heap_len;);A.heap[--A.heap_max]=A.heap[1],function(A,t){var e,n,r,i,o,s,c=t.dyn_tree,B=t.max_code,g=t.stat_desc.static_tree,l=t.stat_desc.has_stree,u=t.stat_desc.extra_bits,w=t.stat_desc.extra_base,h=t.stat_desc.max_length,E=0;for(i=0;i<=a;i++)A.bl_count[i]=0;for(c[2*A.heap[A.heap_max]+1]=0,e=A.heap_max+1;e<573;e++)h<(i=c[2*c[2*(n=A.heap[e])+1]+1]+1)&&(i=h,E++),c[2*n+1]=i,B<n||(A.bl_count[i]++,o=0,w<=n&&(o=u[n-w]),s=c[2*n],A.opt_len+=s*(i+o),l&&(A.static_len+=s*(g[2*n+1]+o)));if(0!==E){do{for(i=h-1;0===A.bl_count[i];)i--;A.bl_count[i]--,A.bl_count[i+1]+=2,A.bl_count[h]--,E-=2}while(0<E);for(i=h;0!==i;i--)for(n=A.bl_count[i];0!==n;)B<(r=A.heap[--e])||(c[2*r+1]!==i&&(A.opt_len+=(i-c[2*r+1])*c[2*r],c[2*r+1]=i),n--)}}(A,t),b(i,B,A.bl_count)}function N(A,t,e){var n,r,i=-1,o=t[1],s=0,a=7,c=4;for(0===o&&(a=138,c=3),t[2*(e+1)+1]=65535,n=0;n<=e;n++)r=o,o=t[2*(n+1)+1],++s<a&&r===o||(s<c?A.bl_tree[2*r]+=s:0!==r?(r!==i&&A.bl_tree[2*r]++,A.bl_tree[32]++):s<=10?A.bl_tree[34]++:A.bl_tree[36]++,i=r,c=(s=0)===o?(a=138,3):r===o?(a=6,3):(a=7,4))}function R(A,t,e){var n,r,i=-1,o=t[1],s=0,a=7,c=4;for(0===o&&(a=138,c=3),n=0;n<=e;n++)if(r=o,o=t[2*(n+1)+1],!(++s<a&&r===o)){if(s<c)for(;F(A,r,A.bl_tree),0!=--s;);else 0!==r?(r!==i&&(F(A,r,A.bl_tree),s--),F(A,16,A.bl_tree),m(A,s-3,2)):s<=10?(F(A,17,A.bl_tree),m(A,s-3,3)):(F(A,18,A.bl_tree),m(A,s-11,7));i=r,c=(s=0)===o?(a=138,3):r===o?(a=6,3):(a=7,4)}}r(I);var G=!1;function H(A,t,e,r){m(A,0+(r?1:0),3),function(A,t,e,r){U(A),v(A,e),v(A,~e),n.arraySet(A.pending_buf,A.window,t,e,A.pending),A.pending+=e}(A,t,e)}e._tr_init=function(A){G||(function(){var A,t,e,n,r,i=new Array(a+1);for(n=e=0;n<28;n++)for(Q[n]=e,A=0;A<1<<B[n];A++)f[e++]=n;for(f[e-1]=n,n=r=0;n<16;n++)for(I[n]=r,A=0;A<1<<g[n];A++)E[r++]=n;for(r>>=7;n<s;n++)for(I[n]=r<<7,A=0;A<1<<g[n]-7;A++)E[256+r++]=n;for(t=0;t<=a;t++)i[t]=0;for(A=0;A<=143;)w[2*A+1]=8,A++,i[8]++;for(;A<=255;)w[2*A+1]=9,A++,i[9]++;for(;A<=279;)w[2*A+1]=7,A++,i[7]++;for(;A<=287;)w[2*A+1]=8,A++,i[8]++;for(b(w,287,i),A=0;A<s;A++)h[2*A+1]=5,h[2*A]=Y(A,5);d=new p(w,B,257,o,a),C=new p(h,g,0,s,a),M=new p(new Array(0),l,0,19,7)}(),G=!0),A.l_desc=new D(A.dyn_ltree,d),A.d_desc=new D(A.dyn_dtree,C),A.bl_desc=new D(A.bl_tree,M),A.bi_buf=0,A.bi_valid=0,z(A)},e._tr_stored_block=H,e._tr_flush_block=function(A,t,e,n){var r,o,s=0;0<A.level?(2===A.strm.data_type&&(A.strm.data_type=function(A){var t,e=4093624447;for(t=0;t<=31;t++,e>>>=1)if(1&e&&0!==A.dyn_ltree[2*t])return 0;if(0!==A.dyn_ltree[18]||0!==A.dyn_ltree[20]||0!==A.dyn_ltree[26])return 1;for(t=32;t<i;t++)if(0!==A.dyn_ltree[2*t])return 1;return 0}(A)),P(A,A.l_desc),P(A,A.d_desc),s=function(A){var t;for(N(A,A.dyn_ltree,A.l_desc.max_code),N(A,A.dyn_dtree,A.d_desc.max_code),P(A,A.bl_desc),t=18;3<=t&&0===A.bl_tree[2*u[t]+1];t--);return A.opt_len+=3*(t+1)+5+5+4,t}(A),r=A.opt_len+3+7>>>3,(o=A.static_len+3+7>>>3)<=r&&(r=o)):r=o=e+5,e+4<=r&&-1!==t?H(A,t,e,n):4===A.strategy||o===r?(m(A,2+(n?1:0),3),T(A,w,h)):(m(A,4+(n?1:0),3),function(A,t,e,n){var r;for(m(A,t-257,5),m(A,e-1,5),m(A,n-4,4),r=0;r<n;r++)m(A,A.bl_tree[2*u[r]+1],3);R(A,A.dyn_ltree,t-1),R(A,A.dyn_dtree,e-1)}(A,A.l_desc.max_code+1,A.d_desc.max_code+1,s+1),T(A,A.dyn_ltree,A.dyn_dtree)),z(A),n&&U(A)},e._tr_tally=function(A,t,e){return A.pending_buf[A.d_buf+2*A.last_lit]=t>>>8&255,A.pending_buf[A.d_buf+2*A.last_lit+1]=255&t,A.pending_buf[A.l_buf+A.last_lit]=255&e,A.last_lit++,0===t?A.dyn_ltree[2*e]++:(A.matches++,t--,A.dyn_ltree[2*(f[e]+i+1)]++,A.dyn_dtree[2*y(t)]++),A.last_lit===A.lit_bufsize-1},e._tr_align=function(A){m(A,2,3),F(A,256,w),function(A){16===A.bi_valid?(v(A,A.bi_buf),A.bi_buf=0,A.bi_valid=0):8<=A.bi_valid&&(A.pending_buf[A.pending++]=255&A.bi_buf,A.bi_buf>>=8,A.bi_valid-=8)}(A)}},{"../utils/common":41}],53:[function(A,t,e){"use strict";t.exports=function(){this.input=null,this.next_in=0,this.avail_in=0,this.total_in=0,this.output=null,this.next_out=0,this.avail_out=0,this.total_out=0,this.msg="",this.state=null,this.data_type=2,this.adler=0}},{}],54:[function(A,t,e){(function(A){!function(A,t){"use strict";if(!A.setImmediate){var e,n,r,i,o=1,s={},a=!1,c=A.document,B=Object.getPrototypeOf&&Object.getPrototypeOf(A);B=B&&B.setTimeout?B:A,e="[object process]"==={}.toString.call(A.process)?function(A){process.nextTick((function(){l(A)}))}:function(){if(A.postMessage&&!A.importScripts){var t=!0,e=A.onmessage;return A.onmessage=function(){t=!1},A.postMessage("","*"),A.onmessage=e,t}}()?(i="setImmediate$"+Math.random()+"$",A.addEventListener?A.addEventListener("message",u,!1):A.attachEvent("onmessage",u),function(t){A.postMessage(i+t,"*")}):A.MessageChannel?((r=new MessageChannel).port1.onmessage=function(A){l(A.data)},function(A){r.port2.postMessage(A)}):c&&"onreadystatechange"in c.createElement("script")?(n=c.documentElement,function(A){var t=c.createElement("script");t.onreadystatechange=function(){l(A),t.onreadystatechange=null,n.removeChild(t),t=null},n.appendChild(t)}):function(A){setTimeout(l,0,A)},B.setImmediate=function(A){"function"!=typeof A&&(A=new Function(""+A));for(var t=new Array(arguments.length-1),n=0;n<t.length;n++)t[n]=arguments[n+1];var r={callback:A,args:t};return s[o]=r,e(o),o++},B.clearImmediate=g}function g(A){delete s[A]}function l(A){if(a)setTimeout(l,0,A);else{var e=s[A];if(e){a=!0;try{!function(A){var e=A.callback,n=A.args;switch(n.length){case 0:e();break;case 1:e(n[0]);break;case 2:e(n[0],n[1]);break;case 3:e(n[0],n[1],n[2]);break;default:e.apply(t,n)}}(e)}finally{g(A),a=!1}}}}function u(t){t.source===A&&"string"==typeof t.data&&0===t.data.indexOf(i)&&l(+t.data.slice(i.length))}}("undefined"==typeof self?void 0===A?this:A:self)}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{}]},{},[10])(10)})),function(A,t){if("object"==typeof exports&&"object"==typeof module)module.exports=t();else if("function"==typeof define&&define.amd)define([],t);else{var e=t();for(var n in e)("object"==typeof exports?exports:A)[n]=e[n]}}("undefined"!=typeof self?self:this,(function(){return function(){var A={9282:function(A,t,e){"use strict";var n=e(4155);function r(A){return r="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(A){return typeof A}:function(A){return A&&"function"==typeof Symbol&&A.constructor===Symbol&&A!==Symbol.prototype?"symbol":typeof A},r(A)}var i,o,s=e(2136).codes,a=s.ERR_AMBIGUOUS_ARGUMENT,c=s.ERR_INVALID_ARG_TYPE,B=s.ERR_INVALID_ARG_VALUE,g=s.ERR_INVALID_RETURN_VALUE,l=s.ERR_MISSING_ARGS,u=e(5961),w=e(9539).inspect,h=e(9539).types,E=h.isPromise,f=h.isRegExp,Q=Object.assign?Object.assign:e(8091).assign,d=Object.is?Object.is:e(609);function C(){var A=e(9158);i=A.isDeepEqual,o=A.isDeepStrictEqual}new Map;var M=!1,I=A.exports=v,p={};function D(A){if(A.message instanceof Error)throw A.message;throw new u(A)}function y(A,t,e,n){if(!e){var r=!1;if(0===t)r=!0,n="No value argument passed to `assert.ok()`";else if(n instanceof Error)throw n;var i=new u({actual:e,expected:!0,message:n,operator:"==",stackStartFn:A});throw i.generatedMessage=r,i}}function v(){for(var A=arguments.length,t=new Array(A),e=0;e<A;e++)t[e]=arguments[e];y.apply(void 0,[v,t.length].concat(t))}I.fail=function A(t,e,r,i,o){var s,a=arguments.length;if(0===a)s="Failed";else if(1===a)r=t,t=void 0;else{if(!1===M)M=!0,(n.emitWarning?n.emitWarning:void 0)("assert.fail() with more than one argument is deprecated. Please use assert.strictEqual() instead or only pass a message.","DeprecationWarning","DEP0094");2===a&&(i="!=")}if(r instanceof Error)throw r;var c={actual:t,expected:e,operator:void 0===i?"fail":i,stackStartFn:o||A};void 0!==r&&(c.message=r);var B=new u(c);throw s&&(B.message=s,B.generatedMessage=!0),B},I.AssertionError=u,I.ok=v,I.equal=function A(t,e,n){if(arguments.length<2)throw new l("actual","expected");t!=e&&D({actual:t,expected:e,message:n,operator:"==",stackStartFn:A})},I.notEqual=function A(t,e,n){if(arguments.length<2)throw new l("actual","expected");t==e&&D({actual:t,expected:e,message:n,operator:"!=",stackStartFn:A})},I.deepEqual=function A(t,e,n){if(arguments.length<2)throw new l("actual","expected");void 0===i&&C(),i(t,e)||D({actual:t,expected:e,message:n,operator:"deepEqual",stackStartFn:A})},I.notDeepEqual=function A(t,e,n){if(arguments.length<2)throw new l("actual","expected");void 0===i&&C(),i(t,e)&&D({actual:t,expected:e,message:n,operator:"notDeepEqual",stackStartFn:A})},I.deepStrictEqual=function A(t,e,n){if(arguments.length<2)throw new l("actual","expected");void 0===i&&C(),o(t,e)||D({actual:t,expected:e,message:n,operator:"deepStrictEqual",stackStartFn:A})},I.notDeepStrictEqual=function A(t,e,n){if(arguments.length<2)throw new l("actual","expected");void 0===i&&C(),o(t,e)&&D({actual:t,expected:e,message:n,operator:"notDeepStrictEqual",stackStartFn:A})},I.strictEqual=function A(t,e,n){if(arguments.length<2)throw new l("actual","expected");d(t,e)||D({actual:t,expected:e,message:n,operator:"strictEqual",stackStartFn:A})},I.notStrictEqual=function A(t,e,n){if(arguments.length<2)throw new l("actual","expected");d(t,e)&&D({actual:t,expected:e,message:n,operator:"notStrictEqual",stackStartFn:A})};var m=function A(t,e,n){var r=this;!function(A,t){if(!(A instanceof t))throw new TypeError("Cannot call a class as a function")}(this,A),e.forEach((function(A){A in t&&(void 0!==n&&"string"==typeof n[A]&&f(t[A])&&t[A].test(n[A])?r[A]=n[A]:r[A]=t[A])}))};function F(A,t,e,n,r,i){if(!(e in A)||!o(A[e],t[e])){if(!n){var s=new m(A,r),a=new m(t,r,A),c=new u({actual:s,expected:a,operator:"deepStrictEqual",stackStartFn:i});throw c.actual=A,c.expected=t,c.operator=i.name,c}D({actual:A,expected:t,message:n,operator:i.name,stackStartFn:i})}}function Y(A,t,e,n){if("function"!=typeof t){if(f(t))return t.test(A);if(2===arguments.length)throw new c("expected",["Function","RegExp"],t);if("object"!==r(A)||null===A){var o=new u({actual:A,expected:t,message:e,operator:"deepStrictEqual",stackStartFn:n});throw o.operator=n.name,o}var s=Object.keys(t);if(t instanceof Error)s.push("name","message");else if(0===s.length)throw new B("error",t,"may not be an empty object");return void 0===i&&C(),s.forEach((function(r){"string"==typeof A[r]&&f(t[r])&&t[r].test(A[r])||F(A,t,r,e,s,n)})),!0}return void 0!==t.prototype&&A instanceof t||!Error.isPrototypeOf(t)&&!0===t.call({},A)}function b(A){if("function"!=typeof A)throw new c("fn","Function",A);try{A()}catch(A){return A}return p}function z(A){return E(A)||null!==A&&"object"===r(A)&&"function"==typeof A.then&&"function"==typeof A.catch}function U(A){return Promise.resolve().then((function(){var t;if("function"==typeof A){if(!z(t=A()))throw new g("instance of Promise","promiseFn",t)}else{if(!z(A))throw new c("promiseFn",["Function","Promise"],A);t=A}return Promise.resolve().then((function(){return t})).then((function(){return p})).catch((function(A){return A}))}))}function S(A,t,e,n){if("string"==typeof e){if(4===arguments.length)throw new c("error",["Object","Error","Function","RegExp"],e);if("object"===r(t)&&null!==t){if(t.message===e)throw new a("error/message",'The error message "'.concat(t.message,'" is identical to the message.'))}else if(t===e)throw new a("error/message",'The error "'.concat(t,'" is identical to the message.'));n=e,e=void 0}else if(null!=e&&"object"!==r(e)&&"function"!=typeof e)throw new c("error",["Object","Error","Function","RegExp"],e);if(t===p){var i="";e&&e.name&&(i+=" (".concat(e.name,")")),i+=n?": ".concat(n):".";var o="rejects"===A.name?"rejection":"exception";D({actual:void 0,expected:e,operator:A.name,message:"Missing expected ".concat(o).concat(i),stackStartFn:A})}if(e&&!Y(t,e,n,A))throw t}function x(A,t,e,n){if(t!==p){if("string"==typeof e&&(n=e,e=void 0),!e||Y(t,e)){var r=n?": ".concat(n):".",i="doesNotReject"===A.name?"rejection":"exception";D({actual:t,expected:e,operator:A.name,message:"Got unwanted ".concat(i).concat(r,"\n")+'Actual message: "'.concat(t&&t.message,'"'),stackStartFn:A})}throw t}}function T(){for(var A=arguments.length,t=new Array(A),e=0;e<A;e++)t[e]=arguments[e];y.apply(void 0,[T,t.length].concat(t))}I.throws=function A(t){for(var e=arguments.length,n=new Array(e>1?e-1:0),r=1;r<e;r++)n[r-1]=arguments[r];S.apply(void 0,[A,b(t)].concat(n))},I.rejects=function A(t){for(var e=arguments.length,n=new Array(e>1?e-1:0),r=1;r<e;r++)n[r-1]=arguments[r];return U(t).then((function(t){return S.apply(void 0,[A,t].concat(n))}))},I.doesNotThrow=function A(t){for(var e=arguments.length,n=new Array(e>1?e-1:0),r=1;r<e;r++)n[r-1]=arguments[r];x.apply(void 0,[A,b(t)].concat(n))},I.doesNotReject=function A(t){for(var e=arguments.length,n=new Array(e>1?e-1:0),r=1;r<e;r++)n[r-1]=arguments[r];return U(t).then((function(t){return x.apply(void 0,[A,t].concat(n))}))},I.ifError=function A(t){if(null!=t){var e="ifError got unwanted exception: ";"object"===r(t)&&"string"==typeof t.message?0===t.message.length&&t.constructor?e+=t.constructor.name:e+=t.message:e+=w(t);var n=new u({actual:t,expected:null,operator:"ifError",message:e,stackStartFn:A}),i=t.stack;if("string"==typeof i){var o=i.split("\n");o.shift();for(var s=n.stack.split("\n"),a=0;a<o.length;a++){var c=s.indexOf(o[a]);if(-1!==c){s=s.slice(0,c);break}}n.stack="".concat(s.join("\n"),"\n").concat(o.join("\n"))}throw n}},I.strict=Q(T,I,{equal:I.strictEqual,deepEqual:I.deepStrictEqual,notEqual:I.notStrictEqual,notDeepEqual:I.notDeepStrictEqual}),I.strict.strict=I.strict},5961:function(A,t,e){"use strict";var n=e(4155);function r(A,t,e){return t in A?Object.defineProperty(A,t,{value:e,enumerable:!0,configurable:!0,writable:!0}):A[t]=e,A}function i(A,t){for(var e=0;e<t.length;e++){var n=t[e];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(A,n.key,n)}}function o(A,t){return!t||"object"!==l(t)&&"function"!=typeof t?s(A):t}function s(A){if(void 0===A)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return A}function a(A){var t="function"==typeof Map?new Map:void 0;return a=function(A){if(null===A||!function(A){return-1!==Function.toString.call(A).indexOf("[native code]")}(A))return A;if("function"!=typeof A)throw new TypeError("Super expression must either be null or a function");if(void 0!==t){if(t.has(A))return t.get(A);t.set(A,e)}function e(){return c(A,arguments,g(this).constructor)}return e.prototype=Object.create(A.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),B(e,A)},a(A)}function c(A,t,e){return c=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],(function(){}))),!0}catch(A){return!1}}()?Reflect.construct:function(A,t,e){var n=[null];n.push.apply(n,t);var r=new(Function.bind.apply(A,n));return e&&B(r,e.prototype),r},c.apply(null,arguments)}function B(A,t){return B=Object.setPrototypeOf||function(A,t){return A.__proto__=t,A},B(A,t)}function g(A){return g=Object.setPrototypeOf?Object.getPrototypeOf:function(A){return A.__proto__||Object.getPrototypeOf(A)},g(A)}function l(A){return l="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(A){return typeof A}:function(A){return A&&"function"==typeof Symbol&&A.constructor===Symbol&&A!==Symbol.prototype?"symbol":typeof A},l(A)}var u=e(9539).inspect,w=e(2136).codes.ERR_INVALID_ARG_TYPE;function h(A,t,e){return(void 0===e||e>A.length)&&(e=A.length),A.substring(e-t.length,e)===t}var E="",f="",Q="",d="",C={deepStrictEqual:"Expected values to be strictly deep-equal:",strictEqual:"Expected values to be strictly equal:",strictEqualObject:'Expected "actual" to be reference-equal to "expected":',deepEqual:"Expected values to be loosely deep-equal:",equal:"Expected values to be loosely equal:",notDeepStrictEqual:'Expected "actual" not to be strictly deep-equal to:',notStrictEqual:'Expected "actual" to be strictly unequal to:',notStrictEqualObject:'Expected "actual" not to be reference-equal to "expected":',notDeepEqual:'Expected "actual" not to be loosely deep-equal to:',notEqual:'Expected "actual" to be loosely unequal to:',notIdentical:"Values identical but not reference-equal:"};function M(A){var t=Object.keys(A),e=Object.create(Object.getPrototypeOf(A));return t.forEach((function(t){e[t]=A[t]})),Object.defineProperty(e,"message",{value:A.message}),e}function I(A){return u(A,{compact:!1,customInspect:!1,depth:1e3,maxArrayLength:1/0,showHidden:!1,breakLength:1/0,showProxy:!1,sorted:!0,getters:!0})}var p=function(A){function t(A){var e;if(function(A,t){if(!(A instanceof t))throw new TypeError("Cannot call a class as a function")}(this,t),"object"!==l(A)||null===A)throw new w("options","Object",A);var r=A.message,i=A.operator,a=A.stackStartFn,c=A.actual,B=A.expected,u=Error.stackTraceLimit;if(Error.stackTraceLimit=0,null!=r)e=o(this,g(t).call(this,String(r)));else if(n.stderr&&n.stderr.isTTY&&(n.stderr&&n.stderr.getColorDepth&&1!==n.stderr.getColorDepth()?(E="[34m",f="[32m",d="[39m",Q="[31m"):(E="",f="",d="",Q="")),"object"===l(c)&&null!==c&&"object"===l(B)&&null!==B&&"stack"in c&&c instanceof Error&&"stack"in B&&B instanceof Error&&(c=M(c),B=M(B)),"deepStrictEqual"===i||"strictEqual"===i)e=o(this,g(t).call(this,function(A,t,e){var r="",i="",o=0,s="",a=!1,c=I(A),B=c.split("\n"),g=I(t).split("\n"),u=0,w="";if("strictEqual"===e&&"object"===l(A)&&"object"===l(t)&&null!==A&&null!==t&&(e="strictEqualObject"),1===B.length&&1===g.length&&B[0]!==g[0]){var M=B[0].length+g[0].length;if(M<=10){if(!("object"===l(A)&&null!==A||"object"===l(t)&&null!==t||0===A&&0===t))return"".concat(C[e],"\n\n")+"".concat(B[0]," !== ").concat(g[0],"\n")}else if("strictEqualObject"!==e&&M<(n.stderr&&n.stderr.isTTY?n.stderr.columns:80)){for(;B[0][u]===g[0][u];)u++;u>2&&(w="\n  ".concat(function(A,t){if(t=Math.floor(t),0==A.length||0==t)return"";var e=A.length*t;for(t=Math.floor(Math.log(t)/Math.log(2));t;)A+=A,t--;return A+A.substring(0,e-A.length)}(" ",u),"^"),u=0)}}for(var p=B[B.length-1],D=g[g.length-1];p===D&&(u++<2?s="\n  ".concat(p).concat(s):r=p,B.pop(),g.pop(),0!==B.length&&0!==g.length);)p=B[B.length-1],D=g[g.length-1];var y=Math.max(B.length,g.length);if(0===y){var v=c.split("\n");if(v.length>30)for(v[26]="".concat(E,"...").concat(d);v.length>27;)v.pop();return"".concat(C.notIdentical,"\n\n").concat(v.join("\n"),"\n")}u>3&&(s="\n".concat(E,"...").concat(d).concat(s),a=!0),""!==r&&(s="\n  ".concat(r).concat(s),r="");var m=0,F=C[e]+"\n".concat(f,"+ actual").concat(d," ").concat(Q,"- expected").concat(d),Y=" ".concat(E,"...").concat(d," Lines skipped");for(u=0;u<y;u++){var b=u-o;if(B.length<u+1)b>1&&u>2&&(b>4?(i+="\n".concat(E,"...").concat(d),a=!0):b>3&&(i+="\n  ".concat(g[u-2]),m++),i+="\n  ".concat(g[u-1]),m++),o=u,r+="\n".concat(Q,"-").concat(d," ").concat(g[u]),m++;else if(g.length<u+1)b>1&&u>2&&(b>4?(i+="\n".concat(E,"...").concat(d),a=!0):b>3&&(i+="\n  ".concat(B[u-2]),m++),i+="\n  ".concat(B[u-1]),m++),o=u,i+="\n".concat(f,"+").concat(d," ").concat(B[u]),m++;else{var z=g[u],U=B[u],S=U!==z&&(!h(U,",")||U.slice(0,-1)!==z);S&&h(z,",")&&z.slice(0,-1)===U&&(S=!1,U+=","),S?(b>1&&u>2&&(b>4?(i+="\n".concat(E,"...").concat(d),a=!0):b>3&&(i+="\n  ".concat(B[u-2]),m++),i+="\n  ".concat(B[u-1]),m++),o=u,i+="\n".concat(f,"+").concat(d," ").concat(U),r+="\n".concat(Q,"-").concat(d," ").concat(z),m+=2):(i+=r,r="",1!==b&&0!==u||(i+="\n  ".concat(U),m++))}if(m>20&&u<y-2)return"".concat(F).concat(Y,"\n").concat(i,"\n").concat(E,"...").concat(d).concat(r,"\n")+"".concat(E,"...").concat(d)}return"".concat(F).concat(a?Y:"","\n").concat(i).concat(r).concat(s).concat(w)}(c,B,i)));else if("notDeepStrictEqual"===i||"notStrictEqual"===i){var p=C[i],D=I(c).split("\n");if("notStrictEqual"===i&&"object"===l(c)&&null!==c&&(p=C.notStrictEqualObject),D.length>30)for(D[26]="".concat(E,"...").concat(d);D.length>27;)D.pop();e=1===D.length?o(this,g(t).call(this,"".concat(p," ").concat(D[0]))):o(this,g(t).call(this,"".concat(p,"\n\n").concat(D.join("\n"),"\n")))}else{var y=I(c),v="",m=C[i];"notDeepEqual"===i||"notEqual"===i?(y="".concat(C[i],"\n\n").concat(y)).length>1024&&(y="".concat(y.slice(0,1021),"...")):(v="".concat(I(B)),y.length>512&&(y="".concat(y.slice(0,509),"...")),v.length>512&&(v="".concat(v.slice(0,509),"...")),"deepEqual"===i||"equal"===i?y="".concat(m,"\n\n").concat(y,"\n\nshould equal\n\n"):v=" ".concat(i," ").concat(v)),e=o(this,g(t).call(this,"".concat(y).concat(v)))}return Error.stackTraceLimit=u,e.generatedMessage=!r,Object.defineProperty(s(e),"name",{value:"AssertionError [ERR_ASSERTION]",enumerable:!1,writable:!0,configurable:!0}),e.code="ERR_ASSERTION",e.actual=c,e.expected=B,e.operator=i,Error.captureStackTrace&&Error.captureStackTrace(s(e),a),e.stack,e.name="AssertionError",o(e)}return function(A,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function");A.prototype=Object.create(t&&t.prototype,{constructor:{value:A,writable:!0,configurable:!0}}),t&&B(A,t)}(t,A),function(A,t,e){t&&i(A.prototype,t),e&&i(A,e)}(t,[{key:"toString",value:function(){return"".concat(this.name," [").concat(this.code,"]: ").concat(this.message)}},{key:u.custom,value:function(A,t){return u(this,function(A){for(var t=1;t<arguments.length;t++){var e=null!=arguments[t]?arguments[t]:{},n=Object.keys(e);"function"==typeof Object.getOwnPropertySymbols&&(n=n.concat(Object.getOwnPropertySymbols(e).filter((function(A){return Object.getOwnPropertyDescriptor(e,A).enumerable})))),n.forEach((function(t){r(A,t,e[t])}))}return A}({},t,{customInspect:!1,depth:0}))}}]),t}(a(Error));A.exports=p},2136:function(A,t,e){"use strict";function n(A){return n="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(A){return typeof A}:function(A){return A&&"function"==typeof Symbol&&A.constructor===Symbol&&A!==Symbol.prototype?"symbol":typeof A},n(A)}function r(A){return r=Object.setPrototypeOf?Object.getPrototypeOf:function(A){return A.__proto__||Object.getPrototypeOf(A)},r(A)}function i(A,t){return i=Object.setPrototypeOf||function(A,t){return A.__proto__=t,A},i(A,t)}var o,s,a={};function c(A,t,e){e||(e=Error);var o=function(e){function o(e,i,s){var a;return function(A,t){if(!(A instanceof t))throw new TypeError("Cannot call a class as a function")}(this,o),a=function(A,t){return!t||"object"!==n(t)&&"function"!=typeof t?function(A){if(void 0===A)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return A}(A):t}(this,r(o).call(this,function(A,e,n){return"string"==typeof t?t:t(A,e,n)}(e,i,s))),a.code=A,a}return function(A,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function");A.prototype=Object.create(t&&t.prototype,{constructor:{value:A,writable:!0,configurable:!0}}),t&&i(A,t)}(o,e),o}(e);a[A]=o}function B(A,t){if(Array.isArray(A)){var e=A.length;return A=A.map((function(A){return String(A)})),e>2?"one of ".concat(t," ").concat(A.slice(0,e-1).join(", "),", or ")+A[e-1]:2===e?"one of ".concat(t," ").concat(A[0]," or ").concat(A[1]):"of ".concat(t," ").concat(A[0])}return"of ".concat(t," ").concat(String(A))}c("ERR_AMBIGUOUS_ARGUMENT",'The "%s" argument is ambiguous. %s',TypeError),c("ERR_INVALID_ARG_TYPE",(function(A,t,r){var i,s;if(void 0===o&&(o=e(9282)),o("string"==typeof A,"'name' must be a string"),"string"==typeof t&&function(A,t,e){return A.substr(!e||e<0?0:+e,t.length)===t}(t,"not ")?(i="must not be",t=t.replace(/^not /,"")):i="must be",function(A,t,e){return(void 0===e||e>A.length)&&(e=A.length),A.substring(e-t.length,e)===t}(A," argument"))s="The ".concat(A," ").concat(i," ").concat(B(t,"type"));else{var a=function(A,t,e){return"number"!=typeof e&&(e=0),!(e+t.length>A.length)&&-1!==A.indexOf(t,e)}(A,".")?"property":"argument";s='The "'.concat(A,'" ').concat(a," ").concat(i," ").concat(B(t,"type"))}return s+". Received type ".concat(n(r))}),TypeError),c("ERR_INVALID_ARG_VALUE",(function(A,t){var n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"is invalid";void 0===s&&(s=e(9539));var r=s.inspect(t);return r.length>128&&(r="".concat(r.slice(0,128),"...")),"The argument '".concat(A,"' ").concat(n,". Received ").concat(r)}),TypeError,RangeError),c("ERR_INVALID_RETURN_VALUE",(function(A,t,e){var r;return r=e&&e.constructor&&e.constructor.name?"instance of ".concat(e.constructor.name):"type ".concat(n(e)),"Expected ".concat(A,' to be returned from the "').concat(t,'"')+" function but got ".concat(r,".")}),TypeError),c("ERR_MISSING_ARGS",(function(){for(var A=arguments.length,t=new Array(A),n=0;n<A;n++)t[n]=arguments[n];void 0===o&&(o=e(9282)),o(t.length>0,"At least one arg needs to be specified");var r="The ",i=t.length;switch(t=t.map((function(A){return'"'.concat(A,'"')})),i){case 1:r+="".concat(t[0]," argument");break;case 2:r+="".concat(t[0]," and ").concat(t[1]," arguments");break;default:r+=t.slice(0,i-1).join(", "),r+=", and ".concat(t[i-1]," arguments")}return"".concat(r," must be specified")}),TypeError),A.exports.codes=a},9158:function(A,t,e){"use strict";function n(A,t){return function(A){if(Array.isArray(A))return A}(A)||function(A,t){var e=[],n=!0,r=!1,i=void 0;try{for(var o,s=A[Symbol.iterator]();!(n=(o=s.next()).done)&&(e.push(o.value),!t||e.length!==t);n=!0);}catch(A){r=!0,i=A}finally{try{n||null==s.return||s.return()}finally{if(r)throw i}}return e}(A,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance")}()}function r(A){return r="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(A){return typeof A}:function(A){return A&&"function"==typeof Symbol&&A.constructor===Symbol&&A!==Symbol.prototype?"symbol":typeof A},r(A)}var i=void 0!==/a/g.flags,o=function(A){var t=[];return A.forEach((function(A){return t.push(A)})),t},s=function(A){var t=[];return A.forEach((function(A,e){return t.push([e,A])})),t},a=Object.is?Object.is:e(609),c=Object.getOwnPropertySymbols?Object.getOwnPropertySymbols:function(){return[]},B=Number.isNaN?Number.isNaN:e(360);function g(A){return A.call.bind(A)}var l=g(Object.prototype.hasOwnProperty),u=g(Object.prototype.propertyIsEnumerable),w=g(Object.prototype.toString),h=e(9539).types,E=h.isAnyArrayBuffer,f=h.isArrayBufferView,Q=h.isDate,d=h.isMap,C=h.isRegExp,M=h.isSet,I=h.isNativeError,p=h.isBoxedPrimitive,D=h.isNumberObject,y=h.isStringObject,v=h.isBooleanObject,m=h.isBigIntObject,F=h.isSymbolObject,Y=h.isFloat32Array,b=h.isFloat64Array;function z(A){if(0===A.length||A.length>10)return!0;for(var t=0;t<A.length;t++){var e=A.charCodeAt(t);if(e<48||e>57)return!0}return 10===A.length&&A>=Math.pow(2,32)}function U(A){return Object.keys(A).filter(z).concat(c(A).filter(Object.prototype.propertyIsEnumerable.bind(A)))}function S(A,t){if(A===t)return 0;for(var e=A.length,n=t.length,r=0,i=Math.min(e,n);r<i;++r)if(A[r]!==t[r]){e=A[r],n=t[r];break}return e<n?-1:n<e?1:0}function x(A,t,e,n){if(A===t)return 0!==A||!e||a(A,t);if(e){if("object"!==r(A))return"number"==typeof A&&B(A)&&B(t);if("object"!==r(t)||null===A||null===t)return!1;if(Object.getPrototypeOf(A)!==Object.getPrototypeOf(t))return!1}else{if(null===A||"object"!==r(A))return(null===t||"object"!==r(t))&&A==t;if(null===t||"object"!==r(t))return!1}var o=w(A);if(o!==w(t))return!1;if(Array.isArray(A)){if(A.length!==t.length)return!1;var s=U(A),c=U(t);return s.length===c.length&&P(A,t,e,n,1,s)}if("[object Object]"===o&&(!d(A)&&d(t)||!M(A)&&M(t)))return!1;if(Q(A)){if(!Q(t)||Date.prototype.getTime.call(A)!==Date.prototype.getTime.call(t))return!1}else if(C(A)){if(!C(t)||!function(A,t){return i?A.source===t.source&&A.flags===t.flags:RegExp.prototype.toString.call(A)===RegExp.prototype.toString.call(t)}(A,t))return!1}else if(I(A)||A instanceof Error){if(A.message!==t.message||A.name!==t.name)return!1}else{if(f(A)){if(e||!Y(A)&&!b(A)){if(!function(A,t){return A.byteLength===t.byteLength&&0===S(new Uint8Array(A.buffer,A.byteOffset,A.byteLength),new Uint8Array(t.buffer,t.byteOffset,t.byteLength))}(A,t))return!1}else if(!function(A,t){if(A.byteLength!==t.byteLength)return!1;for(var e=0;e<A.byteLength;e++)if(A[e]!==t[e])return!1;return!0}(A,t))return!1;var g=U(A),l=U(t);return g.length===l.length&&P(A,t,e,n,0,g)}if(M(A))return!(!M(t)||A.size!==t.size)&&P(A,t,e,n,2);if(d(A))return!(!d(t)||A.size!==t.size)&&P(A,t,e,n,3);if(E(A)){if(!function(A,t){return A.byteLength===t.byteLength&&0===S(new Uint8Array(A),new Uint8Array(t))}(A,t))return!1}else if(p(A)&&!function(A,t){return D(A)?D(t)&&a(Number.prototype.valueOf.call(A),Number.prototype.valueOf.call(t)):y(A)?y(t)&&String.prototype.valueOf.call(A)===String.prototype.valueOf.call(t):v(A)?v(t)&&Boolean.prototype.valueOf.call(A)===Boolean.prototype.valueOf.call(t):m(A)?m(t)&&BigInt.prototype.valueOf.call(A)===BigInt.prototype.valueOf.call(t):F(t)&&Symbol.prototype.valueOf.call(A)===Symbol.prototype.valueOf.call(t)}(A,t))return!1}return P(A,t,e,n,0)}function T(A,t){return t.filter((function(t){return u(A,t)}))}function P(A,t,e,n,r,i){if(5===arguments.length){i=Object.keys(A);var o=Object.keys(t);if(i.length!==o.length)return!1}for(var s=0;s<i.length;s++)if(!l(t,i[s]))return!1;if(e&&5===arguments.length){var a=c(A);if(0!==a.length){var B=0;for(s=0;s<a.length;s++){var g=a[s];if(u(A,g)){if(!u(t,g))return!1;i.push(g),B++}else if(u(t,g))return!1}var w=c(t);if(a.length!==w.length&&T(t,w).length!==B)return!1}else{var h=c(t);if(0!==h.length&&0!==T(t,h).length)return!1}}if(0===i.length&&(0===r||1===r&&0===A.length||0===A.size))return!0;if(void 0===n)n={val1:new Map,val2:new Map,position:0};else{var E=n.val1.get(A);if(void 0!==E){var f=n.val2.get(t);if(void 0!==f)return E===f}n.position++}n.val1.set(A,n.position),n.val2.set(t,n.position);var Q=L(A,t,e,i,n,r);return n.val1.delete(A),n.val2.delete(t),Q}function N(A,t,e,n){for(var r=o(A),i=0;i<r.length;i++){var s=r[i];if(x(t,s,e,n))return A.delete(s),!0}return!1}function R(A){switch(r(A)){case"undefined":return null;case"object":return;case"symbol":return!1;case"string":A=+A;case"number":if(B(A))return!1}return!0}function G(A,t,e){var n=R(e);return null!=n?n:t.has(n)&&!A.has(n)}function H(A,t,e,n,r){var i=R(e);if(null!=i)return i;var o=t.get(i);return!(void 0===o&&!t.has(i)||!x(n,o,!1,r))&&!A.has(i)&&x(n,o,!1,r)}function k(A,t,e,n,r,i){for(var s=o(A),a=0;a<s.length;a++){var c=s[a];if(x(e,c,r,i)&&x(n,t.get(c),r,i))return A.delete(c),!0}return!1}function L(A,t,e,i,a,c){var B=0;if(2===c){if(!function(A,t,e,n){for(var i=null,s=o(A),a=0;a<s.length;a++){var c=s[a];if("object"===r(c)&&null!==c)null===i&&(i=new Set),i.add(c);else if(!t.has(c)){if(e)return!1;if(!G(A,t,c))return!1;null===i&&(i=new Set),i.add(c)}}if(null!==i){for(var B=o(t),g=0;g<B.length;g++){var l=B[g];if("object"===r(l)&&null!==l){if(!N(i,l,e,n))return!1}else if(!e&&!A.has(l)&&!N(i,l,e,n))return!1}return 0===i.size}return!0}(A,t,e,a))return!1}else if(3===c){if(!function(A,t,e,i){for(var o=null,a=s(A),c=0;c<a.length;c++){var B=n(a[c],2),g=B[0],l=B[1];if("object"===r(g)&&null!==g)null===o&&(o=new Set),o.add(g);else{var u=t.get(g);if(void 0===u&&!t.has(g)||!x(l,u,e,i)){if(e)return!1;if(!H(A,t,g,l,i))return!1;null===o&&(o=new Set),o.add(g)}}}if(null!==o){for(var w=s(t),h=0;h<w.length;h++){var E=n(w[h],2),f=(g=E[0],E[1]);if("object"===r(g)&&null!==g){if(!k(o,A,g,f,e,i))return!1}else if(!(e||A.has(g)&&x(A.get(g),f,!1,i)||k(o,A,g,f,!1,i)))return!1}return 0===o.size}return!0}(A,t,e,a))return!1}else if(1===c)for(;B<A.length;B++){if(!l(A,B)){if(l(t,B))return!1;for(var g=Object.keys(A);B<g.length;B++){var u=g[B];if(!l(t,u)||!x(A[u],t[u],e,a))return!1}return g.length===Object.keys(t).length}if(!l(t,B)||!x(A[B],t[B],e,a))return!1}for(B=0;B<i.length;B++){var w=i[B];if(!x(A[w],t[w],e,a))return!1}return!0}A.exports={isDeepEqual:function(A,t){return x(A,t,!1)},isDeepStrictEqual:function(A,t){return x(A,t,!0)}}},2055:function(A,t){"use strict";t.OP=0,t.CL=1,t.CP=2,t.QU=3,t.GL=4,t.NS=5,t.EX=6,t.SY=7,t.IS=8,t.PR=9,t.PO=10,t.NU=11,t.AL=12,t.HL=13,t.ID=14,t.IN=15,t.HY=16,t.BA=17,t.BB=18,t.B2=19,t.ZW=20,t.CM=21,t.WJ=22,t.H2=23,t.H3=24,t.JL=25,t.JV=26,t.JT=27,t.RI=28,t.EB=29,t.EM=30,t.ZWJ=31,t.CB=32,t.AI=33,t.BK=34,t.CJ=35,t.CR=36,t.LF=37,t.NL=38,t.SA=39,t.SG=40,t.SP=41,t.XX=42},8383:function(A,t){"use strict";t.DI_BRK=0,t.IN_BRK=1,t.CI_BRK=2,t.CP_BRK=3,t.PR_BRK=4,t.pairTable=[[4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,3,4,4,4,4,4,4,4,4,4,4,4],[0,4,4,1,1,4,4,4,4,1,1,0,0,0,0,1,1,1,0,0,4,2,4,0,0,0,0,0,0,0,0,1,0],[0,4,4,1,1,4,4,4,4,1,1,1,1,1,0,1,1,1,0,0,4,2,4,0,0,0,0,0,0,0,0,1,0],[4,4,4,1,1,1,4,4,4,1,1,1,1,1,1,1,1,1,1,1,4,2,4,1,1,1,1,1,1,1,1,1,1],[1,4,4,1,1,1,4,4,4,1,1,1,1,1,1,1,1,1,1,1,4,2,4,1,1,1,1,1,1,1,1,1,1],[0,4,4,1,1,1,4,4,4,0,0,0,0,0,0,1,1,1,0,0,4,2,4,0,0,0,0,0,0,0,0,1,0],[0,4,4,1,1,1,4,4,4,0,0,0,0,0,0,1,1,1,0,0,4,2,4,0,0,0,0,0,0,0,0,1,0],[0,4,4,1,1,1,4,4,4,0,0,1,0,1,0,1,1,1,0,0,4,2,4,0,0,0,0,0,0,0,0,1,0],[0,4,4,1,1,1,4,4,4,0,0,1,1,1,0,1,1,1,0,0,4,2,4,0,0,0,0,0,0,0,0,1,0],[1,4,4,1,1,1,4,4,4,0,0,1,1,1,1,1,1,1,0,0,4,2,4,1,1,1,1,1,0,1,1,1,0],[1,4,4,1,1,1,4,4,4,0,0,1,1,1,0,1,1,1,0,0,4,2,4,0,0,0,0,0,0,0,0,1,0],[1,4,4,1,1,1,4,4,4,1,1,1,1,1,0,1,1,1,0,0,4,2,4,0,0,0,0,0,0,0,0,1,0],[1,4,4,1,1,1,4,4,4,1,1,1,1,1,0,1,1,1,0,0,4,2,4,0,0,0,0,0,0,0,0,1,0],[1,4,4,1,1,1,4,4,4,1,1,1,1,1,0,1,1,1,0,0,4,2,4,0,0,0,0,0,0,0,0,1,0],[0,4,4,1,1,1,4,4,4,0,1,0,0,0,0,1,1,1,0,0,4,2,4,0,0,0,0,0,0,0,0,1,0],[0,4,4,1,1,1,4,4,4,0,0,0,0,0,0,1,1,1,0,0,4,2,4,0,0,0,0,0,0,0,0,1,0],[0,4,4,1,0,1,4,4,4,0,0,1,0,0,0,1,1,1,0,0,4,2,4,0,0,0,0,0,0,0,0,1,0],[0,4,4,1,0,1,4,4,4,0,0,0,0,0,0,1,1,1,0,0,4,2,4,0,0,0,0,0,0,0,0,1,0],[1,4,4,1,1,1,4,4,4,1,1,1,1,1,1,1,1,1,1,1,4,2,4,1,1,1,1,1,1,1,1,1,0],[0,4,4,1,1,1,4,4,4,0,0,0,0,0,0,1,1,1,0,4,4,2,4,0,0,0,0,0,0,0,0,1,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0],[1,4,4,1,1,1,4,4,4,1,1,1,1,1,0,1,1,1,0,0,4,2,4,0,0,0,0,0,0,0,0,1,0],[1,4,4,1,1,1,4,4,4,1,1,1,1,1,1,1,1,1,1,1,4,2,4,1,1,1,1,1,1,1,1,1,1],[0,4,4,1,1,1,4,4,4,0,1,0,0,0,0,1,1,1,0,0,4,2,4,0,0,0,1,1,0,0,0,1,0],[0,4,4,1,1,1,4,4,4,0,1,0,0,0,0,1,1,1,0,0,4,2,4,0,0,0,0,1,0,0,0,1,0],[0,4,4,1,1,1,4,4,4,0,1,0,0,0,0,1,1,1,0,0,4,2,4,1,1,1,1,0,0,0,0,1,0],[0,4,4,1,1,1,4,4,4,0,1,0,0,0,0,1,1,1,0,0,4,2,4,0,0,0,1,1,0,0,0,1,0],[0,4,4,1,1,1,4,4,4,0,1,0,0,0,0,1,1,1,0,0,4,2,4,0,0,0,0,1,0,0,0,1,0],[0,4,4,1,1,1,4,4,4,0,0,0,0,0,0,1,1,1,0,0,4,2,4,0,0,0,0,0,1,0,0,1,0],[0,4,4,1,1,1,4,4,4,0,1,0,0,0,0,1,1,1,0,0,4,2,4,0,0,0,0,0,0,0,1,1,0],[0,4,4,1,1,1,4,4,4,0,1,0,0,0,0,1,1,1,0,0,4,2,4,0,0,0,0,0,0,0,0,1,0],[1,4,4,1,1,1,4,4,4,1,1,1,1,1,0,1,1,1,0,0,4,2,4,0,0,0,0,0,0,0,0,1,0],[0,4,4,1,1,0,4,4,4,0,0,0,0,0,0,0,0,0,0,0,4,2,4,0,0,0,0,0,0,0,0,1,0]]},5106:function(A,t,e){"use strict";e(9601),t.EncodeStream=e(9126),t.DecodeStream=e(3030),t.Array=e(1988),t.LazyArray=e(6768),t.Bitfield=e(3425),t.Boolean=e(9024),t.Buffer=e(5250),t.Enum=e(3100),t.Optional=e(9541),t.Reserved=e(7468),t.String=e(1466),t.Struct=e(1219),t.VersionedStruct=e(3585);var n=e(6610),r=e(6462),i=e(8011);Object.assign(t,n,r,i)},1988:function(A,t,e){"use strict";function n(A,t){var e="undefined"!=typeof Symbol&&A[Symbol.iterator]||A["@@iterator"];if(e)return(e=e.call(A)).next.bind(e);if(Array.isArray(A)||(e=function(A,t){if(A){if("string"==typeof A)return r(A,t);var e=Object.prototype.toString.call(A).slice(8,-1);return"Object"===e&&A.constructor&&(e=A.constructor.name),"Map"===e||"Set"===e?Array.from(A):"Arguments"===e||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(e)?r(A,t):void 0}}(A))||t&&A&&"number"==typeof A.length){e&&(A=e);var n=0;return function(){return n>=A.length?{done:!0}:{done:!1,value:A[n++]}}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}function r(A,t){(null==t||t>A.length)&&(t=A.length);for(var e=0,n=new Array(t);e<t;e++)n[e]=A[e];return n}e(7042),e(1539),e(8309),e(1038),e(8783),e(4916),e(2526),e(1817),e(2165),e(6992),e(3948);var i=e(6462).Number,o=e(6610),s=function(){function A(A,t,e){void 0===e&&(e="count"),this.type=A,this.length=t,this.lengthType=e}var t=A.prototype;return t.decode=function(A,t){var e,n=A.pos,r=[],s=t;if(null!=this.length&&(e=o.resolveLength(this.length,A,t)),this.length instanceof i&&(Object.defineProperties(r,{parent:{value:t},_startOffset:{value:n},_currentOffset:{value:0,writable:!0},_length:{value:e}}),s=r),null==e||"bytes"===this.lengthType)for(var a=null!=e?A.pos+e:(null!=t?t._length:void 0)?t._startOffset+t._length:A.length;A.pos<a;)r.push(this.type.decode(A,s));else for(var c=0,B=e;c<B;c++)r.push(this.type.decode(A,s));return r},t.size=function(A,t){if(!A)return this.type.size(null,t)*o.resolveLength(this.length,null,t);var e=0;this.length instanceof i&&(e+=this.length.size(),t={parent:t});for(var r,s=n(A);!(r=s()).done;){var a=r.value;e+=this.type.size(a,t)}return e},t.encode=function(A,t,e){var r=e;this.length instanceof i&&((r={pointers:[],startOffset:A.pos,parent:e}).pointerOffset=A.pos+this.size(t,r),this.length.encode(A,t.length));for(var o,s=n(t);!(o=s()).done;){var a=o.value;this.type.encode(A,a,r)}if(this.length instanceof i)for(var c=0;c<r.pointers.length;){var B=r.pointers[c++];B.type.encode(A,B.val)}},A}();A.exports=s},3425:function(A,t,e){"use strict";e(2087);var n=function(){function A(A,t){void 0===t&&(t=[]),this.type=A,this.flags=t}var t=A.prototype;return t.decode=function(A){for(var t=this.type.decode(A),e={},n=0;n<this.flags.length;n++){var r=this.flags[n];null!=r&&(e[r]=!!(t&1<<n))}return e},t.size=function(){return this.type.size()},t.encode=function(A,t){for(var e=0,n=0;n<this.flags.length;n++){var r=this.flags[n];null!=r&&t[r]&&(e|=1<<n)}return this.type.encode(A,e)},A}();A.exports=n},9024:function(A){"use strict";var t=function(){function A(A){this.type=A}var t=A.prototype;return t.decode=function(A,t){return!!this.type.decode(A,t)},t.size=function(A,t){return this.type.size(A,t)},t.encode=function(A,t,e){return this.type.encode(A,+t,e)},A}();A.exports=t},5250:function(A,t,e){"use strict";var n=e(6610),r=e(6462).Number,i=function(){function A(A){this.length=A}var t=A.prototype;return t.decode=function(A,t){var e=n.resolveLength(this.length,A,t);return A.readBuffer(e)},t.size=function(A,t){return A?A.length:n.resolveLength(this.length,null,t)},t.encode=function(A,t,e){return this.length instanceof r&&this.length.encode(A,t.length),A.writeBuffer(t)},A}();A.exports=i},3030:function(A,t,e){"use strict";var n,r=e(8823).Buffer;e(1539),e(9714),e(7042),e(4916),e(5306);try{n=e(4914)}catch(A){}var i=function(){function A(A){this.buffer=A,this.pos=0,this.length=this.buffer.length}var t=A.prototype;return t.readString=function(A,t){switch(void 0===t&&(t="ascii"),t){case"utf16le":case"ucs2":case"utf8":case"ascii":return this.buffer.toString(t,this.pos,this.pos+=A);case"utf16be":for(var e=r.from(this.readBuffer(A)),i=0,o=e.length-1;i<o;i+=2){var s=e[i];e[i]=e[i+1],e[i+1]=s}return e.toString("utf16le");default:if(e=this.readBuffer(A),n)try{return n.decode(e,t)}catch(A){}return e}},t.readBuffer=function(A){return this.buffer.slice(this.pos,this.pos+=A)},t.readUInt24BE=function(){return(this.readUInt16BE()<<8)+this.readUInt8()},t.readUInt24LE=function(){return this.readUInt16LE()+(this.readUInt8()<<16)},t.readInt24BE=function(){return(this.readInt16BE()<<8)+this.readUInt8()},t.readInt24LE=function(){return this.readUInt16LE()+(this.readInt8()<<16)},A}();i.TYPES={UInt8:1,UInt16:2,UInt24:3,UInt32:4,Int8:1,Int16:2,Int24:3,Int32:4,Float:4,Double:8};var o=function(A){if("read"===A.slice(0,4)){var t=i.TYPES[A.replace(/read|[BL]E/g,"")];i.prototype[A]=function(){var e=this.buffer[A](this.pos);return this.pos+=t,e}}};for(var s in r.prototype)o(s);A.exports=i},9126:function(A,t,e){"use strict";var n,r=e(8823).Buffer;function i(A,t){return i=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(A,t){return A.__proto__=t,A},i(A,t)}e(7042),e(3290),e(4916),e(5306);var o=e(2830),s=e(3030);try{n=e(4914)}catch(A){}var a=function(A){function t(t){var e;return void 0===t&&(t=65536),(e=A.apply(this,arguments)||this).buffer=r.alloc(t),e.bufferOffset=0,e.pos=0,e}!function(A,t){A.prototype=Object.create(t.prototype),A.prototype.constructor=A,i(A,t)}(t,A);var e=t.prototype;return e._read=function(){},e.ensure=function(A){if(this.bufferOffset+A>this.buffer.length)return this.flush()},e.flush=function(){if(this.bufferOffset>0)return this.push(r.from(this.buffer.slice(0,this.bufferOffset))),this.bufferOffset=0},e.writeBuffer=function(A){return this.flush(),this.push(A),this.pos+=A.length},e.writeString=function(A,t){switch(void 0===t&&(t="ascii"),t){case"utf16le":case"ucs2":case"utf8":case"ascii":return this.writeBuffer(r.from(A,t));case"utf16be":for(var e=r.from(A,"utf16le"),i=0,o=e.length-1;i<o;i+=2){var s=e[i];e[i]=e[i+1],e[i+1]=s}return this.writeBuffer(e);default:if(n)return this.writeBuffer(n.encode(A,t));throw new Error("Install iconv-lite to enable additional string encodings.")}},e.writeUInt24BE=function(A){return this.ensure(3),this.buffer[this.bufferOffset++]=A>>>16&255,this.buffer[this.bufferOffset++]=A>>>8&255,this.buffer[this.bufferOffset++]=255&A,this.pos+=3},e.writeUInt24LE=function(A){return this.ensure(3),this.buffer[this.bufferOffset++]=255&A,this.buffer[this.bufferOffset++]=A>>>8&255,this.buffer[this.bufferOffset++]=A>>>16&255,this.pos+=3},e.writeInt24BE=function(A){return A>=0?this.writeUInt24BE(A):this.writeUInt24BE(A+16777215+1)},e.writeInt24LE=function(A){return A>=0?this.writeUInt24LE(A):this.writeUInt24LE(A+16777215+1)},e.fill=function(A,t){if(t<this.buffer.length)return this.ensure(t),this.buffer.fill(A,this.bufferOffset,this.bufferOffset+t),this.bufferOffset+=t,this.pos+=t;var e=r.alloc(t);return e.fill(A),this.writeBuffer(e)},e.end=function(){return this.flush(),this.push(null)},t}(o.Readable),c=function(A){if("write"===A.slice(0,5)){var t=+s.TYPES[A.replace(/write|[BL]E/g,"")];a.prototype[A]=function(e){return this.ensure(t),this.buffer[A](e,this.bufferOffset),this.bufferOffset+=t,this.pos+=t}}};for(var B in r.prototype)c(B);A.exports=a},3100:function(A){"use strict";var t=function(){function A(A,t){void 0===t&&(t=[]),this.type=A,this.options=t}var t=A.prototype;return t.decode=function(A){var t=this.type.decode(A);return this.options[t]||t},t.size=function(){return this.type.size()},t.encode=function(A,t){var e=this.options.indexOf(t);if(-1===e)throw new Error("Unknown option in enum: "+t);return this.type.encode(A,e)},A}();A.exports=t},6768:function(A,t,e){"use strict";function n(A,t){return n=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(A,t){return A.__proto__=t,A},n(A,t)}e(1539),e(8674);var r=e(1988),i=e(6462).Number,o=e(6610),s=e(9539).inspect,a=function(A){function t(){return A.apply(this,arguments)||this}!function(A,t){A.prototype=Object.create(t.prototype),A.prototype.constructor=A,n(A,t)}(t,A);var e=t.prototype;return e.decode=function(A,t){var e=A.pos,n=o.resolveLength(this.length,A,t);this.length instanceof i&&(t={parent:t,_startOffset:e,_currentOffset:0,_length:n});var r=new c(this.type,n,A,t);return A.pos+=n*this.type.size(null,t),r},e.size=function(t,e){return t instanceof c&&(t=t.toArray()),A.prototype.size.call(this,t,e)},e.encode=function(t,e,n){return e instanceof c&&(e=e.toArray()),A.prototype.encode.call(this,t,e,n)},t}(r),c=function(){function A(A,t,e,n){this.type=A,this.length=t,this.stream=e,this.ctx=n,this.base=this.stream.pos,this.items=[]}var t=A.prototype;return t.get=function(A){if(!(A<0||A>=this.length)){if(null==this.items[A]){var t=this.stream.pos;this.stream.pos=this.base+this.type.size(null,this.ctx)*A,this.items[A]=this.type.decode(this.stream,this.ctx),this.stream.pos=t}return this.items[A]}},t.toArray=function(){for(var A=[],t=0,e=this.length;t<e;t++)A.push(this.get(t));return A},t.inspect=function(){return s(this.toArray())},A}();A.exports=a},6462:function(A,t,e){"use strict";function n(A,t){return n=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(A,t){return A.__proto__=t,A},n(A,t)}var r=e(3030),i=function(){function A(A,t){void 0===t&&(t="BE"),this.type=A,this.endian=t,this.fn=this.type,"8"!==this.type[this.type.length-1]&&(this.fn+=this.endian)}var t=A.prototype;return t.size=function(){return r.TYPES[this.type]},t.decode=function(A){return A["read"+this.fn]()},t.encode=function(A,t){return A["write"+this.fn](t)},A}();t.Number=i,t.uint8=new i("UInt8"),t.uint16be=t.uint16=new i("UInt16","BE"),t.uint16le=new i("UInt16","LE"),t.uint24be=t.uint24=new i("UInt24","BE"),t.uint24le=new i("UInt24","LE"),t.uint32be=t.uint32=new i("UInt32","BE"),t.uint32le=new i("UInt32","LE"),t.int8=new i("Int8"),t.int16be=t.int16=new i("Int16","BE"),t.int16le=new i("Int16","LE"),t.int24be=t.int24=new i("Int24","BE"),t.int24le=new i("Int24","LE"),t.int32be=t.int32=new i("Int32","BE"),t.int32le=new i("Int32","LE"),t.floatbe=t.float=new i("Float","BE"),t.floatle=new i("Float","LE"),t.doublebe=t.double=new i("Double","BE"),t.doublele=new i("Double","LE");var o=function(A){function t(t,e,n){var r;return void 0===n&&(n=t>>1),(r=A.call(this,"Int"+t,e)||this)._point=1<<n,r}!function(A,t){A.prototype=Object.create(t.prototype),A.prototype.constructor=A,n(A,t)}(t,A);var e=t.prototype;return e.decode=function(t){return A.prototype.decode.call(this,t)/this._point},e.encode=function(t,e){return A.prototype.encode.call(this,t,e*this._point|0)},t}(i);t.Fixed=o,t.fixed16be=t.fixed16=new o(16,"BE"),t.fixed16le=new o(16,"LE"),t.fixed32be=t.fixed32=new o(32,"BE"),t.fixed32le=new o(32,"LE")},9541:function(A){"use strict";var t=function(){function A(A,t){void 0===t&&(t=!0),this.type=A,this.condition=t}var t=A.prototype;return t.decode=function(A,t){var e=this.condition;if("function"==typeof e&&(e=e.call(t,t)),e)return this.type.decode(A,t)},t.size=function(A,t){var e=this.condition;return"function"==typeof e&&(e=e.call(t,t)),e?this.type.size(A,t):0},t.encode=function(A,t,e){var n=this.condition;if("function"==typeof n&&(n=n.call(e,e)),n)return this.type.encode(A,t,e)},A}();A.exports=t},8011:function(A,t,e){"use strict";var n=e(6610),r=function(){function A(A,t,e){if(void 0===e&&(e={}),this.offsetType=A,this.type=t,this.options=e,"void"===this.type&&(this.type=null),null==this.options.type&&(this.options.type="local"),null==this.options.allowNull&&(this.options.allowNull=!0),null==this.options.nullValue&&(this.options.nullValue=0),null==this.options.lazy&&(this.options.lazy=!1),this.options.relativeTo){if("function"!=typeof this.options.relativeTo)throw new Error("relativeTo option must be a function");this.relativeToGetter=e.relativeTo}}var t=A.prototype;return t.decode=function(A,t){var e,r=this,i=this.offsetType.decode(A,t);if(i===this.options.nullValue&&this.options.allowNull)return null;switch(this.options.type){case"local":e=t._startOffset;break;case"immediate":e=A.pos-this.offsetType.size();break;case"parent":e=t.parent._startOffset;break;default:for(var o=t;o.parent;)o=o.parent;e=o._startOffset||0}this.options.relativeTo&&(e+=this.relativeToGetter(t));var s=i+e;if(null!=this.type){var a=null,c=function(){if(null!=a)return a;var e=A.pos;return A.pos=s,a=r.type.decode(A,t),A.pos=e,a};return this.options.lazy?new n.PropertyDescriptor({get:c}):c()}return s},t.size=function(A,t){var e=t;switch(this.options.type){case"local":case"immediate":break;case"parent":t=t.parent;break;default:for(;t.parent;)t=t.parent}var n=this.type;if(null==n){if(!(A instanceof i))throw new Error("Must be a VoidPointer");n=A.type,A=A.value}return A&&t&&(t.pointerSize+=n.size(A,e)),this.offsetType.size()},t.encode=function(A,t,e){var n,r=e;if(null!=t){switch(this.options.type){case"local":n=e.startOffset;break;case"immediate":n=A.pos+this.offsetType.size(t,r);break;case"parent":n=(e=e.parent).startOffset;break;default:for(n=0;e.parent;)e=e.parent}this.options.relativeTo&&(n+=this.relativeToGetter(r.val)),this.offsetType.encode(A,e.pointerOffset-n);var o=this.type;if(null==o){if(!(t instanceof i))throw new Error("Must be a VoidPointer");o=t.type,t=t.value}return e.pointers.push({type:o,val:t,parent:r}),e.pointerOffset+=o.size(t,r)}this.offsetType.encode(A,this.options.nullValue)},A}(),i=function(A,t){this.type=A,this.value=t};t.Pointer=r,t.VoidPointer=i},7468:function(A,t,e){"use strict";e(3290);var n=e(6610),r=function(){function A(A,t){void 0===t&&(t=1),this.type=A,this.count=t}var t=A.prototype;return t.decode=function(A,t){A.pos+=this.size(null,t)},t.size=function(A,t){var e=n.resolveLength(this.count,null,t);return this.type.size()*e},t.encode=function(A,t,e){return A.fill(0,this.size(t,e))},A}();A.exports=r},1466:function(A,t,e){"use strict";var n=e(8823).Buffer,r=e(6462).Number,i=e(6610),o=function(){function A(A,t){void 0===t&&(t="ascii"),this.length=A,this.encoding=t}var t=A.prototype;return t.decode=function(A,t){var e,n;if(null!=this.length)e=i.resolveLength(this.length,A,t);else{var r;for(r=A.buffer,e=A.length,n=A.pos;n<e&&0!==r[n];)++n;e=n-A.pos}var o=this.encoding;"function"==typeof o&&(o=o.call(t,t)||"ascii");var s=A.readString(e,o);return null==this.length&&A.pos<A.length&&A.pos++,s},t.size=function(A,t){if(!A)return i.resolveLength(this.length,null,t);var e=this.encoding;"function"==typeof e&&(e=e.call(null!=t?t.val:void 0,null!=t?t.val:void 0)||"ascii"),"utf16be"===e&&(e="utf16le");var o=n.byteLength(A,e);return this.length instanceof r&&(o+=this.length.size()),null==this.length&&o++,o},t.encode=function(A,t,e){var i=this.encoding;if("function"==typeof i&&(i=i.call(null!=e?e.val:void 0,null!=e?e.val:void 0)||"ascii"),this.length instanceof r&&this.length.encode(A,n.byteLength(t,i)),A.writeString(t,i),null==this.length)return A.writeUInt8(0)},A}();A.exports=o},1219:function(A,t,e){"use strict";var n=e(6610),r=function(){function A(A){void 0===A&&(A={}),this.fields=A}var t=A.prototype;return t.decode=function(A,t,e){void 0===e&&(e=0);var n=this._setup(A,t,e);return this._parseFields(A,n,this.fields),null!=this.process&&this.process.call(n,A),n},t._setup=function(A,t,e){var n={};return Object.defineProperties(n,{parent:{value:t},_startOffset:{value:A.pos},_currentOffset:{value:0,writable:!0},_length:{value:e}}),n},t._parseFields=function(A,t,e){for(var r in e){var i,o=e[r];void 0!==(i="function"==typeof o?o.call(t,t):o.decode(A,t))&&(i instanceof n.PropertyDescriptor?Object.defineProperty(t,r,i):t[r]=i),t._currentOffset=A.pos-t._startOffset}},t.size=function(A,t,e){null==A&&(A={}),null==e&&(e=!0);var n={parent:t,val:A,pointerSize:0},r=0;for(var i in this.fields){var o=this.fields[i];null!=o.size&&(r+=o.size(A[i],n))}return e&&(r+=n.pointerSize),r},t.encode=function(A,t,e){var n;null!=this.preEncode&&this.preEncode.call(t,A);var r={pointers:[],startOffset:A.pos,parent:e,val:t,pointerSize:0};for(var i in r.pointerOffset=A.pos+this.size(t,r,!1),this.fields)null!=(n=this.fields[i]).encode&&n.encode(A,t[i],r);for(var o=0;o<r.pointers.length;){var s=r.pointers[o++];s.type.encode(A,s.val,s.parent)}},A}();A.exports=r},3585:function(A,t,e){"use strict";function n(A,t){return n=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(A,t){return A.__proto__=t,A},n(A,t)}e(1539);var r=function(A){function t(t,e){var n;return void 0===e&&(e={}),(n=A.call(this)||this).type=t,n.versions=e,"string"==typeof t&&(n.versionPath=t.split(".")),n}!function(A,t){A.prototype=Object.create(t.prototype),A.prototype.constructor=A,n(A,t)}(t,A);var e=t.prototype;return e.decode=function(A,e,n){void 0===n&&(n=0);var r=this._setup(A,e,n);"string"==typeof this.type?r.version=function(A,t){return t.reduce((function(A,t){return A&&A[t]}),A)}(e,this.versionPath):r.version=this.type.decode(A),this.versions.header&&this._parseFields(A,r,this.versions.header);var i=this.versions[r.version];if(null==i)throw new Error("Unknown version "+r.version);return i instanceof t?i.decode(A,e):(this._parseFields(A,r,i),null!=this.process&&this.process.call(r,A),r)},e.size=function(A,t,e){var n,r;if(void 0===e&&(e=!0),!A)throw new Error("Not a fixed size");var i={parent:t,val:A,pointerSize:0},o=0;if("string"!=typeof this.type&&(o+=this.type.size(A.version,i)),this.versions.header)for(n in this.versions.header)null!=(r=this.versions.header[n]).size&&(o+=r.size(A[n],i));var s=this.versions[A.version];if(null==s)throw new Error("Unknown version "+A.version);for(n in s)null!=(r=s[n]).size&&(o+=r.size(A[n],i));return e&&(o+=i.pointerSize),o},e.encode=function(A,t,e){var n,r;null!=this.preEncode&&this.preEncode.call(t,A);var i={pointers:[],startOffset:A.pos,parent:e,val:t,pointerSize:0};if(i.pointerOffset=A.pos+this.size(t,i,!1),"string"!=typeof this.type&&this.type.encode(A,t.version),this.versions.header)for(n in this.versions.header)null!=(r=this.versions.header[n]).encode&&r.encode(A,t[n],i);var o=this.versions[t.version];for(n in o)null!=(r=o[n]).encode&&r.encode(A,t[n],i);for(var s=0;s<i.pointers.length;){var a=i.pointers[s++];a.type.encode(A,a.val,a.parent)}},t}(e(1219));A.exports=r},6610:function(A,t,e){"use strict";var n=e(6462).Number;t.resolveLength=function(A,t,e){var r;if("number"==typeof A?r=A:"function"==typeof A?r=A.call(e,e):e&&"string"==typeof A?r=e[A]:t&&A instanceof n&&(r=A.decode(t)),isNaN(r))throw new Error("Not a fixed size");return r},t.PropertyDescriptor=function(A){for(var t in void 0===A&&(A={}),this.enumerable=!0,this.configurable=!0,A){var e=A[t];this[t]=e}}},8823:function(A,t,e){"use strict";function n(A,t){for(var e=0;e<t.length;e++){var n=t[e];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(A,(void 0,"symbol"==typeof(r=function(A,t){if("object"!=typeof A||null===A)return A;var e=A[Symbol.toPrimitive];if(void 0!==e){var n=e.call(A,t||"default");if("object"!=typeof n)return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return("string"===t?String:Number)(A)}(n.key,"string"))?r:String(r)),n)}var r}function r(A){if(void 0===A)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return A}function i(A,t){return i=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(A,t){return A.__proto__=t,A},i(A,t)}e(2526),e(1817),e(1539),e(6992),e(2472),e(2990),e(8927),e(3105),e(5035),e(4345),e(7174),e(2846),e(4731),e(7209),e(6319),e(8867),e(7789),e(3739),e(9368),e(4483),e(2056),e(3462),e(678),e(7462),e(3824),e(5021),e(2974),e(5016),e(7803),e(6649),e(6078),e(3290),e(7042),e(2222),e(9714),e(3210),e(4916),e(5306),e(6699),e(2023),e(9653),e(3753),e(545),e(8309),e(3161);var o=e(9742),s=e(645),a="function"==typeof Symbol&&"function"==typeof Symbol.for?Symbol.for("nodejs.util.inspect.custom"):null;t.Buffer=g,t.SlowBuffer=function(A){return+A!=A&&(A=0),g.alloc(+A)},t.INSPECT_MAX_BYTES=50;var c=2147483647;function B(A){if(A>c)throw new RangeError('The value "'+A+'" is invalid for option "size"');var t=new Uint8Array(A);return Object.setPrototypeOf(t,g.prototype),t}function g(A,t,e){if("number"==typeof A){if("string"==typeof t)throw new TypeError('The "string" argument must be of type string. Received type number');return w(A)}return l(A,t,e)}function l(A,t,e){if("string"==typeof A)return function(A,t){if("string"==typeof t&&""!==t||(t="utf8"),!g.isEncoding(t))throw new TypeError("Unknown encoding: "+t);var e=0|Q(A,t),n=B(e),r=n.write(A,t);return r!==e&&(n=n.slice(0,r)),n}(A,t);if(ArrayBuffer.isView(A))return function(A){if(q(A,Uint8Array)){var t=new Uint8Array(A);return E(t.buffer,t.byteOffset,t.byteLength)}return h(A)}(A);if(null==A)throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type "+typeof A);if(q(A,ArrayBuffer)||A&&q(A.buffer,ArrayBuffer))return E(A,t,e);if("undefined"!=typeof SharedArrayBuffer&&(q(A,SharedArrayBuffer)||A&&q(A.buffer,SharedArrayBuffer)))return E(A,t,e);if("number"==typeof A)throw new TypeError('The "value" argument must not be of type number. Received type number');var n=A.valueOf&&A.valueOf();if(null!=n&&n!==A)return g.from(n,t,e);var r=function(A){if(g.isBuffer(A)){var t=0|f(A.length),e=B(t);return 0===e.length||A.copy(e,0,0,t),e}return void 0!==A.length?"number"!=typeof A.length||$(A.length)?B(0):h(A):"Buffer"===A.type&&Array.isArray(A.data)?h(A.data):void 0}(A);if(r)return r;if("undefined"!=typeof Symbol&&null!=Symbol.toPrimitive&&"function"==typeof A[Symbol.toPrimitive])return g.from(A[Symbol.toPrimitive]("string"),t,e);throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type "+typeof A)}function u(A){if("number"!=typeof A)throw new TypeError('"size" argument must be of type number');if(A<0)throw new RangeError('The value "'+A+'" is invalid for option "size"')}function w(A){return u(A),B(A<0?0:0|f(A))}function h(A){for(var t=A.length<0?0:0|f(A.length),e=B(t),n=0;n<t;n+=1)e[n]=255&A[n];return e}function E(A,t,e){if(t<0||A.byteLength<t)throw new RangeError('"offset" is outside of buffer bounds');if(A.byteLength<t+(e||0))throw new RangeError('"length" is outside of buffer bounds');var n;return n=void 0===t&&void 0===e?new Uint8Array(A):void 0===e?new Uint8Array(A,t):new Uint8Array(A,t,e),Object.setPrototypeOf(n,g.prototype),n}function f(A){if(A>=c)throw new RangeError("Attempt to allocate Buffer larger than maximum size: 0x"+c.toString(16)+" bytes");return 0|A}function Q(A,t){if(g.isBuffer(A))return A.length;if(ArrayBuffer.isView(A)||q(A,ArrayBuffer))return A.byteLength;if("string"!=typeof A)throw new TypeError('The "string" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof A);var e=A.length,n=arguments.length>2&&!0===arguments[2];if(!n&&0===e)return 0;for(var r=!1;;)switch(t){case"ascii":case"latin1":case"binary":return e;case"utf8":case"utf-8":return X(A).length;case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return 2*e;case"hex":return e>>>1;case"base64":return Z(A).length;default:if(r)return n?-1:X(A).length;t=(""+t).toLowerCase(),r=!0}}function d(A,t,e){var n=!1;if((void 0===t||t<0)&&(t=0),t>this.length)return"";if((void 0===e||e>this.length)&&(e=this.length),e<=0)return"";if((e>>>=0)<=(t>>>=0))return"";for(A||(A="utf8");;)switch(A){case"hex":return S(this,t,e);case"utf8":case"utf-8":return Y(this,t,e);case"ascii":return z(this,t,e);case"latin1":case"binary":return U(this,t,e);case"base64":return F(this,t,e);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return x(this,t,e);default:if(n)throw new TypeError("Unknown encoding: "+A);A=(A+"").toLowerCase(),n=!0}}function C(A,t,e){var n=A[t];A[t]=A[e],A[e]=n}function M(A,t,e,n,r){if(0===A.length)return-1;if("string"==typeof e?(n=e,e=0):e>2147483647?e=2147483647:e<-2147483648&&(e=-2147483648),$(e=+e)&&(e=r?0:A.length-1),e<0&&(e=A.length+e),e>=A.length){if(r)return-1;e=A.length-1}else if(e<0){if(!r)return-1;e=0}if("string"==typeof t&&(t=g.from(t,n)),g.isBuffer(t))return 0===t.length?-1:I(A,t,e,n,r);if("number"==typeof t)return t&=255,"function"==typeof Uint8Array.prototype.indexOf?r?Uint8Array.prototype.indexOf.call(A,t,e):Uint8Array.prototype.lastIndexOf.call(A,t,e):I(A,[t],e,n,r);throw new TypeError("val must be string, number or Buffer")}function I(A,t,e,n,r){var i,o=1,s=A.length,a=t.length;if(void 0!==n&&("ucs2"===(n=String(n).toLowerCase())||"ucs-2"===n||"utf16le"===n||"utf-16le"===n)){if(A.length<2||t.length<2)return-1;o=2,s/=2,a/=2,e/=2}function c(A,t){return 1===o?A[t]:A.readUInt16BE(t*o)}if(r){var B=-1;for(i=e;i<s;i++)if(c(A,i)===c(t,-1===B?0:i-B)){if(-1===B&&(B=i),i-B+1===a)return B*o}else-1!==B&&(i-=i-B),B=-1}else for(e+a>s&&(e=s-a),i=e;i>=0;i--){for(var g=!0,l=0;l<a;l++)if(c(A,i+l)!==c(t,l)){g=!1;break}if(g)return i}return-1}function p(A,t,e,n){e=Number(e)||0;var r=A.length-e;n?(n=Number(n))>r&&(n=r):n=r;var i,o=t.length;for(n>o/2&&(n=o/2),i=0;i<n;++i){var s=parseInt(t.substr(2*i,2),16);if($(s))return i;A[e+i]=s}return i}function D(A,t,e,n){return _(X(t,A.length-e),A,e,n)}function y(A,t,e,n){return _(function(A){for(var t=[],e=0;e<A.length;++e)t.push(255&A.charCodeAt(e));return t}(t),A,e,n)}function v(A,t,e,n){return _(Z(t),A,e,n)}function m(A,t,e,n){return _(function(A,t){for(var e,n,r,i=[],o=0;o<A.length&&!((t-=2)<0);++o)n=(e=A.charCodeAt(o))>>8,r=e%256,i.push(r),i.push(n);return i}(t,A.length-e),A,e,n)}function F(A,t,e){return 0===t&&e===A.length?o.fromByteArray(A):o.fromByteArray(A.slice(t,e))}function Y(A,t,e){e=Math.min(A.length,e);for(var n=[],r=t;r<e;){var i=A[r],o=null,s=i>239?4:i>223?3:i>191?2:1;if(r+s<=e){var a=void 0,c=void 0,B=void 0,g=void 0;switch(s){case 1:i<128&&(o=i);break;case 2:128==(192&(a=A[r+1]))&&(g=(31&i)<<6|63&a)>127&&(o=g);break;case 3:a=A[r+1],c=A[r+2],128==(192&a)&&128==(192&c)&&(g=(15&i)<<12|(63&a)<<6|63&c)>2047&&(g<55296||g>57343)&&(o=g);break;case 4:a=A[r+1],c=A[r+2],B=A[r+3],128==(192&a)&&128==(192&c)&&128==(192&B)&&(g=(15&i)<<18|(63&a)<<12|(63&c)<<6|63&B)>65535&&g<1114112&&(o=g)}}null===o?(o=65533,s=1):o>65535&&(o-=65536,n.push(o>>>10&1023|55296),o=56320|1023&o),n.push(o),r+=s}return function(A){var t=A.length;if(t<=b)return String.fromCharCode.apply(String,A);for(var e="",n=0;n<t;)e+=String.fromCharCode.apply(String,A.slice(n,n+=b));return e}(n)}t.kMaxLength=c,g.TYPED_ARRAY_SUPPORT=function(){try{var A=new Uint8Array(1),t={foo:function(){return 42}};return Object.setPrototypeOf(t,Uint8Array.prototype),Object.setPrototypeOf(A,t),42===A.foo()}catch(A){return!1}}(),!g.TYPED_ARRAY_SUPPORT&&"undefined"!=typeof console&&console.error,Object.defineProperty(g.prototype,"parent",{enumerable:!0,get:function(){if(g.isBuffer(this))return this.buffer}}),Object.defineProperty(g.prototype,"offset",{enumerable:!0,get:function(){if(g.isBuffer(this))return this.byteOffset}}),g.poolSize=8192,g.from=function(A,t,e){return l(A,t,e)},Object.setPrototypeOf(g.prototype,Uint8Array.prototype),Object.setPrototypeOf(g,Uint8Array),g.alloc=function(A,t,e){return function(A,t,e){return u(A),A<=0?B(A):void 0!==t?"string"==typeof e?B(A).fill(t,e):B(A).fill(t):B(A)}(A,t,e)},g.allocUnsafe=function(A){return w(A)},g.allocUnsafeSlow=function(A){return w(A)},g.isBuffer=function(A){return null!=A&&!0===A._isBuffer&&A!==g.prototype},g.compare=function(A,t){if(q(A,Uint8Array)&&(A=g.from(A,A.offset,A.byteLength)),q(t,Uint8Array)&&(t=g.from(t,t.offset,t.byteLength)),!g.isBuffer(A)||!g.isBuffer(t))throw new TypeError('The "buf1", "buf2" arguments must be one of type Buffer or Uint8Array');if(A===t)return 0;for(var e=A.length,n=t.length,r=0,i=Math.min(e,n);r<i;++r)if(A[r]!==t[r]){e=A[r],n=t[r];break}return e<n?-1:n<e?1:0},g.isEncoding=function(A){switch(String(A).toLowerCase()){case"hex":case"utf8":case"utf-8":case"ascii":case"latin1":case"binary":case"base64":case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return!0;default:return!1}},g.concat=function(A,t){if(!Array.isArray(A))throw new TypeError('"list" argument must be an Array of Buffers');if(0===A.length)return g.alloc(0);var e;if(void 0===t)for(t=0,e=0;e<A.length;++e)t+=A[e].length;var n=g.allocUnsafe(t),r=0;for(e=0;e<A.length;++e){var i=A[e];if(q(i,Uint8Array))r+i.length>n.length?(g.isBuffer(i)||(i=g.from(i)),i.copy(n,r)):Uint8Array.prototype.set.call(n,i,r);else{if(!g.isBuffer(i))throw new TypeError('"list" argument must be an Array of Buffers');i.copy(n,r)}r+=i.length}return n},g.byteLength=Q,g.prototype._isBuffer=!0,g.prototype.swap16=function(){var A=this.length;if(A%2!=0)throw new RangeError("Buffer size must be a multiple of 16-bits");for(var t=0;t<A;t+=2)C(this,t,t+1);return this},g.prototype.swap32=function(){var A=this.length;if(A%4!=0)throw new RangeError("Buffer size must be a multiple of 32-bits");for(var t=0;t<A;t+=4)C(this,t,t+3),C(this,t+1,t+2);return this},g.prototype.swap64=function(){var A=this.length;if(A%8!=0)throw new RangeError("Buffer size must be a multiple of 64-bits");for(var t=0;t<A;t+=8)C(this,t,t+7),C(this,t+1,t+6),C(this,t+2,t+5),C(this,t+3,t+4);return this},g.prototype.toString=function(){var A=this.length;return 0===A?"":0===arguments.length?Y(this,0,A):d.apply(this,arguments)},g.prototype.toLocaleString=g.prototype.toString,g.prototype.equals=function(A){if(!g.isBuffer(A))throw new TypeError("Argument must be a Buffer");return this===A||0===g.compare(this,A)},g.prototype.inspect=function(){var A="",e=t.INSPECT_MAX_BYTES;return A=this.toString("hex",0,e).replace(/(.{2})/g,"$1 ").trim(),this.length>e&&(A+=" ... "),"<Buffer "+A+">"},a&&(g.prototype[a]=g.prototype.inspect),g.prototype.compare=function(A,t,e,n,r){if(q(A,Uint8Array)&&(A=g.from(A,A.offset,A.byteLength)),!g.isBuffer(A))throw new TypeError('The "target" argument must be one of type Buffer or Uint8Array. Received type '+typeof A);if(void 0===t&&(t=0),void 0===e&&(e=A?A.length:0),void 0===n&&(n=0),void 0===r&&(r=this.length),t<0||e>A.length||n<0||r>this.length)throw new RangeError("out of range index");if(n>=r&&t>=e)return 0;if(n>=r)return-1;if(t>=e)return 1;if(this===A)return 0;for(var i=(r>>>=0)-(n>>>=0),o=(e>>>=0)-(t>>>=0),s=Math.min(i,o),a=this.slice(n,r),c=A.slice(t,e),B=0;B<s;++B)if(a[B]!==c[B]){i=a[B],o=c[B];break}return i<o?-1:o<i?1:0},g.prototype.includes=function(A,t,e){return-1!==this.indexOf(A,t,e)},g.prototype.indexOf=function(A,t,e){return M(this,A,t,e,!0)},g.prototype.lastIndexOf=function(A,t,e){return M(this,A,t,e,!1)},g.prototype.write=function(A,t,e,n){if(void 0===t)n="utf8",e=this.length,t=0;else if(void 0===e&&"string"==typeof t)n=t,e=this.length,t=0;else{if(!isFinite(t))throw new Error("Buffer.write(string, encoding, offset[, length]) is no longer supported");t>>>=0,isFinite(e)?(e>>>=0,void 0===n&&(n="utf8")):(n=e,e=void 0)}var r=this.length-t;if((void 0===e||e>r)&&(e=r),A.length>0&&(e<0||t<0)||t>this.length)throw new RangeError("Attempt to write outside buffer bounds");n||(n="utf8");for(var i=!1;;)switch(n){case"hex":return p(this,A,t,e);case"utf8":case"utf-8":return D(this,A,t,e);case"ascii":case"latin1":case"binary":return y(this,A,t,e);case"base64":return v(this,A,t,e);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return m(this,A,t,e);default:if(i)throw new TypeError("Unknown encoding: "+n);n=(""+n).toLowerCase(),i=!0}},g.prototype.toJSON=function(){return{type:"Buffer",data:Array.prototype.slice.call(this._arr||this,0)}};var b=4096;function z(A,t,e){var n="";e=Math.min(A.length,e);for(var r=t;r<e;++r)n+=String.fromCharCode(127&A[r]);return n}function U(A,t,e){var n="";e=Math.min(A.length,e);for(var r=t;r<e;++r)n+=String.fromCharCode(A[r]);return n}function S(A,t,e){var n=A.length;(!t||t<0)&&(t=0),(!e||e<0||e>n)&&(e=n);for(var r="",i=t;i<e;++i)r+=AA[A[i]];return r}function x(A,t,e){for(var n=A.slice(t,e),r="",i=0;i<n.length-1;i+=2)r+=String.fromCharCode(n[i]+256*n[i+1]);return r}function T(A,t,e){if(A%1!=0||A<0)throw new RangeError("offset is not uint");if(A+t>e)throw new RangeError("Trying to access beyond buffer length")}function P(A,t,e,n,r,i){if(!g.isBuffer(A))throw new TypeError('"buffer" argument must be a Buffer instance');if(t>r||t<i)throw new RangeError('"value" argument is out of bounds');if(e+n>A.length)throw new RangeError("Index out of range")}function N(A,t,e,n,r){O(t,n,r,A,e,7);var i=Number(t&BigInt(4294967295));A[e++]=i,i>>=8,A[e++]=i,i>>=8,A[e++]=i,i>>=8,A[e++]=i;var o=Number(t>>BigInt(32)&BigInt(4294967295));return A[e++]=o,o>>=8,A[e++]=o,o>>=8,A[e++]=o,o>>=8,A[e++]=o,e}function R(A,t,e,n,r){O(t,n,r,A,e,7);var i=Number(t&BigInt(4294967295));A[e+7]=i,i>>=8,A[e+6]=i,i>>=8,A[e+5]=i,i>>=8,A[e+4]=i;var o=Number(t>>BigInt(32)&BigInt(4294967295));return A[e+3]=o,o>>=8,A[e+2]=o,o>>=8,A[e+1]=o,o>>=8,A[e]=o,e+8}function G(A,t,e,n,r,i){if(e+n>A.length)throw new RangeError("Index out of range");if(e<0)throw new RangeError("Index out of range")}function H(A,t,e,n,r){return t=+t,e>>>=0,r||G(A,0,e,4),s.write(A,t,e,n,23,4),e+4}function k(A,t,e,n,r){return t=+t,e>>>=0,r||G(A,0,e,8),s.write(A,t,e,n,52,8),e+8}g.prototype.slice=function(A,t){var e=this.length;(A=~~A)<0?(A+=e)<0&&(A=0):A>e&&(A=e),(t=void 0===t?e:~~t)<0?(t+=e)<0&&(t=0):t>e&&(t=e),t<A&&(t=A);var n=this.subarray(A,t);return Object.setPrototypeOf(n,g.prototype),n},g.prototype.readUintLE=g.prototype.readUIntLE=function(A,t,e){A>>>=0,t>>>=0,e||T(A,t,this.length);for(var n=this[A],r=1,i=0;++i<t&&(r*=256);)n+=this[A+i]*r;return n},g.prototype.readUintBE=g.prototype.readUIntBE=function(A,t,e){A>>>=0,t>>>=0,e||T(A,t,this.length);for(var n=this[A+--t],r=1;t>0&&(r*=256);)n+=this[A+--t]*r;return n},g.prototype.readUint8=g.prototype.readUInt8=function(A,t){return A>>>=0,t||T(A,1,this.length),this[A]},g.prototype.readUint16LE=g.prototype.readUInt16LE=function(A,t){return A>>>=0,t||T(A,2,this.length),this[A]|this[A+1]<<8},g.prototype.readUint16BE=g.prototype.readUInt16BE=function(A,t){return A>>>=0,t||T(A,2,this.length),this[A]<<8|this[A+1]},g.prototype.readUint32LE=g.prototype.readUInt32LE=function(A,t){return A>>>=0,t||T(A,4,this.length),(this[A]|this[A+1]<<8|this[A+2]<<16)+16777216*this[A+3]},g.prototype.readUint32BE=g.prototype.readUInt32BE=function(A,t){return A>>>=0,t||T(A,4,this.length),16777216*this[A]+(this[A+1]<<16|this[A+2]<<8|this[A+3])},g.prototype.readBigUInt64LE=tA((function(A){W(A>>>=0,"offset");var t=this[A],e=this[A+7];void 0!==t&&void 0!==e||K(A,this.length-8);var n=t+this[++A]*Math.pow(2,8)+this[++A]*Math.pow(2,16)+this[++A]*Math.pow(2,24),r=this[++A]+this[++A]*Math.pow(2,8)+this[++A]*Math.pow(2,16)+e*Math.pow(2,24);return BigInt(n)+(BigInt(r)<<BigInt(32))})),g.prototype.readBigUInt64BE=tA((function(A){W(A>>>=0,"offset");var t=this[A],e=this[A+7];void 0!==t&&void 0!==e||K(A,this.length-8);var n=t*Math.pow(2,24)+this[++A]*Math.pow(2,16)+this[++A]*Math.pow(2,8)+this[++A],r=this[++A]*Math.pow(2,24)+this[++A]*Math.pow(2,16)+this[++A]*Math.pow(2,8)+e;return(BigInt(n)<<BigInt(32))+BigInt(r)})),g.prototype.readIntLE=function(A,t,e){A>>>=0,t>>>=0,e||T(A,t,this.length);for(var n=this[A],r=1,i=0;++i<t&&(r*=256);)n+=this[A+i]*r;return n>=(r*=128)&&(n-=Math.pow(2,8*t)),n},g.prototype.readIntBE=function(A,t,e){A>>>=0,t>>>=0,e||T(A,t,this.length);for(var n=t,r=1,i=this[A+--n];n>0&&(r*=256);)i+=this[A+--n]*r;return i>=(r*=128)&&(i-=Math.pow(2,8*t)),i},g.prototype.readInt8=function(A,t){return A>>>=0,t||T(A,1,this.length),128&this[A]?-1*(255-this[A]+1):this[A]},g.prototype.readInt16LE=function(A,t){A>>>=0,t||T(A,2,this.length);var e=this[A]|this[A+1]<<8;return 32768&e?4294901760|e:e},g.prototype.readInt16BE=function(A,t){A>>>=0,t||T(A,2,this.length);var e=this[A+1]|this[A]<<8;return 32768&e?4294901760|e:e},g.prototype.readInt32LE=function(A,t){return A>>>=0,t||T(A,4,this.length),this[A]|this[A+1]<<8|this[A+2]<<16|this[A+3]<<24},g.prototype.readInt32BE=function(A,t){return A>>>=0,t||T(A,4,this.length),this[A]<<24|this[A+1]<<16|this[A+2]<<8|this[A+3]},g.prototype.readBigInt64LE=tA((function(A){W(A>>>=0,"offset");var t=this[A],e=this[A+7];void 0!==t&&void 0!==e||K(A,this.length-8);var n=this[A+4]+this[A+5]*Math.pow(2,8)+this[A+6]*Math.pow(2,16)+(e<<24);return(BigInt(n)<<BigInt(32))+BigInt(t+this[++A]*Math.pow(2,8)+this[++A]*Math.pow(2,16)+this[++A]*Math.pow(2,24))})),g.prototype.readBigInt64BE=tA((function(A){W(A>>>=0,"offset");var t=this[A],e=this[A+7];void 0!==t&&void 0!==e||K(A,this.length-8);var n=(t<<24)+this[++A]*Math.pow(2,16)+this[++A]*Math.pow(2,8)+this[++A];return(BigInt(n)<<BigInt(32))+BigInt(this[++A]*Math.pow(2,24)+this[++A]*Math.pow(2,16)+this[++A]*Math.pow(2,8)+e)})),g.prototype.readFloatLE=function(A,t){return A>>>=0,t||T(A,4,this.length),s.read(this,A,!0,23,4)},g.prototype.readFloatBE=function(A,t){return A>>>=0,t||T(A,4,this.length),s.read(this,A,!1,23,4)},g.prototype.readDoubleLE=function(A,t){return A>>>=0,t||T(A,8,this.length),s.read(this,A,!0,52,8)},g.prototype.readDoubleBE=function(A,t){return A>>>=0,t||T(A,8,this.length),s.read(this,A,!1,52,8)},g.prototype.writeUintLE=g.prototype.writeUIntLE=function(A,t,e,n){A=+A,t>>>=0,e>>>=0,n||P(this,A,t,e,Math.pow(2,8*e)-1,0);var r=1,i=0;for(this[t]=255&A;++i<e&&(r*=256);)this[t+i]=A/r&255;return t+e},g.prototype.writeUintBE=g.prototype.writeUIntBE=function(A,t,e,n){A=+A,t>>>=0,e>>>=0,n||P(this,A,t,e,Math.pow(2,8*e)-1,0);var r=e-1,i=1;for(this[t+r]=255&A;--r>=0&&(i*=256);)this[t+r]=A/i&255;return t+e},g.prototype.writeUint8=g.prototype.writeUInt8=function(A,t,e){return A=+A,t>>>=0,e||P(this,A,t,1,255,0),this[t]=255&A,t+1},g.prototype.writeUint16LE=g.prototype.writeUInt16LE=function(A,t,e){return A=+A,t>>>=0,e||P(this,A,t,2,65535,0),this[t]=255&A,this[t+1]=A>>>8,t+2},g.prototype.writeUint16BE=g.prototype.writeUInt16BE=function(A,t,e){return A=+A,t>>>=0,e||P(this,A,t,2,65535,0),this[t]=A>>>8,this[t+1]=255&A,t+2},g.prototype.writeUint32LE=g.prototype.writeUInt32LE=function(A,t,e){return A=+A,t>>>=0,e||P(this,A,t,4,4294967295,0),this[t+3]=A>>>24,this[t+2]=A>>>16,this[t+1]=A>>>8,this[t]=255&A,t+4},g.prototype.writeUint32BE=g.prototype.writeUInt32BE=function(A,t,e){return A=+A,t>>>=0,e||P(this,A,t,4,4294967295,0),this[t]=A>>>24,this[t+1]=A>>>16,this[t+2]=A>>>8,this[t+3]=255&A,t+4},g.prototype.writeBigUInt64LE=tA((function(A,t){return void 0===t&&(t=0),N(this,A,t,BigInt(0),BigInt("0xffffffffffffffff"))})),g.prototype.writeBigUInt64BE=tA((function(A,t){return void 0===t&&(t=0),R(this,A,t,BigInt(0),BigInt("0xffffffffffffffff"))})),g.prototype.writeIntLE=function(A,t,e,n){if(A=+A,t>>>=0,!n){var r=Math.pow(2,8*e-1);P(this,A,t,e,r-1,-r)}var i=0,o=1,s=0;for(this[t]=255&A;++i<e&&(o*=256);)A<0&&0===s&&0!==this[t+i-1]&&(s=1),this[t+i]=(A/o>>0)-s&255;return t+e},g.prototype.writeIntBE=function(A,t,e,n){if(A=+A,t>>>=0,!n){var r=Math.pow(2,8*e-1);P(this,A,t,e,r-1,-r)}var i=e-1,o=1,s=0;for(this[t+i]=255&A;--i>=0&&(o*=256);)A<0&&0===s&&0!==this[t+i+1]&&(s=1),this[t+i]=(A/o>>0)-s&255;return t+e},g.prototype.writeInt8=function(A,t,e){return A=+A,t>>>=0,e||P(this,A,t,1,127,-128),A<0&&(A=255+A+1),this[t]=255&A,t+1},g.prototype.writeInt16LE=function(A,t,e){return A=+A,t>>>=0,e||P(this,A,t,2,32767,-32768),this[t]=255&A,this[t+1]=A>>>8,t+2},g.prototype.writeInt16BE=function(A,t,e){return A=+A,t>>>=0,e||P(this,A,t,2,32767,-32768),this[t]=A>>>8,this[t+1]=255&A,t+2},g.prototype.writeInt32LE=function(A,t,e){return A=+A,t>>>=0,e||P(this,A,t,4,2147483647,-2147483648),this[t]=255&A,this[t+1]=A>>>8,this[t+2]=A>>>16,this[t+3]=A>>>24,t+4},g.prototype.writeInt32BE=function(A,t,e){return A=+A,t>>>=0,e||P(this,A,t,4,2147483647,-2147483648),A<0&&(A=4294967295+A+1),this[t]=A>>>24,this[t+1]=A>>>16,this[t+2]=A>>>8,this[t+3]=255&A,t+4},g.prototype.writeBigInt64LE=tA((function(A,t){return void 0===t&&(t=0),N(this,A,t,-BigInt("0x8000000000000000"),BigInt("0x7fffffffffffffff"))})),g.prototype.writeBigInt64BE=tA((function(A,t){return void 0===t&&(t=0),R(this,A,t,-BigInt("0x8000000000000000"),BigInt("0x7fffffffffffffff"))})),g.prototype.writeFloatLE=function(A,t,e){return H(this,A,t,!0,e)},g.prototype.writeFloatBE=function(A,t,e){return H(this,A,t,!1,e)},g.prototype.writeDoubleLE=function(A,t,e){return k(this,A,t,!0,e)},g.prototype.writeDoubleBE=function(A,t,e){return k(this,A,t,!1,e)},g.prototype.copy=function(A,t,e,n){if(!g.isBuffer(A))throw new TypeError("argument should be a Buffer");if(e||(e=0),n||0===n||(n=this.length),t>=A.length&&(t=A.length),t||(t=0),n>0&&n<e&&(n=e),n===e)return 0;if(0===A.length||0===this.length)return 0;if(t<0)throw new RangeError("targetStart out of bounds");if(e<0||e>=this.length)throw new RangeError("Index out of range");if(n<0)throw new RangeError("sourceEnd out of bounds");n>this.length&&(n=this.length),A.length-t<n-e&&(n=A.length-t+e);var r=n-e;return this===A&&"function"==typeof Uint8Array.prototype.copyWithin?this.copyWithin(t,e,n):Uint8Array.prototype.set.call(A,this.subarray(e,n),t),r},g.prototype.fill=function(A,t,e,n){if("string"==typeof A){if("string"==typeof t?(n=t,t=0,e=this.length):"string"==typeof e&&(n=e,e=this.length),void 0!==n&&"string"!=typeof n)throw new TypeError("encoding must be a string");if("string"==typeof n&&!g.isEncoding(n))throw new TypeError("Unknown encoding: "+n);if(1===A.length){var r=A.charCodeAt(0);("utf8"===n&&r<128||"latin1"===n)&&(A=r)}}else"number"==typeof A?A&=255:"boolean"==typeof A&&(A=Number(A));if(t<0||this.length<t||this.length<e)throw new RangeError("Out of range index");if(e<=t)return this;var i;if(t>>>=0,e=void 0===e?this.length:e>>>0,A||(A=0),"number"==typeof A)for(i=t;i<e;++i)this[i]=A;else{var o=g.isBuffer(A)?A:g.from(A,n),s=o.length;if(0===s)throw new TypeError('The value "'+A+'" is invalid for argument "value"');for(i=0;i<e-t;++i)this[i+t]=o[i%s]}return this};var L={};function J(A,t,e){L[A]=function(e){function o(){var n;return n=e.call(this)||this,Object.defineProperty(r(n),"message",{value:t.apply(r(n),arguments),writable:!0,configurable:!0}),n.name=n.name+" ["+A+"]",n.stack,delete n.name,n}return function(A,t){A.prototype=Object.create(t.prototype),A.prototype.constructor=A,i(A,t)}(o,e),o.prototype.toString=function(){return this.name+" ["+A+"]: "+this.message},function(A,t,e){t&&n(A.prototype,t),e&&n(A,e),Object.defineProperty(A,"prototype",{writable:!1})}(o,[{key:"code",get:function(){return A},set:function(A){Object.defineProperty(this,"code",{configurable:!0,enumerable:!0,value:A,writable:!0})}}]),o}(e)}function j(A){for(var t="",e=A.length,n="-"===A[0]?1:0;e>=n+4;e-=3)t="_"+A.slice(e-3,e)+t;return""+A.slice(0,e)+t}function O(A,t,e,n,r,i){if(A>e||A<t){var o,s="bigint"==typeof t?"n":"";throw o=i>3?0===t||t===BigInt(0)?">= 0"+s+" and < 2"+s+" ** "+8*(i+1)+s:">= -(2"+s+" ** "+(8*(i+1)-1)+s+") and < 2 ** "+(8*(i+1)-1)+s:">= "+t+s+" and <= "+e+s,new L.ERR_OUT_OF_RANGE("value",o,A)}!function(A,t,e){W(t,"offset"),void 0!==A[t]&&void 0!==A[t+e]||K(t,A.length-(e+1))}(n,r,i)}function W(A,t){if("number"!=typeof A)throw new L.ERR_INVALID_ARG_TYPE(t,"number",A)}function K(A,t,e){if(Math.floor(A)!==A)throw W(A,e),new L.ERR_OUT_OF_RANGE(e||"offset","an integer",A);if(t<0)throw new L.ERR_BUFFER_OUT_OF_BOUNDS;throw new L.ERR_OUT_OF_RANGE(e||"offset",">= "+(e?1:0)+" and <= "+t,A)}J("ERR_BUFFER_OUT_OF_BOUNDS",(function(A){return A?A+" is outside of buffer bounds":"Attempt to access memory outside buffer bounds"}),RangeError),J("ERR_INVALID_ARG_TYPE",(function(A,t){return'The "'+A+'" argument must be of type number. Received type '+typeof t}),TypeError),J("ERR_OUT_OF_RANGE",(function(A,t,e){var n='The value of "'+A+'" is out of range.',r=e;return Number.isInteger(e)&&Math.abs(e)>Math.pow(2,32)?r=j(String(e)):"bigint"==typeof e&&(r=String(e),(e>Math.pow(BigInt(2),BigInt(32))||e<-Math.pow(BigInt(2),BigInt(32)))&&(r=j(r)),r+="n"),n+" It must be "+t+". Received "+r}),RangeError);var V=/[^+/0-9A-Za-z-_]/g;function X(A,t){var e;t=t||1/0;for(var n=A.length,r=null,i=[],o=0;o<n;++o){if((e=A.charCodeAt(o))>55295&&e<57344){if(!r){if(e>56319){(t-=3)>-1&&i.push(239,191,189);continue}if(o+1===n){(t-=3)>-1&&i.push(239,191,189);continue}r=e;continue}if(e<56320){(t-=3)>-1&&i.push(239,191,189),r=e;continue}e=65536+(r-55296<<10|e-56320)}else r&&(t-=3)>-1&&i.push(239,191,189);if(r=null,e<128){if((t-=1)<0)break;i.push(e)}else if(e<2048){if((t-=2)<0)break;i.push(e>>6|192,63&e|128)}else if(e<65536){if((t-=3)<0)break;i.push(e>>12|224,e>>6&63|128,63&e|128)}else{if(!(e<1114112))throw new Error("Invalid code point");if((t-=4)<0)break;i.push(e>>18|240,e>>12&63|128,e>>6&63|128,63&e|128)}}return i}function Z(A){return o.toByteArray(function(A){if((A=(A=A.split("=")[0]).trim().replace(V,"")).length<2)return"";for(;A.length%4!=0;)A+="=";return A}(A))}function _(A,t,e,n){var r;for(r=0;r<n&&!(r+e>=t.length||r>=A.length);++r)t[r+e]=A[r];return r}function q(A,t){return A instanceof t||null!=A&&null!=A.constructor&&null!=A.constructor.name&&A.constructor.name===t.name}function $(A){return A!=A}var AA=function(){for(var A="0123456789abcdef",t=new Array(256),e=0;e<16;++e)for(var n=16*e,r=0;r<16;++r)t[n+r]=A[e]+A[r];return t}();function tA(A){return"undefined"==typeof BigInt?eA:A}function eA(){throw new Error("BigInt not supported")}},477:function(A,t,e){"use strict";e(7803),e(1539),A.exports="undefined"!=typeof ArrayBuffer&&"undefined"!=typeof DataView},2094:function(A,t,e){"use strict";var n,r,i,o=e(477),s=e(9781),a=e(7854),c=e(614),B=e(111),g=e(2597),l=e(648),u=e(6330),w=e(8880),h=e(1320),E=e(3070).f,f=e(7976),Q=e(9518),d=e(7674),C=e(5112),M=e(9711),I=a.Int8Array,p=I&&I.prototype,D=a.Uint8ClampedArray,y=D&&D.prototype,v=I&&Q(I),m=p&&Q(p),F=Object.prototype,Y=a.TypeError,b=C("toStringTag"),z=M("TYPED_ARRAY_TAG"),U=M("TYPED_ARRAY_CONSTRUCTOR"),S=o&&!!d&&"Opera"!==l(a.opera),x=!1,T={Int8Array:1,Uint8Array:1,Uint8ClampedArray:1,Int16Array:2,Uint16Array:2,Int32Array:4,Uint32Array:4,Float32Array:4,Float64Array:8},P={BigInt64Array:8,BigUint64Array:8},N=function(A){if(!B(A))return!1;var t=l(A);return g(T,t)||g(P,t)};for(n in T)(i=(r=a[n])&&r.prototype)?w(i,U,r):S=!1;for(n in P)(i=(r=a[n])&&r.prototype)&&w(i,U,r);if((!S||!c(v)||v===Function.prototype)&&(v=function(){throw Y("Incorrect invocation")},S))for(n in T)a[n]&&d(a[n],v);if((!S||!m||m===F)&&(m=v.prototype,S))for(n in T)a[n]&&d(a[n].prototype,m);if(S&&Q(y)!==m&&d(y,m),s&&!g(m,b))for(n in x=!0,E(m,b,{get:function(){return B(this)?this[z]:void 0}}),T)a[n]&&w(a[n],z,n);A.exports={NATIVE_ARRAY_BUFFER_VIEWS:S,TYPED_ARRAY_CONSTRUCTOR:U,TYPED_ARRAY_TAG:x&&z,aTypedArray:function(A){if(N(A))return A;throw Y("Target is not a typed array")},aTypedArrayConstructor:function(A){if(c(A)&&(!d||f(v,A)))return A;throw Y(u(A)+" is not a typed array constructor")},exportTypedArrayMethod:function(A,t,e){if(s){if(e)for(var n in T){var r=a[n];if(r&&g(r.prototype,A))try{delete r.prototype[A]}catch(A){}}m[A]&&!e||h(m,A,e?t:S&&p[A]||t)}},exportTypedArrayStaticMethod:function(A,t,e){var n,r;if(s){if(d){if(e)for(n in T)if((r=a[n])&&g(r,A))try{delete r[A]}catch(A){}if(v[A]&&!e)return;try{return h(v,A,e?t:S&&v[A]||t)}catch(A){}}for(n in T)!(r=a[n])||r[A]&&!e||h(r,A,t)}},isView:function(A){if(!B(A))return!1;var t=l(A);return"DataView"===t||g(T,t)||g(P,t)},isTypedArray:N,TypedArray:v,TypedArrayPrototype:m}},2091:function(A,t,e){"use strict";e(8309);var n=e(7854),r=e(1702),i=e(9781),o=e(477),s=e(6530),a=e(8880),c=e(2248),B=e(7293),g=e(5787),l=e(9303),u=e(7466),w=e(7067),h=e(1179),E=e(9518),f=e(7674),Q=e(8006).f,d=e(3070).f,C=e(1285),M=e(206),I=e(8003),p=e(9909),D=s.PROPER,y=s.CONFIGURABLE,v=p.get,m=p.set,F="ArrayBuffer",Y="DataView",b="prototype",z="Wrong index",U=n[F],S=U,x=S&&S[b],T=n[Y],P=T&&T[b],N=Object.prototype,R=n.Array,G=n.RangeError,H=r(C),k=r([].reverse),L=h.pack,J=h.unpack,j=function(A){return[255&A]},O=function(A){return[255&A,A>>8&255]},W=function(A){return[255&A,A>>8&255,A>>16&255,A>>24&255]},K=function(A){return A[3]<<24|A[2]<<16|A[1]<<8|A[0]},V=function(A){return L(A,23,4)},X=function(A){return L(A,52,8)},Z=function(A,t){d(A[b],t,{get:function(){return v(this)[t]}})},_=function(A,t,e,n){var r=w(e),i=v(A);if(r+t>i.byteLength)throw G(z);var o=v(i.buffer).bytes,s=r+i.byteOffset,a=M(o,s,s+t);return n?a:k(a)},q=function(A,t,e,n,r,i){var o=w(e),s=v(A);if(o+t>s.byteLength)throw G(z);for(var a=v(s.buffer).bytes,c=o+s.byteOffset,B=n(+r),g=0;g<t;g++)a[c+g]=B[i?g:t-g-1]};if(o){var $=D&&U.name!==F;if(B((function(){U(1)}))&&B((function(){new U(-1)}))&&!B((function(){return new U,new U(1.5),new U(NaN),$&&!y})))$&&y&&a(U,"name",F);else{(S=function(A){return g(this,x),new U(w(A))})[b]=x;for(var AA,tA=Q(U),eA=0;tA.length>eA;)(AA=tA[eA++])in S||a(S,AA,U[AA]);x.constructor=S}f&&E(P)!==N&&f(P,N);var nA=new T(new S(2)),rA=r(P.setInt8);nA.setInt8(0,2147483648),nA.setInt8(1,2147483649),!nA.getInt8(0)&&nA.getInt8(1)||c(P,{setInt8:function(A,t){rA(this,A,t<<24>>24)},setUint8:function(A,t){rA(this,A,t<<24>>24)}},{unsafe:!0})}else x=(S=function(A){g(this,x);var t=w(A);m(this,{bytes:H(R(t),0),byteLength:t}),i||(this.byteLength=t)})[b],P=(T=function(A,t,e){g(this,P),g(A,x);var n=v(A).byteLength,r=l(t);if(r<0||r>n)throw G("Wrong offset");if(r+(e=void 0===e?n-r:u(e))>n)throw G("Wrong length");m(this,{buffer:A,byteLength:e,byteOffset:r}),i||(this.buffer=A,this.byteLength=e,this.byteOffset=r)})[b],i&&(Z(S,"byteLength"),Z(T,"buffer"),Z(T,"byteLength"),Z(T,"byteOffset")),c(P,{getInt8:function(A){return _(this,1,A)[0]<<24>>24},getUint8:function(A){return _(this,1,A)[0]},getInt16:function(A){var t=_(this,2,A,arguments.length>1?arguments[1]:void 0);return(t[1]<<8|t[0])<<16>>16},getUint16:function(A){var t=_(this,2,A,arguments.length>1?arguments[1]:void 0);return t[1]<<8|t[0]},getInt32:function(A){return K(_(this,4,A,arguments.length>1?arguments[1]:void 0))},getUint32:function(A){return K(_(this,4,A,arguments.length>1?arguments[1]:void 0))>>>0},getFloat32:function(A){return J(_(this,4,A,arguments.length>1?arguments[1]:void 0),23)},getFloat64:function(A){return J(_(this,8,A,arguments.length>1?arguments[1]:void 0),52)},setInt8:function(A,t){q(this,1,A,j,t)},setUint8:function(A,t){q(this,1,A,j,t)},setInt16:function(A,t){q(this,2,A,O,t,arguments.length>2?arguments[2]:void 0)},setUint16:function(A,t){q(this,2,A,O,t,arguments.length>2?arguments[2]:void 0)},setInt32:function(A,t){q(this,4,A,W,t,arguments.length>2?arguments[2]:void 0)},setUint32:function(A,t){q(this,4,A,W,t,arguments.length>2?arguments[2]:void 0)},setFloat32:function(A,t){q(this,4,A,V,t,arguments.length>2?arguments[2]:void 0)},setFloat64:function(A,t){q(this,8,A,X,t,arguments.length>2?arguments[2]:void 0)}});I(S,F),I(T,Y),A.exports={ArrayBuffer:S,DataView:T}},7803:function(A,t,e){"use strict";var n=e(2109),r=e(7854),i=e(2091),o=e(6340),s="ArrayBuffer",a=i[s];n({global:!0,forced:r[s]!==a},{ArrayBuffer:a}),o(s)},194:function(A,t,e){"use strict";var n;A.exports=(n=e(757),e(7508),e(3440),e(3839),e(1582),function(){var A=n,t=A.lib.BlockCipher,e=A.algo,r=[],i=[],o=[],s=[],a=[],c=[],B=[],g=[],l=[],u=[];!function(){for(var A=[],t=0;t<256;t++)A[t]=t<128?t<<1:t<<1^283;var e=0,n=0;for(t=0;t<256;t++){var w=n^n<<1^n<<2^n<<3^n<<4;w=w>>>8^255&w^99,r[e]=w,i[w]=e;var h=A[e],E=A[h],f=A[E],Q=257*A[w]^16843008*w;o[e]=Q<<24|Q>>>8,s[e]=Q<<16|Q>>>16,a[e]=Q<<8|Q>>>24,c[e]=Q,Q=16843009*f^65537*E^257*h^16843008*e,B[w]=Q<<24|Q>>>8,g[w]=Q<<16|Q>>>16,l[w]=Q<<8|Q>>>24,u[w]=Q,e?(e=h^A[A[A[f^h]]],n^=A[A[n]]):e=n=1}}();var w=[0,1,2,4,8,16,32,64,128,27,54],h=e.AES=t.extend({_doReset:function(){if(!this._nRounds||this._keyPriorReset!==this._key){for(var A=this._keyPriorReset=this._key,t=A.words,e=A.sigBytes/4,n=4*((this._nRounds=e+6)+1),i=this._keySchedule=[],o=0;o<n;o++)o<e?i[o]=t[o]:(c=i[o-1],o%e?e>6&&o%e==4&&(c=r[c>>>24]<<24|r[c>>>16&255]<<16|r[c>>>8&255]<<8|r[255&c]):(c=r[(c=c<<8|c>>>24)>>>24]<<24|r[c>>>16&255]<<16|r[c>>>8&255]<<8|r[255&c],c^=w[o/e|0]<<24),i[o]=i[o-e]^c);for(var s=this._invKeySchedule=[],a=0;a<n;a++){if(o=n-a,a%4)var c=i[o];else c=i[o-4];s[a]=a<4||o<=4?c:B[r[c>>>24]]^g[r[c>>>16&255]]^l[r[c>>>8&255]]^u[r[255&c]]}}},encryptBlock:function(A,t){this._doCryptBlock(A,t,this._keySchedule,o,s,a,c,r)},decryptBlock:function(A,t){var e=A[t+1];A[t+1]=A[t+3],A[t+3]=e,this._doCryptBlock(A,t,this._invKeySchedule,B,g,l,u,i),e=A[t+1],A[t+1]=A[t+3],A[t+3]=e},_doCryptBlock:function(A,t,e,n,r,i,o,s){for(var a=this._nRounds,c=A[t]^e[0],B=A[t+1]^e[1],g=A[t+2]^e[2],l=A[t+3]^e[3],u=4,w=1;w<a;w++){var h=n[c>>>24]^r[B>>>16&255]^i[g>>>8&255]^o[255&l]^e[u++],E=n[B>>>24]^r[g>>>16&255]^i[l>>>8&255]^o[255&c]^e[u++],f=n[g>>>24]^r[l>>>16&255]^i[c>>>8&255]^o[255&B]^e[u++],Q=n[l>>>24]^r[c>>>16&255]^i[B>>>8&255]^o[255&g]^e[u++];c=h,B=E,g=f,l=Q}h=(s[c>>>24]<<24|s[B>>>16&255]<<16|s[g>>>8&255]<<8|s[255&l])^e[u++],E=(s[B>>>24]<<24|s[g>>>16&255]<<16|s[l>>>8&255]<<8|s[255&c])^e[u++],f=(s[g>>>24]<<24|s[l>>>16&255]<<16|s[c>>>8&255]<<8|s[255&B])^e[u++],Q=(s[l>>>24]<<24|s[c>>>16&255]<<16|s[B>>>8&255]<<8|s[255&g])^e[u++],A[t]=h,A[t+1]=E,A[t+2]=f,A[t+3]=Q},keySize:8});A.AES=t._createHelper(h)}(),n.AES)},1582:function(A,t,e){"use strict";var n;e(7042),e(2222),e(1539),e(9714),e(561),A.exports=(n=e(757),e(3839),void(n.lib.Cipher||function(A){var t=n,e=t.lib,r=e.Base,i=e.WordArray,o=e.BufferedBlockAlgorithm,s=t.enc,a=(s.Utf8,s.Base64),c=t.algo.EvpKDF,B=e.Cipher=o.extend({cfg:r.extend(),createEncryptor:function(A,t){return this.create(this._ENC_XFORM_MODE,A,t)},createDecryptor:function(A,t){return this.create(this._DEC_XFORM_MODE,A,t)},init:function(A,t,e){this.cfg=this.cfg.extend(e),this._xformMode=A,this._key=t,this.reset()},reset:function(){o.reset.call(this),this._doReset()},process:function(A){return this._append(A),this._process()},finalize:function(A){return A&&this._append(A),this._doFinalize()},keySize:4,ivSize:4,_ENC_XFORM_MODE:1,_DEC_XFORM_MODE:2,_createHelper:function(){function A(A){return"string"==typeof A?d:f}return function(t){return{encrypt:function(e,n,r){return A(n).encrypt(t,e,n,r)},decrypt:function(e,n,r){return A(n).decrypt(t,e,n,r)}}}}()}),g=(e.StreamCipher=B.extend({_doFinalize:function(){return this._process(!0)},blockSize:1}),t.mode={}),l=e.BlockCipherMode=r.extend({createEncryptor:function(A,t){return this.Encryptor.create(A,t)},createDecryptor:function(A,t){return this.Decryptor.create(A,t)},init:function(A,t){this._cipher=A,this._iv=t}}),u=g.CBC=function(){var A=l.extend();function t(A,t,e){var n,r=this._iv;r?(n=r,this._iv=undefined):n=this._prevBlock;for(var i=0;i<e;i++)A[t+i]^=n[i]}return A.Encryptor=A.extend({processBlock:function(A,e){var n=this._cipher,r=n.blockSize;t.call(this,A,e,r),n.encryptBlock(A,e),this._prevBlock=A.slice(e,e+r)}}),A.Decryptor=A.extend({processBlock:function(A,e){var n=this._cipher,r=n.blockSize,i=A.slice(e,e+r);n.decryptBlock(A,e),t.call(this,A,e,r),this._prevBlock=i}}),A}(),w=(t.pad={}).Pkcs7={pad:function(A,t){for(var e=4*t,n=e-A.sigBytes%e,r=n<<24|n<<16|n<<8|n,o=[],s=0;s<n;s+=4)o.push(r);var a=i.create(o,n);A.concat(a)},unpad:function(A){var t=255&A.words[A.sigBytes-1>>>2];A.sigBytes-=t}},h=(e.BlockCipher=B.extend({cfg:B.cfg.extend({mode:u,padding:w}),reset:function(){var A;B.reset.call(this);var t=this.cfg,e=t.iv,n=t.mode;this._xformMode==this._ENC_XFORM_MODE?A=n.createEncryptor:(A=n.createDecryptor,this._minBufferSize=1),this._mode&&this._mode.__creator==A?this._mode.init(this,e&&e.words):(this._mode=A.call(n,this,e&&e.words),this._mode.__creator=A)},_doProcessBlock:function(A,t){this._mode.processBlock(A,t)},_doFinalize:function(){var A,t=this.cfg.padding;return this._xformMode==this._ENC_XFORM_MODE?(t.pad(this._data,this.blockSize),A=this._process(!0)):(A=this._process(!0),t.unpad(A)),A},blockSize:4}),e.CipherParams=r.extend({init:function(A){this.mixIn(A)},toString:function(A){return(A||this.formatter).stringify(this)}})),E=(t.format={}).OpenSSL={stringify:function(A){var t=A.ciphertext,e=A.salt;return(e?i.create([1398893684,1701076831]).concat(e).concat(t):t).toString(a)},parse:function(A){var t,e=a.parse(A),n=e.words;return 1398893684==n[0]&&1701076831==n[1]&&(t=i.create(n.slice(2,4)),n.splice(0,4),e.sigBytes-=16),h.create({ciphertext:e,salt:t})}},f=e.SerializableCipher=r.extend({cfg:r.extend({format:E}),encrypt:function(A,t,e,n){n=this.cfg.extend(n);var r=A.createEncryptor(e,n),i=r.finalize(t),o=r.cfg;return h.create({ciphertext:i,key:e,iv:o.iv,algorithm:A,mode:o.mode,padding:o.padding,blockSize:A.blockSize,formatter:n.format})},decrypt:function(A,t,e,n){return n=this.cfg.extend(n),t=this._parse(t,n.format),A.createDecryptor(e,n).finalize(t.ciphertext)},_parse:function(A,t){return"string"==typeof A?t.parse(A,this):A}}),Q=(t.kdf={}).OpenSSL={execute:function(A,t,e,n){n||(n=i.random(8));var r=c.create({keySize:t+e}).compute(A,n),o=i.create(r.words.slice(t),4*e);return r.sigBytes=4*t,h.create({key:r,iv:o,salt:n})}},d=e.PasswordBasedCipher=f.extend({cfg:f.cfg.extend({kdf:Q}),encrypt:function(A,t,e,n){var r=(n=this.cfg.extend(n)).kdf.execute(e,A.keySize,A.ivSize);n.iv=r.iv;var i=f.encrypt.call(this,A,t,r.key,n);return i.mixIn(r),i},decrypt:function(A,t,e,n){n=this.cfg.extend(n),t=this._parse(t,n.format);var r=n.kdf.execute(e,A.keySize,A.ivSize,t.salt);return n.iv=r.iv,f.decrypt.call(this,A,t,r.key,n)}})}()))},757:function(A,t,e){"use strict";var n;e(5743),e(6992),e(1539),e(9135),e(2990),e(8927),e(3105),e(5035),e(4345),e(7174),e(2846),e(4731),e(7209),e(6319),e(8867),e(7789),e(3739),e(9368),e(4483),e(2056),e(3462),e(678),e(7462),e(3824),e(5021),e(2974),e(5016),e(9714),e(7042),e(9600),e(2222),e(561),A.exports=(n=n||function(A,t){var n;if("undefined"!=typeof window&&window.crypto&&(n=window.crypto),"undefined"!=typeof self&&self.crypto&&(n=self.crypto),"undefined"!=typeof globalThis&&globalThis.crypto&&(n=globalThis.crypto),!n&&"undefined"!=typeof window&&window.msCrypto&&(n=window.msCrypto),!n&&void 0!==e.g&&e.g.crypto&&(n=e.g.crypto),!n)try{n=e(2480)}catch(A){}var r=function(){if(n){if("function"==typeof n.getRandomValues)try{return n.getRandomValues(new Uint32Array(1))[0]}catch(A){}if("function"==typeof n.randomBytes)try{return n.randomBytes(4).readInt32LE()}catch(A){}}throw new Error("Native crypto module could not be used to get secure random number.")},i=Object.create||function(){function A(){}return function(t){var e;return A.prototype=t,e=new A,A.prototype=null,e}}(),o={},s=o.lib={},a=s.Base={extend:function(A){var t=i(this);return A&&t.mixIn(A),t.hasOwnProperty("init")&&this.init!==t.init||(t.init=function(){t.$super.init.apply(this,arguments)}),t.init.prototype=t,t.$super=this,t},create:function(){var A=this.extend();return A.init.apply(A,arguments),A},init:function(){},mixIn:function(A){for(var t in A)A.hasOwnProperty(t)&&(this[t]=A[t]);A.hasOwnProperty("toString")&&(this.toString=A.toString)},clone:function(){return this.init.prototype.extend(this)}},c=s.WordArray=a.extend({init:function(A,t){A=this.words=A||[],this.sigBytes=null!=t?t:4*A.length},toString:function(A){return(A||g).stringify(this)},concat:function(A){var t=this.words,e=A.words,n=this.sigBytes,r=A.sigBytes;if(this.clamp(),n%4)for(var i=0;i<r;i++){var o=e[i>>>2]>>>24-i%4*8&255;t[n+i>>>2]|=o<<24-(n+i)%4*8}else for(var s=0;s<r;s+=4)t[n+s>>>2]=e[s>>>2];return this.sigBytes+=r,this},clamp:function(){var t=this.words,e=this.sigBytes;t[e>>>2]&=4294967295<<32-e%4*8,t.length=A.ceil(e/4)},clone:function(){var A=a.clone.call(this);return A.words=this.words.slice(0),A},random:function(A){for(var t=[],e=0;e<A;e+=4)t.push(r());return new c.init(t,A)}}),B=o.enc={},g=B.Hex={stringify:function(A){for(var t=A.words,e=A.sigBytes,n=[],r=0;r<e;r++){var i=t[r>>>2]>>>24-r%4*8&255;n.push((i>>>4).toString(16)),n.push((15&i).toString(16))}return n.join("")},parse:function(A){for(var t=A.length,e=[],n=0;n<t;n+=2)e[n>>>3]|=parseInt(A.substr(n,2),16)<<24-n%8*4;return new c.init(e,t/2)}},l=B.Latin1={stringify:function(A){for(var t=A.words,e=A.sigBytes,n=[],r=0;r<e;r++){var i=t[r>>>2]>>>24-r%4*8&255;n.push(String.fromCharCode(i))}return n.join("")},parse:function(A){for(var t=A.length,e=[],n=0;n<t;n++)e[n>>>2]|=(255&A.charCodeAt(n))<<24-n%4*8;return new c.init(e,t)}},u=B.Utf8={stringify:function(A){try{return decodeURIComponent(escape(l.stringify(A)))}catch(A){throw new Error("Malformed UTF-8 data")}},parse:function(A){return l.parse(unescape(encodeURIComponent(A)))}},w=s.BufferedBlockAlgorithm=a.extend({reset:function(){this._data=new c.init,this._nDataBytes=0},_append:function(A){"string"==typeof A&&(A=u.parse(A)),this._data.concat(A),this._nDataBytes+=A.sigBytes},_process:function(t){var e,n=this._data,r=n.words,i=n.sigBytes,o=this.blockSize,s=i/(4*o),a=(s=t?A.ceil(s):A.max((0|s)-this._minBufferSize,0))*o,B=A.min(4*a,i);if(a){for(var g=0;g<a;g+=o)this._doProcessBlock(r,g);e=r.splice(0,a),n.sigBytes-=B}return new c.init(e,B)},clone:function(){var A=a.clone.call(this);return A._data=this._data.clone(),A},_minBufferSize:0}),h=(s.Hasher=w.extend({cfg:a.extend(),init:function(A){this.cfg=this.cfg.extend(A),this.reset()},reset:function(){w.reset.call(this),this._doReset()},update:function(A){return this._append(A),this._process(),this},finalize:function(A){return A&&this._append(A),this._doFinalize()},blockSize:16,_createHelper:function(A){return function(t,e){return new A.init(e).finalize(t)}},_createHmacHelper:function(A){return function(t,e){return new h.HMAC.init(A,e).finalize(t)}}}),o.algo={});return o}(Math),n)},7508:function(A,t,e){"use strict";var n;e(9600),A.exports=(n=e(757),function(){var A=n,t=A.lib.WordArray;function e(A,e,n){for(var r=[],i=0,o=0;o<e;o++)if(o%4){var s=n[A.charCodeAt(o-1)]<<o%4*2|n[A.charCodeAt(o)]>>>6-o%4*2;r[i>>>2]|=s<<24-i%4*8,i++}return t.create(r,i)}A.enc.Base64={stringify:function(A){var t=A.words,e=A.sigBytes,n=this._map;A.clamp();for(var r=[],i=0;i<e;i+=3)for(var o=(t[i>>>2]>>>24-i%4*8&255)<<16|(t[i+1>>>2]>>>24-(i+1)%4*8&255)<<8|t[i+2>>>2]>>>24-(i+2)%4*8&255,s=0;s<4&&i+.75*s<e;s++)r.push(n.charAt(o>>>6*(3-s)&63));var a=n.charAt(64);if(a)for(;r.length%4;)r.push(a);return r.join("")},parse:function(A){var t=A.length,n=this._map,r=this._reverseMap;if(!r){r=this._reverseMap=[];for(var i=0;i<n.length;i++)r[n.charCodeAt(i)]=i}var o=n.charAt(64);if(o){var s=A.indexOf(o);-1!==s&&(t=s)}return e(A,t,r)},_map:"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="}}(),n.enc.Base64)},7590:function(A,t,e){"use strict";var n;e(9600),A.exports=(n=e(757),function(){var A=n,t=A.lib.WordArray;function e(A,e,n){for(var r=[],i=0,o=0;o<e;o++)if(o%4){var s=n[A.charCodeAt(o-1)]<<o%4*2|n[A.charCodeAt(o)]>>>6-o%4*2;r[i>>>2]|=s<<24-i%4*8,i++}return t.create(r,i)}A.enc.Base64url={stringify:function(A,t){void 0===t&&(t=!0);var e=A.words,n=A.sigBytes,r=t?this._safe_map:this._map;A.clamp();for(var i=[],o=0;o<n;o+=3)for(var s=(e[o>>>2]>>>24-o%4*8&255)<<16|(e[o+1>>>2]>>>24-(o+1)%4*8&255)<<8|e[o+2>>>2]>>>24-(o+2)%4*8&255,a=0;a<4&&o+.75*a<n;a++)i.push(r.charAt(s>>>6*(3-a)&63));var c=r.charAt(64);if(c)for(;i.length%4;)i.push(c);return i.join("")},parse:function(A,t){void 0===t&&(t=!0);var n=A.length,r=t?this._safe_map:this._map,i=this._reverseMap;if(!i){i=this._reverseMap=[];for(var o=0;o<r.length;o++)i[r.charCodeAt(o)]=o}var s=r.charAt(64);if(s){var a=A.indexOf(s);-1!==a&&(n=a)}return e(A,n,i)},_map:"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=",_safe_map:"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-_"}}(),n.enc.Base64url)},4978:function(A,t,e){"use strict";var n;e(9600),A.exports=(n=e(757),function(){var A=n,t=A.lib.WordArray,e=A.enc;function r(A){return A<<8&4278255360|A>>>8&16711935}e.Utf16=e.Utf16BE={stringify:function(A){for(var t=A.words,e=A.sigBytes,n=[],r=0;r<e;r+=2){var i=t[r>>>2]>>>16-r%4*8&65535;n.push(String.fromCharCode(i))}return n.join("")},parse:function(A){for(var e=A.length,n=[],r=0;r<e;r++)n[r>>>1]|=A.charCodeAt(r)<<16-r%2*16;return t.create(n,2*e)}},e.Utf16LE={stringify:function(A){for(var t=A.words,e=A.sigBytes,n=[],i=0;i<e;i+=2){var o=r(t[i>>>2]>>>16-i%4*8&65535);n.push(String.fromCharCode(o))}return n.join("")},parse:function(A){for(var e=A.length,n=[],i=0;i<e;i++)n[i>>>1]|=r(A.charCodeAt(i)<<16-i%2*16);return t.create(n,2*e)}}}(),n.enc.Utf16)},3839:function(A,t,e){"use strict";var n,r,i,o,s,a,c,B;e(2222),A.exports=(B=e(757),e(9865),e(6727),i=(r=(n=B).lib).Base,o=r.WordArray,a=(s=n.algo).MD5,c=s.EvpKDF=i.extend({cfg:i.extend({keySize:4,hasher:a,iterations:1}),init:function(A){this.cfg=this.cfg.extend(A)},compute:function(A,t){for(var e,n=this.cfg,r=n.hasher.create(),i=o.create(),s=i.words,a=n.keySize,c=n.iterations;s.length<a;){e&&r.update(e),e=r.update(A).finalize(t),r.reset();for(var B=1;B<c;B++)e=r.finalize(e),r.reset();i.concat(e)}return i.sigBytes=4*a,i}}),n.EvpKDF=function(A,t,e){return c.create(e).compute(A,t)},B.EvpKDF)},8942:function(A,t,e){"use strict";var n,r,i,o;e(1539),e(9714),A.exports=(o=e(757),e(1582),r=(n=o).lib.CipherParams,i=n.enc.Hex,n.format.Hex={stringify:function(A){return A.ciphertext.toString(i)},parse:function(A){var t=i.parse(A);return r.create({ciphertext:t})}},o.format.Hex)},6727:function(A,t,e){"use strict";var n,r,i;e(2222),A.exports=(r=(n=e(757)).lib.Base,i=n.enc.Utf8,void(n.algo.HMAC=r.extend({init:function(A,t){A=this._hasher=new A.init,"string"==typeof t&&(t=i.parse(t));var e=A.blockSize,n=4*e;t.sigBytes>n&&(t=A.finalize(t)),t.clamp();for(var r=this._oKey=t.clone(),o=this._iKey=t.clone(),s=r.words,a=o.words,c=0;c<e;c++)s[c]^=1549556828,a[c]^=909522486;r.sigBytes=o.sigBytes=n,this.reset()},reset:function(){var A=this._hasher;A.reset(),A.update(this._iKey)},update:function(A){return this._hasher.update(A),this},finalize:function(A){var t=this._hasher,e=t.finalize(A);return t.reset(),t.finalize(this._oKey.clone().concat(e))}})))},5153:function(A,t,e){"use strict";var n;A.exports=(n=e(757),e(2601),e(1947),e(4978),e(7508),e(7590),e(3440),e(9865),e(8921),e(6876),e(7991),e(8122),e(8342),e(8714),e(6727),e(3486),e(3839),e(1582),e(702),e(2362),e(4412),e(5720),e(3518),e(6362),e(4431),e(8800),e(3992),e(649),e(8942),e(194),e(8437),e(4640),e(5323),e(4363),n)},1947:function(A,t,e){"use strict";var n;e(7803),e(1539),e(6992),e(2472),e(2990),e(8927),e(3105),e(5035),e(4345),e(7174),e(2846),e(4731),e(7209),e(6319),e(8867),e(7789),e(3739),e(9368),e(4483),e(2056),e(3462),e(678),e(7462),e(3824),e(5021),e(2974),e(5016),e(7145),e(9743),e(5109),e(8255),e(5125),e(9135),e(4197),e(6495),A.exports=(n=e(757),function(){if("function"==typeof ArrayBuffer){var A=n.lib.WordArray,t=A.init,e=A.init=function(A){if(A instanceof ArrayBuffer&&(A=new Uint8Array(A)),(A instanceof Int8Array||"undefined"!=typeof Uint8ClampedArray&&A instanceof Uint8ClampedArray||A instanceof Int16Array||A instanceof Uint16Array||A instanceof Int32Array||A instanceof Uint32Array||A instanceof Float32Array||A instanceof Float64Array)&&(A=new Uint8Array(A.buffer,A.byteOffset,A.byteLength)),A instanceof Uint8Array){for(var e=A.byteLength,n=[],r=0;r<e;r++)n[r>>>2]|=A[r]<<24-r%4*8;t.call(this,n,e)}else t.apply(this,arguments)};e.prototype=A}}(),n.lib.WordArray)},3440:function(A,t,e){"use strict";var n;A.exports=(n=e(757),function(A){var t=n,e=t.lib,r=e.WordArray,i=e.Hasher,o=t.algo,s=[];!function(){for(var t=0;t<64;t++)s[t]=4294967296*A.abs(A.sin(t+1))|0}();var a=o.MD5=i.extend({_doReset:function(){this._hash=new r.init([1732584193,4023233417,2562383102,271733878])},_doProcessBlock:function(A,t){for(var e=0;e<16;e++){var n=t+e,r=A[n];A[n]=16711935&(r<<8|r>>>24)|4278255360&(r<<24|r>>>8)}var i=this._hash.words,o=A[t+0],a=A[t+1],u=A[t+2],w=A[t+3],h=A[t+4],E=A[t+5],f=A[t+6],Q=A[t+7],d=A[t+8],C=A[t+9],M=A[t+10],I=A[t+11],p=A[t+12],D=A[t+13],y=A[t+14],v=A[t+15],m=i[0],F=i[1],Y=i[2],b=i[3];m=c(m,F,Y,b,o,7,s[0]),b=c(b,m,F,Y,a,12,s[1]),Y=c(Y,b,m,F,u,17,s[2]),F=c(F,Y,b,m,w,22,s[3]),m=c(m,F,Y,b,h,7,s[4]),b=c(b,m,F,Y,E,12,s[5]),Y=c(Y,b,m,F,f,17,s[6]),F=c(F,Y,b,m,Q,22,s[7]),m=c(m,F,Y,b,d,7,s[8]),b=c(b,m,F,Y,C,12,s[9]),Y=c(Y,b,m,F,M,17,s[10]),F=c(F,Y,b,m,I,22,s[11]),m=c(m,F,Y,b,p,7,s[12]),b=c(b,m,F,Y,D,12,s[13]),Y=c(Y,b,m,F,y,17,s[14]),m=B(m,F=c(F,Y,b,m,v,22,s[15]),Y,b,a,5,s[16]),b=B(b,m,F,Y,f,9,s[17]),Y=B(Y,b,m,F,I,14,s[18]),F=B(F,Y,b,m,o,20,s[19]),m=B(m,F,Y,b,E,5,s[20]),b=B(b,m,F,Y,M,9,s[21]),Y=B(Y,b,m,F,v,14,s[22]),F=B(F,Y,b,m,h,20,s[23]),m=B(m,F,Y,b,C,5,s[24]),b=B(b,m,F,Y,y,9,s[25]),Y=B(Y,b,m,F,w,14,s[26]),F=B(F,Y,b,m,d,20,s[27]),m=B(m,F,Y,b,D,5,s[28]),b=B(b,m,F,Y,u,9,s[29]),Y=B(Y,b,m,F,Q,14,s[30]),m=g(m,F=B(F,Y,b,m,p,20,s[31]),Y,b,E,4,s[32]),b=g(b,m,F,Y,d,11,s[33]),Y=g(Y,b,m,F,I,16,s[34]),F=g(F,Y,b,m,y,23,s[35]),m=g(m,F,Y,b,a,4,s[36]),b=g(b,m,F,Y,h,11,s[37]),Y=g(Y,b,m,F,Q,16,s[38]),F=g(F,Y,b,m,M,23,s[39]),m=g(m,F,Y,b,D,4,s[40]),b=g(b,m,F,Y,o,11,s[41]),Y=g(Y,b,m,F,w,16,s[42]),F=g(F,Y,b,m,f,23,s[43]),m=g(m,F,Y,b,C,4,s[44]),b=g(b,m,F,Y,p,11,s[45]),Y=g(Y,b,m,F,v,16,s[46]),m=l(m,F=g(F,Y,b,m,u,23,s[47]),Y,b,o,6,s[48]),b=l(b,m,F,Y,Q,10,s[49]),Y=l(Y,b,m,F,y,15,s[50]),F=l(F,Y,b,m,E,21,s[51]),m=l(m,F,Y,b,p,6,s[52]),b=l(b,m,F,Y,w,10,s[53]),Y=l(Y,b,m,F,M,15,s[54]),F=l(F,Y,b,m,a,21,s[55]),m=l(m,F,Y,b,d,6,s[56]),b=l(b,m,F,Y,v,10,s[57]),Y=l(Y,b,m,F,f,15,s[58]),F=l(F,Y,b,m,D,21,s[59]),m=l(m,F,Y,b,h,6,s[60]),b=l(b,m,F,Y,I,10,s[61]),Y=l(Y,b,m,F,u,15,s[62]),F=l(F,Y,b,m,C,21,s[63]),i[0]=i[0]+m|0,i[1]=i[1]+F|0,i[2]=i[2]+Y|0,i[3]=i[3]+b|0},_doFinalize:function(){var t=this._data,e=t.words,n=8*this._nDataBytes,r=8*t.sigBytes;e[r>>>5]|=128<<24-r%32;var i=A.floor(n/4294967296),o=n;e[15+(r+64>>>9<<4)]=16711935&(i<<8|i>>>24)|4278255360&(i<<24|i>>>8),e[14+(r+64>>>9<<4)]=16711935&(o<<8|o>>>24)|4278255360&(o<<24|o>>>8),t.sigBytes=4*(e.length+1),this._process();for(var s=this._hash,a=s.words,c=0;c<4;c++){var B=a[c];a[c]=16711935&(B<<8|B>>>24)|4278255360&(B<<24|B>>>8)}return s},clone:function(){var A=i.clone.call(this);return A._hash=this._hash.clone(),A}});function c(A,t,e,n,r,i,o){var s=A+(t&e|~t&n)+r+o;return(s<<i|s>>>32-i)+t}function B(A,t,e,n,r,i,o){var s=A+(t&n|e&~n)+r+o;return(s<<i|s>>>32-i)+t}function g(A,t,e,n,r,i,o){var s=A+(t^e^n)+r+o;return(s<<i|s>>>32-i)+t}function l(A,t,e,n,r,i,o){var s=A+(e^(t|~n))+r+o;return(s<<i|s>>>32-i)+t}t.MD5=i._createHelper(a),t.HmacMD5=i._createHmacHelper(a)}(Math),n.MD5)},702:function(A,t,e){"use strict";var n;e(7042),A.exports=(n=e(757),e(1582),n.mode.CFB=function(){var A=n.lib.BlockCipherMode.extend();function t(A,t,e,n){var r,i=this._iv;i?(r=i.slice(0),this._iv=void 0):r=this._prevBlock,n.encryptBlock(r,0);for(var o=0;o<e;o++)A[t+o]^=r[o]}return A.Encryptor=A.extend({processBlock:function(A,e){var n=this._cipher,r=n.blockSize;t.call(this,A,e,r,n),this._prevBlock=A.slice(e,e+r)}}),A.Decryptor=A.extend({processBlock:function(A,e){var n=this._cipher,r=n.blockSize,i=A.slice(e,e+r);t.call(this,A,e,r,n),this._prevBlock=i}}),A}(),n.mode.CFB)},4412:function(A,t,e){"use strict";var n;e(7042),A.exports=(n=e(757),e(1582),n.mode.CTRGladman=function(){var A=n.lib.BlockCipherMode.extend();function t(A){if(255==(A>>24&255)){var t=A>>16&255,e=A>>8&255,n=255&A;255===t?(t=0,255===e?(e=0,255===n?n=0:++n):++e):++t,A=0,A+=t<<16,A+=e<<8,A+=n}else A+=1<<24;return A}var e=A.Encryptor=A.extend({processBlock:function(A,e){var n=this._cipher,r=n.blockSize,i=this._iv,o=this._counter;i&&(o=this._counter=i.slice(0),this._iv=void 0),function(A){0===(A[0]=t(A[0]))&&(A[1]=t(A[1]))}(o);var s=o.slice(0);n.encryptBlock(s,0);for(var a=0;a<r;a++)A[e+a]^=s[a]}});return A.Decryptor=e,A}(),n.mode.CTRGladman)},2362:function(A,t,e){"use strict";var n,r,i;e(7042),A.exports=(i=e(757),e(1582),i.mode.CTR=(r=(n=i.lib.BlockCipherMode.extend()).Encryptor=n.extend({processBlock:function(A,t){var e=this._cipher,n=e.blockSize,r=this._iv,i=this._counter;r&&(i=this._counter=r.slice(0),this._iv=void 0);var o=i.slice(0);e.encryptBlock(o,0),i[n-1]=i[n-1]+1|0;for(var s=0;s<n;s++)A[t+s]^=o[s]}}),n.Decryptor=r,n),i.mode.CTR)},3518:function(A,t,e){"use strict";var n,r;A.exports=(r=e(757),e(1582),r.mode.ECB=((n=r.lib.BlockCipherMode.extend()).Encryptor=n.extend({processBlock:function(A,t){this._cipher.encryptBlock(A,t)}}),n.Decryptor=n.extend({processBlock:function(A,t){this._cipher.decryptBlock(A,t)}}),n),r.mode.ECB)},5720:function(A,t,e){"use strict";var n,r,i;e(7042),A.exports=(i=e(757),e(1582),i.mode.OFB=(r=(n=i.lib.BlockCipherMode.extend()).Encryptor=n.extend({processBlock:function(A,t){var e=this._cipher,n=e.blockSize,r=this._iv,i=this._keystream;r&&(i=this._keystream=r.slice(0),this._iv=void 0),e.encryptBlock(i,0);for(var o=0;o<n;o++)A[t+o]^=i[o]}}),n.Decryptor=r,n),i.mode.OFB)},6362:function(A,t,e){"use strict";var n;A.exports=(n=e(757),e(1582),n.pad.AnsiX923={pad:function(A,t){var e=A.sigBytes,n=4*t,r=n-e%n,i=e+r-1;A.clamp(),A.words[i>>>2]|=r<<24-i%4*8,A.sigBytes+=r},unpad:function(A){var t=255&A.words[A.sigBytes-1>>>2];A.sigBytes-=t}},n.pad.Ansix923)},4431:function(A,t,e){"use strict";var n;e(2222),A.exports=(n=e(757),e(1582),n.pad.Iso10126={pad:function(A,t){var e=4*t,r=e-A.sigBytes%e;A.concat(n.lib.WordArray.random(r-1)).concat(n.lib.WordArray.create([r<<24],1))},unpad:function(A){var t=255&A.words[A.sigBytes-1>>>2];A.sigBytes-=t}},n.pad.Iso10126)},8800:function(A,t,e){"use strict";var n;e(2222),A.exports=(n=e(757),e(1582),n.pad.Iso97971={pad:function(A,t){A.concat(n.lib.WordArray.create([2147483648],1)),n.pad.ZeroPadding.pad(A,t)},unpad:function(A){n.pad.ZeroPadding.unpad(A),A.sigBytes--}},n.pad.Iso97971)},649:function(A,t,e){"use strict";var n;A.exports=(n=e(757),e(1582),n.pad.NoPadding={pad:function(){},unpad:function(){}},n.pad.NoPadding)},3992:function(A,t,e){"use strict";var n;A.exports=(n=e(757),e(1582),n.pad.ZeroPadding={pad:function(A,t){var e=4*t;A.clamp(),A.sigBytes+=e-(A.sigBytes%e||e)},unpad:function(A){var t=A.words,e=A.sigBytes-1;for(e=A.sigBytes-1;e>=0;e--)if(t[e>>>2]>>>24-e%4*8&255){A.sigBytes=e+1;break}}},n.pad.ZeroPadding)},3486:function(A,t,e){"use strict";var n,r,i,o,s,a,c,B,g;e(2222),A.exports=(g=e(757),e(9865),e(6727),i=(r=(n=g).lib).Base,o=r.WordArray,a=(s=n.algo).SHA1,c=s.HMAC,B=s.PBKDF2=i.extend({cfg:i.extend({keySize:4,hasher:a,iterations:1}),init:function(A){this.cfg=this.cfg.extend(A)},compute:function(A,t){for(var e=this.cfg,n=c.create(e.hasher,A),r=o.create(),i=o.create([1]),s=r.words,a=i.words,B=e.keySize,g=e.iterations;s.length<B;){var l=n.update(t).finalize(i);n.reset();for(var u=l.words,w=u.length,h=l,E=1;E<g;E++){h=n.finalize(h),n.reset();for(var f=h.words,Q=0;Q<w;Q++)u[Q]^=f[Q]}r.concat(l),a[0]++}return r.sigBytes=4*B,r}}),n.PBKDF2=function(A,t,e){return B.create(e).compute(A,t)},g.PBKDF2)},4363:function(A,t,e){"use strict";var n;A.exports=(n=e(757),e(7508),e(3440),e(3839),e(1582),function(){var A=n,t=A.lib.StreamCipher,e=A.algo,r=[],i=[],o=[],s=e.RabbitLegacy=t.extend({_doReset:function(){var A=this._key.words,t=this.cfg.iv,e=this._X=[A[0],A[3]<<16|A[2]>>>16,A[1],A[0]<<16|A[3]>>>16,A[2],A[1]<<16|A[0]>>>16,A[3],A[2]<<16|A[1]>>>16],n=this._C=[A[2]<<16|A[2]>>>16,4294901760&A[0]|65535&A[1],A[3]<<16|A[3]>>>16,4294901760&A[1]|65535&A[2],A[0]<<16|A[0]>>>16,4294901760&A[2]|65535&A[3],A[1]<<16|A[1]>>>16,4294901760&A[3]|65535&A[0]];this._b=0;for(var r=0;r<4;r++)a.call(this);for(r=0;r<8;r++)n[r]^=e[r+4&7];if(t){var i=t.words,o=i[0],s=i[1],c=16711935&(o<<8|o>>>24)|4278255360&(o<<24|o>>>8),B=16711935&(s<<8|s>>>24)|4278255360&(s<<24|s>>>8),g=c>>>16|4294901760&B,l=B<<16|65535&c;for(n[0]^=c,n[1]^=g,n[2]^=B,n[3]^=l,n[4]^=c,n[5]^=g,n[6]^=B,n[7]^=l,r=0;r<4;r++)a.call(this)}},_doProcessBlock:function(A,t){var e=this._X;a.call(this),r[0]=e[0]^e[5]>>>16^e[3]<<16,r[1]=e[2]^e[7]>>>16^e[5]<<16,r[2]=e[4]^e[1]>>>16^e[7]<<16,r[3]=e[6]^e[3]>>>16^e[1]<<16;for(var n=0;n<4;n++)r[n]=16711935&(r[n]<<8|r[n]>>>24)|4278255360&(r[n]<<24|r[n]>>>8),A[t+n]^=r[n]},blockSize:4,ivSize:2});function a(){for(var A=this._X,t=this._C,e=0;e<8;e++)i[e]=t[e];for(t[0]=t[0]+1295307597+this._b|0,t[1]=t[1]+3545052371+(t[0]>>>0<i[0]>>>0?1:0)|0,t[2]=t[2]+886263092+(t[1]>>>0<i[1]>>>0?1:0)|0,t[3]=t[3]+1295307597+(t[2]>>>0<i[2]>>>0?1:0)|0,t[4]=t[4]+3545052371+(t[3]>>>0<i[3]>>>0?1:0)|0,t[5]=t[5]+886263092+(t[4]>>>0<i[4]>>>0?1:0)|0,t[6]=t[6]+1295307597+(t[5]>>>0<i[5]>>>0?1:0)|0,t[7]=t[7]+3545052371+(t[6]>>>0<i[6]>>>0?1:0)|0,this._b=t[7]>>>0<i[7]>>>0?1:0,e=0;e<8;e++){var n=A[e]+t[e],r=65535&n,s=n>>>16,a=((r*r>>>17)+r*s>>>15)+s*s,c=((4294901760&n)*n|0)+((65535&n)*n|0);o[e]=a^c}A[0]=o[0]+(o[7]<<16|o[7]>>>16)+(o[6]<<16|o[6]>>>16)|0,A[1]=o[1]+(o[0]<<8|o[0]>>>24)+o[7]|0,A[2]=o[2]+(o[1]<<16|o[1]>>>16)+(o[0]<<16|o[0]>>>16)|0,A[3]=o[3]+(o[2]<<8|o[2]>>>24)+o[1]|0,A[4]=o[4]+(o[3]<<16|o[3]>>>16)+(o[2]<<16|o[2]>>>16)|0,A[5]=o[5]+(o[4]<<8|o[4]>>>24)+o[3]|0,A[6]=o[6]+(o[5]<<16|o[5]>>>16)+(o[4]<<16|o[4]>>>16)|0,A[7]=o[7]+(o[6]<<8|o[6]>>>24)+o[5]|0}A.RabbitLegacy=t._createHelper(s)}(),n.RabbitLegacy)},5323:function(A,t,e){"use strict";var n;A.exports=(n=e(757),e(7508),e(3440),e(3839),e(1582),function(){var A=n,t=A.lib.StreamCipher,e=A.algo,r=[],i=[],o=[],s=e.Rabbit=t.extend({_doReset:function(){for(var A=this._key.words,t=this.cfg.iv,e=0;e<4;e++)A[e]=16711935&(A[e]<<8|A[e]>>>24)|4278255360&(A[e]<<24|A[e]>>>8);var n=this._X=[A[0],A[3]<<16|A[2]>>>16,A[1],A[0]<<16|A[3]>>>16,A[2],A[1]<<16|A[0]>>>16,A[3],A[2]<<16|A[1]>>>16],r=this._C=[A[2]<<16|A[2]>>>16,4294901760&A[0]|65535&A[1],A[3]<<16|A[3]>>>16,4294901760&A[1]|65535&A[2],A[0]<<16|A[0]>>>16,4294901760&A[2]|65535&A[3],A[1]<<16|A[1]>>>16,4294901760&A[3]|65535&A[0]];for(this._b=0,e=0;e<4;e++)a.call(this);for(e=0;e<8;e++)r[e]^=n[e+4&7];if(t){var i=t.words,o=i[0],s=i[1],c=16711935&(o<<8|o>>>24)|4278255360&(o<<24|o>>>8),B=16711935&(s<<8|s>>>24)|4278255360&(s<<24|s>>>8),g=c>>>16|4294901760&B,l=B<<16|65535&c;for(r[0]^=c,r[1]^=g,r[2]^=B,r[3]^=l,r[4]^=c,r[5]^=g,r[6]^=B,r[7]^=l,e=0;e<4;e++)a.call(this)}},_doProcessBlock:function(A,t){var e=this._X;a.call(this),r[0]=e[0]^e[5]>>>16^e[3]<<16,r[1]=e[2]^e[7]>>>16^e[5]<<16,r[2]=e[4]^e[1]>>>16^e[7]<<16,r[3]=e[6]^e[3]>>>16^e[1]<<16;for(var n=0;n<4;n++)r[n]=16711935&(r[n]<<8|r[n]>>>24)|4278255360&(r[n]<<24|r[n]>>>8),A[t+n]^=r[n]},blockSize:4,ivSize:2});function a(){for(var A=this._X,t=this._C,e=0;e<8;e++)i[e]=t[e];for(t[0]=t[0]+1295307597+this._b|0,t[1]=t[1]+3545052371+(t[0]>>>0<i[0]>>>0?1:0)|0,t[2]=t[2]+886263092+(t[1]>>>0<i[1]>>>0?1:0)|0,t[3]=t[3]+1295307597+(t[2]>>>0<i[2]>>>0?1:0)|0,t[4]=t[4]+3545052371+(t[3]>>>0<i[3]>>>0?1:0)|0,t[5]=t[5]+886263092+(t[4]>>>0<i[4]>>>0?1:0)|0,t[6]=t[6]+1295307597+(t[5]>>>0<i[5]>>>0?1:0)|0,t[7]=t[7]+3545052371+(t[6]>>>0<i[6]>>>0?1:0)|0,this._b=t[7]>>>0<i[7]>>>0?1:0,e=0;e<8;e++){var n=A[e]+t[e],r=65535&n,s=n>>>16,a=((r*r>>>17)+r*s>>>15)+s*s,c=((4294901760&n)*n|0)+((65535&n)*n|0);o[e]=a^c}A[0]=o[0]+(o[7]<<16|o[7]>>>16)+(o[6]<<16|o[6]>>>16)|0,A[1]=o[1]+(o[0]<<8|o[0]>>>24)+o[7]|0,A[2]=o[2]+(o[1]<<16|o[1]>>>16)+(o[0]<<16|o[0]>>>16)|0,A[3]=o[3]+(o[2]<<8|o[2]>>>24)+o[1]|0,A[4]=o[4]+(o[3]<<16|o[3]>>>16)+(o[2]<<16|o[2]>>>16)|0,A[5]=o[5]+(o[4]<<8|o[4]>>>24)+o[3]|0,A[6]=o[6]+(o[5]<<16|o[5]>>>16)+(o[4]<<16|o[4]>>>16)|0,A[7]=o[7]+(o[6]<<8|o[6]>>>24)+o[5]|0}A.Rabbit=t._createHelper(s)}(),n.Rabbit)},4640:function(A,t,e){"use strict";var n;e(1539),e(8674),A.exports=(n=e(757),e(7508),e(3440),e(3839),e(1582),function(){var A=n,t=A.lib.StreamCipher,e=A.algo,r=e.RC4=t.extend({_doReset:function(){for(var A=this._key,t=A.words,e=A.sigBytes,n=this._S=[],r=0;r<256;r++)n[r]=r;r=0;for(var i=0;r<256;r++){var o=r%e,s=t[o>>>2]>>>24-o%4*8&255;i=(i+n[r]+s)%256;var a=n[r];n[r]=n[i],n[i]=a}this._i=this._j=0},_doProcessBlock:function(A,t){A[t]^=i.call(this)},keySize:8,ivSize:0});function i(){for(var A=this._S,t=this._i,e=this._j,n=0,r=0;r<4;r++){e=(e+A[t=(t+1)%256])%256;var i=A[t];A[t]=A[e],A[e]=i,n|=A[(A[t]+A[e])%256]<<24-8*r}return this._i=t,this._j=e,n}A.RC4=t._createHelper(r);var o=e.RC4Drop=r.extend({cfg:r.cfg.extend({drop:192}),_doReset:function(){r._doReset.call(this);for(var A=this.cfg.drop;A>0;A--)i.call(this)}});A.RC4Drop=t._createHelper(o)}(),n.RC4)},8714:function(A,t,e){"use strict";var n;A.exports=(n=e(757),function(A){var t=n,e=t.lib,r=e.WordArray,i=e.Hasher,o=t.algo,s=r.create([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,7,4,13,1,10,6,15,3,12,0,9,5,2,14,11,8,3,10,14,4,9,15,8,1,2,7,0,6,13,11,5,12,1,9,11,10,0,8,12,4,13,3,7,15,14,5,6,2,4,0,5,9,7,12,2,10,14,1,3,8,11,6,15,13]),a=r.create([5,14,7,0,9,2,11,4,13,6,15,8,1,10,3,12,6,11,3,7,0,13,5,10,14,15,8,12,4,9,1,2,15,5,1,3,7,14,6,9,11,8,12,2,10,0,4,13,8,6,4,1,3,11,15,0,5,12,2,13,9,7,10,14,12,15,10,4,1,5,8,7,6,2,13,14,0,3,9,11]),c=r.create([11,14,15,12,5,8,7,9,11,13,14,15,6,7,9,8,7,6,8,13,11,9,7,15,7,12,15,9,11,7,13,12,11,13,6,7,14,9,13,15,14,8,13,6,5,12,7,5,11,12,14,15,14,15,9,8,9,14,5,6,8,6,5,12,9,15,5,11,6,8,13,12,5,12,13,14,11,8,5,6]),B=r.create([8,9,9,11,13,15,15,5,7,7,8,11,14,14,12,6,9,13,15,7,12,8,9,11,7,7,12,7,6,15,13,11,9,7,15,11,8,6,6,14,12,13,5,14,13,13,7,5,15,5,8,11,14,14,6,14,6,9,12,9,12,5,15,8,8,5,12,9,12,5,14,6,8,13,6,5,15,13,11,11]),g=r.create([0,1518500249,1859775393,2400959708,2840853838]),l=r.create([1352829926,1548603684,1836072691,2053994217,0]),u=o.RIPEMD160=i.extend({_doReset:function(){this._hash=r.create([1732584193,4023233417,2562383102,271733878,3285377520])},_doProcessBlock:function(A,t){for(var e=0;e<16;e++){var n=t+e,r=A[n];A[n]=16711935&(r<<8|r>>>24)|4278255360&(r<<24|r>>>8)}var i,o,u,C,M,I,p,D,y,v,m,F=this._hash.words,Y=g.words,b=l.words,z=s.words,U=a.words,S=c.words,x=B.words;for(I=i=F[0],p=o=F[1],D=u=F[2],y=C=F[3],v=M=F[4],e=0;e<80;e+=1)m=i+A[t+z[e]]|0,m+=e<16?w(o,u,C)+Y[0]:e<32?h(o,u,C)+Y[1]:e<48?E(o,u,C)+Y[2]:e<64?f(o,u,C)+Y[3]:Q(o,u,C)+Y[4],m=(m=d(m|=0,S[e]))+M|0,i=M,M=C,C=d(u,10),u=o,o=m,m=I+A[t+U[e]]|0,m+=e<16?Q(p,D,y)+b[0]:e<32?f(p,D,y)+b[1]:e<48?E(p,D,y)+b[2]:e<64?h(p,D,y)+b[3]:w(p,D,y)+b[4],m=(m=d(m|=0,x[e]))+v|0,I=v,v=y,y=d(D,10),D=p,p=m;m=F[1]+u+y|0,F[1]=F[2]+C+v|0,F[2]=F[3]+M+I|0,F[3]=F[4]+i+p|0,F[4]=F[0]+o+D|0,F[0]=m},_doFinalize:function(){var A=this._data,t=A.words,e=8*this._nDataBytes,n=8*A.sigBytes;t[n>>>5]|=128<<24-n%32,t[14+(n+64>>>9<<4)]=16711935&(e<<8|e>>>24)|4278255360&(e<<24|e>>>8),A.sigBytes=4*(t.length+1),this._process();for(var r=this._hash,i=r.words,o=0;o<5;o++){var s=i[o];i[o]=16711935&(s<<8|s>>>24)|4278255360&(s<<24|s>>>8)}return r},clone:function(){var A=i.clone.call(this);return A._hash=this._hash.clone(),A}});function w(A,t,e){return A^t^e}function h(A,t,e){return A&t|~A&e}function E(A,t,e){return(A|~t)^e}function f(A,t,e){return A&e|t&~e}function Q(A,t,e){return A^(t|~e)}function d(A,t){return A<<t|A>>>32-t}t.RIPEMD160=i._createHelper(u),t.HmacRIPEMD160=i._createHmacHelper(u)}(Math),n.RIPEMD160)},9865:function(A,t,e){"use strict";var n,r,i,o,s,a,c,B;A.exports=(r=(n=B=e(757)).lib,i=r.WordArray,o=r.Hasher,s=n.algo,a=[],c=s.SHA1=o.extend({_doReset:function(){this._hash=new i.init([1732584193,4023233417,2562383102,271733878,3285377520])},_doProcessBlock:function(A,t){for(var e=this._hash.words,n=e[0],r=e[1],i=e[2],o=e[3],s=e[4],c=0;c<80;c++){if(c<16)a[c]=0|A[t+c];else{var B=a[c-3]^a[c-8]^a[c-14]^a[c-16];a[c]=B<<1|B>>>31}var g=(n<<5|n>>>27)+s+a[c];g+=c<20?1518500249+(r&i|~r&o):c<40?1859775393+(r^i^o):c<60?(r&i|r&o|i&o)-1894007588:(r^i^o)-899497514,s=o,o=i,i=r<<30|r>>>2,r=n,n=g}e[0]=e[0]+n|0,e[1]=e[1]+r|0,e[2]=e[2]+i|0,e[3]=e[3]+o|0,e[4]=e[4]+s|0},_doFinalize:function(){var A=this._data,t=A.words,e=8*this._nDataBytes,n=8*A.sigBytes;return t[n>>>5]|=128<<24-n%32,t[14+(n+64>>>9<<4)]=Math.floor(e/4294967296),t[15+(n+64>>>9<<4)]=e,A.sigBytes=4*t.length,this._process(),this._hash},clone:function(){var A=o.clone.call(this);return A._hash=this._hash.clone(),A}}),n.SHA1=o._createHelper(c),n.HmacSHA1=o._createHmacHelper(c),B.SHA1)},6876:function(A,t,e){"use strict";var n,r,i,o,s,a;A.exports=(a=e(757),e(8921),r=(n=a).lib.WordArray,i=n.algo,o=i.SHA256,s=i.SHA224=o.extend({_doReset:function(){this._hash=new r.init([3238371032,914150663,812702999,4144912697,4290775857,1750603025,1694076839,3204075428])},_doFinalize:function(){var A=o._doFinalize.call(this);return A.sigBytes-=4,A}}),n.SHA224=o._createHelper(s),n.HmacSHA224=o._createHmacHelper(s),a.SHA224)},8921:function(A,t,e){"use strict";var n;e(7042),A.exports=(n=e(757),function(A){var t=n,e=t.lib,r=e.WordArray,i=e.Hasher,o=t.algo,s=[],a=[];!function(){function t(t){for(var e=A.sqrt(t),n=2;n<=e;n++)if(!(t%n))return!1;return!0}function e(A){return 4294967296*(A-(0|A))|0}for(var n=2,r=0;r<64;)t(n)&&(r<8&&(s[r]=e(A.pow(n,.5))),a[r]=e(A.pow(n,1/3)),r++),n++}();var c=[],B=o.SHA256=i.extend({_doReset:function(){this._hash=new r.init(s.slice(0))},_doProcessBlock:function(A,t){for(var e=this._hash.words,n=e[0],r=e[1],i=e[2],o=e[3],s=e[4],B=e[5],g=e[6],l=e[7],u=0;u<64;u++){if(u<16)c[u]=0|A[t+u];else{var w=c[u-15],h=(w<<25|w>>>7)^(w<<14|w>>>18)^w>>>3,E=c[u-2],f=(E<<15|E>>>17)^(E<<13|E>>>19)^E>>>10;c[u]=h+c[u-7]+f+c[u-16]}var Q=n&r^n&i^r&i,d=(n<<30|n>>>2)^(n<<19|n>>>13)^(n<<10|n>>>22),C=l+((s<<26|s>>>6)^(s<<21|s>>>11)^(s<<7|s>>>25))+(s&B^~s&g)+a[u]+c[u];l=g,g=B,B=s,s=o+C|0,o=i,i=r,r=n,n=C+(d+Q)|0}e[0]=e[0]+n|0,e[1]=e[1]+r|0,e[2]=e[2]+i|0,e[3]=e[3]+o|0,e[4]=e[4]+s|0,e[5]=e[5]+B|0,e[6]=e[6]+g|0,e[7]=e[7]+l|0},_doFinalize:function(){var t=this._data,e=t.words,n=8*this._nDataBytes,r=8*t.sigBytes;return e[r>>>5]|=128<<24-r%32,e[14+(r+64>>>9<<4)]=A.floor(n/4294967296),e[15+(r+64>>>9<<4)]=n,t.sigBytes=4*e.length,this._process(),this._hash},clone:function(){var A=i.clone.call(this);return A._hash=this._hash.clone(),A}});t.SHA256=i._createHelper(B),t.HmacSHA256=i._createHmacHelper(B)}(Math),n.SHA256)},8342:function(A,t,e){"use strict";var n;e(7042),A.exports=(n=e(757),e(2601),function(A){var t=n,e=t.lib,r=e.WordArray,i=e.Hasher,o=t.x64.Word,s=t.algo,a=[],c=[],B=[];!function(){for(var A=1,t=0,e=0;e<24;e++){a[A+5*t]=(e+1)*(e+2)/2%64;var n=(2*A+3*t)%5;A=t%5,t=n}for(A=0;A<5;A++)for(t=0;t<5;t++)c[A+5*t]=t+(2*A+3*t)%5*5;for(var r=1,i=0;i<24;i++){for(var s=0,g=0,l=0;l<7;l++){if(1&r){var u=(1<<l)-1;u<32?g^=1<<u:s^=1<<u-32}128&r?r=r<<1^113:r<<=1}B[i]=o.create(s,g)}}();var g=[];!function(){for(var A=0;A<25;A++)g[A]=o.create()}();var l=s.SHA3=i.extend({cfg:i.cfg.extend({outputLength:512}),_doReset:function(){for(var A=this._state=[],t=0;t<25;t++)A[t]=new o.init;this.blockSize=(1600-2*this.cfg.outputLength)/32},_doProcessBlock:function(A,t){for(var e=this._state,n=this.blockSize/2,r=0;r<n;r++){var i=A[t+2*r],o=A[t+2*r+1];i=16711935&(i<<8|i>>>24)|4278255360&(i<<24|i>>>8),o=16711935&(o<<8|o>>>24)|4278255360&(o<<24|o>>>8),(F=e[r]).high^=o,F.low^=i}for(var s=0;s<24;s++){for(var l=0;l<5;l++){for(var u=0,w=0,h=0;h<5;h++)u^=(F=e[l+5*h]).high,w^=F.low;var E=g[l];E.high=u,E.low=w}for(l=0;l<5;l++){var f=g[(l+4)%5],Q=g[(l+1)%5],d=Q.high,C=Q.low;for(u=f.high^(d<<1|C>>>31),w=f.low^(C<<1|d>>>31),h=0;h<5;h++)(F=e[l+5*h]).high^=u,F.low^=w}for(var M=1;M<25;M++){var I=(F=e[M]).high,p=F.low,D=a[M];D<32?(u=I<<D|p>>>32-D,w=p<<D|I>>>32-D):(u=p<<D-32|I>>>64-D,w=I<<D-32|p>>>64-D);var y=g[c[M]];y.high=u,y.low=w}var v=g[0],m=e[0];for(v.high=m.high,v.low=m.low,l=0;l<5;l++)for(h=0;h<5;h++){var F=e[M=l+5*h],Y=g[M],b=g[(l+1)%5+5*h],z=g[(l+2)%5+5*h];F.high=Y.high^~b.high&z.high,F.low=Y.low^~b.low&z.low}F=e[0];var U=B[s];F.high^=U.high,F.low^=U.low}},_doFinalize:function(){var t=this._data,e=t.words,n=(this._nDataBytes,8*t.sigBytes),i=32*this.blockSize;e[n>>>5]|=1<<24-n%32,e[(A.ceil((n+1)/i)*i>>>5)-1]|=128,t.sigBytes=4*e.length,this._process();for(var o=this._state,s=this.cfg.outputLength/8,a=s/8,c=[],B=0;B<a;B++){var g=o[B],l=g.high,u=g.low;l=16711935&(l<<8|l>>>24)|4278255360&(l<<24|l>>>8),u=16711935&(u<<8|u>>>24)|4278255360&(u<<24|u>>>8),c.push(u),c.push(l)}return new r.init(c,s)},clone:function(){for(var A=i.clone.call(this),t=A._state=this._state.slice(0),e=0;e<25;e++)t[e]=t[e].clone();return A}});t.SHA3=i._createHelper(l),t.HmacSHA3=i._createHmacHelper(l)}(Math),n.SHA3)},8122:function(A,t,e){"use strict";var n,r,i,o,s,a,c,B;A.exports=(B=e(757),e(2601),e(7991),r=(n=B).x64,i=r.Word,o=r.WordArray,s=n.algo,a=s.SHA512,c=s.SHA384=a.extend({_doReset:function(){this._hash=new o.init([new i.init(3418070365,3238371032),new i.init(1654270250,914150663),new i.init(2438529370,812702999),new i.init(355462360,4144912697),new i.init(1731405415,4290775857),new i.init(2394180231,1750603025),new i.init(3675008525,1694076839),new i.init(1203062813,3204075428)])},_doFinalize:function(){var A=a._doFinalize.call(this);return A.sigBytes-=16,A}}),n.SHA384=a._createHelper(c),n.HmacSHA384=a._createHmacHelper(c),B.SHA384)},7991:function(A,t,e){"use strict";var n;A.exports=(n=e(757),e(2601),function(){var A=n,t=A.lib.Hasher,e=A.x64,r=e.Word,i=e.WordArray,o=A.algo;function s(){return r.create.apply(r,arguments)}var a=[s(1116352408,3609767458),s(1899447441,602891725),s(3049323471,3964484399),s(3921009573,2173295548),s(961987163,4081628472),s(1508970993,3053834265),s(2453635748,2937671579),s(2870763221,3664609560),s(3624381080,2734883394),s(310598401,1164996542),s(607225278,1323610764),s(1426881987,3590304994),s(1925078388,4068182383),s(2162078206,991336113),s(2614888103,633803317),s(3248222580,3479774868),s(3835390401,2666613458),s(4022224774,944711139),s(264347078,2341262773),s(604807628,2007800933),s(770255983,1495990901),s(1249150122,1856431235),s(1555081692,3175218132),s(1996064986,2198950837),s(2554220882,3999719339),s(2821834349,766784016),s(2952996808,2566594879),s(3210313671,3203337956),s(3336571891,1034457026),s(3584528711,2466948901),s(113926993,3758326383),s(338241895,168717936),s(666307205,1188179964),s(773529912,1546045734),s(1294757372,1522805485),s(1396182291,2643833823),s(1695183700,2343527390),s(1986661051,1014477480),s(2177026350,1206759142),s(2456956037,344077627),s(2730485921,1290863460),s(2820302411,3158454273),s(3259730800,3505952657),s(3345764771,106217008),s(3516065817,3606008344),s(3600352804,1432725776),s(4094571909,1467031594),s(275423344,851169720),s(430227734,3100823752),s(506948616,1363258195),s(659060556,3750685593),s(883997877,3785050280),s(958139571,3318307427),s(1322822218,3812723403),s(1537002063,2003034995),s(1747873779,3602036899),s(1955562222,1575990012),s(2024104815,1125592928),s(2227730452,2716904306),s(2361852424,442776044),s(2428436474,593698344),s(2756734187,3733110249),s(3204031479,2999351573),s(3329325298,3815920427),s(3391569614,3928383900),s(3515267271,566280711),s(3940187606,3454069534),s(4118630271,4000239992),s(116418474,1914138554),s(174292421,2731055270),s(289380356,3203993006),s(460393269,320620315),s(685471733,587496836),s(852142971,1086792851),s(1017036298,365543100),s(1126000580,2618297676),s(1288033470,3409855158),s(1501505948,4234509866),s(1607167915,987167468),s(1816402316,1246189591)],c=[];!function(){for(var A=0;A<80;A++)c[A]=s()}();var B=o.SHA512=t.extend({_doReset:function(){this._hash=new i.init([new r.init(1779033703,4089235720),new r.init(3144134277,2227873595),new r.init(1013904242,4271175723),new r.init(2773480762,1595750129),new r.init(1359893119,2917565137),new r.init(2600822924,725511199),new r.init(528734635,4215389547),new r.init(1541459225,327033209)])},_doProcessBlock:function(A,t){for(var e=this._hash.words,n=e[0],r=e[1],i=e[2],o=e[3],s=e[4],B=e[5],g=e[6],l=e[7],u=n.high,w=n.low,h=r.high,E=r.low,f=i.high,Q=i.low,d=o.high,C=o.low,M=s.high,I=s.low,p=B.high,D=B.low,y=g.high,v=g.low,m=l.high,F=l.low,Y=u,b=w,z=h,U=E,S=f,x=Q,T=d,P=C,N=M,R=I,G=p,H=D,k=y,L=v,J=m,j=F,O=0;O<80;O++){var W,K,V=c[O];if(O<16)K=V.high=0|A[t+2*O],W=V.low=0|A[t+2*O+1];else{var X=c[O-15],Z=X.high,_=X.low,q=(Z>>>1|_<<31)^(Z>>>8|_<<24)^Z>>>7,$=(_>>>1|Z<<31)^(_>>>8|Z<<24)^(_>>>7|Z<<25),AA=c[O-2],tA=AA.high,eA=AA.low,nA=(tA>>>19|eA<<13)^(tA<<3|eA>>>29)^tA>>>6,rA=(eA>>>19|tA<<13)^(eA<<3|tA>>>29)^(eA>>>6|tA<<26),iA=c[O-7],oA=iA.high,sA=iA.low,aA=c[O-16],cA=aA.high,BA=aA.low;K=(K=(K=q+oA+((W=$+sA)>>>0<$>>>0?1:0))+nA+((W+=rA)>>>0<rA>>>0?1:0))+cA+((W+=BA)>>>0<BA>>>0?1:0),V.high=K,V.low=W}var gA,lA=N&G^~N&k,uA=R&H^~R&L,wA=Y&z^Y&S^z&S,hA=b&U^b&x^U&x,EA=(Y>>>28|b<<4)^(Y<<30|b>>>2)^(Y<<25|b>>>7),fA=(b>>>28|Y<<4)^(b<<30|Y>>>2)^(b<<25|Y>>>7),QA=(N>>>14|R<<18)^(N>>>18|R<<14)^(N<<23|R>>>9),dA=(R>>>14|N<<18)^(R>>>18|N<<14)^(R<<23|N>>>9),CA=a[O],MA=CA.high,IA=CA.low,pA=J+QA+((gA=j+dA)>>>0<j>>>0?1:0),DA=fA+hA;J=k,j=L,k=G,L=H,G=N,H=R,N=T+(pA=(pA=(pA=pA+lA+((gA+=uA)>>>0<uA>>>0?1:0))+MA+((gA+=IA)>>>0<IA>>>0?1:0))+K+((gA+=W)>>>0<W>>>0?1:0))+((R=P+gA|0)>>>0<P>>>0?1:0)|0,T=S,P=x,S=z,x=U,z=Y,U=b,Y=pA+(EA+wA+(DA>>>0<fA>>>0?1:0))+((b=gA+DA|0)>>>0<gA>>>0?1:0)|0}w=n.low=w+b,n.high=u+Y+(w>>>0<b>>>0?1:0),E=r.low=E+U,r.high=h+z+(E>>>0<U>>>0?1:0),Q=i.low=Q+x,i.high=f+S+(Q>>>0<x>>>0?1:0),C=o.low=C+P,o.high=d+T+(C>>>0<P>>>0?1:0),I=s.low=I+R,s.high=M+N+(I>>>0<R>>>0?1:0),D=B.low=D+H,B.high=p+G+(D>>>0<H>>>0?1:0),v=g.low=v+L,g.high=y+k+(v>>>0<L>>>0?1:0),F=l.low=F+j,l.high=m+J+(F>>>0<j>>>0?1:0)},_doFinalize:function(){var A=this._data,t=A.words,e=8*this._nDataBytes,n=8*A.sigBytes;return t[n>>>5]|=128<<24-n%32,t[30+(n+128>>>10<<5)]=Math.floor(e/4294967296),t[31+(n+128>>>10<<5)]=e,A.sigBytes=4*t.length,this._process(),this._hash.toX32()},clone:function(){var A=t.clone.call(this);return A._hash=this._hash.clone(),A},blockSize:32});A.SHA512=t._createHelper(B),A.HmacSHA512=t._createHmacHelper(B)}(),n.SHA512)},8437:function(A,t,e){"use strict";var n;e(7042),A.exports=(n=e(757),e(7508),e(3440),e(3839),e(1582),function(){var A=n,t=A.lib,e=t.WordArray,r=t.BlockCipher,i=A.algo,o=[57,49,41,33,25,17,9,1,58,50,42,34,26,18,10,2,59,51,43,35,27,19,11,3,60,52,44,36,63,55,47,39,31,23,15,7,62,54,46,38,30,22,14,6,61,53,45,37,29,21,13,5,28,20,12,4],s=[14,17,11,24,1,5,3,28,15,6,21,10,23,19,12,4,26,8,16,7,27,20,13,2,41,52,31,37,47,55,30,40,51,45,33,48,44,49,39,56,34,53,46,42,50,36,29,32],a=[1,2,4,6,8,10,12,14,15,17,19,21,23,25,27,28],c=[{0:8421888,268435456:32768,536870912:8421378,805306368:2,1073741824:512,1342177280:8421890,1610612736:8389122,1879048192:8388608,2147483648:514,2415919104:8389120,2684354560:33280,2952790016:8421376,3221225472:32770,3489660928:8388610,3758096384:0,4026531840:33282,134217728:0,402653184:8421890,671088640:33282,939524096:32768,1207959552:8421888,1476395008:512,1744830464:8421378,2013265920:2,2281701376:8389120,2550136832:33280,2818572288:8421376,3087007744:8389122,3355443200:8388610,3623878656:32770,3892314112:514,4160749568:8388608,1:32768,268435457:2,536870913:8421888,805306369:8388608,1073741825:8421378,1342177281:33280,1610612737:512,1879048193:8389122,2147483649:8421890,2415919105:8421376,2684354561:8388610,2952790017:33282,3221225473:514,3489660929:8389120,3758096385:32770,4026531841:0,134217729:8421890,402653185:8421376,671088641:8388608,939524097:512,1207959553:32768,1476395009:8388610,1744830465:2,2013265921:33282,2281701377:32770,2550136833:8389122,2818572289:514,3087007745:8421888,3355443201:8389120,3623878657:0,3892314113:33280,4160749569:8421378},{0:1074282512,16777216:16384,33554432:524288,50331648:1074266128,67108864:1073741840,83886080:1074282496,100663296:1073758208,117440512:16,134217728:540672,150994944:1073758224,167772160:1073741824,184549376:540688,201326592:524304,218103808:0,234881024:16400,251658240:1074266112,8388608:1073758208,25165824:540688,41943040:16,58720256:1073758224,75497472:1074282512,92274688:1073741824,109051904:524288,125829120:1074266128,142606336:524304,159383552:0,176160768:16384,192937984:1074266112,209715200:1073741840,226492416:540672,243269632:1074282496,260046848:16400,268435456:0,285212672:1074266128,301989888:1073758224,318767104:1074282496,335544320:1074266112,352321536:16,369098752:540688,385875968:16384,402653184:16400,419430400:524288,436207616:524304,452984832:1073741840,469762048:540672,486539264:1073758208,503316480:1073741824,520093696:1074282512,276824064:540688,293601280:524288,310378496:1074266112,327155712:16384,343932928:1073758208,360710144:1074282512,377487360:16,394264576:1073741824,411041792:1074282496,427819008:1073741840,444596224:1073758224,461373440:524304,478150656:0,494927872:16400,511705088:1074266128,528482304:540672},{0:260,1048576:0,2097152:67109120,3145728:65796,4194304:65540,5242880:67108868,6291456:67174660,7340032:67174400,8388608:67108864,9437184:67174656,10485760:65792,11534336:67174404,12582912:67109124,13631488:65536,14680064:4,15728640:256,524288:67174656,1572864:67174404,2621440:0,3670016:67109120,4718592:67108868,5767168:65536,6815744:65540,7864320:260,8912896:4,9961472:256,11010048:67174400,12058624:65796,13107200:65792,14155776:67109124,15204352:67174660,16252928:67108864,16777216:67174656,17825792:65540,18874368:65536,19922944:67109120,20971520:256,22020096:67174660,23068672:67108868,24117248:0,25165824:67109124,26214400:67108864,27262976:4,28311552:65792,29360128:67174400,30408704:260,31457280:65796,32505856:67174404,17301504:67108864,18350080:260,19398656:67174656,20447232:0,21495808:65540,22544384:67109120,23592960:256,24641536:67174404,25690112:65536,26738688:67174660,27787264:65796,28835840:67108868,29884416:67109124,30932992:67174400,31981568:4,33030144:65792},{0:2151682048,65536:2147487808,131072:4198464,196608:2151677952,262144:0,327680:4198400,393216:2147483712,458752:4194368,524288:2147483648,589824:4194304,655360:64,720896:2147487744,786432:2151678016,851968:4160,917504:4096,983040:2151682112,32768:2147487808,98304:64,163840:2151678016,229376:2147487744,294912:4198400,360448:2151682112,425984:0,491520:2151677952,557056:4096,622592:2151682048,688128:4194304,753664:4160,819200:2147483648,884736:4194368,950272:4198464,1015808:2147483712,1048576:4194368,1114112:4198400,1179648:2147483712,1245184:0,1310720:4160,1376256:2151678016,1441792:2151682048,1507328:2147487808,1572864:2151682112,1638400:2147483648,1703936:2151677952,1769472:4198464,1835008:2147487744,1900544:4194304,1966080:64,2031616:4096,1081344:2151677952,1146880:2151682112,1212416:0,1277952:4198400,1343488:4194368,1409024:2147483648,1474560:2147487808,1540096:64,1605632:2147483712,1671168:4096,1736704:2147487744,1802240:2151678016,1867776:4160,1933312:2151682048,1998848:4194304,2064384:4198464},{0:128,4096:17039360,8192:262144,12288:536870912,16384:537133184,20480:16777344,24576:553648256,28672:262272,32768:16777216,36864:537133056,40960:536871040,45056:553910400,49152:553910272,53248:0,57344:17039488,61440:553648128,2048:17039488,6144:553648256,10240:128,14336:17039360,18432:262144,22528:537133184,26624:553910272,30720:536870912,34816:537133056,38912:0,43008:553910400,47104:16777344,51200:536871040,55296:553648128,59392:16777216,63488:262272,65536:262144,69632:128,73728:536870912,77824:553648256,81920:16777344,86016:553910272,90112:537133184,94208:16777216,98304:553910400,102400:553648128,106496:17039360,110592:537133056,114688:262272,118784:536871040,122880:0,126976:17039488,67584:553648256,71680:16777216,75776:17039360,79872:537133184,83968:536870912,88064:17039488,92160:128,96256:553910272,100352:262272,104448:553910400,108544:0,112640:553648128,116736:16777344,120832:262144,124928:537133056,129024:536871040},{0:268435464,256:8192,512:270532608,768:270540808,1024:268443648,1280:2097152,1536:2097160,1792:268435456,2048:0,2304:268443656,2560:2105344,2816:8,3072:270532616,3328:2105352,3584:8200,3840:270540800,128:270532608,384:270540808,640:8,896:2097152,1152:2105352,1408:268435464,1664:268443648,1920:8200,2176:2097160,2432:8192,2688:268443656,2944:270532616,3200:0,3456:270540800,3712:2105344,3968:268435456,4096:268443648,4352:270532616,4608:270540808,4864:8200,5120:2097152,5376:268435456,5632:268435464,5888:2105344,6144:2105352,6400:0,6656:8,6912:270532608,7168:8192,7424:268443656,7680:270540800,7936:2097160,4224:8,4480:2105344,4736:2097152,4992:268435464,5248:268443648,5504:8200,5760:270540808,6016:270532608,6272:270540800,6528:270532616,6784:8192,7040:2105352,7296:2097160,7552:0,7808:268435456,8064:268443656},{0:1048576,16:33555457,32:1024,48:1049601,64:34604033,80:0,96:1,112:34603009,128:33555456,144:1048577,160:33554433,176:34604032,192:34603008,208:1025,224:1049600,240:33554432,8:34603009,24:0,40:33555457,56:34604032,72:1048576,88:33554433,104:33554432,120:1025,136:1049601,152:33555456,168:34603008,184:1048577,200:1024,216:34604033,232:1,248:1049600,256:33554432,272:1048576,288:33555457,304:34603009,320:1048577,336:33555456,352:34604032,368:1049601,384:1025,400:34604033,416:1049600,432:1,448:0,464:34603008,480:33554433,496:1024,264:1049600,280:33555457,296:34603009,312:1,328:33554432,344:1048576,360:1025,376:34604032,392:33554433,408:34603008,424:0,440:34604033,456:1049601,472:1024,488:33555456,504:1048577},{0:134219808,1:131072,2:134217728,3:32,4:131104,5:134350880,6:134350848,7:2048,8:134348800,9:134219776,10:133120,11:134348832,12:2080,13:0,14:134217760,15:133152,2147483648:2048,2147483649:134350880,2147483650:134219808,2147483651:134217728,2147483652:134348800,2147483653:133120,2147483654:133152,2147483655:32,2147483656:134217760,2147483657:2080,2147483658:131104,2147483659:134350848,2147483660:0,2147483661:134348832,2147483662:134219776,2147483663:131072,16:133152,17:134350848,18:32,19:2048,20:134219776,21:134217760,22:134348832,23:131072,24:0,25:131104,26:134348800,27:134219808,28:134350880,29:133120,30:2080,31:134217728,2147483664:131072,2147483665:2048,2147483666:134348832,2147483667:133152,2147483668:32,2147483669:134348800,2147483670:134217728,2147483671:134219808,2147483672:134350880,2147483673:134217760,2147483674:134219776,2147483675:0,2147483676:133120,2147483677:2080,2147483678:131104,2147483679:134350848}],B=[4160749569,528482304,33030144,2064384,129024,8064,504,2147483679],g=i.DES=r.extend({_doReset:function(){for(var A=this._key.words,t=[],e=0;e<56;e++){var n=o[e]-1;t[e]=A[n>>>5]>>>31-n%32&1}for(var r=this._subKeys=[],i=0;i<16;i++){var c=r[i]=[],B=a[i];for(e=0;e<24;e++)c[e/6|0]|=t[(s[e]-1+B)%28]<<31-e%6,c[4+(e/6|0)]|=t[28+(s[e+24]-1+B)%28]<<31-e%6;for(c[0]=c[0]<<1|c[0]>>>31,e=1;e<7;e++)c[e]=c[e]>>>4*(e-1)+3;c[7]=c[7]<<5|c[7]>>>27}var g=this._invSubKeys=[];for(e=0;e<16;e++)g[e]=r[15-e]},encryptBlock:function(A,t){this._doCryptBlock(A,t,this._subKeys)},decryptBlock:function(A,t){this._doCryptBlock(A,t,this._invSubKeys)},_doCryptBlock:function(A,t,e){this._lBlock=A[t],this._rBlock=A[t+1],l.call(this,4,252645135),l.call(this,16,65535),u.call(this,2,858993459),u.call(this,8,16711935),l.call(this,1,1431655765);for(var n=0;n<16;n++){for(var r=e[n],i=this._lBlock,o=this._rBlock,s=0,a=0;a<8;a++)s|=c[a][((o^r[a])&B[a])>>>0];this._lBlock=o,this._rBlock=i^s}var g=this._lBlock;this._lBlock=this._rBlock,this._rBlock=g,l.call(this,1,1431655765),u.call(this,8,16711935),u.call(this,2,858993459),l.call(this,16,65535),l.call(this,4,252645135),A[t]=this._lBlock,A[t+1]=this._rBlock},keySize:2,ivSize:2,blockSize:2});function l(A,t){var e=(this._lBlock>>>A^this._rBlock)&t;this._rBlock^=e,this._lBlock^=e<<A}function u(A,t){var e=(this._rBlock>>>A^this._lBlock)&t;this._lBlock^=e,this._rBlock^=e<<A}A.DES=r._createHelper(g);var w=i.TripleDES=r.extend({_doReset:function(){var A=this._key.words;if(2!==A.length&&4!==A.length&&A.length<6)throw new Error("Invalid key length - 3DES requires the key length to be 64, 128, 192 or >192.");var t=A.slice(0,2),n=A.length<4?A.slice(0,2):A.slice(2,4),r=A.length<6?A.slice(0,2):A.slice(4,6);this._des1=g.createEncryptor(e.create(t)),this._des2=g.createEncryptor(e.create(n)),this._des3=g.createEncryptor(e.create(r))},encryptBlock:function(A,t){this._des1.encryptBlock(A,t),this._des2.decryptBlock(A,t),this._des3.encryptBlock(A,t)},decryptBlock:function(A,t){this._des3.decryptBlock(A,t),this._des2.encryptBlock(A,t),this._des1.decryptBlock(A,t)},keySize:6,ivSize:2,blockSize:2});A.TripleDES=r._createHelper(w)}(),n.TripleDES)},2601:function(A,t,e){"use strict";var n;e(7042),A.exports=(n=e(757),function(A){var t=n,e=t.lib,r=e.Base,i=e.WordArray,o=t.x64={};o.Word=r.extend({init:function(A,t){this.high=A,this.low=t}}),o.WordArray=r.extend({init:function(A,t){A=this.words=A||[],this.sigBytes=null!=t?t:8*A.length},toX32:function(){for(var A=this.words,t=A.length,e=[],n=0;n<t;n++){var r=A[n];e.push(r.high),e.push(r.low)}return i.create(e,this.sigBytes)},clone:function(){for(var A=r.clone.call(this),t=A.words=this.words.slice(0),e=t.length,n=0;n<e;n++)t[n]=t[n].clone();return A}})}(),n)},9811:function(A,t,e){"use strict";function n(A,t){var e="undefined"!=typeof Symbol&&A[Symbol.iterator]||A["@@iterator"];if(e)return(e=e.call(A)).next.bind(e);if(Array.isArray(A)||(e=function(A,t){if(A){if("string"==typeof A)return r(A,t);var e=Object.prototype.toString.call(A).slice(8,-1);return"Object"===e&&A.constructor&&(e=A.constructor.name),"Map"===e||"Set"===e?Array.from(A):"Arguments"===e||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(e)?r(A,t):void 0}}(A))||t&&A&&"number"==typeof A.length){e&&(A=e);var n=0;return function(){return n>=A.length?{done:!0}:{done:!1,value:A[n++]}}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}function r(A,t){(null==t||t>A.length)&&(t=A.length);for(var e=0,n=new Array(t);e<t;e++)n[e]=A[e];return n}function i(){i=function(){return A};var A={},t=Object.prototype,e=t.hasOwnProperty,n=Object.defineProperty||function(A,t,e){A[t]=e.value},r="function"==typeof Symbol?Symbol:{},o=r.iterator||"@@iterator",s=r.asyncIterator||"@@asyncIterator",a=r.toStringTag||"@@toStringTag";function c(A,t,e){return Object.defineProperty(A,t,{value:e,enumerable:!0,configurable:!0,writable:!0}),A[t]}try{c({},"")}catch(A){c=function(A,t,e){return A[t]=e}}function B(A,t,e,r){var i=t&&t.prototype instanceof u?t:u,o=Object.create(i.prototype),s=new v(r||[]);return n(o,"_invoke",{value:I(A,e,s)}),o}function g(A,t,e){try{return{type:"normal",arg:A.call(t,e)}}catch(A){return{type:"throw",arg:A}}}A.wrap=B;var l={};function u(){}function w(){}function h(){}var E={};c(E,o,(function(){return this}));var f=Object.getPrototypeOf,Q=f&&f(f(m([])));Q&&Q!==t&&e.call(Q,o)&&(E=Q);var d=h.prototype=u.prototype=Object.create(E);function C(A){["next","throw","return"].forEach((function(t){c(A,t,(function(A){return this._invoke(t,A)}))}))}function M(A,t){function r(n,i,o,s){var a=g(A[n],A,i);if("throw"!==a.type){var c=a.arg,B=c.value;return B&&"object"==typeof B&&e.call(B,"__await")?t.resolve(B.__await).then((function(A){r("next",A,o,s)}),(function(A){r("throw",A,o,s)})):t.resolve(B).then((function(A){c.value=A,o(c)}),(function(A){return r("throw",A,o,s)}))}s(a.arg)}var i;n(this,"_invoke",{value:function(A,e){function n(){return new t((function(t,n){r(A,e,t,n)}))}return i=i?i.then(n,n):n()}})}function I(A,t,e){var n="suspendedStart";return function(r,i){if("executing"===n)throw new Error("Generator is already running");if("completed"===n){if("throw"===r)throw i;return{value:void 0,done:!0}}for(e.method=r,e.arg=i;;){var o=e.delegate;if(o){var s=p(o,e);if(s){if(s===l)continue;return s}}if("next"===e.method)e.sent=e._sent=e.arg;else if("throw"===e.method){if("suspendedStart"===n)throw n="completed",e.arg;e.dispatchException(e.arg)}else"return"===e.method&&e.abrupt("return",e.arg);n="executing";var a=g(A,t,e);if("normal"===a.type){if(n=e.done?"completed":"suspendedYield",a.arg===l)continue;return{value:a.arg,done:e.done}}"throw"===a.type&&(n="completed",e.method="throw",e.arg=a.arg)}}}function p(A,t){var e=t.method,n=A.iterator[e];if(void 0===n)return t.delegate=null,"throw"===e&&A.iterator.return&&(t.method="return",t.arg=void 0,p(A,t),"throw"===t.method)||"return"!==e&&(t.method="throw",t.arg=new TypeError("The iterator does not provide a '"+e+"' method")),l;var r=g(n,A.iterator,t.arg);if("throw"===r.type)return t.method="throw",t.arg=r.arg,t.delegate=null,l;var i=r.arg;return i?i.done?(t[A.resultName]=i.value,t.next=A.nextLoc,"return"!==t.method&&(t.method="next",t.arg=void 0),t.delegate=null,l):i:(t.method="throw",t.arg=new TypeError("iterator result is not an object"),t.delegate=null,l)}function D(A){var t={tryLoc:A[0]};1 in A&&(t.catchLoc=A[1]),2 in A&&(t.finallyLoc=A[2],t.afterLoc=A[3]),this.tryEntries.push(t)}function y(A){var t=A.completion||{};t.type="normal",delete t.arg,A.completion=t}function v(A){this.tryEntries=[{tryLoc:"root"}],A.forEach(D,this),this.reset(!0)}function m(A){if(A){var t=A[o];if(t)return t.call(A);if("function"==typeof A.next)return A;if(!isNaN(A.length)){var n=-1,r=function t(){for(;++n<A.length;)if(e.call(A,n))return t.value=A[n],t.done=!1,t;return t.value=void 0,t.done=!0,t};return r.next=r}}return{next:F}}function F(){return{value:void 0,done:!0}}return w.prototype=h,n(d,"constructor",{value:h,configurable:!0}),n(h,"constructor",{value:w,configurable:!0}),w.displayName=c(h,a,"GeneratorFunction"),A.isGeneratorFunction=function(A){var t="function"==typeof A&&A.constructor;return!!t&&(t===w||"GeneratorFunction"===(t.displayName||t.name))},A.mark=function(A){return Object.setPrototypeOf?Object.setPrototypeOf(A,h):(A.__proto__=h,c(A,a,"GeneratorFunction")),A.prototype=Object.create(d),A},A.awrap=function(A){return{__await:A}},C(M.prototype),c(M.prototype,s,(function(){return this})),A.AsyncIterator=M,A.async=function(t,e,n,r,i){void 0===i&&(i=Promise);var o=new M(B(t,e,n,r),i);return A.isGeneratorFunction(e)?o:o.next().then((function(A){return A.done?A.value:o.next()}))},C(d),c(d,a,"Generator"),c(d,o,(function(){return this})),c(d,"toString",(function(){return"[object Generator]"})),A.keys=function(A){var t=Object(A),e=[];for(var n in t)e.push(n);return e.reverse(),function A(){for(;e.length;){var n=e.pop();if(n in t)return A.value=n,A.done=!1,A}return A.done=!0,A}},A.values=m,v.prototype={constructor:v,reset:function(A){if(this.prev=0,this.next=0,this.sent=this._sent=void 0,this.done=!1,this.delegate=null,this.method="next",this.arg=void 0,this.tryEntries.forEach(y),!A)for(var t in this)"t"===t.charAt(0)&&e.call(this,t)&&!isNaN(+t.slice(1))&&(this[t]=void 0)},stop:function(){this.done=!0;var A=this.tryEntries[0].completion;if("throw"===A.type)throw A.arg;return this.rval},dispatchException:function(A){if(this.done)throw A;var t=this;function n(e,n){return o.type="throw",o.arg=A,t.next=e,n&&(t.method="next",t.arg=void 0),!!n}for(var r=this.tryEntries.length-1;r>=0;--r){var i=this.tryEntries[r],o=i.completion;if("root"===i.tryLoc)return n("end");if(i.tryLoc<=this.prev){var s=e.call(i,"catchLoc"),a=e.call(i,"finallyLoc");if(s&&a){if(this.prev<i.catchLoc)return n(i.catchLoc,!0);if(this.prev<i.finallyLoc)return n(i.finallyLoc)}else if(s){if(this.prev<i.catchLoc)return n(i.catchLoc,!0)}else{if(!a)throw new Error("try statement without catch or finally");if(this.prev<i.finallyLoc)return n(i.finallyLoc)}}}},abrupt:function(A,t){for(var n=this.tryEntries.length-1;n>=0;--n){var r=this.tryEntries[n];if(r.tryLoc<=this.prev&&e.call(r,"finallyLoc")&&this.prev<r.finallyLoc){var i=r;break}}i&&("break"===A||"continue"===A)&&i.tryLoc<=t&&t<=i.finallyLoc&&(i=null);var o=i?i.completion:{};return o.type=A,o.arg=t,i?(this.method="next",this.next=i.finallyLoc,l):this.complete(o)},complete:function(A,t){if("throw"===A.type)throw A.arg;return"break"===A.type||"continue"===A.type?this.next=A.arg:"return"===A.type?(this.rval=this.arg=A.arg,this.method="return",this.next="end"):"normal"===A.type&&t&&(this.next=t),l},finish:function(A){for(var t=this.tryEntries.length-1;t>=0;--t){var e=this.tryEntries[t];if(e.finallyLoc===A)return this.complete(e.completion,e.afterLoc),y(e),l}},catch:function(A){for(var t=this.tryEntries.length-1;t>=0;--t){var e=this.tryEntries[t];if(e.tryLoc===A){var n=e.completion;if("throw"===n.type){var r=n.arg;y(e)}return r}}throw new Error("illegal catch attempt")},delegateYield:function(A,t,e){return this.delegate={iterator:m(A),resultName:t,nextLoc:e},"next"===this.method&&(this.arg=void 0),l}},A}e(2443),e(3680),e(3706),e(2703),e(489),e(4747),e(8309),e(8674),e(1038),e(4916),e(4723),e(2165),e(6992),e(1539),e(8783),e(3948),e(2526),e(1817),e(7042);var o=function(){function A(A){this.stateTable=A.stateTable,this.accepting=A.accepting,this.tags=A.tags}var t=A.prototype;return t.match=function(A){var t,e=this;return(t={})[Symbol.iterator]=i().mark((function t(){var n,r,o,s,a,c;return i().wrap((function(t){for(;;)switch(t.prev=t.next){case 0:n=1,r=null,o=null,s=null,a=0;case 5:if(!(a<A.length)){t.next=21;break}if(c=A[a],s=n,0!==(n=e.stateTable[n][c])){t.next=15;break}if(!(null!=r&&null!=o&&o>=r)){t.next=13;break}return t.next=13,[r,o,e.tags[s]];case 13:n=e.stateTable[1][c],r=null;case 15:0!==n&&null==r&&(r=a),e.accepting[n]&&(o=a),0===n&&(n=1);case 18:a++,t.next=5;break;case 21:if(!(null!=r&&null!=o&&o>=r)){t.next=24;break}return t.next=24,[r,o,e.tags[n]];case 24:case"end":return t.stop()}}),t)})),t},t.apply=function(A,t){for(var e,r=n(this.match(A));!(e=r()).done;)for(var i,o=e.value,s=o[0],a=o[1],c=n(o[2]);!(i=c()).done;){var B=i.value;"function"==typeof t[B]&&t[B](s,a,A.slice(s,a+1))}},A}();A.exports=o},8478:function(A,t,e){"use strict";var n=e(8823).Buffer;e(1539),e(8674),e(7042),e(6699);var r=e(3857),i=e(2635);A.exports=function(){function A(A){var t;for(this.data=A,this.pos=8,this.palette=[],this.imgData=[],this.transparency={},this.text={};;){var e=this.readUInt32(),r="";for(t=0;t<4;t++)r+=String.fromCharCode(this.data[this.pos++]);switch(r){case"IHDR":this.width=this.readUInt32(),this.height=this.readUInt32(),this.bits=this.data[this.pos++],this.colorType=this.data[this.pos++],this.compressionMethod=this.data[this.pos++],this.filterMethod=this.data[this.pos++],this.interlaceMethod=this.data[this.pos++];break;case"PLTE":this.palette=this.read(e);break;case"IDAT":for(t=0;t<e;t++)this.imgData.push(this.data[this.pos++]);break;case"tRNS":switch(this.transparency={},this.colorType){case 3:this.transparency.indexed=this.read(e);var i=255-this.transparency.indexed.length;if(i>0)for(t=0;t<i;t++)this.transparency.indexed.push(255);break;case 0:this.transparency.grayscale=this.read(e)[0];break;case 2:this.transparency.rgb=this.read(e)}break;case"tEXt":var o=this.read(e),s=o.indexOf(0),a=String.fromCharCode.apply(String,o.slice(0,s));this.text[a]=String.fromCharCode.apply(String,o.slice(s+1));break;case"IEND":switch(this.colorType){case 0:case 3:case 4:this.colors=1;break;case 2:case 6:this.colors=3}this.hasAlphaChannel=[4,6].includes(this.colorType);var c=this.colors+(this.hasAlphaChannel?1:0);switch(this.pixelBitlength=this.bits*c,this.colors){case 1:this.colorSpace="DeviceGray";break;case 3:this.colorSpace="DeviceRGB"}return void(this.imgData=new n(this.imgData));default:this.pos+=e}if(this.pos+=4,this.pos>this.data.length)throw new Error("Incomplete or corrupt PNG file")}}A.decode=function(t,e){return r.readFile(t,(function(t,n){return new A(n).decode((function(A){return e(A)}))}))},A.load=function(t){return new A(r.readFileSync(t))};var t=A.prototype;return t.read=function(A){for(var t=new Array(A),e=0;e<A;e++)t[e]=this.data[this.pos++];return t},t.readUInt32=function(){return this.data[this.pos++]<<24|this.data[this.pos++]<<16|this.data[this.pos++]<<8|this.data[this.pos++]},t.readUInt16=function(){return this.data[this.pos++]<<8|this.data[this.pos++]},t.decodePixels=function(A){var t=this;return i.inflate(this.imgData,(function(e,r){if(e)throw e;var i=t.width,o=t.height,s=t.pixelBitlength/8,a=new n(i*o*s),c=r.length,B=0;function g(A,t,e,g,l){void 0===l&&(l=!1);for(var u=Math.ceil((i-A)/e),w=Math.ceil((o-t)/g),h=s*u,E=l?a:new n(h*w),f=0,Q=0;f<w&&B<c;){var d,C,M,I,p;switch(r[B++]){case 0:for(M=0;M<h;M++)E[Q++]=r[B++];break;case 1:for(M=0;M<h;M++)d=r[B++],I=M<s?0:E[Q-s],E[Q++]=(d+I)%256;break;case 2:for(M=0;M<h;M++)d=r[B++],C=(M-M%s)/s,p=f&&E[(f-1)*h+C*s+M%s],E[Q++]=(p+d)%256;break;case 3:for(M=0;M<h;M++)d=r[B++],C=(M-M%s)/s,I=M<s?0:E[Q-s],p=f&&E[(f-1)*h+C*s+M%s],E[Q++]=(d+Math.floor((I+p)/2))%256;break;case 4:for(M=0;M<h;M++){var D,y;d=r[B++],C=(M-M%s)/s,I=M<s?0:E[Q-s],0===f?p=y=0:(p=E[(f-1)*h+C*s+M%s],y=C&&E[(f-1)*h+(C-1)*s+M%s]);var v=I+p-y,m=Math.abs(v-I),F=Math.abs(v-p),Y=Math.abs(v-y);D=m<=F&&m<=Y?I:F<=Y?p:y,E[Q++]=(d+D)%256}break;default:throw new Error("Invalid filter algorithm: "+r[B-1])}if(!l){var b=((t+f*g)*i+A)*s,z=f*h;for(M=0;M<u;M++){for(var U=0;U<s;U++)a[b++]=E[z++];b+=(e-1)*s}}f++}}return 1===t.interlaceMethod?(g(0,0,8,8),g(4,0,8,8),g(0,4,4,8),g(2,0,4,4),g(0,2,2,4),g(1,0,2,2),g(0,1,1,2)):g(0,0,1,1,!0),A(a)}))},t.decodePalette=function(){for(var A=this.palette,t=A.length,e=this.transparency.indexed||[],r=new n(e.length+t),i=0,o=0,s=0;s<t;s+=3){var a;r[i++]=A[s],r[i++]=A[s+1],r[i++]=A[s+2],r[i++]=null!=(a=e[o++])?a:255}return r},t.copyToImageData=function(A,t){var e,n,r=this.colors,i=null,o=this.hasAlphaChannel;this.palette.length&&(i=this._decodedPalette||(this._decodedPalette=this.decodePalette()),r=4,o=!0);var s=A.data||A,a=s.length,c=i||t,B=e=0;if(1===r)for(;B<a;){n=i?4*t[B/4]:e;var g=c[n++];s[B++]=g,s[B++]=g,s[B++]=g,s[B++]=o?c[n++]:255,e=n}else for(;B<a;)n=i?4*t[B/4]:e,s[B++]=c[n++],s[B++]=c[n++],s[B++]=c[n++],s[B++]=o?c[n++]:255,e=n},t.decode=function(A){var t=this,e=new n(this.width*this.height*4);return this.decodePixels((function(n){return t.copyToImageData(e,n),A(e)}))},A}()},7103:function(A,t,e){"use strict";var n=e(4155);e(8145),e(6992),e(1539),e(2472),e(2990),e(8927),e(3105),e(5035),e(4345),e(7174),e(2846),e(4731),e(7209),e(6319),e(8867),e(7789),e(3739),e(9368),e(4483),e(2056),e(3462),e(678),e(7462),e(3824),e(5021),e(2974),e(5016),e(3290);var r,i=e(8823),o=i.Buffer,s={};for(r in i)i.hasOwnProperty(r)&&"SlowBuffer"!==r&&"Buffer"!==r&&(s[r]=i[r]);var a=s.Buffer={};for(r in o)o.hasOwnProperty(r)&&"allocUnsafe"!==r&&"allocUnsafeSlow"!==r&&(a[r]=o[r]);if(s.Buffer.prototype=o.prototype,a.from&&a.from!==Uint8Array.from||(a.from=function(A,t,e){if("number"==typeof A)throw new TypeError('The "value" argument must not be of type number. Received type '+typeof A);if(A&&void 0===A.length)throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type "+typeof A);return o(A,t,e)}),a.alloc||(a.alloc=function(A,t,e){if("number"!=typeof A)throw new TypeError('The "size" argument must be of type number. Received type '+typeof A);if(A<0||A>=2*(1<<30))throw new RangeError('The value "'+A+'" is invalid for option "size"');var n=o(A);return t&&0!==t.length?"string"==typeof e?n.fill(t,e):n.fill(t):n.fill(0),n}),!s.kStringMaxLength)try{s.kStringMaxLength=n.binding("buffer").kStringMaxLength}catch(A){}s.constants||(s.constants={MAX_LENGTH:s.kMaxLength},s.kStringMaxLength&&(s.constants.MAX_STRING_LENGTH=s.kStringMaxLength)),A.exports=s},3361:function(A,t,e){"use strict";function n(A,t){var e=Object.keys(A);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(A);t&&(n=n.filter((function(t){return Object.getOwnPropertyDescriptor(A,t).enumerable}))),e.push.apply(e,n)}return e}function r(A,t,e){return t in A?Object.defineProperty(A,t,{value:e,enumerable:!0,configurable:!0,writable:!0}):A[t]=e,A}function i(A,t){for(var e=0;e<t.length;e++){var n=t[e];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(A,n.key,n)}}e(7941),e(2526),e(7327),e(1539),e(5003),e(4747),e(9337),e(7042);var o=e(8823).Buffer,s=e(9862).inspect,a=s&&s.custom||"inspect";A.exports=function(){function A(){!function(A,t){if(!(A instanceof t))throw new TypeError("Cannot call a class as a function")}(this,A),this.head=null,this.tail=null,this.length=0}return function(A,t,e){t&&i(A.prototype,t),e&&i(A,e)}(A,[{key:"push",value:function(A){var t={data:A,next:null};this.length>0?this.tail.next=t:this.head=t,this.tail=t,++this.length}},{key:"unshift",value:function(A){var t={data:A,next:this.head};0===this.length&&(this.tail=t),this.head=t,++this.length}},{key:"shift",value:function(){if(0!==this.length){var A=this.head.data;return 1===this.length?this.head=this.tail=null:this.head=this.head.next,--this.length,A}}},{key:"clear",value:function(){this.head=this.tail=null,this.length=0}},{key:"join",value:function(A){if(0===this.length)return"";for(var t=this.head,e=""+t.data;t=t.next;)e+=A+t.data;return e}},{key:"concat",value:function(A){if(0===this.length)return o.alloc(0);for(var t,e,n,r=o.allocUnsafe(A>>>0),i=this.head,s=0;i;)t=i.data,e=r,n=s,o.prototype.copy.call(t,e,n),s+=i.data.length,i=i.next;return r}},{key:"consume",value:function(A,t){var e;return A<this.head.data.length?(e=this.head.data.slice(0,A),this.head.data=this.head.data.slice(A)):e=A===this.head.data.length?this.shift():t?this._getString(A):this._getBuffer(A),e}},{key:"first",value:function(){return this.head.data}},{key:"_getString",value:function(A){var t=this.head,e=1,n=t.data;for(A-=n.length;t=t.next;){var r=t.data,i=A>r.length?r.length:A;if(i===r.length?n+=r:n+=r.slice(0,A),0==(A-=i)){i===r.length?(++e,t.next?this.head=t.next:this.head=this.tail=null):(this.head=t,t.data=r.slice(i));break}++e}return this.length-=e,n}},{key:"_getBuffer",value:function(A){var t=o.allocUnsafe(A),e=this.head,n=1;for(e.data.copy(t),A-=e.data.length;e=e.next;){var r=e.data,i=A>r.length?r.length:A;if(r.copy(t,t.length-A,0,i),0==(A-=i)){i===r.length?(++n,e.next?this.head=e.next:this.head=this.tail=null):(this.head=e,e.data=r.slice(i));break}++n}return this.length-=n,t}},{key:a,value:function(A,t){return s(this,function(A){for(var t=1;t<arguments.length;t++){var e=null!=arguments[t]?arguments[t]:{};t%2?n(Object(e),!0).forEach((function(t){r(A,t,e[t])})):Object.getOwnPropertyDescriptors?Object.defineProperties(A,Object.getOwnPropertyDescriptors(e)):n(Object(e)).forEach((function(t){Object.defineProperty(A,t,Object.getOwnPropertyDescriptor(e,t))}))}return A}({},t,{depth:0,customInspect:!1}))}}]),A}()},5219:function(A,t,e){"use strict";var n=e(8823).Buffer;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0,e(7941),e(2526),e(7327),e(1539),e(5003),e(4747),e(9337),e(489),e(2419),e(1817),e(2165),e(6992),e(8783),e(3948),e(1038),e(7042),e(8309),e(4916),e(2707),e(2222),e(9600),e(9714),e(5306),e(1249),e(9841),e(4953),e(6977),e(6699),e(5192),e(9653),e(3123),e(4723),e(8734),e(2472),e(2990),e(8927),e(3105),e(5035),e(4345),e(7174),e(2846),e(4731),e(7209),e(6319),e(8867),e(7789),e(3739),e(9368),e(4483),e(2056),e(3462),e(678),e(7462),e(3824),e(5021),e(2974),e(5016),e(7803),e(3290),e(9601),e(3210),e(9254),e(7397),e(8674);var r=g(e(2830)),i=g(e(2635)),o=g(e(5153)),s=g(e(1917)),a=e(7187),c=g(e(7337)),B=g(e(8478));function g(A){return A&&A.__esModule?A:{default:A}}var l=e(3857);function u(A,t){if(!(A instanceof t))throw new TypeError("Cannot call a class as a function")}function w(A,t){for(var e=0;e<t.length;e++){var n=t[e];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(A,n.key,n)}}function h(A,t,e){return t&&w(A.prototype,t),e&&w(A,e),A}function E(A,t,e){return t in A?Object.defineProperty(A,t,{value:e,enumerable:!0,configurable:!0,writable:!0}):A[t]=e,A}function f(A,t){var e=Object.keys(A);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(A);t&&(n=n.filter((function(t){return Object.getOwnPropertyDescriptor(A,t).enumerable}))),e.push.apply(e,n)}return e}function Q(A){for(var t=1;t<arguments.length;t++){var e=null!=arguments[t]?arguments[t]:{};t%2?f(Object(e),!0).forEach((function(t){E(A,t,e[t])})):Object.getOwnPropertyDescriptors?Object.defineProperties(A,Object.getOwnPropertyDescriptors(e)):f(Object(e)).forEach((function(t){Object.defineProperty(A,t,Object.getOwnPropertyDescriptor(e,t))}))}return A}function d(A,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function");A.prototype=Object.create(t&&t.prototype,{constructor:{value:A,writable:!0,configurable:!0}}),t&&M(A,t)}function C(A){return C=Object.setPrototypeOf?Object.getPrototypeOf:function(A){return A.__proto__||Object.getPrototypeOf(A)},C(A)}function M(A,t){return M=Object.setPrototypeOf||function(A,t){return A.__proto__=t,A},M(A,t)}function I(A){if(void 0===A)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return A}function p(A){var t=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],(function(){}))),!0}catch(A){return!1}}();return function(){var e,n=C(A);if(t){var r=C(this).constructor;e=Reflect.construct(n,arguments,r)}else e=n.apply(this,arguments);return function(A,t){return!t||"object"!=typeof t&&"function"!=typeof t?I(A):t}(this,e)}}function D(A,t){return function(A){if(Array.isArray(A))return A}(A)||function(A,t){if("undefined"!=typeof Symbol&&Symbol.iterator in Object(A)){var e=[],n=!0,r=!1,i=void 0;try{for(var o,s=A[Symbol.iterator]();!(n=(o=s.next()).done)&&(e.push(o.value),!t||e.length!==t);n=!0);}catch(A){r=!0,i=A}finally{try{n||null==s.return||s.return()}finally{if(r)throw i}}return e}}(A,t)||v(A,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function y(A){return function(A){if(Array.isArray(A))return m(A)}(A)||function(A){if("undefined"!=typeof Symbol&&Symbol.iterator in Object(A))return Array.from(A)}(A)||v(A)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function v(A,t){if(A){if("string"==typeof A)return m(A,t);var e=Object.prototype.toString.call(A).slice(8,-1);return"Object"===e&&A.constructor&&(e=A.constructor.name),"Map"===e||"Set"===e?Array.from(A):"Arguments"===e||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(e)?m(A,t):void 0}}function m(A,t){(null==t||t>A.length)&&(t=A.length);for(var e=0,n=new Array(t);e<t;e++)n[e]=A[e];return n}function F(A,t){var e;if("undefined"==typeof Symbol||null==A[Symbol.iterator]){if(Array.isArray(A)||(e=v(A))||t&&A&&"number"==typeof A.length){e&&(A=e);var n=0,r=function(){};return{s:r,n:function(){return n>=A.length?{done:!0}:{done:!1,value:A[n++]}},e:function(A){throw A},f:r}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,o=!0,s=!1;return{s:function(){e=A[Symbol.iterator]()},n:function(){var A=e.next();return o=A.done,A},e:function(A){s=!0,i=A},f:function(){try{o||null==e.return||e.return()}finally{if(s)throw i}}}}var Y=function(){function A(){u(this,A)}return h(A,[{key:"toString",value:function(){throw new Error("Must be implemented by subclasses")}}]),A}(),b=function(){function A(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{};u(this,A),this._items={},this.limits="boolean"!=typeof t.limits||t.limits}return h(A,[{key:"add",value:function(A,t){return this._items[A]=t}},{key:"get",value:function(A){return this._items[A]}},{key:"toString",value:function(){var A=this,t=Object.keys(this._items).sort((function(t,e){return A._compareKeys(t,e)})),e=["<<"];if(this.limits&&t.length>1){var n=t[0],r=t[t.length-1];e.push("  /Limits ".concat(x.convert([this._dataForKey(n),this._dataForKey(r)])))}e.push("  /".concat(this._keysName()," ["));var i,o=F(t);try{for(o.s();!(i=o.n()).done;){var s=i.value;e.push("    ".concat(x.convert(this._dataForKey(s))," ").concat(x.convert(this._items[s])))}}catch(A){o.e(A)}finally{o.f()}return e.push("]"),e.push(">>"),e.join("\n")}},{key:"_compareKeys",value:function(){throw new Error("Must be implemented by subclasses")}},{key:"_keysName",value:function(){throw new Error("Must be implemented by subclasses")}},{key:"_dataForKey",value:function(){throw new Error("Must be implemented by subclasses")}}]),A}(),z=function(A,t){return(Array(t+1).join("0")+A).slice(-t)},U=/[\n\r\t\b\f()\\]/g,S={"\n":"\\n","\r":"\\r","\t":"\\t","\b":"\\b","\f":"\\f","\\":"\\\\","(":"\\(",")":"\\)"},x=function(){function A(){u(this,A)}return h(A,null,[{key:"convert",value:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:null;if("string"==typeof t)return"/".concat(t);if(t instanceof String){for(var r,i=t,o=!1,s=0,a=i.length;s<a;s++)if(i.charCodeAt(s)>127){o=!0;break}return r=o?function(A){var t=A.length;if(1&t)throw new Error("Buffer length must be even");for(var e=0,n=t-1;e<n;e+=2){var r=A[e];A[e]=A[e+1],A[e+1]=r}return A}(n.from("\ufeff".concat(i),"utf16le")):n.from(i.valueOf(),"ascii"),i=(i=e?e(r).toString("binary"):r.toString("binary")).replace(U,(function(A){return S[A]})),"(".concat(i,")")}if(n.isBuffer(t))return"<".concat(t.toString("hex"),">");if(t instanceof Y||t instanceof b)return t.toString();if(t instanceof Date){var c="D:".concat(z(t.getUTCFullYear(),4))+z(t.getUTCMonth()+1,2)+z(t.getUTCDate(),2)+z(t.getUTCHours(),2)+z(t.getUTCMinutes(),2)+z(t.getUTCSeconds(),2)+"Z";return e&&(c=(c=e(n.from(c,"ascii")).toString("binary")).replace(U,(function(A){return S[A]}))),"(".concat(c,")")}if(Array.isArray(t)){var B=t.map((function(t){return A.convert(t,e)})).join(" ");return"[".concat(B,"]")}if("[object Object]"==={}.toString.call(t)){var g=["<<"];for(var l in t){var u=t[l];g.push("/".concat(l," ").concat(A.convert(u,e)))}return g.push(">>"),g.join("\n")}return"number"==typeof t?A.number(t):"".concat(t)}},{key:"number",value:function(A){if(A>-1e21&&A<1e21)return Math.round(1e6*A)/1e6;throw new Error("unsupported number: ".concat(A))}}]),A}(),T=function(A){d(e,A);var t=p(e);function e(A,n){var r,i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};return u(this,e),(r=t.call(this)).document=A,r.id=n,r.data=i,r.gen=0,r.compress=r.document.compress&&!r.data.Filter,r.uncompressedLength=0,r.buffer=[],r}return h(e,[{key:"write",value:function(A){if(n.isBuffer(A)||(A=n.from(A+"\n","binary")),this.uncompressedLength+=A.length,null==this.data.Length&&(this.data.Length=0),this.buffer.push(A),this.data.Length+=A.length,this.compress)return this.data.Filter="FlateDecode"}},{key:"end",value:function(A){return A&&this.write(A),this.finalize()}},{key:"finalize",value:function(){this.offset=this.document._offset;var A=this.document._security?this.document._security.getEncryptFn(this.id,this.gen):null;this.buffer.length&&(this.buffer=n.concat(this.buffer),this.compress&&(this.buffer=i.default.deflateSync(this.buffer)),A&&(this.buffer=A(this.buffer)),this.data.Length=this.buffer.length),this.document._write("".concat(this.id," ").concat(this.gen," obj")),this.document._write(x.convert(this.data,A)),this.buffer.length&&(this.document._write("stream"),this.document._write(this.buffer),this.buffer=[],this.document._write("\nendstream")),this.document._write("endobj"),this.document._refEnd(this)}},{key:"toString",value:function(){return"".concat(this.id," ").concat(this.gen," R")}}]),e}(Y),P={top:72,left:72,bottom:72,right:72},N={"4A0":[4767.87,6740.79],"2A0":[3370.39,4767.87],A0:[2383.94,3370.39],A1:[1683.78,2383.94],A2:[1190.55,1683.78],A3:[841.89,1190.55],A4:[595.28,841.89],A5:[419.53,595.28],A6:[297.64,419.53],A7:[209.76,297.64],A8:[147.4,209.76],A9:[104.88,147.4],A10:[73.7,104.88],B0:[2834.65,4008.19],B1:[2004.09,2834.65],B2:[1417.32,2004.09],B3:[1000.63,1417.32],B4:[708.66,1000.63],B5:[498.9,708.66],B6:[354.33,498.9],B7:[249.45,354.33],B8:[175.75,249.45],B9:[124.72,175.75],B10:[87.87,124.72],C0:[2599.37,3676.54],C1:[1836.85,2599.37],C2:[1298.27,1836.85],C3:[918.43,1298.27],C4:[649.13,918.43],C5:[459.21,649.13],C6:[323.15,459.21],C7:[229.61,323.15],C8:[161.57,229.61],C9:[113.39,161.57],C10:[79.37,113.39],RA0:[2437.8,3458.27],RA1:[1729.13,2437.8],RA2:[1218.9,1729.13],RA3:[864.57,1218.9],RA4:[609.45,864.57],SRA0:[2551.18,3628.35],SRA1:[1814.17,2551.18],SRA2:[1275.59,1814.17],SRA3:[907.09,1275.59],SRA4:[637.8,907.09],EXECUTIVE:[521.86,756],FOLIO:[612,936],LEGAL:[612,1008],LETTER:[612,792],TABLOID:[792,1224]},R=function(){function A(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};u(this,A),this.document=t,this.size=e.size||"letter",this.layout=e.layout||"portrait","number"==typeof e.margin?this.margins={top:e.margin,left:e.margin,bottom:e.margin,right:e.margin}:this.margins=e.margins||P;var n=Array.isArray(this.size)?this.size:N[this.size.toUpperCase()];this.width=n["portrait"===this.layout?0:1],this.height=n["portrait"===this.layout?1:0],this.content=this.document.ref(),this.resources=this.document.ref({ProcSet:["PDF","Text","ImageB","ImageC","ImageI"]}),this.dictionary=this.document.ref({Type:"Page",Parent:this.document._root.data.Pages,MediaBox:[0,0,this.width,this.height],Contents:this.content,Resources:this.resources}),this.markings=[]}return h(A,[{key:"maxY",value:function(){return this.height-this.margins.bottom}},{key:"write",value:function(A){return this.content.write(A)}},{key:"end",value:function(){return this.dictionary.end(),this.resources.end(),this.content.end()}},{key:"fonts",get:function(){var A=this.resources.data;return null!=A.Font?A.Font:A.Font={}}},{key:"xobjects",get:function(){var A=this.resources.data;return null!=A.XObject?A.XObject:A.XObject={}}},{key:"ext_gstates",get:function(){var A=this.resources.data;return null!=A.ExtGState?A.ExtGState:A.ExtGState={}}},{key:"patterns",get:function(){var A=this.resources.data;return null!=A.Pattern?A.Pattern:A.Pattern={}}},{key:"colorSpaces",get:function(){var A=this.resources.data;return A.ColorSpace||(A.ColorSpace={})}},{key:"annotations",get:function(){var A=this.dictionary.data;return null!=A.Annots?A.Annots:A.Annots=[]}},{key:"structParentTreeKey",get:function(){var A=this.dictionary.data;return null!=A.StructParents?A.StructParents:A.StructParents=this.document.createStructParentTreeNextKey()}}]),A}(),G=function(A){d(e,A);var t=p(e);function e(){return u(this,e),t.apply(this,arguments)}return h(e,[{key:"_compareKeys",value:function(A,t){return A.localeCompare(t)}},{key:"_keysName",value:function(){return"Names"}},{key:"_dataForKey",value:function(A){return new String(A)}}]),e}(b);function H(A,t){if(A<t[0])return!1;for(var e=0,n=t.length/2;e<=n;){var r=Math.floor((e+n)/2),i=2*r;if(A>=t[i]&&A<=t[i+1])return!0;A>t[i+1]?e=r+1:n=r-1}return!1}var k=[545,545,564,591,686,687,751,767,848,863,880,883,886,889,891,893,895,899,907,907,909,909,930,930,975,975,1015,1023,1159,1159,1231,1231,1270,1271,1274,1279,1296,1328,1367,1368,1376,1376,1416,1416,1419,1424,1442,1442,1466,1466,1477,1487,1515,1519,1525,1547,1549,1562,1564,1566,1568,1568,1595,1599,1622,1631,1774,1775,1791,1791,1806,1806,1837,1839,1867,1919,1970,2304,2308,2308,2362,2363,2382,2383,2389,2391,2417,2432,2436,2436,2445,2446,2449,2450,2473,2473,2481,2481,2483,2485,2490,2491,2493,2493,2501,2502,2505,2506,2510,2518,2520,2523,2526,2526,2532,2533,2555,2561,2563,2564,2571,2574,2577,2578,2601,2601,2609,2609,2612,2612,2615,2615,2618,2619,2621,2621,2627,2630,2633,2634,2638,2648,2653,2653,2655,2661,2677,2688,2692,2692,2700,2700,2702,2702,2706,2706,2729,2729,2737,2737,2740,2740,2746,2747,2758,2758,2762,2762,2766,2767,2769,2783,2785,2789,2800,2816,2820,2820,2829,2830,2833,2834,2857,2857,2865,2865,2868,2869,2874,2875,2884,2886,2889,2890,2894,2901,2904,2907,2910,2910,2914,2917,2929,2945,2948,2948,2955,2957,2961,2961,2966,2968,2971,2971,2973,2973,2976,2978,2981,2983,2987,2989,2998,2998,3002,3005,3011,3013,3017,3017,3022,3030,3032,3046,3059,3072,3076,3076,3085,3085,3089,3089,3113,3113,3124,3124,3130,3133,3141,3141,3145,3145,3150,3156,3159,3167,3170,3173,3184,3201,3204,3204,3213,3213,3217,3217,3241,3241,3252,3252,3258,3261,3269,3269,3273,3273,3278,3284,3287,3293,3295,3295,3298,3301,3312,3329,3332,3332,3341,3341,3345,3345,3369,3369,3386,3389,3396,3397,3401,3401,3406,3414,3416,3423,3426,3429,3440,3457,3460,3460,3479,3481,3506,3506,3516,3516,3518,3519,3527,3529,3531,3534,3541,3541,3543,3543,3552,3569,3573,3584,3643,3646,3676,3712,3715,3715,3717,3718,3721,3721,3723,3724,3726,3731,3736,3736,3744,3744,3748,3748,3750,3750,3752,3753,3756,3756,3770,3770,3774,3775,3781,3781,3783,3783,3790,3791,3802,3803,3806,3839,3912,3912,3947,3952,3980,3983,3992,3992,4029,4029,4045,4046,4048,4095,4130,4130,4136,4136,4139,4139,4147,4149,4154,4159,4186,4255,4294,4303,4345,4346,4348,4351,4442,4446,4515,4519,4602,4607,4615,4615,4679,4679,4681,4681,4686,4687,4695,4695,4697,4697,4702,4703,4743,4743,4745,4745,4750,4751,4783,4783,4785,4785,4790,4791,4799,4799,4801,4801,4806,4807,4815,4815,4823,4823,4847,4847,4879,4879,4881,4881,4886,4887,4895,4895,4935,4935,4955,4960,4989,5023,5109,5120,5751,5759,5789,5791,5873,5887,5901,5901,5909,5919,5943,5951,5972,5983,5997,5997,6001,6001,6004,6015,6109,6111,6122,6143,6159,6159,6170,6175,6264,6271,6314,7679,7836,7839,7930,7935,7958,7959,7966,7967,8006,8007,8014,8015,8024,8024,8026,8026,8028,8028,8030,8030,8062,8063,8117,8117,8133,8133,8148,8149,8156,8156,8176,8177,8181,8181,8191,8191,8275,8278,8280,8286,8292,8297,8306,8307,8335,8351,8370,8399,8427,8447,8507,8508,8524,8530,8580,8591,9167,9215,9255,9279,9291,9311,9471,9471,9748,9749,9752,9752,9854,9855,9866,9984,9989,9989,9994,9995,10024,10024,10060,10060,10062,10062,10067,10069,10071,10071,10079,10080,10133,10135,10160,10160,10175,10191,10220,10223,11008,11903,11930,11930,12020,12031,12246,12271,12284,12287,12352,12352,12439,12440,12544,12548,12589,12592,12687,12687,12728,12783,12829,12831,12868,12880,12924,12926,13004,13007,13055,13055,13175,13178,13278,13279,13311,13311,19894,19967,40870,40959,42125,42127,42183,44031,55204,55295,64046,64047,64107,64255,64263,64274,64280,64284,64311,64311,64317,64317,64319,64319,64322,64322,64325,64325,64434,64466,64832,64847,64912,64913,64968,64975,65021,65023,65040,65055,65060,65071,65095,65096,65107,65107,65127,65127,65132,65135,65141,65141,65277,65278,65280,65280,65471,65473,65480,65481,65488,65489,65496,65497,65501,65503,65511,65511,65519,65528,65536,66303,66335,66335,66340,66351,66379,66559,66598,66599,66638,118783,119030,119039,119079,119081,119262,119807,119893,119893,119965,119965,119968,119969,119971,119972,119975,119976,119981,119981,119994,119994,119996,119996,120001,120001,120004,120004,120070,120070,120075,120076,120085,120085,120093,120093,120122,120122,120127,120127,120133,120133,120135,120137,120145,120145,120484,120487,120778,120781,120832,131069,173783,194559,195102,196605,196608,262141,262144,327677,327680,393213,393216,458749,458752,524285,524288,589821,589824,655357,655360,720893,720896,786429,786432,851965,851968,917501,917504,917504,917506,917535,917632,983037],L=function(A){return H(A,k)},J=[173,173,847,847,6150,6150,6155,6155,6156,6156,6157,6157,8203,8203,8204,8204,8205,8205,8288,8288,65024,65024,65025,65025,65026,65026,65027,65027,65028,65028,65029,65029,65030,65030,65031,65031,65032,65032,65033,65033,65034,65034,65035,65035,65036,65036,65037,65037,65038,65038,65039,65039,65279,65279],j=[160,160,5760,5760,8192,8192,8193,8193,8194,8194,8195,8195,8196,8196,8197,8197,8198,8198,8199,8199,8200,8200,8201,8201,8202,8202,8203,8203,8239,8239,8287,8287,12288,12288],O=[128,159,1757,1757,1807,1807,6158,6158,8204,8204,8205,8205,8232,8232,8233,8233,8288,8288,8289,8289,8290,8290,8291,8291,8298,8303,65279,65279,65529,65532,119155,119162],W=[64976,65007,65534,65535,131070,131071,196606,196607,262142,262143,327678,327679,393214,393215,458750,458751,524286,524287,589822,589823,655358,655359,720894,720895,786430,786431,851966,851967,917502,917503,983038,983039,1114110,1114111],K=[0,31,127,127,832,832,833,833,8206,8206,8207,8207,8234,8234,8235,8235,8236,8236,8237,8237,8238,8238,8298,8298,8299,8299,8300,8300,8301,8301,8302,8302,8303,8303,12272,12283,55296,57343,57344,63743,65529,65529,65530,65530,65531,65531,65532,65532,65533,65533,917505,917505,917536,917631,983040,1048573,1048576,1114109],V=function(A){return H(A,j)||H(A,K)||H(A,O)||H(A,W)},X=[1470,1470,1472,1472,1475,1475,1488,1514,1520,1524,1563,1563,1567,1567,1569,1594,1600,1610,1645,1647,1649,1749,1757,1757,1765,1766,1786,1790,1792,1805,1808,1808,1810,1836,1920,1957,1969,1969,8207,8207,64285,64285,64287,64296,64298,64310,64312,64316,64318,64318,64320,64321,64323,64324,64326,64433,64467,64829,64848,64911,64914,64967,65008,65020,65136,65140,65142,65276],Z=function(A){return H(A,X)},_=[65,90,97,122,170,170,181,181,186,186,192,214,216,246,248,544,546,563,592,685,688,696,699,705,720,721,736,740,750,750,890,890,902,902,904,906,908,908,910,929,931,974,976,1013,1024,1154,1162,1230,1232,1269,1272,1273,1280,1295,1329,1366,1369,1375,1377,1415,1417,1417,2307,2307,2309,2361,2365,2368,2377,2380,2384,2384,2392,2401,2404,2416,2434,2435,2437,2444,2447,2448,2451,2472,2474,2480,2482,2482,2486,2489,2494,2496,2503,2504,2507,2508,2519,2519,2524,2525,2527,2529,2534,2545,2548,2554,2565,2570,2575,2576,2579,2600,2602,2608,2610,2611,2613,2614,2616,2617,2622,2624,2649,2652,2654,2654,2662,2671,2674,2676,2691,2691,2693,2699,2701,2701,2703,2705,2707,2728,2730,2736,2738,2739,2741,2745,2749,2752,2761,2761,2763,2764,2768,2768,2784,2784,2790,2799,2818,2819,2821,2828,2831,2832,2835,2856,2858,2864,2866,2867,2870,2873,2877,2878,2880,2880,2887,2888,2891,2892,2903,2903,2908,2909,2911,2913,2918,2928,2947,2947,2949,2954,2958,2960,2962,2965,2969,2970,2972,2972,2974,2975,2979,2980,2984,2986,2990,2997,2999,3001,3006,3007,3009,3010,3014,3016,3018,3020,3031,3031,3047,3058,3073,3075,3077,3084,3086,3088,3090,3112,3114,3123,3125,3129,3137,3140,3168,3169,3174,3183,3202,3203,3205,3212,3214,3216,3218,3240,3242,3251,3253,3257,3262,3262,3264,3268,3271,3272,3274,3275,3285,3286,3294,3294,3296,3297,3302,3311,3330,3331,3333,3340,3342,3344,3346,3368,3370,3385,3390,3392,3398,3400,3402,3404,3415,3415,3424,3425,3430,3439,3458,3459,3461,3478,3482,3505,3507,3515,3517,3517,3520,3526,3535,3537,3544,3551,3570,3572,3585,3632,3634,3635,3648,3654,3663,3675,3713,3714,3716,3716,3719,3720,3722,3722,3725,3725,3732,3735,3737,3743,3745,3747,3749,3749,3751,3751,3754,3755,3757,3760,3762,3763,3773,3773,3776,3780,3782,3782,3792,3801,3804,3805,3840,3863,3866,3892,3894,3894,3896,3896,3902,3911,3913,3946,3967,3967,3973,3973,3976,3979,4030,4037,4039,4044,4047,4047,4096,4129,4131,4135,4137,4138,4140,4140,4145,4145,4152,4152,4160,4183,4256,4293,4304,4344,4347,4347,4352,4441,4447,4514,4520,4601,4608,4614,4616,4678,4680,4680,4682,4685,4688,4694,4696,4696,4698,4701,4704,4742,4744,4744,4746,4749,4752,4782,4784,4784,4786,4789,4792,4798,4800,4800,4802,4805,4808,4814,4816,4822,4824,4846,4848,4878,4880,4880,4882,4885,4888,4894,4896,4934,4936,4954,4961,4988,5024,5108,5121,5750,5761,5786,5792,5872,5888,5900,5902,5905,5920,5937,5941,5942,5952,5969,5984,5996,5998,6e3,6016,6070,6078,6085,6087,6088,6100,6106,6108,6108,6112,6121,6160,6169,6176,6263,6272,6312,7680,7835,7840,7929,7936,7957,7960,7965,7968,8005,8008,8013,8016,8023,8025,8025,8027,8027,8029,8029,8031,8061,8064,8116,8118,8124,8126,8126,8130,8132,8134,8140,8144,8147,8150,8155,8160,8172,8178,8180,8182,8188,8206,8206,8305,8305,8319,8319,8450,8450,8455,8455,8458,8467,8469,8469,8473,8477,8484,8484,8486,8486,8488,8488,8490,8493,8495,8497,8499,8505,8509,8511,8517,8521,8544,8579,9014,9082,9109,9109,9372,9449,12293,12295,12321,12329,12337,12341,12344,12348,12353,12438,12445,12447,12449,12538,12540,12543,12549,12588,12593,12686,12688,12727,12784,12828,12832,12867,12896,12923,12927,12976,12992,13003,13008,13054,13056,13174,13179,13277,13280,13310,13312,19893,19968,40869,40960,42124,44032,55203,55296,64045,64048,64106,64256,64262,64275,64279,65313,65338,65345,65370,65382,65470,65474,65479,65482,65487,65490,65495,65498,65500,66304,66334,66336,66339,66352,66378,66560,66597,66600,66637,118784,119029,119040,119078,119082,119142,119146,119154,119171,119172,119180,119209,119214,119261,119808,119892,119894,119964,119966,119967,119970,119970,119973,119974,119977,119980,119982,119993,119995,119995,119997,12e4,120002,120003,120005,120069,120071,120074,120077,120084,120086,120092,120094,120121,120123,120126,120128,120132,120134,120134,120138,120144,120146,120483,120488,120777,131072,173782,194560,195101,983040,1048573,1048576,1114109],q=function(A){return H(A,_)},$=function(A){return H(A,j)},AA=function(A){return H(A,J)},tA=function(A){return A.codePointAt(0)},eA=function(A){return A[0]},nA=function(A){return A[A.length-1]};function rA(A){for(var t=[],e=A.length,n=0;n<e;n+=1){var r=A.charCodeAt(n);if(r>=55296&&r<=56319&&e>n+1){var i=A.charCodeAt(n+1);if(i>=56320&&i<=57343){t.push(1024*(r-55296)+i-56320+65536),n+=1;continue}}t.push(r)}return t}var iA=function(){function A(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};if(u(this,A),!e.ownerPassword&&!e.userPassword)throw new Error("None of owner password and user password is defined.");this.document=t,this._setupEncryption(e)}return h(A,null,[{key:"generateFileID",value:function(){var A=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t="".concat(A.CreationDate.getTime(),"\n");for(var e in A)A.hasOwnProperty(e)&&(t+="".concat(e,": ").concat(A[e].valueOf(),"\n"));return BA(o.default.MD5(t))}},{key:"generateRandomWordArray",value:function(A){return o.default.lib.WordArray.random(A)}},{key:"create",value:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return e.ownerPassword||e.userPassword?new A(t,e):null}}]),h(A,[{key:"_setupEncryption",value:function(A){switch(A.pdfVersion){case"1.4":case"1.5":this.version=2;break;case"1.6":case"1.7":this.version=4;break;case"1.7ext3":this.version=5;break;default:this.version=1}var t={Filter:"Standard"};switch(this.version){case 1:case 2:case 4:this._setupEncryptionV1V2V4(this.version,t,A);break;case 5:this._setupEncryptionV5(t,A)}this.dictionary=this.document.ref(t)}},{key:"_setupEncryptionV1V2V4",value:function(A,t,e){var n,r;switch(A){case 1:n=2,this.keyBits=40,r=function(){var A=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=-64;return A.printing&&(t|=4),A.modifying&&(t|=8),A.copying&&(t|=16),A.annotating&&(t|=32),t}(e.permissions);break;case 2:n=3,this.keyBits=128,r=oA(e.permissions);break;case 4:n=4,this.keyBits=128,r=oA(e.permissions)}var i,s=sA(e.userPassword),a=e.ownerPassword?sA(e.ownerPassword):s,c=function(A,t,e,n){for(var r=n,i=A>=3?51:1,s=0;s<i;s++)r=o.default.MD5(r);var a=r.clone();a.sigBytes=t/8;var c=e;i=A>=3?20:1;for(var B=0;B<i;B++){for(var g=Math.ceil(a.sigBytes/4),l=0;l<g;l++)a.words[l]=r.words[l]^(B|B<<8|B<<16|B<<24);c=o.default.RC4.encrypt(c,a).ciphertext}return c}(n,this.keyBits,s,a);this.encryptionKey=function(A,t,e,n,r,i){for(var s=n.clone().concat(r).concat(o.default.lib.WordArray.create([cA(i)],4)).concat(o.default.lib.WordArray.create(e)),a=A>=3?51:1,c=0;c<a;c++)(s=o.default.MD5(s)).sigBytes=t/8;return s}(n,this.keyBits,this.document._id,s,c,r),i=2===n?function(A){return o.default.RC4.encrypt(sA(),A).ciphertext}(this.encryptionKey):function(A,t){for(var e=t.clone(),n=o.default.MD5(sA().concat(o.default.lib.WordArray.create(A))),r=0;r<20;r++){for(var i=Math.ceil(e.sigBytes/4),s=0;s<i;s++)e.words[s]=t.words[s]^(r|r<<8|r<<16|r<<24);n=o.default.RC4.encrypt(n,e).ciphertext}return n.concat(o.default.lib.WordArray.create(null,16))}(this.document._id,this.encryptionKey),t.V=A,A>=2&&(t.Length=this.keyBits),4===A&&(t.CF={StdCF:{AuthEvent:"DocOpen",CFM:"AESV2",Length:this.keyBits/8}},t.StmF="StdCF",t.StrF="StdCF"),t.R=n,t.O=BA(c),t.U=BA(i),t.P=r}},{key:"_setupEncryptionV5",value:function(t,e){this.keyBits=256;var n=oA(e.permissions),r=aA(e.userPassword),i=e.ownerPassword?aA(e.ownerPassword):r;this.encryptionKey=function(A){return A(32)}(A.generateRandomWordArray);var s=function(A,t){var e=t(8),n=t(8);return o.default.SHA256(A.clone().concat(e)).concat(e).concat(n)}(r,A.generateRandomWordArray),a=function(A,t,e){var n=o.default.SHA256(A.clone().concat(t)),r={mode:o.default.mode.CBC,padding:o.default.pad.NoPadding,iv:o.default.lib.WordArray.create(null,16)};return o.default.AES.encrypt(e,n,r).ciphertext}(r,o.default.lib.WordArray.create(s.words.slice(10,12),8),this.encryptionKey),c=function(A,t,e){var n=e(8),r=e(8);return o.default.SHA256(A.clone().concat(n).concat(t)).concat(n).concat(r)}(i,s,A.generateRandomWordArray),B=function(A,t,e,n){var r=o.default.SHA256(A.clone().concat(t).concat(e)),i={mode:o.default.mode.CBC,padding:o.default.pad.NoPadding,iv:o.default.lib.WordArray.create(null,16)};return o.default.AES.encrypt(n,r,i).ciphertext}(i,o.default.lib.WordArray.create(c.words.slice(10,12),8),s,this.encryptionKey),g=function(A,t,e){var n=o.default.lib.WordArray.create([cA(A),4294967295,1415668834],12).concat(e(4)),r={mode:o.default.mode.ECB,padding:o.default.pad.NoPadding};return o.default.AES.encrypt(n,t,r).ciphertext}(n,this.encryptionKey,A.generateRandomWordArray);t.V=5,t.Length=this.keyBits,t.CF={StdCF:{AuthEvent:"DocOpen",CFM:"AESV3",Length:this.keyBits/8}},t.StmF="StdCF",t.StrF="StdCF",t.R=5,t.O=BA(c),t.OE=BA(B),t.U=BA(s),t.UE=BA(a),t.P=n,t.Perms=BA(g)}},{key:"getEncryptFn",value:function(t,e){var n,r;if(this.version<5&&(n=this.encryptionKey.clone().concat(o.default.lib.WordArray.create([(255&t)<<24|(65280&t)<<8|t>>8&65280|255&e,(65280&e)<<16],5))),1===this.version||2===this.version){var i=o.default.MD5(n);return i.sigBytes=Math.min(16,this.keyBits/8+5),function(A){return BA(o.default.RC4.encrypt(o.default.lib.WordArray.create(A),i).ciphertext)}}r=4===this.version?o.default.MD5(n.concat(o.default.lib.WordArray.create([1933667412],4))):this.encryptionKey;var s=A.generateRandomWordArray(16),a={mode:o.default.mode.CBC,padding:o.default.pad.Pkcs7,iv:s};return function(A){return BA(s.clone().concat(o.default.AES.encrypt(o.default.lib.WordArray.create(A),r,a).ciphertext))}}},{key:"end",value:function(){this.dictionary.end()}}]),A}();function oA(){var A=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=-3904;return"lowResolution"===A.printing&&(t|=4),"highResolution"===A.printing&&(t|=2052),A.modifying&&(t|=8),A.copying&&(t|=16),A.annotating&&(t|=32),A.fillingForms&&(t|=256),A.contentAccessibility&&(t|=512),A.documentAssembly&&(t|=1024),t}function sA(){for(var A=arguments.length>0&&void 0!==arguments[0]?arguments[0]:"",t=n.alloc(32),e=A.length,r=0;r<e&&r<32;){var i=A.charCodeAt(r);if(i>255)throw new Error("Password contains one or more invalid characters.");t[r]=i,r++}for(;r<32;)t[r]=fA[r-e],r++;return o.default.lib.WordArray.create(t)}function aA(){var A=arguments.length>0&&void 0!==arguments[0]?arguments[0]:"";A=unescape(encodeURIComponent(function(A){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};if("string"!=typeof A)throw new TypeError("Expected string.");if(0===A.length)return"";var e=rA(A).map((function(A){return $(A)?32:A})).filter((function(A){return!AA(A)})),n=String.fromCodePoint.apply(null,e).normalize("NFKC"),r=rA(n);if(r.some(V))throw new Error("Prohibited character, see https://tools.ietf.org/html/rfc4013#section-2.3");if(!0!==t.allowUnassigned&&r.some(L))throw new Error("Unassigned code point, see https://tools.ietf.org/html/rfc4013#section-2.5");var i=r.some(Z),o=r.some(q);if(i&&o)throw new Error("String must not contain RandALCat and LCat at the same time, see https://tools.ietf.org/html/rfc3454#section-6");var s=Z(tA(eA(n))),a=Z(tA(nA(n)));if(i&&(!s||!a))throw new Error("Bidirectional RandALCat character must be the first and the last character of the string, see https://tools.ietf.org/html/rfc3454#section-6");return n}(A)));for(var t=Math.min(127,A.length),e=n.alloc(t),r=0;r<t;r++)e[r]=A.charCodeAt(r);return o.default.lib.WordArray.create(e)}function cA(A){return(255&A)<<24|(65280&A)<<8|A>>8&65280|A>>24&255}function BA(A){for(var t=[],e=0;e<A.sigBytes;e++)t.push(A.words[Math.floor(e/4)]>>8*(3-e%4)&255);return n.from(t)}var gA,lA,uA,wA,hA,EA,fA=[40,191,78,94,78,117,138,65,100,0,78,86,255,250,1,8,46,46,0,182,208,104,62,128,47,12,169,254,100,83,105,122],QA=x.number,dA=function(){function A(t){u(this,A),this.doc=t,this.stops=[],this.embedded=!1,this.transform=[1,0,0,1,0,0]}return h(A,[{key:"stop",value:function(A,t,e){if(null==e&&(e=1),t=this.doc._normalizeColor(t),0===this.stops.length)if(3===t.length)this._colorSpace="DeviceRGB";else if(4===t.length)this._colorSpace="DeviceCMYK";else{if(1!==t.length)throw new Error("Unknown color space");this._colorSpace="DeviceGray"}else if("DeviceRGB"===this._colorSpace&&3!==t.length||"DeviceCMYK"===this._colorSpace&&4!==t.length||"DeviceGray"===this._colorSpace&&1!==t.length)throw new Error("All gradient stops must use the same color space");return e=Math.max(0,Math.min(1,e)),this.stops.push([A,t,e]),this}},{key:"setTransform",value:function(A,t,e,n,r,i){return this.transform=[A,t,e,n,r,i],this}},{key:"embed",value:function(A){var t,e=this.stops.length;if(0!==e){this.embedded=!0,this.matrix=A;var n=this.stops[e-1];n[0]<1&&this.stops.push([1,n[1],n[2]]);for(var r=[],i=[],o=[],s=0;s<e-1;s++)i.push(0,1),s+2!==e&&r.push(this.stops[s+1][0]),t=this.doc.ref({FunctionType:2,Domain:[0,1],C0:this.stops[s+0][1],C1:this.stops[s+1][1],N:1}),o.push(t),t.end();1===e?t=o[0]:(t=this.doc.ref({FunctionType:3,Domain:[0,1],Functions:o,Bounds:r,Encode:i})).end(),this.id="Sh".concat(++this.doc._gradCount);var a=this.shader(t);a.end();var c=this.doc.ref({Type:"Pattern",PatternType:2,Shading:a,Matrix:this.matrix.map(QA)});if(c.end(),this.stops.some((function(A){return A[2]<1}))){var B=this.opacityGradient();B._colorSpace="DeviceGray";var g,l=F(this.stops);try{for(l.s();!(g=l.n()).done;){var u=g.value;B.stop(u[0],[u[2]])}}catch(A){l.e(A)}finally{l.f()}B=B.embed(this.matrix);var w=[0,0,this.doc.page.width,this.doc.page.height],h=this.doc.ref({Type:"XObject",Subtype:"Form",FormType:1,BBox:w,Group:{Type:"Group",S:"Transparency",CS:"DeviceGray"},Resources:{ProcSet:["PDF","Text","ImageB","ImageC","ImageI"],Pattern:{Sh1:B}}});h.write("/Pattern cs /Sh1 scn"),h.end("".concat(w.join(" ")," re f"));var E=this.doc.ref({Type:"ExtGState",SMask:{Type:"Mask",S:"Luminosity",G:h}});E.end();var f=this.doc.ref({Type:"Pattern",PatternType:1,PaintType:1,TilingType:2,BBox:w,XStep:w[2],YStep:w[3],Resources:{ProcSet:["PDF","Text","ImageB","ImageC","ImageI"],Pattern:{Sh1:c},ExtGState:{Gs1:E}}});f.write("/Gs1 gs /Pattern cs /Sh1 scn"),f.end("".concat(w.join(" ")," re f")),this.doc.page.patterns[this.id]=f}else this.doc.page.patterns[this.id]=c;return c}}},{key:"apply",value:function(A){var t=D(this.doc._ctm,6),e=t[0],n=t[1],r=t[2],i=t[3],o=t[4],s=t[5],a=D(this.transform,6),c=a[0],B=a[1],g=a[2],l=a[3],u=a[4],w=a[5],h=[e*c+r*B,n*c+i*B,e*g+r*l,n*g+i*l,e*u+r*w+o,n*u+i*w+s];this.embedded&&h.join(" ")===this.matrix.join(" ")||this.embed(h),this.doc._setColorSpace("Pattern",A);var E=A?"SCN":"scn";return this.doc.addContent("/".concat(this.id," ").concat(E))}}]),A}(),CA={PDFGradient:dA,PDFLinearGradient:function(A){d(e,A);var t=p(e);function e(A,n,r,i,o){var s;return u(this,e),(s=t.call(this,A)).x1=n,s.y1=r,s.x2=i,s.y2=o,s}return h(e,[{key:"shader",value:function(A){return this.doc.ref({ShadingType:2,ColorSpace:this._colorSpace,Coords:[this.x1,this.y1,this.x2,this.y2],Function:A,Extend:[!0,!0]})}},{key:"opacityGradient",value:function(){return new e(this.doc,this.x1,this.y1,this.x2,this.y2)}}]),e}(dA),PDFRadialGradient:function(A){d(e,A);var t=p(e);function e(A,n,r,i,o,s,a){var c;return u(this,e),(c=t.call(this,A)).doc=A,c.x1=n,c.y1=r,c.r1=i,c.x2=o,c.y2=s,c.r2=a,c}return h(e,[{key:"shader",value:function(A){return this.doc.ref({ShadingType:3,ColorSpace:this._colorSpace,Coords:[this.x1,this.y1,this.r1,this.x2,this.y2,this.r2],Function:A,Extend:[!0,!0]})}},{key:"opacityGradient",value:function(){return new e(this.doc,this.x1,this.y1,this.r1,this.x2,this.y2,this.r2)}}]),e}(dA)},MA=["DeviceCMYK","DeviceRGB"],IA=function(){function A(t,e,n,r,i){u(this,A),this.doc=t,this.bBox=e,this.xStep=n,this.yStep=r,this.stream=i}return h(A,[{key:"createPattern",value:function(){var A=this.doc.ref();A.end();var t=D(this.doc._ctm,6),e=t[0],n=t[1],r=t[2],i=t[3],o=[1*e+0*r,1*n+0*i,0*e+1*r,0*n+1*i,0*e+0*r+t[4],0*n+0*i+t[5]],s=this.doc.ref({Type:"Pattern",PatternType:1,PaintType:2,TilingType:2,BBox:this.bBox,XStep:this.xStep,YStep:this.yStep,Matrix:o.map((function(A){return+A.toFixed(5)})),Resources:A});return s.end(this.stream),s}},{key:"embedPatternColorSpaces",value:function(){var A=this;MA.forEach((function(t){var e=A.getPatternColorSpaceId(t);if(!A.doc.page.colorSpaces[e]){var n=A.doc.ref(["Pattern",t]);n.end(),A.doc.page.colorSpaces[e]=n}}))}},{key:"getPatternColorSpaceId",value:function(A){return"CsP".concat(A)}},{key:"embed",value:function(){this.id||(this.doc._patternCount=this.doc._patternCount+1,this.id="P"+this.doc._patternCount,this.pattern=this.createPattern()),this.doc.page.patterns[this.id]||(this.doc.page.patterns[this.id]=this.pattern)}},{key:"apply",value:function(A,t){this.embedPatternColorSpaces(),this.embed();var e=this.doc._normalizeColor(t);if(!e)throw Error("invalid pattern color. (value: ".concat(t,")"));var n=this.getPatternColorSpaceId(this.doc._getColorSpace(e));this.doc._setColorSpace(n,A);var r=A?"SCN":"scn";return this.doc.addContent("".concat(e.join(" ")," /").concat(this.id," ").concat(r))}}]),A}(),pA=CA.PDFGradient,DA=CA.PDFLinearGradient,yA=CA.PDFRadialGradient,vA=IA,mA={initColor:function(){return this._opacityRegistry={},this._opacityCount=0,this._patternCount=0,this._gradCount=0},_normalizeColor:function(A){if("string"==typeof A)if("#"===A.charAt(0)){4===A.length&&(A=A.replace(/#([0-9A-F])([0-9A-F])([0-9A-F])/i,"#$1$1$2$2$3$3"));var t=parseInt(A.slice(1),16);A=[t>>16,t>>8&255,255&t]}else FA[A]&&(A=FA[A]);return Array.isArray(A)?(3===A.length?A=A.map((function(A){return A/255})):4===A.length&&(A=A.map((function(A){return A/100}))),A):null},_setColor:function(A,t){return A instanceof pA?(A.apply(t),!0):Array.isArray(A)&&A[0]instanceof vA?(A[0].apply(t,A[1]),!0):this._setColorCore(A,t)},_setColorCore:function(A,t){if(!(A=this._normalizeColor(A)))return!1;var e=t?"SCN":"scn",n=this._getColorSpace(A);return this._setColorSpace(n,t),A=A.join(" "),this.addContent("".concat(A," ").concat(e)),!0},_setColorSpace:function(A,t){var e=t?"CS":"cs";return this.addContent("/".concat(A," ").concat(e))},_getColorSpace:function(A){return 4===A.length?"DeviceCMYK":"DeviceRGB"},fillColor:function(A,t){return this._setColor(A,!1)&&this.fillOpacity(t),this._fillColor=[A,t],this},strokeColor:function(A,t){return this._setColor(A,!0)&&this.strokeOpacity(t),this},opacity:function(A){return this._doOpacity(A,A),this},fillOpacity:function(A){return this._doOpacity(A,null),this},strokeOpacity:function(A){return this._doOpacity(null,A),this},_doOpacity:function(A,t){var e,n;if(null!=A||null!=t){null!=A&&(A=Math.max(0,Math.min(1,A))),null!=t&&(t=Math.max(0,Math.min(1,t)));var r="".concat(A,"_").concat(t);if(this._opacityRegistry[r]){var i=D(this._opacityRegistry[r],2);e=i[0],n=i[1]}else{e={Type:"ExtGState"},null!=A&&(e.ca=A),null!=t&&(e.CA=t),(e=this.ref(e)).end();var o=++this._opacityCount;n="Gs".concat(o),this._opacityRegistry[r]=[e,n]}return this.page.ext_gstates[n]=e,this.addContent("/".concat(n," gs"))}},linearGradient:function(A,t,e,n){return new DA(this,A,t,e,n)},radialGradient:function(A,t,e,n,r,i){return new yA(this,A,t,e,n,r,i)},pattern:function(A,t,e,n){return new vA(this,A,t,e,n)}},FA={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],grey:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]};gA=lA=uA=wA=hA=EA=0;var YA={A:7,a:7,C:6,c:6,H:1,h:1,L:2,l:2,M:2,m:2,Q:4,q:4,S:4,s:4,T:2,t:2,V:1,v:1,Z:0,z:0},bA={M:function(A,t){return gA=t[0],lA=t[1],uA=wA=null,hA=gA,EA=lA,A.moveTo(gA,lA)},m:function(A,t){return gA+=t[0],lA+=t[1],uA=wA=null,hA=gA,EA=lA,A.moveTo(gA,lA)},C:function(A,t){return gA=t[4],lA=t[5],uA=t[2],wA=t[3],A.bezierCurveTo.apply(A,y(t))},c:function(A,t){return A.bezierCurveTo(t[0]+gA,t[1]+lA,t[2]+gA,t[3]+lA,t[4]+gA,t[5]+lA),uA=gA+t[2],wA=lA+t[3],gA+=t[4],lA+=t[5]},S:function(A,t){return null===uA&&(uA=gA,wA=lA),A.bezierCurveTo(gA-(uA-gA),lA-(wA-lA),t[0],t[1],t[2],t[3]),uA=t[0],wA=t[1],gA=t[2],lA=t[3]},s:function(A,t){return null===uA&&(uA=gA,wA=lA),A.bezierCurveTo(gA-(uA-gA),lA-(wA-lA),gA+t[0],lA+t[1],gA+t[2],lA+t[3]),uA=gA+t[0],wA=lA+t[1],gA+=t[2],lA+=t[3]},Q:function(A,t){return uA=t[0],wA=t[1],gA=t[2],lA=t[3],A.quadraticCurveTo(t[0],t[1],gA,lA)},q:function(A,t){return A.quadraticCurveTo(t[0]+gA,t[1]+lA,t[2]+gA,t[3]+lA),uA=gA+t[0],wA=lA+t[1],gA+=t[2],lA+=t[3]},T:function(A,t){return null===uA?(uA=gA,wA=lA):(uA=gA-(uA-gA),wA=lA-(wA-lA)),A.quadraticCurveTo(uA,wA,t[0],t[1]),uA=gA-(uA-gA),wA=lA-(wA-lA),gA=t[0],lA=t[1]},t:function(A,t){return null===uA?(uA=gA,wA=lA):(uA=gA-(uA-gA),wA=lA-(wA-lA)),A.quadraticCurveTo(uA,wA,gA+t[0],lA+t[1]),gA+=t[0],lA+=t[1]},A:function(A,t){return zA(A,gA,lA,t),gA=t[5],lA=t[6]},a:function(A,t){return t[5]+=gA,t[6]+=lA,zA(A,gA,lA,t),gA=t[5],lA=t[6]},L:function(A,t){return gA=t[0],lA=t[1],uA=wA=null,A.lineTo(gA,lA)},l:function(A,t){return gA+=t[0],lA+=t[1],uA=wA=null,A.lineTo(gA,lA)},H:function(A,t){return gA=t[0],uA=wA=null,A.lineTo(gA,lA)},h:function(A,t){return gA+=t[0],uA=wA=null,A.lineTo(gA,lA)},V:function(A,t){return lA=t[0],uA=wA=null,A.lineTo(gA,lA)},v:function(A,t){return lA+=t[0],uA=wA=null,A.lineTo(gA,lA)},Z:function(A){return A.closePath(),gA=hA,lA=EA},z:function(A){return A.closePath(),gA=hA,lA=EA}},zA=function(A,t,e,n){var r,i=D(n,7),o=i[0],s=i[1],a=i[2],c=i[3],B=i[4],g=i[5],l=i[6],u=F(UA(g,l,o,s,c,B,a,t,e));try{for(u.s();!(r=u.n()).done;){var w=r.value,h=SA.apply(void 0,y(w));A.bezierCurveTo.apply(A,y(h))}}catch(A){u.e(A)}finally{u.f()}},UA=function(A,t,e,n,r,i,o,s,a){var c=o*(Math.PI/180),B=Math.sin(c),g=Math.cos(c);e=Math.abs(e),n=Math.abs(n);var l=(uA=g*(s-A)*.5+B*(a-t)*.5)*uA/(e*e)+(wA=g*(a-t)*.5-B*(s-A)*.5)*wA/(n*n);l>1&&(e*=l=Math.sqrt(l),n*=l);var u=g/e,w=B/e,h=-B/n,E=g/n,f=u*s+w*a,Q=h*s+E*a,d=u*A+w*t,C=h*A+E*t,M=1/((d-f)*(d-f)+(C-Q)*(C-Q))-.25;M<0&&(M=0);var I=Math.sqrt(M);i===r&&(I=-I);var p=.5*(f+d)-I*(C-Q),D=.5*(Q+C)+I*(d-f),y=Math.atan2(Q-D,f-p),v=Math.atan2(C-D,d-p)-y;v<0&&1===i?v+=2*Math.PI:v>0&&0===i&&(v-=2*Math.PI);for(var m=Math.ceil(Math.abs(v/(.5*Math.PI+.001))),F=[],Y=0;Y<m;Y++){var b=y+Y*v/m,z=y+(Y+1)*v/m;F[Y]=[p,D,b,z,e,n,B,g]}return F},SA=function(A,t,e,n,r,i,o,s){var a=s*r,c=-o*i,B=o*r,g=s*i,l=.5*(n-e),u=8/3*Math.sin(.5*l)*Math.sin(.5*l)/Math.sin(l),w=A+Math.cos(e)-u*Math.sin(e),h=t+Math.sin(e)+u*Math.cos(e),E=A+Math.cos(n),f=t+Math.sin(n),Q=E+u*Math.sin(n),d=f-u*Math.cos(n);return[a*w+c*h,B*w+g*h,a*Q+c*d,B*Q+g*d,a*E+c*f,B*E+g*f]},xA=function(){function A(){u(this,A)}return h(A,null,[{key:"apply",value:function(A,t){var e=function(A){var t,e,n=[],r=[],i="",o=!1,s=0,a=F(A);try{for(a.s();!(e=a.n()).done;){var c=e.value;if(null!=YA[c])s=YA[c],t&&(i.length>0&&(r[r.length]=+i),n[n.length]={cmd:t,args:r},r=[],i="",o=!1),t=c;else if([" ",","].includes(c)||"-"===c&&i.length>0&&"e"!==i[i.length-1]||"."===c&&o){if(0===i.length)continue;r.length===s?(n[n.length]={cmd:t,args:r},r=[+i],"M"===t&&(t="L"),"m"===t&&(t="l")):r[r.length]=+i,o="."===c,i=["-","."].includes(c)?c:""}else i+=c,"."===c&&(o=!0)}}catch(A){a.e(A)}finally{a.f()}return i.length>0&&(r.length===s?(n[n.length]={cmd:t,args:r},r=[+i],"M"===t&&(t="L"),"m"===t&&(t="l")):r[r.length]=+i),n[n.length]={cmd:t,args:r},n}(t);!function(A,t){gA=lA=uA=wA=hA=EA=0;for(var e=0;e<A.length;e++){var n=A[e];"function"==typeof bA[n.cmd]&&bA[n.cmd](t,n.args)}}(e,A)}}]),A}(),TA=x.number,PA=(Math.sqrt(2)-1)/3*4,NA={initVector:function(){return this._ctm=[1,0,0,1,0,0],this._ctmStack=[]},save:function(){return this._ctmStack.push(this._ctm.slice()),this.addContent("q")},restore:function(){return this._ctm=this._ctmStack.pop()||[1,0,0,1,0,0],this.addContent("Q")},closePath:function(){return this.addContent("h")},lineWidth:function(A){return this.addContent("".concat(TA(A)," w"))},_CAP_STYLES:{BUTT:0,ROUND:1,SQUARE:2},lineCap:function(A){return"string"==typeof A&&(A=this._CAP_STYLES[A.toUpperCase()]),this.addContent("".concat(A," J"))},_JOIN_STYLES:{MITER:0,ROUND:1,BEVEL:2},lineJoin:function(A){return"string"==typeof A&&(A=this._JOIN_STYLES[A.toUpperCase()]),this.addContent("".concat(A," j"))},miterLimit:function(A){return this.addContent("".concat(TA(A)," M"))},dash:function(A){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},e=A;if(Array.isArray(A)||(A=[A,t.space||A]),!A.every((function(A){return Number.isFinite(A)&&A>0})))throw new Error("dash(".concat(JSON.stringify(e),", ").concat(JSON.stringify(t),") invalid, lengths must be numeric and greater than zero"));return A=A.map(TA).join(" "),this.addContent("[".concat(A,"] ").concat(TA(t.phase||0)," d"))},undash:function(){return this.addContent("[] 0 d")},moveTo:function(A,t){return this.addContent("".concat(TA(A)," ").concat(TA(t)," m"))},lineTo:function(A,t){return this.addContent("".concat(TA(A)," ").concat(TA(t)," l"))},bezierCurveTo:function(A,t,e,n,r,i){return this.addContent("".concat(TA(A)," ").concat(TA(t)," ").concat(TA(e)," ").concat(TA(n)," ").concat(TA(r)," ").concat(TA(i)," c"))},quadraticCurveTo:function(A,t,e,n){return this.addContent("".concat(TA(A)," ").concat(TA(t)," ").concat(TA(e)," ").concat(TA(n)," v"))},rect:function(A,t,e,n){return this.addContent("".concat(TA(A)," ").concat(TA(t)," ").concat(TA(e)," ").concat(TA(n)," re"))},roundedRect:function(A,t,e,n,r){null==r&&(r=0);var i=(r=Math.min(r,.5*e,.5*n))*(1-PA);return this.moveTo(A+r,t),this.lineTo(A+e-r,t),this.bezierCurveTo(A+e-i,t,A+e,t+i,A+e,t+r),this.lineTo(A+e,t+n-r),this.bezierCurveTo(A+e,t+n-i,A+e-i,t+n,A+e-r,t+n),this.lineTo(A+r,t+n),this.bezierCurveTo(A+i,t+n,A,t+n-i,A,t+n-r),this.lineTo(A,t+r),this.bezierCurveTo(A,t+i,A+i,t,A+r,t),this.closePath()},ellipse:function(A,t,e,n){null==n&&(n=e);var r=e*PA,i=n*PA,o=(A-=e)+2*e,s=(t-=n)+2*n,a=A+e,c=t+n;return this.moveTo(A,c),this.bezierCurveTo(A,c-i,a-r,t,a,t),this.bezierCurveTo(a+r,t,o,c-i,o,c),this.bezierCurveTo(o,c+i,a+r,s,a,s),this.bezierCurveTo(a-r,s,A,c+i,A,c),this.closePath()},circle:function(A,t,e){return this.ellipse(A,t,e)},arc:function(A,t,e,n,r,i){null==i&&(i=!1);var o=2*Math.PI,s=.5*Math.PI,a=r-n;Math.abs(a)>o?a=o:0!==a&&i!==a<0&&(a=(i?-1:1)*o+a);var c=Math.ceil(Math.abs(a)/s),B=a/c,g=B/s*PA*e,l=n,u=-Math.sin(l)*g,w=Math.cos(l)*g,h=A+Math.cos(l)*e,E=t+Math.sin(l)*e;this.moveTo(h,E);for(var f=0;f<c;f++){var Q=h+u,d=E+w;l+=B,h=A+Math.cos(l)*e,E=t+Math.sin(l)*e;var C=h-(u=-Math.sin(l)*g),M=E-(w=Math.cos(l)*g);this.bezierCurveTo(Q,d,C,M,h,E)}return this},polygon:function(){for(var A=arguments.length,t=new Array(A),e=0;e<A;e++)t[e]=arguments[e];this.moveTo.apply(this,y(t.shift()||[]));for(var n=0,r=t;n<r.length;n++){var i=r[n];this.lineTo.apply(this,y(i||[]))}return this.closePath()},path:function(A){return xA.apply(this,A),this},_windingRule:function(A){return/even-?odd/.test(A)?"*":""},fill:function(A,t){return/(even-?odd)|(non-?zero)/.test(A)&&(t=A,A=null),A&&this.fillColor(A),this.addContent("f".concat(this._windingRule(t)))},stroke:function(A){return A&&this.strokeColor(A),this.addContent("S")},fillAndStroke:function(A,t,e){null==t&&(t=A);var n=/(even-?odd)|(non-?zero)/;return n.test(A)&&(e=A,A=null),n.test(t)&&(e=t,t=A),A&&(this.fillColor(A),this.strokeColor(t)),this.addContent("B".concat(this._windingRule(e)))},clip:function(A){return this.addContent("W".concat(this._windingRule(A)," n"))},transform:function(A,t,e,n,r,i){var o=this._ctm,s=D(o,6),a=s[0],c=s[1],B=s[2],g=s[3],l=s[4],u=s[5];o[0]=a*A+B*t,o[1]=c*A+g*t,o[2]=a*e+B*n,o[3]=c*e+g*n,o[4]=a*r+B*i+l,o[5]=c*r+g*i+u;var w=[A,t,e,n,r,i].map((function(A){return TA(A)})).join(" ");return this.addContent("".concat(w," cm"))},translate:function(A,t){return this.transform(1,0,0,1,A,t)},rotate:function(A){var t,e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},n=A*Math.PI/180,r=Math.cos(n),i=Math.sin(n),o=t=0;if(null!=e.origin){var s=D(e.origin,2),a=(o=s[0])*r-(t=s[1])*i,c=o*i+t*r;o-=a,t-=c}return this.transform(r,i,-i,r,o,t)},scale:function(A,t){var e,n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};null==t&&(t=A),"object"==typeof t&&(n=t,t=A);var r=e=0;if(null!=n.origin){var i=D(n.origin,2);r=i[0],e=i[1],r-=A*r,e-=t*e}return this.transform(A,0,0,t,r,e)}},RA={402:131,8211:150,8212:151,8216:145,8217:146,8218:130,8220:147,8221:148,8222:132,8224:134,8225:135,8226:149,8230:133,8364:128,8240:137,8249:139,8250:155,710:136,8482:153,338:140,339:156,732:152,352:138,353:154,376:159,381:142,382:158},GA=".notdef       .notdef        .notdef        .notdef\n.notdef       .notdef        .notdef        .notdef\n.notdef       .notdef        .notdef        .notdef\n.notdef       .notdef        .notdef        .notdef\n.notdef       .notdef        .notdef        .notdef\n.notdef       .notdef        .notdef        .notdef\n.notdef       .notdef        .notdef        .notdef\n.notdef       .notdef        .notdef        .notdef\n  \nspace         exclam         quotedbl       numbersign\ndollar        percent        ampersand      quotesingle\nparenleft     parenright     asterisk       plus\ncomma         hyphen         period         slash\nzero          one            two            three\nfour          five           six            seven\neight         nine           colon          semicolon\nless          equal          greater        question\n  \nat            A              B              C\nD             E              F              G\nH             I              J              K\nL             M              N              O\nP             Q              R              S\nT             U              V              W\nX             Y              Z              bracketleft\nbackslash     bracketright   asciicircum    underscore\n  \ngrave         a              b              c\nd             e              f              g\nh             i              j              k\nl             m              n              o\np             q              r              s\nt             u              v              w\nx             y              z              braceleft\nbar           braceright     asciitilde     .notdef\n  \nEuro          .notdef        quotesinglbase florin\nquotedblbase  ellipsis       dagger         daggerdbl\ncircumflex    perthousand    Scaron         guilsinglleft\nOE            .notdef        Zcaron         .notdef\n.notdef       quoteleft      quoteright     quotedblleft\nquotedblright bullet         endash         emdash\ntilde         trademark      scaron         guilsinglright\noe            .notdef        zcaron         ydieresis\n  \nspace         exclamdown     cent           sterling\ncurrency      yen            brokenbar      section\ndieresis      copyright      ordfeminine    guillemotleft\nlogicalnot    hyphen         registered     macron\ndegree        plusminus      twosuperior    threesuperior\nacute         mu             paragraph      periodcentered\ncedilla       onesuperior    ordmasculine   guillemotright\nonequarter    onehalf        threequarters  questiondown\n  \nAgrave        Aacute         Acircumflex    Atilde\nAdieresis     Aring          AE             Ccedilla\nEgrave        Eacute         Ecircumflex    Edieresis\nIgrave        Iacute         Icircumflex    Idieresis\nEth           Ntilde         Ograve         Oacute\nOcircumflex   Otilde         Odieresis      multiply\nOslash        Ugrave         Uacute         Ucircumflex\nUdieresis     Yacute         Thorn          germandbls\n  \nagrave        aacute         acircumflex    atilde\nadieresis     aring          ae             ccedilla\negrave        eacute         ecircumflex    edieresis\nigrave        iacute         icircumflex    idieresis\neth           ntilde         ograve         oacute\nocircumflex   otilde         odieresis      divide\noslash        ugrave         uacute         ucircumflex\nudieresis     yacute         thorn          ydieresis".split(/\s+/),HA=function(){function A(t){u(this,A),this.contents=t,this.attributes={},this.glyphWidths={},this.boundingBoxes={},this.kernPairs={},this.parse(),this.charWidths=new Array(256);for(var e=0;e<=255;e++)this.charWidths[e]=this.glyphWidths[GA[e]];this.bbox=this.attributes.FontBBox.split(/\s+/).map((function(A){return+A})),this.ascender=+(this.attributes.Ascender||0),this.descender=+(this.attributes.Descender||0),this.xHeight=+(this.attributes.XHeight||0),this.capHeight=+(this.attributes.CapHeight||0),this.lineGap=this.bbox[3]-this.bbox[1]-(this.ascender-this.descender)}return h(A,null,[{key:"open",value:function(t){return new A(l.readFileSync(t,"utf8"))}}]),h(A,[{key:"parse",value:function(){var A,t="",e=F(this.contents.split("\n"));try{for(e.s();!(A=e.n()).done;){var n,r,i=A.value;if(n=i.match(/^Start(\w+)/))t=n[1];else if(n=i.match(/^End(\w+)/))t="";else switch(t){case"FontMetrics":var o=(n=i.match(/(^\w+)\s+(.*)/))[1],s=n[2];(r=this.attributes[o])?(Array.isArray(r)||(r=this.attributes[o]=[r]),r.push(s)):this.attributes[o]=s;break;case"CharMetrics":if(!/^CH?\s/.test(i))continue;var a=i.match(/\bN\s+(\.?\w+)\s*;/)[1];this.glyphWidths[a]=+i.match(/\bWX\s+(\d+)\s*;/)[1];break;case"KernPairs":(n=i.match(/^KPX\s+(\.?\w+)\s+(\.?\w+)\s+(-?\d+)/))&&(this.kernPairs[n[1]+"\0"+n[2]]=parseInt(n[3]))}}}catch(A){e.e(A)}finally{e.f()}}},{key:"encodeText",value:function(A){for(var t=[],e=0,n=A.length;e<n;e++){var r=A.charCodeAt(e);r=RA[r]||r,t.push(r.toString(16))}return t}},{key:"glyphsForString",value:function(A){for(var t=[],e=0,n=A.length;e<n;e++){var r=A.charCodeAt(e);t.push(this.characterToGlyph(r))}return t}},{key:"characterToGlyph",value:function(A){return GA[RA[A]||A]||".notdef"}},{key:"widthOfGlyph",value:function(A){return this.glyphWidths[A]||0}},{key:"getKernPair",value:function(A,t){return this.kernPairs[A+"\0"+t]||0}},{key:"advancesForGlyphs",value:function(A){for(var t=[],e=0;e<A.length;e++){var n=A[e],r=A[e+1];t.push(this.widthOfGlyph(n)+this.getKernPair(n,r))}return t}}]),A}(),kA=function(){function A(){u(this,A)}return h(A,[{key:"encode",value:function(){throw new Error("Must be implemented by subclasses")}},{key:"widthOfString",value:function(){throw new Error("Must be implemented by subclasses")}},{key:"ref",value:function(){return null!=this.dictionary?this.dictionary:this.dictionary=this.document.ref()}},{key:"finalize",value:function(){if(!this.embedded&&null!=this.dictionary)return this.embed(),this.embedded=!0}},{key:"embed",value:function(){throw new Error("Must be implemented by subclasses")}},{key:"lineHeight",value:function(A,t){null==t&&(t=!1);var e=t?this.lineGap:0;return(this.ascender+e-this.descender)/1e3*A}}]),A}(),LA={Courier:function(){return l.readFileSync("//data/Courier.afm","utf8")},"Courier-Bold":function(){return l.readFileSync("//data/Courier-Bold.afm","utf8")},"Courier-Oblique":function(){return l.readFileSync("//data/Courier-Oblique.afm","utf8")},"Courier-BoldOblique":function(){return l.readFileSync("//data/Courier-BoldOblique.afm","utf8")},Helvetica:function(){return l.readFileSync("//data/Helvetica.afm","utf8")},"Helvetica-Bold":function(){return l.readFileSync("//data/Helvetica-Bold.afm","utf8")},"Helvetica-Oblique":function(){return l.readFileSync("//data/Helvetica-Oblique.afm","utf8")},"Helvetica-BoldOblique":function(){return l.readFileSync("//data/Helvetica-BoldOblique.afm","utf8")},"Times-Roman":function(){return l.readFileSync("//data/Times-Roman.afm","utf8")},"Times-Bold":function(){return l.readFileSync("//data/Times-Bold.afm","utf8")},"Times-Italic":function(){return l.readFileSync("//data/Times-Italic.afm","utf8")},"Times-BoldItalic":function(){return l.readFileSync("//data/Times-BoldItalic.afm","utf8")},Symbol:function(){return l.readFileSync("//data/Symbol.afm","utf8")},ZapfDingbats:function(){return l.readFileSync("//data/ZapfDingbats.afm","utf8")}},JA=function(A){d(e,A);var t=p(e);function e(A,n,r){var i;u(this,e),(i=t.call(this)).document=A,i.name=n,i.id=r,i.font=new HA(LA[i.name]());var o=i.font;return i.ascender=o.ascender,i.descender=o.descender,i.bbox=o.bbox,i.lineGap=o.lineGap,i.xHeight=o.xHeight,i.capHeight=o.capHeight,i}return h(e,[{key:"embed",value:function(){return this.dictionary.data={Type:"Font",BaseFont:this.name,Subtype:"Type1",Encoding:"WinAnsiEncoding"},this.dictionary.end()}},{key:"encode",value:function(A){for(var t=this.font.encodeText(A),e=this.font.glyphsForString("".concat(A)),n=this.font.advancesForGlyphs(e),r=[],i=0;i<e.length;i++){var o=e[i];r.push({xAdvance:n[i],yAdvance:0,xOffset:0,yOffset:0,advanceWidth:this.font.widthOfGlyph(o)})}return[t,r]}},{key:"widthOfString",value:function(A,t){var e,n=this.font.glyphsForString("".concat(A)),r=0,i=F(this.font.advancesForGlyphs(n));try{for(i.s();!(e=i.n()).done;)r+=e.value}catch(A){i.e(A)}finally{i.f()}return r*(t/1e3)}}],[{key:"isStandardFont",value:function(A){return A in LA}}]),e}(kA),jA=function(A){return"0000".concat(A.toString(16)).slice(-4)},OA=function(A){d(e,A);var t=p(e);function e(A,n,r){var i;return u(this,e),(i=t.call(this)).document=A,i.font=n,i.id=r,i.subset=i.font.createSubset(),i.unicode=[[0]],i.widths=[i.font.getGlyph(0).advanceWidth],i.name=i.font.postscriptName,i.scale=1e3/i.font.unitsPerEm,i.ascender=i.font.ascent*i.scale,i.descender=i.font.descent*i.scale,i.xHeight=i.font.xHeight*i.scale,i.capHeight=i.font.capHeight*i.scale,i.lineGap=i.font.lineGap*i.scale,i.bbox=i.font.bbox,!1!==A.options.fontLayoutCache&&(i.layoutCache=Object.create(null)),i}return h(e,[{key:"layoutRun",value:function(A,t){for(var e=this.font.layout(A,t),n=0;n<e.positions.length;n++){var r=e.positions[n];for(var i in r)r[i]*=this.scale;r.advanceWidth=e.glyphs[n].advanceWidth*this.scale}return e}},{key:"layoutCached",value:function(A){if(!this.layoutCache)return this.layoutRun(A);var t;if(t=this.layoutCache[A])return t;var e=this.layoutRun(A);return this.layoutCache[A]=e,e}},{key:"layout",value:function(A,t,e){if(t)return this.layoutRun(A,t);for(var n=e?null:[],r=e?null:[],i=0,o=0,s=0;s<=A.length;){var a;if(s===A.length&&o<s||(a=A.charAt(s),[" ","\t"].includes(a))){var c=this.layoutCached(A.slice(o,++s));e||(n=n.concat(c.glyphs),r=r.concat(c.positions)),i+=c.advanceWidth,o=s}else s++}return{glyphs:n,positions:r,advanceWidth:i}}},{key:"encode",value:function(A,t){for(var e=this.layout(A,t),n=e.glyphs,r=e.positions,i=[],o=0;o<n.length;o++){var s=n[o],a=this.subset.includeGlyph(s.id);i.push("0000".concat(a.toString(16)).slice(-4)),null==this.widths[a]&&(this.widths[a]=s.advanceWidth*this.scale),null==this.unicode[a]&&(this.unicode[a]=s.codePoints)}return[i,r]}},{key:"widthOfString",value:function(A,t,e){return this.layout(A,e,!0).advanceWidth*(t/1e3)}},{key:"embed",value:function(){var A=this,t=null!=this.subset.cff,e=this.document.ref();t&&(e.data.Subtype="CIDFontType0C"),this.subset.encodeStream().on("data",(function(A){return e.write(A)})).on("end",(function(){return e.end()}));var n=((null!=this.font["OS/2"]?this.font["OS/2"].sFamilyClass:void 0)||0)>>8,r=0;this.font.post.isFixedPitch&&(r|=1),1<=n&&n<=7&&(r|=2),r|=4,10===n&&(r|=8),this.font.head.macStyle.italic&&(r|=64);var i=[1,2,3,4,5,6].map((function(t){return String.fromCharCode((A.id.charCodeAt(t)||73)+17)})).join("")+"+"+this.font.postscriptName,o=this.font.bbox,s=this.document.ref({Type:"FontDescriptor",FontName:i,Flags:r,FontBBox:[o.minX*this.scale,o.minY*this.scale,o.maxX*this.scale,o.maxY*this.scale],ItalicAngle:this.font.italicAngle,Ascent:this.ascender,Descent:this.descender,CapHeight:(this.font.capHeight||this.font.ascent)*this.scale,XHeight:(this.font.xHeight||0)*this.scale,StemV:0});t?s.data.FontFile3=e:s.data.FontFile2=e,s.end();var a={Type:"Font",Subtype:"CIDFontType0",BaseFont:i,CIDSystemInfo:{Registry:new String("Adobe"),Ordering:new String("Identity"),Supplement:0},FontDescriptor:s,W:[0,this.widths]};t||(a.Subtype="CIDFontType2",a.CIDToGIDMap="Identity");var c=this.document.ref(a);return c.end(),this.dictionary.data={Type:"Font",Subtype:"Type0",BaseFont:i,Encoding:"Identity-H",DescendantFonts:[c],ToUnicode:this.toUnicodeCmap()},this.dictionary.end()}},{key:"toUnicodeCmap",value:function(){var A,t=this.document.ref(),e=[],n=F(this.unicode);try{for(n.s();!(A=n.n()).done;){var r,i=A.value,o=[],s=F(i);try{for(s.s();!(r=s.n()).done;){var a=r.value;a>65535&&(a-=65536,o.push(jA(a>>>10&1023|55296)),a=56320|1023&a),o.push(jA(a))}}catch(A){s.e(A)}finally{s.f()}e.push("<".concat(o.join(" "),">"))}}catch(A){n.e(A)}finally{n.f()}return t.end("/CIDInit /ProcSet findresource begin\n12 dict begin\nbegincmap\n/CIDSystemInfo <<\n  /Registry (Adobe)\n  /Ordering (UCS)\n  /Supplement 0\n>> def\n/CMapName /Adobe-Identity-UCS def\n/CMapType 2 def\n1 begincodespacerange\n<0000><ffff>\nendcodespacerange\n1 beginbfrange\n<0000> <".concat(jA(e.length-1),"> [").concat(e.join(" "),"]\nendbfrange\nendcmap\nCMapName currentdict /CMap defineresource pop\nend\nend")),t}}]),e}(kA),WA=function(){function A(){u(this,A)}return h(A,null,[{key:"open",value:function(A,t,e,r){var i;if("string"==typeof t){if(JA.isStandardFont(t))return new JA(A,t,r);t=l.readFileSync(t)}if(n.isBuffer(t)?i=s.default.create(t,e):t instanceof Uint8Array?i=s.default.create(n.from(t),e):t instanceof ArrayBuffer&&(i=s.default.create(n.from(new Uint8Array(t)),e)),null==i)throw new Error("Not a supported font format or standard PDF font.");return new OA(A,i,r)}}]),A}(),KA={initFonts:function(){var A=arguments.length>0&&void 0!==arguments[0]?arguments[0]:"Helvetica";this._fontFamilies={},this._fontCount=0,this._fontSize=12,this._font=null,this._registeredFonts={},A&&this.font(A)},font:function(A,t,e){var n,r;if("number"==typeof t&&(e=t,t=null),"string"==typeof A&&this._registeredFonts[A]){n=A;var i=this._registeredFonts[A];A=i.src,t=i.family}else"string"!=typeof(n=t||A)&&(n=null);if(null!=e&&this.fontSize(e),r=this._fontFamilies[n])return this._font=r,this;var o="F".concat(++this._fontCount);return this._font=WA.open(this,A,t,o),(r=this._fontFamilies[this._font.name])?(this._font=r,this):(n&&(this._fontFamilies[n]=this._font),this._font.name&&(this._fontFamilies[this._font.name]=this._font),this)},fontSize:function(A){return this._fontSize=A,this},currentLineHeight:function(A){return null==A&&(A=!1),this._font.lineHeight(this._fontSize,A)},registerFont:function(A,t,e){return this._registeredFonts[A]={src:t,family:e},this}},VA=function(A){d(e,A);var t=p(e);function e(A,n){var r;return u(this,e),(r=t.call(this)).document=A,r.indent=n.indent||0,r.characterSpacing=n.characterSpacing||0,r.wordSpacing=0===n.wordSpacing,r.columns=n.columns||1,r.columnGap=null!=n.columnGap?n.columnGap:18,r.lineWidth=(n.width-r.columnGap*(r.columns-1))/r.columns,r.spaceLeft=r.lineWidth,r.startX=r.document.x,r.startY=r.document.y,r.column=1,r.ellipsis=n.ellipsis,r.continuedX=0,r.features=n.features,null!=n.height?(r.height=n.height,r.maxY=r.startY+n.height):r.maxY=r.document.page.maxY(),r.on("firstLine",(function(A){var t=r.continuedX||r.indent;return r.document.x+=t,r.lineWidth-=t,r.once("line",(function(){if(r.document.x-=t,r.lineWidth+=t,A.continued&&!r.continuedX&&(r.continuedX=r.indent),!A.continued)return r.continuedX=0}))})),r.on("lastLine",(function(A){var t=A.align;return"justify"===t&&(A.align="left"),r.lastLine=!0,r.once("line",(function(){return r.document.y+=A.paragraphGap||0,A.align=t,r.lastLine=!1}))})),r}return h(e,[{key:"wordWidth",value:function(A){return this.document.widthOfString(A,this)+this.characterSpacing+this.wordSpacing}},{key:"eachWord",value:function(A,t){for(var e,n=new c.default(A),r=null,i=Object.create(null);e=n.nextBreak();){var o,s=A.slice((null!=r?r.position:void 0)||0,e.position),a=null!=i[s]?i[s]:i[s]=this.wordWidth(s);if(a>this.lineWidth+this.continuedX)for(var B=r,g={};s.length;){var l,u;a>this.spaceLeft?(l=Math.ceil(this.spaceLeft/(a/s.length)),u=(a=this.wordWidth(s.slice(0,l)))<=this.spaceLeft&&l<s.length):l=s.length;for(var w=a>this.spaceLeft&&l>0;w||u;)w?w=(a=this.wordWidth(s.slice(0,--l)))>this.spaceLeft&&l>0:(w=(a=this.wordWidth(s.slice(0,++l)))>this.spaceLeft&&l>0,u=a<=this.spaceLeft&&l<s.length);if(0===l&&this.spaceLeft===this.lineWidth&&(l=1),g.required=e.required||l<s.length,o=t(s.slice(0,l),a,g,B),B={required:!1},s=s.slice(l),a=this.wordWidth(s),!1===o)break}else o=t(s,a,e,r);if(!1===o)break;r=e}}},{key:"wrap",value:function(A,t){var e=this;null!=t.indent&&(this.indent=t.indent),null!=t.characterSpacing&&(this.characterSpacing=t.characterSpacing),null!=t.wordSpacing&&(this.wordSpacing=t.wordSpacing),null!=t.ellipsis&&(this.ellipsis=t.ellipsis);var n=this.document.y+this.document.currentLineHeight(!0);(this.document.y>this.maxY||n>this.maxY)&&this.nextSection();var r="",i=0,o=0,s=0,a=this.document.y,c=function(){return t.textWidth=i+e.wordSpacing*(o-1),t.wordCount=o,t.lineWidth=e.lineWidth,a=e.document.y,e.emit("line",r,t,e),s++};return this.emit("sectionStart",t,this),this.eachWord(A,(function(A,n,s,a){if((null==a||a.required)&&(e.emit("firstLine",t,e),e.spaceLeft=e.lineWidth),n<=e.spaceLeft&&(r+=A,i+=n,o++),s.required||n>e.spaceLeft){var B=e.document.currentLineHeight(!0);if(null!=e.height&&e.ellipsis&&e.document.y+2*B>e.maxY&&e.column>=e.columns){for(!0===e.ellipsis&&(e.ellipsis="…"),r=r.replace(/\s+$/,""),i=e.wordWidth(r+e.ellipsis);r&&i>e.lineWidth;)r=r.slice(0,-1).replace(/\s+$/,""),i=e.wordWidth(r+e.ellipsis);i<=e.lineWidth&&(r+=e.ellipsis),i=e.wordWidth(r)}return s.required&&(n>e.spaceLeft&&(c(),r=A,i=n,o=1),e.emit("lastLine",t,e)),c(),e.document.y+B>e.maxY&&!e.nextSection()?(o=0,r="",!1):s.required?(e.spaceLeft=e.lineWidth,r="",i=0,o=0):(e.spaceLeft=e.lineWidth-n,r=A,i=n,o=1)}return e.spaceLeft-=n})),o>0&&(this.emit("lastLine",t,this),c()),this.emit("sectionEnd",t,this),!0===t.continued?(s>1&&(this.continuedX=0),this.continuedX+=t.textWidth||0,this.document.y=a):this.document.x=this.startX}},{key:"nextSection",value:function(A){if(this.emit("sectionEnd",A,this),++this.column>this.columns){if(null!=this.height)return!1;var t;this.document.continueOnNewPage(),this.column=1,this.startY=this.document.page.margins.top,this.maxY=this.document.page.maxY(),this.document.x=this.startX,this.document._fillColor&&(t=this.document).fillColor.apply(t,y(this.document._fillColor)),this.emit("pageBreak",A,this)}else this.document.x+=this.lineWidth+this.columnGap,this.document.y=this.startY,this.emit("columnBreak",A,this);return this.emit("sectionStart",A,this),!0}}]),e}(a.EventEmitter),XA=x.number,ZA={initText:function(){return this._line=this._line.bind(this),this.x=0,this.y=0,this._lineGap=0},lineGap:function(A){return this._lineGap=A,this},moveDown:function(A){return null==A&&(A=1),this.y+=this.currentLineHeight(!0)*A+this._lineGap,this},moveUp:function(A){return null==A&&(A=1),this.y-=this.currentLineHeight(!0)*A+this._lineGap,this},_text:function(A,t,e,n,r){var i=this;n=this._initOptions(t,e,n),A=null==A?"":"".concat(A),n.wordSpacing&&(A=A.replace(/\s{2,}/g," "));var o=function(){n.structParent&&n.structParent.add(i.struct(n.structType||"P",[i.markStructureContent(n.structType||"P")]))};if(n.width){var s=this._wrapper;s||((s=new VA(this,n)).on("line",r),s.on("firstLine",o)),this._wrapper=n.continued?s:null,this._textOptions=n.continued?n:null,s.wrap(A,n)}else{var a,c=F(A.split("\n"));try{for(c.s();!(a=c.n()).done;){var B=a.value;o(),r(B,n)}}catch(A){c.e(A)}finally{c.f()}}return this},text:function(A,t,e,n){return this._text(A,t,e,n,this._line)},widthOfString:function(A){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return this._font.widthOfString(A,this._fontSize,t.features)+(t.characterSpacing||0)*(A.length-1)},heightOfString:function(A,t){var e=this,n=this.x,r=this.y;(t=this._initOptions(t)).height=1/0;var i=t.lineGap||this._lineGap||0;this._text(A,this.x,this.y,t,(function(){return e.y+=e.currentLineHeight(!0)+i}));var o=this.y-r;return this.x=n,this.y=r,o},list:function(A,t,e,n,r){var i=this,o=(n=this._initOptions(t,e,n)).listType||"bullet",s=Math.round(this._font.ascender/1e3*this._fontSize),a=s/2,c=n.bulletRadius||s/3,B=n.textIndent||("bullet"===o?5*c:2*s),g=n.bulletIndent||("bullet"===o?8*c:2*s),l=1,u=[],w=[],h=[];!function A(t){for(var e=1,n=0;n<t.length;n++){var r=t[n];Array.isArray(r)?(l++,A(r),l--):(u.push(r),w.push(l),"bullet"!==o&&h.push(e++))}}(A),(r=new VA(this,n)).on("line",this._line),l=1;var E=0;return r.on("firstLine",(function(){var A,t,e,s,u;if(n.structParent)if(n.structTypes){var f=D(n.structTypes,3);t=f[0],e=f[1],s=f[2]}else t="LI",e="Lbl",s="LBody";if(t?(A=i.struct(t),n.structParent.add(A)):n.structParent&&(A=n.structParent),(u=w[E++])!==l){var Q=g*(u-l);i.x+=Q,r.lineWidth-=Q,l=u}switch(A&&(e||s)&&A.add(i.struct(e||s,[i.markStructureContent(e||s)])),o){case"bullet":i.circle(i.x-B+c,i.y+a,c),i.fill();break;case"numbered":case"lettered":var d=function(A){switch(o){case"numbered":return"".concat(A,".");case"lettered":var t=String.fromCharCode((A-1)%26+65),e=Math.floor((A-1)/26+1),n=Array(e+1).join(t);return"".concat(n,".")}}(h[E-1]);i._fragment(d,i.x-B,i.y,n)}A&&e&&s&&A.add(i.struct(s,[i.markStructureContent(s)])),A&&A!==n.structParent&&A.end()})),r.on("sectionStart",(function(){var A=B+g*(l-1);return i.x+=A,r.lineWidth-=A})),r.on("sectionEnd",(function(){var A=B+g*(l-1);return i.x-=A,r.lineWidth+=A})),r.wrap(u.join("\n"),n),this},_initOptions:function(){var A=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},t=arguments.length>1?arguments[1]:void 0,e=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};"object"==typeof A&&(e=A,A=null);var n=Object.assign({},e);if(this._textOptions)for(var r in this._textOptions){var i=this._textOptions[r];"continued"!==r&&void 0===n[r]&&(n[r]=i)}return null!=A&&(this.x=A),null!=t&&(this.y=t),!1!==n.lineBreak&&(null==n.width&&(n.width=this.page.width-this.x-this.page.margins.right),n.width=Math.max(n.width,0)),n.columns||(n.columns=0),null==n.columnGap&&(n.columnGap=18),n},_line:function(A){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},e=arguments.length>2?arguments[2]:void 0;this._fragment(A,this.x,this.y,t);var n=t.lineGap||this._lineGap||0;return e?this.y+=this.currentLineHeight(!0)+n:this.x+=this.widthOfString(A)},_fragment:function(A,t,e,n){var r,i,o,s,a,c,B=this;if(0!==(A="".concat(A).replace(/\n/g,"")).length){var g=n.align||"left",l=n.wordSpacing||0,u=n.characterSpacing||0;if(n.width)switch(g){case"right":a=this.widthOfString(A.replace(/\s+$/,""),n),t+=n.lineWidth-a;break;case"center":t+=n.lineWidth/2-n.textWidth/2;break;case"justify":c=A.trim().split(/\s+/),a=this.widthOfString(A.replace(/\s+/g,""),n);var w=this.widthOfString(" ")+u;l=Math.max(0,(n.lineWidth-a)/Math.max(1,c.length-1)-w)}if("number"==typeof n.baseline)r=-n.baseline;else{switch(n.baseline){case"svg-middle":r=.5*this._font.xHeight;break;case"middle":case"svg-central":r=.5*(this._font.descender+this._font.ascender);break;case"bottom":case"ideographic":r=this._font.descender;break;case"alphabetic":r=0;break;case"mathematical":r=.5*this._font.ascender;break;case"hanging":r=.8*this._font.ascender;break;default:r=this._font.ascender}r=r/1e3*this._fontSize}var h,E=n.textWidth+l*(n.wordCount-1)+u*(A.length-1);if(null!=n.link&&this.link(t,e,E,this.currentLineHeight(),n.link),null!=n.goTo&&this.goTo(t,e,E,this.currentLineHeight(),n.goTo),null!=n.destination&&this.addNamedDestination(n.destination,"XYZ",t,e,null),n.underline){this.save(),n.stroke||this.strokeColor.apply(this,y(this._fillColor||[]));var f=this._fontSize<10?.5:Math.floor(this._fontSize/10);this.lineWidth(f);var Q=e+this.currentLineHeight()-f;this.moveTo(t,Q),this.lineTo(t+E,Q),this.stroke(),this.restore()}if(n.strike){this.save(),n.stroke||this.strokeColor.apply(this,y(this._fillColor||[]));var d=this._fontSize<10?.5:Math.floor(this._fontSize/10);this.lineWidth(d);var C=e+this.currentLineHeight()/2;this.moveTo(t,C),this.lineTo(t+E,C),this.stroke(),this.restore()}this.save(),n.oblique&&(h="number"==typeof n.oblique?-Math.tan(n.oblique*Math.PI/180):-.25,this.transform(1,0,0,1,t,e),this.transform(1,0,h,1,-h*r,0),this.transform(1,0,0,1,-t,-e)),this.transform(1,0,0,-1,0,this.page.height),e=this.page.height-e-r,null==this.page.fonts[this._font.id]&&(this.page.fonts[this._font.id]=this._font.ref()),this.addContent("BT"),this.addContent("1 0 0 1 ".concat(XA(t)," ").concat(XA(e)," Tm")),this.addContent("/".concat(this._font.id," ").concat(XA(this._fontSize)," Tf"));var M=n.fill&&n.stroke?2:n.stroke?1:0;if(M&&this.addContent("".concat(M," Tr")),u&&this.addContent("".concat(XA(u)," Tc")),l){c=A.trim().split(/\s+/),l+=this.widthOfString(" ")+u,l*=1e3/this._fontSize,i=[],s=[];var I,p=F(c);try{for(p.s();!(I=p.n()).done;){var v=I.value,m=D(this._font.encode(v,n.features),2),Y=m[0],b=m[1];i=i.concat(Y),s=s.concat(b);var z={},U=s[s.length-1];for(var S in U){var x=U[S];z[S]=x}z.xAdvance+=l,s[s.length-1]=z}}catch(A){p.e(A)}finally{p.f()}}else{var T=D(this._font.encode(A,n.features),2);i=T[0],s=T[1]}var P=this._fontSize/1e3,N=[],R=0,G=!1,H=function(A){if(R<A){var t=i.slice(R,A).join(""),e=s[A-1].xAdvance-s[A-1].advanceWidth;N.push("<".concat(t,"> ").concat(XA(-e)))}return R=A},k=function(A){if(H(A),N.length>0)return B.addContent("[".concat(N.join(" "),"] TJ")),N.length=0};for(o=0;o<s.length;o++){var L=s[o];L.xOffset||L.yOffset?(k(o),this.addContent("1 0 0 1 ".concat(XA(t+L.xOffset*P)," ").concat(XA(e+L.yOffset*P)," Tm")),k(o+1),G=!0):(G&&(this.addContent("1 0 0 1 ".concat(XA(t)," ").concat(XA(e)," Tm")),G=!1),L.xAdvance-L.advanceWidth!=0&&H(o+1)),t+=L.xAdvance*P}return k(o),this.addContent("ET"),this.restore()}}},_A=[65472,65473,65474,65475,65477,65478,65479,65480,65481,65482,65483,65484,65485,65486,65487],qA={1:"DeviceGray",3:"DeviceRGB",4:"DeviceCMYK"},$A=function(){function A(t,e){var n;if(u(this,A),this.data=t,this.label=e,65496!==this.data.readUInt16BE(0))throw"SOI not found in JPEG";for(var r=2;r<this.data.length&&(n=this.data.readUInt16BE(r),r+=2,!_A.includes(n));)r+=this.data.readUInt16BE(r);if(!_A.includes(n))throw"Invalid JPEG.";r+=2,this.bits=this.data[r++],this.height=this.data.readUInt16BE(r),r+=2,this.width=this.data.readUInt16BE(r),r+=2;var i=this.data[r++];this.colorSpace=qA[i],this.obj=null}return h(A,[{key:"embed",value:function(A){if(!this.obj)return this.obj=A.ref({Type:"XObject",Subtype:"Image",BitsPerComponent:this.bits,Width:this.width,Height:this.height,ColorSpace:this.colorSpace,Filter:"DCTDecode"}),"DeviceCMYK"===this.colorSpace&&(this.obj.data.Decode=[1,0,1,0,1,0,1,0]),this.obj.end(this.data),this.data=null}}]),A}(),At=function(){function A(t,e){u(this,A),this.label=e,this.image=new B.default(t),this.width=this.image.width,this.height=this.image.height,this.imgData=this.image.imgData,this.obj=null}return h(A,[{key:"embed",value:function(A){var t=!1;if(this.document=A,!this.obj){var e=this.image.hasAlphaChannel,r=1===this.image.interlaceMethod;if(this.obj=this.document.ref({Type:"XObject",Subtype:"Image",BitsPerComponent:e?8:this.image.bits,Width:this.width,Height:this.height,Filter:"FlateDecode"}),!e){var i=this.document.ref({Predictor:r?1:15,Colors:this.image.colors,BitsPerComponent:this.image.bits,Columns:this.width});this.obj.data.DecodeParms=i,i.end()}if(0===this.image.palette.length)this.obj.data.ColorSpace=this.image.colorSpace;else{var o=this.document.ref();o.end(n.from(this.image.palette)),this.obj.data.ColorSpace=["Indexed","DeviceRGB",this.image.palette.length/3-1,o]}if(null!=this.image.transparency.grayscale){var s=this.image.transparency.grayscale;this.obj.data.Mask=[s,s]}else if(this.image.transparency.rgb){var a,c=[],B=F(this.image.transparency.rgb);try{for(B.s();!(a=B.n()).done;){var g=a.value;c.push(g,g)}}catch(A){B.e(A)}finally{B.f()}this.obj.data.Mask=c}else{if(this.image.transparency.indexed)return t=!0,this.loadIndexedAlphaChannel();if(e)return t=!0,this.splitAlphaChannel()}if(r&&!t)return this.decodeData();this.finalize()}}},{key:"finalize",value:function(){if(this.alphaChannel){var A=this.document.ref({Type:"XObject",Subtype:"Image",Height:this.height,Width:this.width,BitsPerComponent:8,Filter:"FlateDecode",ColorSpace:"DeviceGray",Decode:[0,1]});A.end(this.alphaChannel),this.obj.data.SMask=A}return this.obj.end(this.imgData),this.image=null,this.imgData=null}},{key:"splitAlphaChannel",value:function(){var A=this;return this.image.decodePixels((function(t){for(var e,r,o=A.image.colors,s=A.width*A.height,a=n.alloc(s*o),c=n.alloc(s),B=r=e=0,g=t.length,l=16===A.image.bits?1:0;B<g;){for(var u=0;u<o;u++)a[r++]=t[B++],B+=l;c[e++]=t[B++],B+=l}return A.imgData=i.default.deflateSync(a),A.alphaChannel=i.default.deflateSync(c),A.finalize()}))}},{key:"loadIndexedAlphaChannel",value:function(){var A=this,t=this.image.transparency.indexed;return this.image.decodePixels((function(e){for(var r=n.alloc(A.width*A.height),o=0,s=0,a=e.length;s<a;s++)r[o++]=t[e[s]];return A.alphaChannel=i.default.deflateSync(r),A.finalize()}))}},{key:"decodeData",value:function(){var A=this;this.image.decodePixels((function(t){A.imgData=i.default.deflateSync(t),A.finalize()}))}}]),A}(),tt=function(){function A(){u(this,A)}return h(A,null,[{key:"open",value:function(A,t){var e;if(n.isBuffer(A))e=A;else if(A instanceof ArrayBuffer)e=n.from(new Uint8Array(A));else{var r;if(r=/^data:.+;base64,(.*)$/.exec(A))e=n.from(r[1],"base64");else if(!(e=l.readFileSync(A)))return}if(255===e[0]&&216===e[1])return new $A(e,t);if(137===e[0]&&"PNG"===e.toString("ascii",1,4))return new At(e,t);throw new Error("Unknown image format.")}}]),A}(),et={initImages:function(){return this._imageRegistry={},this._imageCount=0},image:function(A,t,e){var n,r,i,o,s,a,c,B=arguments.length>3&&void 0!==arguments[3]?arguments[3]:{};"object"==typeof t&&(B=t,t=null),t=null!=(a=null!=t?t:B.x)?a:this.x,e=null!=(c=null!=e?e:B.y)?c:this.y,"string"==typeof A&&(o=this._imageRegistry[A]),o||(o=A.width&&A.height?A:this.openImage(A)),o.obj||o.embed(this),null==this.page.xobjects[o.label]&&(this.page.xobjects[o.label]=o.obj);var g=B.width||o.width,l=B.height||o.height;if(B.width&&!B.height){var u=g/o.width;g=o.width*u,l=o.height*u}else if(B.height&&!B.width){var w=l/o.height;g=o.width*w,l=o.height*w}else if(B.scale)g=o.width*B.scale,l=o.height*B.scale;else if(B.fit){var h=D(B.fit,2);r=(i=h[0])/(n=h[1]),(s=o.width/o.height)>r?(g=i,l=i/s):(l=n,g=n*s)}else if(B.cover){var E=D(B.cover,2);r=(i=E[0])/(n=E[1]),(s=o.width/o.height)>r?(l=n,g=n*s):(g=i,l=i/s)}return(B.fit||B.cover)&&("center"===B.align?t=t+i/2-g/2:"right"===B.align&&(t=t+i-g),"center"===B.valign?e=e+n/2-l/2:"bottom"===B.valign&&(e=e+n-l)),null!=B.link&&this.link(t,e,g,l,B.link),null!=B.goTo&&this.goTo(t,e,g,l,B.goTo),null!=B.destination&&this.addNamedDestination(B.destination,"XYZ",t,e,null),this.y===e&&(this.y+=l),this.save(),this.transform(g,0,0,-l,t,e+l),this.addContent("/".concat(o.label," Do")),this.restore(),this},openImage:function(A){var t;return"string"==typeof A&&(t=this._imageRegistry[A]),t||(t=tt.open(A,"I".concat(++this._imageCount)),"string"==typeof A&&(this._imageRegistry[A]=t)),t}},nt={annotate:function(A,t,e,n,r){for(var i in r.Type="Annot",r.Rect=this._convertRect(A,t,e,n),r.Border=[0,0,0],"Link"===r.Subtype&&void 0===r.F&&(r.F=4),"Link"!==r.Subtype&&null==r.C&&(r.C=this._normalizeColor(r.color||[0,0,0])),delete r.color,"string"==typeof r.Dest&&(r.Dest=new String(r.Dest)),r){var o=r[i];r[i[0].toUpperCase()+i.slice(1)]=o}var s=this.ref(r);return this.page.annotations.push(s),s.end(),this},note:function(A,t,e,n,r){var i=arguments.length>5&&void 0!==arguments[5]?arguments[5]:{};return i.Subtype="Text",i.Contents=new String(r),i.Name="Comment",null==i.color&&(i.color=[243,223,92]),this.annotate(A,t,e,n,i)},goTo:function(A,t,e,n,r){var i=arguments.length>5&&void 0!==arguments[5]?arguments[5]:{};return i.Subtype="Link",i.A=this.ref({S:"GoTo",D:new String(r)}),i.A.end(),this.annotate(A,t,e,n,i)},link:function(A,t,e,n,r){var i=arguments.length>5&&void 0!==arguments[5]?arguments[5]:{};if(i.Subtype="Link","number"==typeof r){var o=this._root.data.Pages.data;if(!(r>=0&&r<o.Kids.length))throw new Error("The document has no page ".concat(r));i.A=this.ref({S:"GoTo",D:[o.Kids[r],"XYZ",null,null,null]}),i.A.end()}else i.A=this.ref({S:"URI",URI:new String(r)}),i.A.end();return this.annotate(A,t,e,n,i)},_markup:function(A,t,e,n){var r=arguments.length>4&&void 0!==arguments[4]?arguments[4]:{},i=D(this._convertRect(A,t,e,n),4),o=i[0],s=i[1],a=i[2],c=i[3];return r.QuadPoints=[o,c,a,c,o,s,a,s],r.Contents=new String,this.annotate(A,t,e,n,r)},highlight:function(A,t,e,n){var r=arguments.length>4&&void 0!==arguments[4]?arguments[4]:{};return r.Subtype="Highlight",null==r.color&&(r.color=[241,238,148]),this._markup(A,t,e,n,r)},underline:function(A,t,e,n){var r=arguments.length>4&&void 0!==arguments[4]?arguments[4]:{};return r.Subtype="Underline",this._markup(A,t,e,n,r)},strike:function(A,t,e,n){var r=arguments.length>4&&void 0!==arguments[4]?arguments[4]:{};return r.Subtype="StrikeOut",this._markup(A,t,e,n,r)},lineAnnotation:function(A,t,e,n){var r=arguments.length>4&&void 0!==arguments[4]?arguments[4]:{};return r.Subtype="Line",r.Contents=new String,r.L=[A,this.page.height-t,e,this.page.height-n],this.annotate(A,t,e,n,r)},rectAnnotation:function(A,t,e,n){var r=arguments.length>4&&void 0!==arguments[4]?arguments[4]:{};return r.Subtype="Square",r.Contents=new String,this.annotate(A,t,e,n,r)},ellipseAnnotation:function(A,t,e,n){var r=arguments.length>4&&void 0!==arguments[4]?arguments[4]:{};return r.Subtype="Circle",r.Contents=new String,this.annotate(A,t,e,n,r)},textAnnotation:function(A,t,e,n,r){var i=arguments.length>5&&void 0!==arguments[5]?arguments[5]:{};return i.Subtype="FreeText",i.Contents=new String(r),i.DA=new String,this.annotate(A,t,e,n,i)},fileAnnotation:function(A,t,e,n){var r=arguments.length>4&&void 0!==arguments[4]?arguments[4]:{},i=arguments.length>5&&void 0!==arguments[5]?arguments[5]:{},o=this.file(r.src,Object.assign({hidden:!0},r));return i.Subtype="FileAttachment",i.FS=o,i.Contents?i.Contents=new String(i.Contents):o.data.Desc&&(i.Contents=o.data.Desc),this.annotate(A,t,e,n,i)},_convertRect:function(A,t,e,n){var r=t;t+=n;var i=A+e,o=D(this._ctm,6),s=o[0],a=o[1],c=o[2],B=o[3],g=o[4],l=o[5];return[A=s*A+c*t+g,t=a*A+B*t+l,i=s*i+c*r+g,r=a*i+B*r+l]}},rt=function(){function A(t,e,n,r){var i=arguments.length>4&&void 0!==arguments[4]?arguments[4]:{expanded:!1};u(this,A),this.document=t,this.options=i,this.outlineData={},null!==r&&(this.outlineData.Dest=[r.dictionary,"Fit"]),null!==e&&(this.outlineData.Parent=e),null!==n&&(this.outlineData.Title=new String(n)),this.dictionary=this.document.ref(this.outlineData),this.children=[]}return h(A,[{key:"addItem",value:function(t){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{expanded:!1},n=new A(this.document,this.dictionary,t,this.document.page,e);return this.children.push(n),n}},{key:"endOutline",value:function(){if(this.children.length>0){this.options.expanded&&(this.outlineData.Count=this.children.length);var A=this.children[0],t=this.children[this.children.length-1];this.outlineData.First=A.dictionary,this.outlineData.Last=t.dictionary;for(var e=0,n=this.children.length;e<n;e++){var r=this.children[e];e>0&&(r.outlineData.Prev=this.children[e-1].dictionary),e<this.children.length-1&&(r.outlineData.Next=this.children[e+1].dictionary),r.endOutline()}}return this.dictionary.end()}}]),A}(),it={initOutline:function(){return this.outline=new rt(this,null,null,null)},endOutline:function(){if(this.outline.endOutline(),this.outline.children.length>0)return this._root.data.Outlines=this.outline.dictionary,this._root.data.PageMode="UseOutlines"}},ot=function(){function A(t,e){u(this,A),this.refs=[{pageRef:t,mcid:e}]}return h(A,[{key:"push",value:function(A){var t=this;A.refs.forEach((function(A){return t.refs.push(A)}))}}]),A}(),st=function(){function A(t,e){var n=this,r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},i=arguments.length>3&&void 0!==arguments[3]?arguments[3]:null;u(this,A),this.document=t,this._attached=!1,this._ended=!1,this._flushed=!1,this.dictionary=t.ref({S:e});var o=this.dictionary.data;(Array.isArray(r)||this._isValidChild(r))&&(i=r,r={}),void 0!==r.title&&(o.T=new String(r.title)),void 0!==r.lang&&(o.Lang=new String(r.lang)),void 0!==r.alt&&(o.Alt=new String(r.alt)),void 0!==r.expanded&&(o.E=new String(r.expanded)),void 0!==r.actual&&(o.ActualText=new String(r.actual)),this._children=[],i&&(Array.isArray(i)||(i=[i]),i.forEach((function(A){return n.add(A)})),this.end())}return h(A,[{key:"add",value:function(t){if(this._ended)throw new Error("Cannot add child to already-ended structure element");if(!this._isValidChild(t))throw new Error("Invalid structure element child");return t instanceof A&&(t.setParent(this.dictionary),this._attached&&t.setAttached()),t instanceof ot&&this._addContentToParentTree(t),"function"==typeof t&&this._attached&&(t=this._contentForClosure(t)),this._children.push(t),this}},{key:"_addContentToParentTree",value:function(A){var t=this;A.refs.forEach((function(A){var e=A.pageRef,n=A.mcid;t.document.getStructParentTree().get(e.data.StructParents)[n]=t.dictionary}))}},{key:"setParent",value:function(A){if(this.dictionary.data.P)throw new Error("Structure element added to more than one parent");this.dictionary.data.P=A,this._flush()}},{key:"setAttached",value:function(){var t=this;this._attached||(this._children.forEach((function(e,n){e instanceof A&&e.setAttached(),"function"==typeof e&&(t._children[n]=t._contentForClosure(e))})),this._attached=!0,this._flush())}},{key:"end",value:function(){this._ended||(this._children.filter((function(t){return t instanceof A})).forEach((function(A){return A.end()})),this._ended=!0,this._flush())}},{key:"_isValidChild",value:function(t){return t instanceof A||t instanceof ot||"function"==typeof t}},{key:"_contentForClosure",value:function(A){var t=this.document.markStructureContent(this.dictionary.data.S);return A(),this.document.endMarkedContent(),this._addContentToParentTree(t),t}},{key:"_isFlushable",value:function(){return!(!this.dictionary.data.P||!this._ended)&&this._children.every((function(t){return"function"!=typeof t&&(!(t instanceof A)||t._isFlushable())}))}},{key:"_flush",value:function(){var A=this;!this._flushed&&this._isFlushable()&&(this.dictionary.data.K=[],this._children.forEach((function(t){return A._flushChild(t)})),this.dictionary.end(),this._children=[],this.dictionary.data.K=null,this._flushed=!0)}},{key:"_flushChild",value:function(t){var e=this;t instanceof A&&this.dictionary.data.K.push(t.dictionary),t instanceof ot&&t.refs.forEach((function(A){var t=A.pageRef,n=A.mcid;e.dictionary.data.Pg||(e.dictionary.data.Pg=t),e.dictionary.data.Pg===t?e.dictionary.data.K.push(n):e.dictionary.data.K.push({Type:"MCR",Pg:t,MCID:n})}))}}]),A}(),at=function(A){d(e,A);var t=p(e);function e(){return u(this,e),t.apply(this,arguments)}return h(e,[{key:"_compareKeys",value:function(A,t){return parseInt(A)-parseInt(t)}},{key:"_keysName",value:function(){return"Nums"}},{key:"_dataForKey",value:function(A){return parseInt(A)}}]),e}(b),ct={initMarkings:function(A){this.structChildren=[],A.tagged&&(this.getMarkInfoDictionary().data.Marked=!0,this.getStructTreeRoot())},markContent:function(A){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:null;if("Artifact"===A||t&&t.mcid){var e=0;for(this.page.markings.forEach((function(A){(e||A.structContent||"Artifact"===A.tag)&&e++}));e--;)this.endMarkedContent()}if(!t)return this.page.markings.push({tag:A}),this.addContent("/".concat(A," BMC")),this;this.page.markings.push({tag:A,options:t});var n={};return void 0!==t.mcid&&(n.MCID=t.mcid),"Artifact"===A&&("string"==typeof t.type&&(n.Type=t.type),Array.isArray(t.bbox)&&(n.BBox=[t.bbox[0],this.page.height-t.bbox[3],t.bbox[2],this.page.height-t.bbox[1]]),Array.isArray(t.attached)&&t.attached.every((function(A){return"string"==typeof A}))&&(n.Attached=t.attached)),"Span"===A&&(t.lang&&(n.Lang=new String(t.lang)),t.alt&&(n.Alt=new String(t.alt)),t.expanded&&(n.E=new String(t.expanded)),t.actual&&(n.ActualText=new String(t.actual))),this.addContent("/".concat(A," ").concat(x.convert(n)," BDC")),this},markStructureContent:function(A){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},e=this.getStructParentTree().get(this.page.structParentTreeKey),n=e.length;e.push(null),this.markContent(A,Q(Q({},t),{},{mcid:n}));var r=new ot(this.page.dictionary,n);return this.page.markings.slice(-1)[0].structContent=r,r},endMarkedContent:function(){return this.page.markings.pop(),this.addContent("EMC"),this},struct:function(A){return new st(this,A,arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},arguments.length>2&&void 0!==arguments[2]?arguments[2]:null)},addStructure:function(A){var t=this.getStructTreeRoot();return A.setParent(t),A.setAttached(),this.structChildren.push(A),t.data.K||(t.data.K=[]),t.data.K.push(A.dictionary),this},initPageMarkings:function(A){var t=this;A.forEach((function(A){if(A.structContent){var e=A.structContent,n=t.markStructureContent(A.tag,A.options);e.push(n),t.page.markings.slice(-1)[0].structContent=e}else t.markContent(A.tag,A.options)}))},endPageMarkings:function(A){var t=A.markings;return t.forEach((function(){return A.write("EMC")})),A.markings=[],t},getMarkInfoDictionary:function(){return this._root.data.MarkInfo||(this._root.data.MarkInfo=this.ref({})),this._root.data.MarkInfo},getStructTreeRoot:function(){return this._root.data.StructTreeRoot||(this._root.data.StructTreeRoot=this.ref({Type:"StructTreeRoot",ParentTree:new at,ParentTreeNextKey:0})),this._root.data.StructTreeRoot},getStructParentTree:function(){return this.getStructTreeRoot().data.ParentTree},createStructParentTreeNextKey:function(){this.getMarkInfoDictionary();var A=this.getStructTreeRoot(),t=A.data.ParentTreeNextKey++;return A.data.ParentTree.add(t,[]),t},endMarkings:function(){var A=this._root.data.StructTreeRoot;A&&(A.end(),this.structChildren.forEach((function(A){return A.end()}))),this._root.data.MarkInfo&&this._root.data.MarkInfo.end()}},Bt={readOnly:1,required:2,noExport:4,multiline:4096,password:8192,toggleToOffButton:16384,radioButton:32768,pushButton:65536,combo:131072,edit:262144,sort:524288,multiSelect:2097152,noSpell:4194304},gt={left:0,center:1,right:2},lt={value:"V",defaultValue:"DV"},ut={zip:"0",zipPlus4:"1",zip4:"1",phone:"2",ssn:"3"},wt={nDec:0,sepComma:!1,negStyle:"MinusBlack",currency:"",currencyPrepend:!0},ht={nDec:0,sepComma:!1},Et={initForm:function(){if(!this._font)throw new Error("Must set a font before calling initForm method");this._acroform={fonts:{},defaultFont:this._font.name},this._acroform.fonts[this._font.id]=this._font.ref();var A={Fields:[],NeedAppearances:!0,DA:new String("/".concat(this._font.id," 0 Tf 0 g")),DR:{Font:{}}};A.DR.Font[this._font.id]=this._font.ref();var t=this.ref(A);return this._root.data.AcroForm=t,this},endAcroForm:function(){var A=this;if(this._root.data.AcroForm){if(!Object.keys(this._acroform.fonts).length&&!this._acroform.defaultFont)throw new Error("No fonts specified for PDF form");var t=this._root.data.AcroForm.data.DR.Font;Object.keys(this._acroform.fonts).forEach((function(e){t[e]=A._acroform.fonts[e]})),this._root.data.AcroForm.data.Fields.forEach((function(t){A._endChild(t)})),this._root.data.AcroForm.end()}return this},_endChild:function(A){var t=this;return Array.isArray(A.data.Kids)&&(A.data.Kids.forEach((function(A){t._endChild(A)})),A.end()),this},formField:function(A){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},e=this._fieldDict(A,null,t),n=this.ref(e);return this._addToParent(n),n},formAnnotation:function(A,t,e,n,r,i){var o=arguments.length>6&&void 0!==arguments[6]?arguments[6]:{},s=this._fieldDict(A,t,o);s.Subtype="Widget",void 0===s.F&&(s.F=4),this.annotate(e,n,r,i,s);var a=this.page.annotations[this.page.annotations.length-1];return this._addToParent(a)},formText:function(A,t,e,n,r){var i=arguments.length>5&&void 0!==arguments[5]?arguments[5]:{};return this.formAnnotation(A,"text",t,e,n,r,i)},formPushButton:function(A,t,e,n,r){var i=arguments.length>5&&void 0!==arguments[5]?arguments[5]:{};return this.formAnnotation(A,"pushButton",t,e,n,r,i)},formCombo:function(A,t,e,n,r){var i=arguments.length>5&&void 0!==arguments[5]?arguments[5]:{};return this.formAnnotation(A,"combo",t,e,n,r,i)},formList:function(A,t,e,n,r){var i=arguments.length>5&&void 0!==arguments[5]?arguments[5]:{};return this.formAnnotation(A,"list",t,e,n,r,i)},formRadioButton:function(A,t,e,n,r){var i=arguments.length>5&&void 0!==arguments[5]?arguments[5]:{};return this.formAnnotation(A,"radioButton",t,e,n,r,i)},formCheckbox:function(A,t,e,n,r){var i=arguments.length>5&&void 0!==arguments[5]?arguments[5]:{};return this.formAnnotation(A,"checkbox",t,e,n,r,i)},_addToParent:function(A){var t=A.data.Parent;return t?(t.data.Kids||(t.data.Kids=[]),t.data.Kids.push(A)):this._root.data.AcroForm.data.Fields.push(A),this},_fieldDict:function(A,t){var e=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};if(!this._acroform)throw new Error("Call document.initForms() method before adding form elements to document");var n=Object.assign({},e);return null!==t&&(n=this._resolveType(t,e)),n=this._resolveFlags(n),n=this._resolveJustify(n),n=this._resolveFont(n),n=this._resolveStrings(n),n=this._resolveColors(n),(n=this._resolveFormat(n)).T=new String(A),n.parent&&(n.Parent=n.parent,delete n.parent),n},_resolveType:function(A,t){if("text"===A)t.FT="Tx";else if("pushButton"===A)t.FT="Btn",t.pushButton=!0;else if("radioButton"===A)t.FT="Btn",t.radioButton=!0;else if("checkbox"===A)t.FT="Btn";else if("combo"===A)t.FT="Ch",t.combo=!0;else{if("list"!==A)throw new Error("Invalid form annotation type '".concat(A,"'"));t.FT="Ch"}return t},_resolveFormat:function(A){var t=A.format;if(t&&t.type){var e,n,r="";if(void 0!==ut[t.type])e="AFSpecial_Keystroke",n="AFSpecial_Format",r=ut[t.type];else{var i=t.type.charAt(0).toUpperCase()+t.type.slice(1);if(e="AF".concat(i,"_Keystroke"),n="AF".concat(i,"_Format"),"date"===t.type)e+="Ex",r=String(t.param);else if("time"===t.type)r=String(t.param);else if("number"===t.type){var o=Object.assign({},wt,t);r=String([String(o.nDec),o.sepComma?"0":"1",'"'+o.negStyle+'"',"null",'"'+o.currency+'"',String(o.currencyPrepend)].join(","))}else if("percent"===t.type){var s=Object.assign({},ht,t);r=String([String(s.nDec),s.sepComma?"0":"1"].join(","))}}A.AA=A.AA?A.AA:{},A.AA.K={S:"JavaScript",JS:new String("".concat(e,"(").concat(r,");"))},A.AA.F={S:"JavaScript",JS:new String("".concat(n,"(").concat(r,");"))}}return delete A.format,A},_resolveColors:function(A){var t=this._normalizeColor(A.backgroundColor);return t&&(A.MK||(A.MK={}),A.MK.BG=t),(t=this._normalizeColor(A.borderColor))&&(A.MK||(A.MK={}),A.MK.BC=t),delete A.backgroundColor,delete A.borderColor,A},_resolveFlags:function(A){var t=0;return Object.keys(A).forEach((function(e){Bt[e]&&(t|=Bt[e],delete A[e])})),0!==t&&(A.Ff=A.Ff?A.Ff:0,A.Ff|=t),A},_resolveJustify:function(A){var t=0;return void 0!==A.align&&("number"==typeof gt[A.align]&&(t=gt[A.align]),delete A.align),0!==t&&(A.Q=t),A},_resolveFont:function(A){if(null===this._acroform.fonts[this._font.id]&&(this._acroform.fonts[this._font.id]=this._font.ref()),this._acroform.defaultFont!==this._font.name){A.DR={Font:{}};var t=A.fontSize||0;A.DR.Font[this._font.id]=this._font.ref(),A.DA=new String("/".concat(this._font.id," ").concat(t," Tf 0 g"))}return A},_resolveStrings:function(A){var t=[];function e(A){if(Array.isArray(A))for(var e=0;e<A.length;e++)"string"==typeof A[e]?t.push(new String(A[e])):t.push(A[e])}return e(A.Opt),A.select&&(e(A.select),delete A.select),t.length&&(A.Opt=t),Object.keys(lt).forEach((function(t){void 0!==A[t]&&(A[lt[t]]=A[t],delete A[t])})),["V","DV"].forEach((function(t){"string"==typeof A[t]&&(A[t]=new String(A[t]))})),A.MK&&A.MK.CA&&(A.MK.CA=new String(A.MK.CA)),A.label&&(A.MK=A.MK?A.MK:{},A.MK.CA=new String(A.label),delete A.label),A}},ft={file:function(A){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};t.name=t.name||A;var e,r={Type:"EmbeddedFile",Params:{}};if(!A)throw new Error("No src specified");if(n.isBuffer(A))e=A;else if(A instanceof ArrayBuffer)e=n.from(new Uint8Array(A));else{var i;if(i=/^data:(.*);base64,(.*)$/.exec(A))i[1]&&(r.Subtype=i[1].replace("/","#2F")),e=n.from(i[2],"base64");else{if(!(e=l.readFileSync(A)))throw new Error("Could not read contents of file at filepath ".concat(A));var s=l.statSync(A),a=s.birthtime,c=s.ctime;r.Params.CreationDate=a,r.Params.ModDate=c}}t.creationDate instanceof Date&&(r.Params.CreationDate=t.creationDate),t.modifiedDate instanceof Date&&(r.Params.ModDate=t.modifiedDate),t.type&&(r.Subtype=t.type.replace("/","#2F"));var B,g=o.default.MD5(o.default.lib.WordArray.create(new Uint8Array(e)));r.Params.CheckSum=new String(g),r.Params.Size=e.byteLength,this._fileRegistry||(this._fileRegistry={});var u=this._fileRegistry[t.name];u&&function(A,t){return A.Subtype===t.Subtype&&A.Params.CheckSum.toString()===t.Params.CheckSum.toString()&&A.Params.Size===t.Params.Size&&A.Params.CreationDate===t.Params.CreationDate&&A.Params.ModDate===t.Params.ModDate}(r,u)?B=u.ref:((B=this.ref(r)).end(e),this._fileRegistry[t.name]=Q(Q({},r),{},{ref:B}));var w={Type:"Filespec",F:new String(t.name),EF:{F:B},UF:new String(t.name)};t.description&&(w.Desc=new String(t.description));var h=this.ref(w);return h.end(),t.hidden||this.addNamedEmbeddedFile(t.name,h),h}};var Qt=function(A){d(e,A);var t=p(e);function e(){var A,n=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{};switch(u(this,e),(A=t.call(this,n)).options=n,n.pdfVersion){case"1.4":A.version=1.4;break;case"1.5":A.version=1.5;break;case"1.6":A.version=1.6;break;case"1.7":case"1.7ext3":A.version=1.7;break;default:A.version=1.3}A.compress=null==A.options.compress||A.options.compress,A._pageBuffer=[],A._pageBufferStart=0,A._offsets=[],A._waiting=0,A._ended=!1,A._offset=0;var r=A.ref({Type:"Pages",Count:0,Kids:[]}),i=A.ref({Dests:new G});if(A._root=A.ref({Type:"Catalog",Pages:r,Names:i}),A.options.lang&&(A._root.data.Lang=new String(A.options.lang)),A.page=null,A.initColor(),A.initVector(),A.initFonts(n.font),A.initText(),A.initImages(),A.initOutline(),A.initMarkings(n),A.info={Producer:"PDFKit",Creator:"PDFKit",CreationDate:new Date},A.options.info)for(var o in A.options.info){var s=A.options.info[o];A.info[o]=s}return A.options.displayTitle&&(A._root.data.ViewerPreferences=A.ref({DisplayDocTitle:!0})),A._id=iA.generateFileID(A.info),A._security=iA.create(I(A),n),A._write("%PDF-".concat(A.version)),A._write("%ÿÿÿÿ"),!1!==A.options.autoFirstPage&&A.addPage(),A}return h(e,[{key:"addPage",value:function(A){null==A&&(A=this.options),this.options.bufferPages||this.flushPages(),this.page=new R(this,A),this._pageBuffer.push(this.page);var t=this._root.data.Pages.data;return t.Kids.push(this.page.dictionary),t.Count++,this.x=this.page.margins.left,this.y=this.page.margins.top,this._ctm=[1,0,0,1,0,0],this.transform(1,0,0,-1,0,this.page.height),this.emit("pageAdded"),this}},{key:"continueOnNewPage",value:function(A){var t=this.endPageMarkings(this.page);return this.addPage(A),this.initPageMarkings(t),this}},{key:"bufferedPageRange",value:function(){return{start:this._pageBufferStart,count:this._pageBuffer.length}}},{key:"switchToPage",value:function(A){var t;if(!(t=this._pageBuffer[A-this._pageBufferStart]))throw new Error("switchToPage(".concat(A,") out of bounds, current buffer covers pages ").concat(this._pageBufferStart," to ").concat(this._pageBufferStart+this._pageBuffer.length-1));return this.page=t}},{key:"flushPages",value:function(){var A=this._pageBuffer;this._pageBuffer=[],this._pageBufferStart+=A.length;var t,e=F(A);try{for(e.s();!(t=e.n()).done;){var n=t.value;this.endPageMarkings(n),n.end()}}catch(A){e.e(A)}finally{e.f()}}},{key:"addNamedDestination",value:function(A){for(var t=arguments.length,e=new Array(t>1?t-1:0),n=1;n<t;n++)e[n-1]=arguments[n];0===e.length&&(e=["XYZ",null,null,null]),"XYZ"===e[0]&&null!==e[2]&&(e[2]=this.page.height-e[2]),e.unshift(this.page.dictionary),this._root.data.Names.data.Dests.add(A,e)}},{key:"addNamedEmbeddedFile",value:function(A,t){this._root.data.Names.data.EmbeddedFiles||(this._root.data.Names.data.EmbeddedFiles=new G({limits:!1})),this._root.data.Names.data.EmbeddedFiles.add(A,t)}},{key:"addNamedJavaScript",value:function(A,t){this._root.data.Names.data.JavaScript||(this._root.data.Names.data.JavaScript=new G);var e={JS:new String(t),S:"JavaScript"};this._root.data.Names.data.JavaScript.add(A,e)}},{key:"ref",value:function(A){var t=new T(this,this._offsets.length+1,A);return this._offsets.push(null),this._waiting++,t}},{key:"_read",value:function(){}},{key:"_write",value:function(A){return n.isBuffer(A)||(A=n.from(A+"\n","binary")),this.push(A),this._offset+=A.length}},{key:"addContent",value:function(A){return this.page.write(A),this}},{key:"_refEnd",value:function(A){if(this._offsets[A.id-1]=A.offset,0==--this._waiting&&this._ended)return this._finalize(),this._ended=!1}},{key:"write",value:function(A,t){return new Error("PDFDocument#write is deprecated, and will be removed in a future version of PDFKit. Please pipe the document into a Node stream."),this.pipe(l.createWriteStream(A)),this.end(),this.once("end",t)}},{key:"end",value:function(){for(var A in this.flushPages(),this._info=this.ref(),this.info){var t=this.info[A];"string"==typeof t&&(t=new String(t));var e=this.ref(t);e.end(),this._info.data[A]=e}for(var n in this._info.end(),this._fontFamilies)this._fontFamilies[n].finalize();return this.endOutline(),this.endMarkings(),this._root.end(),this._root.data.Pages.end(),this._root.data.Names.end(),this.endAcroForm(),this._root.data.ViewerPreferences&&this._root.data.ViewerPreferences.end(),this._security&&this._security.end(),0===this._waiting?this._finalize():this._ended=!0}},{key:"_finalize",value:function(){var A=this._offset;this._write("xref"),this._write("0 ".concat(this._offsets.length+1)),this._write("0000000000 65535 f ");var t,e=F(this._offsets);try{for(e.s();!(t=e.n()).done;){var n=t.value;n="0000000000".concat(n).slice(-10),this._write(n+" 00000 n ")}}catch(A){e.e(A)}finally{e.f()}var r={Size:this._offsets.length+1,Root:this._root,Info:this._info,ID:[this._id,this._id]};return this._security&&(r.Encrypt=this._security.dictionary),this._write("trailer"),this._write(x.convert(r)),this._write("startxref"),this._write("".concat(A)),this._write("%%EOF"),this.push(null)}},{key:"toString",value:function(){return"[object PDFDocument]"}}]),e}(r.default.Readable),dt=function(A){Object.assign(Qt.prototype,A)};dt(mA),dt(NA),dt(KA),dt(ZA),dt(et),dt(nt),dt(it),dt(ct),dt(Et),dt(ft),Qt.LineWrapper=VA;var Ct=Qt;t.default=Ct},4559:function(A,t,e){"use strict";e(3290);var n=e(8823),r=n.Buffer;function i(A,t){for(var e in A)t[e]=A[e]}function o(A,t,e){return r(A,t,e)}r.from&&r.alloc&&r.allocUnsafe&&r.allocUnsafeSlow?A.exports=n:(i(n,t),t.Buffer=o),i(r,o),o.from=function(A,t,e){if("number"==typeof A)throw new TypeError("Argument must not be a number");return r(A,t,e)},o.alloc=function(A,t,e){if("number"!=typeof A)throw new TypeError("Argument must be a number");var n=r(A);return void 0!==t?"string"==typeof e?n.fill(t,e):n.fill(t):n.fill(0),n},o.allocUnsafe=function(A){if("number"!=typeof A)throw new TypeError("Argument must be a number");return r(A)},o.allocUnsafeSlow=function(A){if("number"!=typeof A)throw new TypeError("Argument must be a number");return n.SlowBuffer(A)}},4781:function(A,t,e){"use strict";e(7042),e(6992),e(1539),e(2472),e(2990),e(8927),e(3105),e(5035),e(4345),e(7174),e(2846),e(4731),e(7209),e(6319),e(8867),e(7789),e(3739),e(9368),e(4483),e(2056),e(3462),e(678),e(7462),e(3824),e(5021),e(2974),e(5016),e(9135);var n=e(311),r=e(1753).swap32LE,i=function(){function A(A){var t="function"==typeof A.readUInt32BE&&"function"==typeof A.slice;if(t||A instanceof Uint8Array){var e;if(t)this.highStart=A.readUInt32LE(0),this.errorValue=A.readUInt32LE(4),e=A.readUInt32LE(8),A=A.slice(12);else{var i=new DataView(A.buffer);this.highStart=i.getUint32(0,!0),this.errorValue=i.getUint32(4,!0),e=i.getUint32(8,!0),A=A.subarray(12)}A=n(A,new Uint8Array(e)),A=n(A,new Uint8Array(e)),r(A),this.data=new Uint32Array(A.buffer)}else{var o=A;this.data=o.data,this.highStart=o.highStart,this.errorValue=o.errorValue}}return A.prototype.get=function(A){var t;return A<0||A>1114111?this.errorValue:A<55296||A>56319&&A<=65535?(t=(this.data[A>>5]<<2)+(31&A),this.data[t]):A<=65535?(t=(this.data[2048+(A-55296>>5)]<<2)+(31&A),this.data[t]):A<this.highStart?(t=this.data[2080+(A>>11)],t=((t=this.data[t+(A>>5&63)])<<2)+(31&A),this.data[t]):this.data[this.data.length-4]},A}();A.exports=i},1753:function(A,t,e){"use strict";e(6992),e(1539),e(2472),e(2990),e(8927),e(3105),e(5035),e(4345),e(7174),e(2846),e(4731),e(7209),e(6319),e(8867),e(7789),e(3739),e(9368),e(4483),e(2056),e(3462),e(678),e(7462),e(3824),e(5021),e(2974),e(5016),e(9135);var n=18===new Uint8Array(new Uint32Array([305419896]).buffer)[0],r=function(A,t,e){var n=A[t];A[t]=A[e],A[e]=n};A.exports={swap32LE:function(A){n&&function(A){for(var t=A.length,e=0;e<t;e+=4)r(A,e,e+3),r(A,e+1,e+2)}(A)}}},8071:function(A,t,e){"use strict";var n=e(8519);A.exports=n},8519:function(A,t,e){"use strict";A=e.nmd(A),e(8309),e(7941),e(3210),e(4916),e(4723),e(3728),e(5306),e(7042),e(9653),e(3123),e(2222),e(6992),e(1539),e(3948),e(9254),e(3290),A&&void 0!==A.exports&&(A.exports=function(A,t,e,n,r){var i={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgrey:[169,169,169],darkgreen:[0,100,0],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],grey:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgrey:[211,211,211],lightgreen:[144,238,144],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0]},o={black:[i.black,1],white:[i.white,1],transparent:[i.black,0]},s={quot:34,amp:38,lt:60,gt:62,apos:39,OElig:338,oelig:339,Scaron:352,scaron:353,Yuml:376,circ:710,tilde:732,ensp:8194,emsp:8195,thinsp:8201,zwnj:8204,zwj:8205,lrm:8206,rlm:8207,ndash:8211,mdash:8212,lsquo:8216,rsquo:8217,sbquo:8218,ldquo:8220,rdquo:8221,bdquo:8222,dagger:8224,Dagger:8225,permil:8240,lsaquo:8249,rsaquo:8250,euro:8364,nbsp:160,iexcl:161,cent:162,pound:163,curren:164,yen:165,brvbar:166,sect:167,uml:168,copy:169,ordf:170,laquo:171,not:172,shy:173,reg:174,macr:175,deg:176,plusmn:177,sup2:178,sup3:179,acute:180,micro:181,para:182,middot:183,cedil:184,sup1:185,ordm:186,raquo:187,frac14:188,frac12:189,frac34:190,iquest:191,Agrave:192,Aacute:193,Acirc:194,Atilde:195,Auml:196,Aring:197,AElig:198,Ccedil:199,Egrave:200,Eacute:201,Ecirc:202,Euml:203,Igrave:204,Iacute:205,Icirc:206,Iuml:207,ETH:208,Ntilde:209,Ograve:210,Oacute:211,Ocirc:212,Otilde:213,Ouml:214,times:215,Oslash:216,Ugrave:217,Uacute:218,Ucirc:219,Uuml:220,Yacute:221,THORN:222,szlig:223,agrave:224,aacute:225,acirc:226,atilde:227,auml:228,aring:229,aelig:230,ccedil:231,egrave:232,eacute:233,ecirc:234,euml:235,igrave:236,iacute:237,icirc:238,iuml:239,eth:240,ntilde:241,ograve:242,oacute:243,ocirc:244,otilde:245,ouml:246,divide:247,oslash:248,ugrave:249,uacute:250,ucirc:251,uuml:252,yacute:253,thorn:254,yuml:255,fnof:402,Alpha:913,Beta:914,Gamma:915,Delta:916,Epsilon:917,Zeta:918,Eta:919,Theta:920,Iota:921,Kappa:922,Lambda:923,Mu:924,Nu:925,Xi:926,Omicron:927,Pi:928,Rho:929,Sigma:931,Tau:932,Upsilon:933,Phi:934,Chi:935,Psi:936,Omega:937,alpha:945,beta:946,gamma:947,delta:948,epsilon:949,zeta:950,eta:951,theta:952,iota:953,kappa:954,lambda:955,mu:956,nu:957,xi:958,omicron:959,pi:960,rho:961,sigmaf:962,sigma:963,tau:964,upsilon:965,phi:966,chi:967,psi:968,omega:969,thetasym:977,upsih:978,piv:982,bull:8226,hellip:8230,prime:8242,Prime:8243,oline:8254,frasl:8260,weierp:8472,image:8465,real:8476,trade:8482,alefsym:8501,larr:8592,uarr:8593,rarr:8594,darr:8595,harr:8596,crarr:8629,lArr:8656,uArr:8657,rArr:8658,dArr:8659,hArr:8660,forall:8704,part:8706,exist:8707,empty:8709,nabla:8711,isin:8712,notin:8713,ni:8715,prod:8719,sum:8721,minus:8722,lowast:8727,radic:8730,prop:8733,infin:8734,ang:8736,and:8743,or:8744,cap:8745,cup:8746,int:8747,there4:8756,sim:8764,cong:8773,asymp:8776,ne:8800,equiv:8801,le:8804,ge:8805,sub:8834,sup:8835,nsub:8836,sube:8838,supe:8839,oplus:8853,otimes:8855,perp:8869,sdot:8901,lceil:8968,rceil:8969,lfloor:8970,rfloor:8971,lang:9001,rang:9002,loz:9674,spades:9824,clubs:9827,hearts:9829,diams:9830},a={A:7,a:7,C:6,c:6,H:1,h:1,L:2,l:2,M:2,m:2,Q:4,q:4,S:4,s:4,T:2,t:2,V:1,v:1,Z:0,z:0},c={A3:!0,A4:!0,a3:!0,a4:!0},B={color:{inherit:!0,initial:void 0},visibility:{inherit:!0,initial:"visible",values:{hidden:"hidden",collapse:"hidden",visible:"visible"}},fill:{inherit:!0,initial:o.black},stroke:{inherit:!0,initial:"none"},"stop-color":{inherit:!1,initial:o.black},"fill-opacity":{inherit:!0,initial:1},"stroke-opacity":{inherit:!0,initial:1},"stop-opacity":{inherit:!1,initial:1},"fill-rule":{inherit:!0,initial:"nonzero",values:{nonzero:"nonzero",evenodd:"evenodd"}},"clip-rule":{inherit:!0,initial:"nonzero",values:{nonzero:"nonzero",evenodd:"evenodd"}},"stroke-width":{inherit:!0,initial:1},"stroke-dasharray":{inherit:!0,initial:[]},"stroke-dashoffset":{inherit:!0,initial:0},"stroke-miterlimit":{inherit:!0,initial:4},"stroke-linejoin":{inherit:!0,initial:"miter",values:{miter:"miter",round:"round",bevel:"bevel"}},"stroke-linecap":{inherit:!0,initial:"butt",values:{butt:"butt",round:"round",square:"square"}},"font-size":{inherit:!0,initial:16,values:{"xx-small":9,"x-small":10,small:13,medium:16,large:18,"x-large":24,"xx-large":32}},"font-family":{inherit:!0,initial:"sans-serif"},"font-weight":{inherit:!0,initial:"normal",values:{600:"bold",700:"bold",800:"bold",900:"bold",bold:"bold",bolder:"bold",500:"normal",400:"normal",300:"normal",200:"normal",100:"normal",normal:"normal",lighter:"normal"}},"font-style":{inherit:!0,initial:"normal",values:{italic:"italic",oblique:"italic",normal:"normal"}},"text-anchor":{inherit:!0,initial:"start",values:{start:"start",middle:"middle",end:"end"}},direction:{inherit:!0,initial:"ltr",values:{ltr:"ltr",rtl:"rtl"}},"dominant-baseline":{inherit:!0,initial:"baseline",values:{auto:"baseline",baseline:"baseline","before-edge":"before-edge","text-before-edge":"before-edge",middle:"middle",central:"central","after-edge":"after-edge","text-after-edge":"after-edge",ideographic:"ideographic",alphabetic:"alphabetic",hanging:"hanging",mathematical:"mathematical"}},"alignment-baseline":{inherit:!1,initial:void 0,values:{auto:"baseline",baseline:"baseline","before-edge":"before-edge","text-before-edge":"before-edge",middle:"middle",central:"central","after-edge":"after-edge","text-after-edge":"after-edge",ideographic:"ideographic",alphabetic:"alphabetic",hanging:"hanging",mathematical:"mathematical"}},"baseline-shift":{inherit:!0,initial:"baseline",values:{baseline:"baseline",sub:"sub",super:"super"}},"word-spacing":{inherit:!0,initial:0,values:{normal:0}},"letter-spacing":{inherit:!0,initial:0,values:{normal:0}},"text-decoration":{inherit:!1,initial:"none",values:{none:"none",underline:"underline",overline:"overline","line-through":"line-through"}},"xml:space":{inherit:!0,initial:"default",css:"white-space",values:{preserve:"preserve",default:"default",pre:"preserve","pre-line":"preserve","pre-wrap":"preserve",nowrap:"default"}},"marker-start":{inherit:!0,initial:"none"},"marker-mid":{inherit:!0,initial:"none"},"marker-end":{inherit:!0,initial:"none"},opacity:{inherit:!1,initial:1},transform:{inherit:!1,initial:[1,0,0,1,0,0]},display:{inherit:!1,initial:"inline",values:{none:"none",inline:"inline",block:"inline"}},"clip-path":{inherit:!1,initial:"none"},mask:{inherit:!1,initial:"none"},overflow:{inherit:!1,initial:"hidden",values:{hidden:"hidden",scroll:"hidden",visible:"visible"}}};function g(t){var e=new function(){};return e.name="G"+(A._groupCount=(A._groupCount||0)+1),e.resources=A.ref(),e.xobj=A.ref({Type:"XObject",Subtype:"Form",FormType:1,BBox:t,Group:{S:"Transparency",CS:"DeviceRGB",I:!0,K:!1},Resources:e.resources}),e.xobj.write(""),e.savedMatrix=A._ctm,e.savedPage=A.page,TA.push(e),A._ctm=[1,0,0,1,0,0],A.page={width:A.page.width,height:A.page.height,write:function(A){e.xobj.write(A)},fonts:{},xobjects:{},ext_gstates:{},patterns:{}},e}function l(t){if(t!==TA.pop())throw"Group not matching";Object.keys(A.page.fonts).length&&(t.resources.data.Font=A.page.fonts),Object.keys(A.page.xobjects).length&&(t.resources.data.XObject=A.page.xobjects),Object.keys(A.page.ext_gstates).length&&(t.resources.data.ExtGState=A.page.ext_gstates),Object.keys(A.page.patterns).length&&(t.resources.data.Pattern=A.page.patterns),t.resources.end(),t.xobj.end(),A._ctm=t.savedMatrix,A.page=t.savedPage}function u(t){A.page.xobjects[t.name]=t.xobj,A.addContent("/"+t.name+" Do")}function w(t,e){var n="M"+(A._maskCount=(A._maskCount||0)+1),r=A.ref({Type:"ExtGState",CA:1,ca:1,BM:"Normal",SMask:{S:"Luminosity",G:t.xobj,BC:e?[0,0,0]:[1,1,1]}});r.end(),A.page.ext_gstates[n]=r,A.addContent("/"+n+" gs")}function h(A,t,e,n){var r=new function(){};return r.group=A,r.dx=t,r.dy=e,r.matrix=n||[1,0,0,1,0,0],r}function E(t,e){var n,r="P"+(A._patternCount=(A._patternCount||0)+1),i=A.ref({Type:"Pattern",PatternType:1,PaintType:1,TilingType:2,BBox:[0,0,t.dx,t.dy],XStep:t.dx,YStep:t.dy,Matrix:D(A._ctm,t.matrix),Resources:{ProcSet:["PDF","Text","ImageB","ImageC","ImageI"],XObject:(n={},n[t.group.name]=t.group.xobj,n)}});i.write("/"+t.group.name+" Do"),i.end(),A.page.patterns[r]=i,e?(A.addContent("/Pattern CS"),A.addContent("/"+r+" SCN")):(A.addContent("/Pattern cs"),A.addContent("/"+r+" scn"))}function f(t,e){var n=t&&e?2:e?1:t?0:3;A.addContent(n+" Tr")}function Q(t){"PDFPattern"===t[0].constructor.name?(A.fillOpacity(t[1]),E(t[0],!1)):A.fillColor(t[0],t[1])}function d(t){"PDFPattern"===t[0].constructor.name?(A.strokeOpacity(t[1]),E(t[0],!0)):A.strokeColor(t[0],t[1])}function C(A){var t=function(A,t,e,n){this.error=n,this.nodeName=A,this.nodeValue=e,this.nodeType=t,this.attributes=Object.create(null),this.childNodes=[],this.parentNode=null,this.id="",this.textContent="",this.classList=[]};t.prototype.getAttribute=function(A){return null!=this.attributes[A]?this.attributes[A]:null},t.prototype.getElementById=function(A){var t=null;return function e(n){if(!t&&1===n.nodeType){n.id===A&&(t=n);for(var r=0;r<n.childNodes.length;r++)e(n.childNodes[r])}}(this),t},t.prototype.getElementsByTagName=function(A){var t=[];return function e(n){if(1===n.nodeType){n.nodeName===A&&t.push(n);for(var r=0;r<n.childNodes.length;r++)e(n.childNodes[r])}}(this),t};for(var e,n,r=new W(A.trim()),i=!1,o=function A(){var e,n;if(e=r.match(/^<([\w:.-]+)\s*/,!0)){for(var o=new t(e[1],1,null,i);e=r.match(/^([\w:.-]+)(?:\s*=\s*"([^"]*)"|\s*=\s*'([^']*)')?\s*/,!0);){var s=e[1],a=M(e[2]||e[3]||"");o.attributes[s]?(YA('parseXml: duplicate attribute "'+s+'"'),i=!0):(o.attributes[s]=a,"id"===s&&(o.id=a),"class"===s&&(o.classList=a.split(" ")))}if(r.match(/^>/)){for(;n=A();)o.childNodes.push(n),n.parentNode=o,o.textContent+=3===n.nodeType||4===n.nodeType?n.nodeValue:n.textContent;return(e=r.match(/^<\/([\w:.-]+)\s*>/,!0))?(e[1]===o.nodeName||(YA('parseXml: tag not matching, opening "'+o.nodeName+'" & closing "'+e[1]+'"'),i=!0),o):(YA('parseXml: tag not matching, opening "'+o.nodeName+'" & not closing'),i=!0,o)}if(r.match(/^\/>/))return o;YA('parseXml: tag could not be parsed "'+o.nodeName+'"'),i=!0}else{if(e=r.match(/^<!--[\s\S]*?-->/))return new t(null,8,e,i);if(e=r.match(/^<\?[\s\S]*?\?>/))return new t(null,7,e,i);if(e=r.match(/^<!DOCTYPE\s*([\s\S]*?)>/))return new t(null,10,e,i);if(e=r.match(/^<!\[CDATA\[([\s\S]*?)\]\]>/,!0))return new t("#cdata-section",4,e[1],i);if(e=r.match(/^([^<]+)/,!0))return new t("#text",3,M(e[1]),i)}};n=o();)1!==n.nodeType||e?(1===n.nodeType||3===n.nodeType&&""!==n.nodeValue.trim())&&YA("parseXml: data after document end has been discarded"):e=n;return r.matchAll()&&YA("parseXml: parsing error"),e}function M(A){return A.replace(/&(?:#([0-9]+)|#[xX]([0-9A-Fa-f]+)|([0-9A-Za-z]+));/g,(function(A,t,e,n){return t?String.fromCharCode(parseInt(t,10)):e?String.fromCharCode(parseInt(e,16)):n&&s[n]?String.fromCharCode(s[n]):A}))}function I(A){var t,e;return A=(A||"").trim(),(t=i[A])?e=[t.slice(),1]:(t=A.match(/^rgba\(\s*([0-9]+)\s*,\s*([0-9]+)\s*,\s*([0-9]+)\s*,\s*([0-9.]+)\s*\)$/i))?(t[1]=parseInt(t[1]),t[2]=parseInt(t[2]),t[3]=parseInt(t[3]),t[4]=parseFloat(t[4]),t[1]<256&&t[2]<256&&t[3]<256&&t[4]<=1&&(e=[t.slice(1,4),t[4]])):(t=A.match(/^rgb\(\s*([0-9]+)\s*,\s*([0-9]+)\s*,\s*([0-9]+)\s*\)$/i))?(t[1]=parseInt(t[1]),t[2]=parseInt(t[2]),t[3]=parseInt(t[3]),t[1]<256&&t[2]<256&&t[3]<256&&(e=[t.slice(1,4),1])):(t=A.match(/^rgb\(\s*([0-9.]+)%\s*,\s*([0-9.]+)%\s*,\s*([0-9.]+)%\s*\)$/i))?(t[1]=2.55*parseFloat(t[1]),t[2]=2.55*parseFloat(t[2]),t[3]=2.55*parseFloat(t[3]),t[1]<256&&t[2]<256&&t[3]<256&&(e=[t.slice(1,4),1])):(t=A.match(/^#([0-9a-f]{2})([0-9a-f]{2})([0-9a-f]{2})$/i))?e=[[parseInt(t[1],16),parseInt(t[2],16),parseInt(t[3],16)],1]:(t=A.match(/^#([0-9a-f])([0-9a-f])([0-9a-f])$/i))&&(e=[[17*parseInt(t[1],16),17*parseInt(t[2],16),17*parseInt(t[3],16)],1]),UA?UA(e,A):e}function p(A,t,e){var n=A[0].slice(),r=A[1]*t;if(e){for(var i=0;i<A.length;i++)n[i]*=r;return[n,1]}return[n,r]}function D(){function A(A,t){return[A[0]*t[0]+A[2]*t[1],A[1]*t[0]+A[3]*t[1],A[0]*t[2]+A[2]*t[3],A[1]*t[2]+A[3]*t[3],A[0]*t[4]+A[2]*t[5]+A[4],A[1]*t[4]+A[3]*t[5]+A[5]]}for(var t=arguments[0],e=1;e<arguments.length;e++)t=A(t,arguments[e]);return t}function y(A,t){return[t[0]*A[0]+t[2]*A[1]+t[4],t[1]*A[0]+t[3]*A[1]+t[5]]}function v(){for(var t=A._ctm,e=TA.length-1;e>=0;e--)t=D(TA[e].savedMatrix,t);return t}function m(){return(new X).M(0,0).L(A.page.width,0).L(A.page.width,A.page.height).L(0,A.page.height).transform(F(v())).getBoundingBox()}function F(A){var t=A[0]*A[3]-A[1]*A[2];return[A[3]/t,-A[1]/t,-A[2]/t,A[0]/t,(A[2]*A[5]-A[3]*A[4])/t,(A[1]*A[4]-A[0]*A[5])/t]}function Y(A){var t=x(A[0]),e=x(A[1]),n=x(A[2]),r=x(A[3]),i=x(A[4]),o=x(A[5]);if(S(t*r-e*n,0))return[t,e,n,r,i,o]}function b(A){var t=A[2]||0,e=A[1]||0,n=A[0]||0;if(U(t,0)&&U(e,0))return[];if(U(t,0))return[-n/e];var r=e*e-4*t*n;return S(r,0)&&r>0?[(-e+Math.sqrt(r))/(2*t),(-e-Math.sqrt(r))/(2*t)]:U(r,0)?[-e/(2*t)]:[]}function z(A,t){return(t[0]||0)+(t[1]||0)*A+(t[2]||0)*A*A+(t[3]||0)*A*A*A}function U(A,t){return Math.abs(A-t)<1e-10}function S(A,t){return Math.abs(A-t)>=1e-10}function x(A){return A>-1e21&&A<1e21?Math.round(1e6*A)/1e6:0}function T(A){for(var t,e=new W((A||"").trim()),n=[1,0,0,1,0,0];t=e.match(/^([A-Za-z]+)\s*[(]([^(]+)[)]/,!0);){for(var r=t[1],i=[],o=new W(t[2].trim()),s=void 0;s=o.matchNumber();)i.push(Number(s)),o.matchSeparator();if("matrix"===r&&6===i.length)n=D(n,[i[0],i[1],i[2],i[3],i[4],i[5]]);else if("translate"===r&&2===i.length)n=D(n,[1,0,0,1,i[0],i[1]]);else if("translate"===r&&1===i.length)n=D(n,[1,0,0,1,i[0],0]);else if("scale"===r&&2===i.length)n=D(n,[i[0],0,0,i[1],0,0]);else if("scale"===r&&1===i.length)n=D(n,[i[0],0,0,i[0],0,0]);else if("rotate"===r&&3===i.length){var a=i[0]*Math.PI/180;n=D(n,[1,0,0,1,i[1],i[2]],[Math.cos(a),Math.sin(a),-Math.sin(a),Math.cos(a),0,0],[1,0,0,1,-i[1],-i[2]])}else if("rotate"===r&&1===i.length){var c=i[0]*Math.PI/180;n=D(n,[Math.cos(c),Math.sin(c),-Math.sin(c),Math.cos(c),0,0])}else if("skewX"===r&&1===i.length){var B=i[0]*Math.PI/180;n=D(n,[1,0,Math.tan(B),1,0,0])}else{if("skewY"!==r||1!==i.length)return;var g=i[0]*Math.PI/180;n=D(n,[1,Math.tan(g),0,1,0,0])}e.matchSeparator()}if(!e.matchAll())return n}function P(A,t,e,n,r,i){var o=(A||"").trim().match(/^(none)$|^x(Min|Mid|Max)Y(Min|Mid|Max)(?:\s+(meet|slice))?$/)||[],s=o[1]||o[4]||"meet",a=o[2]||"Mid",c=o[3]||"Mid",B=t/n,g=e/r,l={Min:0,Mid:.5,Max:1}[a]-(i||0),u={Min:0,Mid:.5,Max:1}[c]-(i||0);return"slice"===s?g=B=Math.max(B,g):"meet"===s&&(g=B=Math.min(B,g)),[B,0,0,g,l*(t-n*B),u*(e-r*g)]}function N(A){var t=Object.create(null);A=(A||"").trim().split(/;/);for(var e=0;e<A.length;e++){var n=(A[e].split(":")[0]||"").trim(),r=(A[e].split(":")[1]||"").trim();n&&(t[n]=r)}if(t.marker&&(t["marker-start"]||(t["marker-start"]=t.marker),t["marker-mid"]||(t["marker-mid"]=t.marker),t["marker-end"]||(t["marker-end"]=t.marker)),t.font){for(var i=null,o=null,s="normal",a="normal",c="normal",B=t.font.split(/\s+/),g=0;g<B.length;g++)switch(B[g]){case"normal":break;case"italic":case"oblique":s=B[g];break;case"small-caps":c=B[g];break;case"bold":case"bolder":case"lighter":case"100":case"200":case"300":case"400":case"500":case"600":case"700":case"800":case"900":a=B[g];break;default:o?i?i+=" "+B[g]:i=B[g]:o=B[g].split("/")[0]}t["font-style"]||(t["font-style"]=s),t["font-variant"]||(t["font-variant"]=c),t["font-weight"]||(t["font-weight"]=a),t["font-size"]||(t["font-size"]=o),t["font-family"]||(t["font-family"]=i)}return t}function R(A){for(var t,e=A.split(/(?=[.#])/g),n=[],r=[],i=[],o=0;o<e.length;o++)if(t=e[o].match(/^[#]([_A-Za-z0-9-]+)$/))n.push(t[1]);else if(t=e[o].match(/^[.]([_A-Za-z0-9-]+)$/))r.push(t[1]);else if(t=e[o].match(/^([_A-Za-z0-9-]+)$/))i.push(t[1]);else if("*"!==e[o])return;return{tags:i,ids:n,classes:r,specificity:1e4*n.length+100*r.length+i.length}}function G(A){for(var t,e=new W(A.trim()),n=[];t=e.match(/^\s*([^\{\}]*?)\s*\{([^\{\}]*?)\}/,!0);)for(var r=t[1].split(/\s*,\s*/g),i=N(t[2]),o=0;o<r.length;o++){var s=R(r[o]);s&&n.push({selector:s,css:i})}return n}function H(A,t){if(1!==A.nodeType)return!1;for(var e=0;e<t.tags.length;e++)if(t.tags[e]!==A.nodeName)return!1;for(var n=0;n<t.ids.length;n++)if(t.ids[n]!==A.id)return!1;for(var r=0;r<t.classes.length;r++)if(-1===A.classList.indexOf(t.classes[r]))return!1;return!0}function k(A,t){return A.concat(t.slice(A.length))}function L(A,t){return Math.max(A.ascender,(A.bbox[3]||A.bbox.maxY)*(A.scale||1))*t/1e3}function J(A,t){return Math.min(A.descender,(A.bbox[1]||A.bbox.minY)*(A.scale||1))*t/1e3}function j(A,t,e){for(var n=A.encode(""+e),r=n[0],i=n[1],o=[],s=0;s<r.length;s++){var a=A.unicode?A.unicode[parseInt(r[s],16)]:[e.charCodeAt(s)];o.push({glyph:r[s],unicode:a,width:i[s].advanceWidth*t/1e3,xOffset:i[s].xOffset*t/1e3,yOffset:i[s].yOffset*t/1e3,xAdvance:i[s].xAdvance*t/1e3,yAdvance:i[s].yAdvance*t/1e3})}return o}function O(A,t){switch(A.nodeName){case"use":return new AA(A,t);case"symbol":return new tA(A,t);case"g":return new eA(A,t);case"a":return new nA(A,t);case"svg":return new rA(A,t);case"image":return new iA(A,t);case"rect":return new cA(A,t);case"circle":return new BA(A,t);case"ellipse":return new gA(A,t);case"line":return new lA(A,t);case"polyline":return new uA(A,t);case"polygon":return new wA(A,t);case"path":return new hA(A,t);case"text":return new pA(A,t);case"tspan":return new MA(A,t);case"textPath":return new IA(A,t);case"#text":case"#cdata-section":return new CA(A,t);default:return new Z(A,t)}}var W=function(A){this.match=function(t,e){var n=A.match(t);if(n&&0===n.index)return A=A.substring(n[0].length),e?n:n[0]},this.matchSeparator=function(){return this.match(/^(?:\s*,\s*|\s*|)/)},this.matchSpace=function(){return this.match(/^(?:\s*)/)},this.matchLengthUnit=function(){return this.match(/^(?:px|pt|cm|mm|in|pc|em|ex|%|)/)},this.matchNumber=function(){return this.match(/^(?:[-+]?(?:[0-9]+[.][0-9]+|[0-9]+[.]|[.][0-9]+|[0-9]+)(?:[eE][-+]?[0-9]+)?)/)},this.matchAll=function(){return this.match(/^[\s\S]+/)}},K=function(A,t,e,n,r,i,o,s){for(var a=6*xA,c=[A,-3*A+3*e,3*A-6*e+3*r,3*e-A-3*r+o],B=[t,-3*t+3*n,3*t-6*n+3*i,3*n-t-3*i+s],g=[-3*A+3*e,6*A-12*e+6*r,-3*A+9*e-9*r+3*o],l=[-3*t+3*n,6*t-12*n+6*i,-3*t+9*n-9*i+3*s],u=[0],w=1;w<=a;w++){var h=(w-.5)/a,E=z(h,g)/a,f=z(h,l)/a,Q=Math.sqrt(E*E+f*f);u[w]=u[w-1]+Q}this.totalLength=u[a],this.startPoint=[A,t,U(A,e)&&U(t,n)?Math.atan2(i-n,r-e):Math.atan2(n-t,e-A)],this.endPoint=[o,s,U(r,o)&&U(i,s)?Math.atan2(i-n,r-e):Math.atan2(s-i,o-r)],this.getBoundingBox=function(){var A,t=z(0,c),e=z(0,B),n=z(1,c),r=z(1,B);t>n&&(A=n,n=t,t=A),e>r&&(A=r,r=e,e=A);for(var i=b(g),o=0;o<i.length;o++)if(i[o]>=0&&i[o]<=1){var s=z(i[o],c);s<t&&(t=s),s>n&&(n=s)}for(var a=b(l),u=0;u<a.length;u++)if(a[u]>=0&&a[u]<=1){var w=z(a[u],B);w<e&&(e=w),w>r&&(r=w)}return[t,e,n,r]},this.getPointAtLength=function(A){if(U(A,0))return this.startPoint;if(U(A,this.totalLength))return this.endPoint;if(!(A<0||A>this.totalLength))for(var t=1;t<=a;t++){var e=u[t-1],n=u[t];if(e<=A&&A<=n){var r=(t-(n-A)/(n-e))/a,i=z(r,c),o=z(r,B),s=z(r,g),w=z(r,l);return[i,o,Math.atan2(w,s)]}}}},V=function(A,t,e,n){this.totalLength=Math.sqrt((e-A)*(e-A)+(n-t)*(n-t)),this.startPoint=[A,t,Math.atan2(n-t,e-A)],this.endPoint=[e,n,Math.atan2(n-t,e-A)],this.getBoundingBox=function(){return[Math.min(this.startPoint[0],this.endPoint[0]),Math.min(this.startPoint[1],this.endPoint[1]),Math.max(this.startPoint[0],this.endPoint[0]),Math.max(this.startPoint[1],this.endPoint[1])]},this.getPointAtLength=function(A){if(A>=0&&A<=this.totalLength){var t=A/this.totalLength||0;return[this.startPoint[0]+t*(this.endPoint[0]-this.startPoint[0]),this.startPoint[1]+t*(this.endPoint[1]-this.startPoint[1]),this.startPoint[2]]}}},X=function t(){this.pathCommands=[],this.pathSegments=[],this.startPoint=null,this.endPoint=null,this.totalLength=0;var e,n,r,i=0,o=0,s=0,B=0;this.move=function(A,t){return i=s=A,o=B=t,null},this.line=function(A,t){var e=new V(s,B,A,t);return s=A,B=t,e},this.curve=function(A,t,e,n,r,i){var o=new K(s,B,A,t,e,n,r,i);return s=r,B=i,o},this.close=function(){var A=new V(s,B,i,o);return s=i,B=o,A},this.addCommand=function(A){this.pathCommands.push(A);var t=this[A[0]].apply(this,A.slice(3));t&&(t.hasStart=A[1],t.hasEnd=A[2],this.startPoint=this.startPoint||t.startPoint,this.endPoint=t.endPoint,this.pathSegments.push(t),this.totalLength+=t.totalLength)},this.M=function(A,t){return this.addCommand(["move",!0,!0,A,t]),e="M",this},this.m=function(A,t){return this.M(s+A,B+t)},this.Z=this.z=function(){return this.addCommand(["close",!0,!0]),e="Z",this},this.L=function(A,t){return this.addCommand(["line",!0,!0,A,t]),e="L",this},this.l=function(A,t){return this.L(s+A,B+t)},this.H=function(A){return this.L(A,B)},this.h=function(A){return this.L(s+A,B)},this.V=function(A){return this.L(s,A)},this.v=function(A){return this.L(s,B+A)},this.C=function(A,t,i,o,s,a){return this.addCommand(["curve",!0,!0,A,t,i,o,s,a]),e="C",n=i,r=o,this},this.c=function(A,t,e,n,r,i){return this.C(s+A,B+t,s+e,B+n,s+r,B+i)},this.S=function(A,t,i,o){return this.C(s+("C"===e?s-n:0),B+("C"===e?B-r:0),A,t,i,o)},this.s=function(A,t,i,o){return this.C(s+("C"===e?s-n:0),B+("C"===e?B-r:0),s+A,B+t,s+i,B+o)},this.Q=function(A,t,i,o){var a=s+2/3*(A-s),c=B+2/3*(t-B),g=i+2/3*(A-i),l=o+2/3*(t-o);return this.addCommand(["curve",!0,!0,a,c,g,l,i,o]),e="Q",n=A,r=t,this},this.q=function(A,t,e,n){return this.Q(s+A,B+t,s+e,B+n)},this.T=function(A,t){return this.Q(s+("Q"===e?s-n:0),B+("Q"===e?B-r:0),A,t)},this.t=function(A,t){return this.Q(s+("Q"===e?s-n:0),B+("Q"===e?B-r:0),s+A,B+t)},this.A=function(A,t,n,r,i,o,a){if(U(A,0)||U(t,0))this.addCommand(["line",!0,!0,o,a]);else{n*=Math.PI/180,A=Math.abs(A),t=Math.abs(t),r=1*!!r,i=1*!!i;var c=Math.cos(n)*(s-o)/2+Math.sin(n)*(B-a)/2,g=Math.cos(n)*(B-a)/2-Math.sin(n)*(s-o)/2,l=c*c/(A*A)+g*g/(t*t);l>1&&(A*=Math.sqrt(l),t*=Math.sqrt(l));var u=Math.sqrt(Math.max(0,A*A*t*t-A*A*g*g-t*t*c*c)/(A*A*g*g+t*t*c*c)),w=(r===i?-1:1)*u*A*g/t,h=(r===i?1:-1)*u*t*c/A,E=Math.cos(n)*w-Math.sin(n)*h+(s+o)/2,f=Math.sin(n)*w+Math.cos(n)*h+(B+a)/2,Q=Math.atan2((g-h)/t,(c-w)/A),d=Math.atan2((-g-h)/t,(-c-w)/A);0===i&&d-Q>0?d-=2*Math.PI:1===i&&d-Q<0&&(d+=2*Math.PI);for(var C=Math.ceil(Math.abs(d-Q)/(Math.PI/xA)),M=0;M<C;M++){var I=Q+M*(d-Q)/C,p=Q+(M+1)*(d-Q)/C,D=4/3*Math.tan((p-I)/4),y=E+Math.cos(n)*A*(Math.cos(I)-D*Math.sin(I))-Math.sin(n)*t*(Math.sin(I)+D*Math.cos(I)),v=f+Math.sin(n)*A*(Math.cos(I)-D*Math.sin(I))+Math.cos(n)*t*(Math.sin(I)+D*Math.cos(I)),m=E+Math.cos(n)*A*(Math.cos(p)+D*Math.sin(p))-Math.sin(n)*t*(Math.sin(p)-D*Math.cos(p)),F=f+Math.sin(n)*A*(Math.cos(p)+D*Math.sin(p))+Math.cos(n)*t*(Math.sin(p)-D*Math.cos(p)),Y=E+Math.cos(n)*A*Math.cos(p)-Math.sin(n)*t*Math.sin(p),b=f+Math.sin(n)*A*Math.cos(p)+Math.cos(n)*t*Math.sin(p);this.addCommand(["curve",0===M,M===C-1,y,v,m,F,Y,b])}}return e="A",this},this.a=function(A,t,e,n,r,i,o){return this.A(A,t,e,n,r,s+i,B+o)},this.path=function(A){for(var t,e,n,r=new W((A||"").trim());t=r.match(/^[astvzqmhlcASTVZQMHLC]/);){r.matchSeparator();for(var i=[];e=c[t+i.length]?r.match(/^[01]/):r.matchNumber();)r.matchSeparator(),i.length===a[t]&&(this[t].apply(this,i),i=[],"M"===t?t="L":"m"===t&&(t="l")),i.push(Number(e));if(i.length!==a[t])return void YA("SvgPath: command "+t+" with "+i.length+" numbers");this[t].apply(this,i)}return(n=r.matchAll())&&YA("SvgPath: unexpected string "+n),this},this.getBoundingBox=function(){for(var A,t=[1/0,1/0,-1/0,-1/0],e=0;e<this.pathSegments.length;e++)(A=this.pathSegments[e].getBoundingBox())[0]<t[0]&&(t[0]=A[0]),A[2]>t[2]&&(t[2]=A[2]),A[1]<t[1]&&(t[1]=A[1]),A[3]>t[3]&&(t[3]=A[3]);return t[0]===1/0&&(t[0]=0),t[1]===1/0&&(t[1]=0),t[2]===-1/0&&(t[2]=0),t[3]===-1/0&&(t[3]=0),t},this.getPointAtLength=function(A){if(A>=0&&A<=this.totalLength){for(var t,e=0;e<this.pathSegments.length;e++){if(t=this.pathSegments[e].getPointAtLength(A))return t;A-=this.pathSegments[e].totalLength}return this.endPoint}},this.transform=function(A){this.pathSegments=[],this.startPoint=null,this.endPoint=null,this.totalLength=0;for(var t=0;t<this.pathCommands.length;t++){for(var e=this.pathCommands.shift(),n=3;n<e.length;n+=2){var r=y([e[n],e[n+1]],A);e[n]=r[0],e[n+1]=r[1]}this.addCommand(e)}return this},this.mergeShape=function(A){for(var t=0;t<A.pathCommands.length;t++)this.addCommand(A.pathCommands[t].slice());return this},this.clone=function(){return(new t).mergeShape(this)},this.insertInDocument=function(){for(var t=0;t<this.pathCommands.length;t++){var e=this.pathCommands[t][0],n=this.pathCommands[t].slice(3);switch(e){case"move":A.moveTo(n[0],n[1]);break;case"line":A.lineTo(n[0],n[1]);break;case"curve":A.bezierCurveTo(n[0],n[1],n[2],n[3],n[4],n[5]);break;case"close":A.closePath()}}},this.getSubPaths=function(){for(var A=[],e=new t,n=0;n<this.pathCommands.length;n++){var r=this.pathCommands[n];"move"===this.pathCommands[n][0]&&0!==n&&(A.push(e),e=new t),e.addCommand(r)}return A.push(e),A},this.getMarkers=function(){for(var A=[],t=this.getSubPaths(),e=0;e<t.length;e++){for(var n=t[e],r=[],i=0;i<n.pathSegments.length;i++){var o=n.pathSegments[i];if(S(o.totalLength,0)||0===i||i===n.pathSegments.length-1){if(o.hasStart){var s=o.getPointAtLength(0),a=r.pop();a&&(s[2]=.5*(a[2]+s[2])),r.push(s)}if(o.hasEnd){var c=o.getPointAtLength(o.totalLength);r.push(c)}}}A=A.concat(r)}return A}},Z=function(A,e){var n=Object.create(null),r=null;this.name=A.nodeName,this.isOuterElement=A===t||!A.parentNode,this.inherits=e||(this.isOuterElement?null:O(A.parentNode,null)),this.stack=this.inherits?this.inherits.stack.concat(A):[A],this.style=N("function"==typeof A.getAttribute&&A.getAttribute("style")),this.css=FA?getComputedStyle(A):function(A){for(var t=Object.create(null),e=Object.create(null),n=0;n<RA.length;n++){var r=RA[n];if(H(A,r.selector))for(var i in r.css)e[i]>r.selector.specificity||(t[i]=r.css[i],e[i]=r.selector.specificity)}return t}(A),this.allowedChildren=[],this.attr=function(t){if("function"==typeof A.getAttribute)return A.getAttribute(t)},this.resolveUrl=function(A){var e=(A||"").match(/^\s*(?:url\("(.*)#(.*)"\)|url\('(.*)#(.*)'\)|url\((.*)#(.*)\)|(.*)#(.*))\s*$/)||[],n=e[1]||e[3]||e[5]||e[7],r=e[2]||e[4]||e[6]||e[8];if(r){if(!n){var i=t.getElementById(r);if(i)return-1===this.stack.indexOf(i)?i:void YA('SVGtoPDF: loop of circular references for id "'+r+'"')}if(SA){var o=PA[n];if(!o){(function(A){return"object"==typeof A&&null!==A&&"number"==typeof A.length})(o=SA(n))||(o=[o]);for(var s=0;s<o.length;s++)"string"==typeof o[s]&&(o[s]=C(o[s]));PA[n]=o}for(var a=0;a<o.length;a++){var c=o[a].getElementById(r);if(c)return-1===this.stack.indexOf(c)?c:void YA('SVGtoPDF: loop of circular references for id "'+n+"#"+r+'"')}}}},this.computeUnits=function(A,t,e,n){return"%"===t?parseFloat(A)/100*(n||null!=e?e:this.getViewport()):"ex"===t||"em"===t?A*{em:1,ex:.5}[t]*(n?e:this.get("font-size")):A*{"":1,px:1,pt:96/72,cm:96/2.54,mm:96/25.4,in:96,pc:16}[t]},this.computeLength=function(A,t,e,n){var r,i,o=new W((A||"").trim());return"string"!=typeof(r=o.matchNumber())||"string"!=typeof(i=o.matchLengthUnit())||o.matchAll()?e:this.computeUnits(r,i,t,n)},this.computeLengthList=function(A,t,e){for(var n,r,i=new W((A||"").trim()),o=[];"string"==typeof(n=i.matchNumber())&&"string"==typeof(r=i.matchLengthUnit());)o.push(this.computeUnits(n,r,t)),i.matchSeparator();if(!e||!i.matchAll())return o},this.getLength=function(A,t,e){return this.computeLength(this.attr(A),t,e)},this.getLengthList=function(A,t){return this.computeLengthList(this.attr(A),t)},this.getUrl=function(A){return this.resolveUrl(this.attr(A))},this.getNumberList=function(A){for(var t,e=new W((this.attr(A)||"").trim()),n=[];t=e.matchNumber();)n.push(Number(t)),e.matchSeparator();return n.error=e.matchAll(),n},this.getViewbox=function(A,t){var e=this.getNumberList(A);return 4===e.length&&e[2]>=0&&e[3]>=0?e:t},this.getPercent=function(A,t){var e=this.attr(A),n=new W((e||"").trim()),r=n.matchNumber();return r?(n.match("%")&&(r*=.01),n.matchAll()?t:Math.max(0,Math.min(1,r))):t},this.chooseValue=function(A){for(var t=0;t<arguments.length;t++)if(null!=arguments[t]&&arguments[t]==arguments[t])return arguments[t];return arguments[arguments.length-1]},this.get=function(A){if(void 0!==n[A])return n[A];for(var t,e,r=B[A]||{},i=0;i<3;i++){switch(i){case 0:"transform"!==A&&(t=this.css[r.css||A]);break;case 1:t=this.style[A];break;case 2:t=this.attr(A)}if("inherit"===t&&null!=(e=this.inherits?this.inherits.get(A):r.initial))return n[A]=e;if(null!=r.values&&null!=(e=r.values[t]))return n[A]=e;if(null!=t){var o=void 0;switch(A){case"font-size":e=this.computeLength(t,this.inherits?this.inherits.get(A):r.initial,void 0,!0);break;case"baseline-shift":e=this.computeLength(t,this.get("font-size"));break;case"font-family":e=t||void 0;break;case"opacity":case"stroke-opacity":case"fill-opacity":case"stop-opacity":o=parseFloat(t),isNaN(o)||(e=Math.max(0,Math.min(1,o)));break;case"transform":e=T(t);break;case"stroke-dasharray":if("none"===t)e=[];else if(o=this.computeLengthList(t,this.getViewport(),!0)){for(var s=0,a=!1,c=0;c<o.length;c++)o[c]<0&&(a=!0),s+=o[c];a||(o.length%2==1&&(o=o.concat(o)),e=0===s?[]:o)}break;case"color":e="none"===t||"transparent"===t?"none":I(t);break;case"fill":case"stroke":if("none"===t||"transparent"===t)e="none";else if("currentColor"===t)e=this.get("color");else{if(o=I(t))return o;if(o=(t||"").split(" ")){var g=this.resolveUrl(o[0]),l=I(o[1]);e=null==g?l:"linearGradient"===g.nodeName||"radialGradient"===g.nodeName?new sA(g,null,l):"pattern"===g.nodeName?new oA(g,null,l):l}}break;case"stop-color":e="none"===t||"transparent"===t?"none":"currentColor"===t?this.get("color"):I(t);break;case"marker-start":case"marker-mid":case"marker-end":case"clip-path":case"mask":e="none"===t?"none":this.resolveUrl(t);break;case"stroke-width":null!=(o=this.computeLength(t,this.getViewport()))&&o>=0&&(e=o);break;case"stroke-miterlimit":null!=(o=parseFloat(t))&&o>=1&&(e=o);break;case"word-spacing":case"letter-spacing":e=this.computeLength(t,this.getViewport());break;case"stroke-dashoffset":if(null!=(e=this.computeLength(t,this.getViewport()))&&e<0)for(var u=this.get("stroke-dasharray"),w=0;w<u.length;w++)e+=u[w]}if(null!=e)return n[A]=e}}return n[A]=r.inherit&&this.inherits?this.inherits.get(A):r.initial},this.getChildren=function(){if(null!=r)return r;for(var t=[],e=0;e<A.childNodes.length;e++){var n=A.childNodes[e];n.error||-1===this.allowedChildren.indexOf(n.nodeName)||t.push(O(n,this))}return r=t},this.getParentVWidth=function(){return this.inherits?this.inherits.getVWidth():yA},this.getParentVHeight=function(){return this.inherits?this.inherits.getVHeight():vA},this.getParentViewport=function(){return Math.sqrt(.5*this.getParentVWidth()*this.getParentVWidth()+.5*this.getParentVHeight()*this.getParentVHeight())},this.getVWidth=function(){return this.getParentVWidth()},this.getVHeight=function(){return this.getParentVHeight()},this.getViewport=function(){return Math.sqrt(.5*this.getVWidth()*this.getVWidth()+.5*this.getVHeight()*this.getVHeight())},this.getBoundingBox=function(){return this.getBoundingShape().getBoundingBox()}},_=function(t,e){Z.call(this,t,e),this.transform=function(){A.transform.apply(A,this.getTransformation())},this.clip=function(){if("none"!==this.get("clip-path"))return new fA(this.get("clip-path"),null).useMask(this.getBoundingBox()),!0},this.mask=function(){if("none"!==this.get("mask"))return new QA(this.get("mask"),null).useMask(this.getBoundingBox()),!0},this.getFill=function(A,t){var e=this.get("opacity"),n=this.get("fill"),r=this.get("fill-opacity");return A?o.white:"none"!==n&&e&&r?n instanceof sA||n instanceof oA?n.getPaint(this.getBoundingBox(),r*e,A,t):p(n,r*e,t):void 0},this.getStroke=function(A,t){var e=this.get("opacity"),n=this.get("stroke"),r=this.get("stroke-opacity");if(!A&&!U(this.get("stroke-width"),0))return"none"!==n&&e&&r?n instanceof sA||n instanceof oA?n.getPaint(this.getBoundingBox(),r*e,A,t):p(n,r*e,t):void 0}},q=function(A,t){_.call(this,A,t),this.allowedChildren=["use","g","a","svg","image","rect","circle","ellipse","line","polyline","polygon","path","text"],this.getBoundingShape=function(){for(var A=new X,t=this.getChildren(),e=0;e<t.length;e++)if("none"!==t[e].get("display")&&"function"==typeof t[e].getBoundingShape){var n=t[e].getBoundingShape().clone();"function"==typeof t[e].getTransformation&&n.transform(t[e].getTransformation()),A.mergeShape(n)}return A},this.drawChildren=function(A,t){for(var e=this.getChildren(),n=0;n<e.length;n++)"none"!==e[n].get("display")&&"function"==typeof e[n].drawInDocument&&e[n].drawInDocument(A,t)}},$=function(t,e){q.call(this,t,e),this.drawContent=function(t,e){this.transform();var n,r=this.clip(),i=this.mask();(this.get("opacity")<1||r||i)&&!t&&(n=g(m())),this.drawChildren(t,e),n&&(l(n),A.fillOpacity(this.get("opacity")),u(n))}},AA=function(t,e){$.call(this,t,e);var n=this.getLength("x",this.getVWidth(),0),r=this.getLength("y",this.getVHeight(),0),i=this.getUrl("href")||this.getUrl("xlink:href");i&&(i=O(i,this)),this.getChildren=function(){return i?[i]:[]},this.drawInDocument=function(t,e){A.save(),this.drawContent(t,e),A.restore()},this.getTransformation=function(){return D(this.get("transform"),[1,0,0,1,n,r])}},tA=function(t,e){$.call(this,t,e);var n=this.getLength("width",this.getParentVWidth(),this.getParentVWidth()),r=this.getLength("height",this.getParentVHeight(),this.getParentVHeight());e instanceof AA&&(n=e.getLength("width",e.getParentVWidth(),n),r=e.getLength("height",e.getParentVHeight(),r));var i=(this.attr("preserveAspectRatio")||"").trim(),o=this.getViewbox("viewBox",[0,0,n,r]);this.getVWidth=function(){return o[2]},this.getVHeight=function(){return o[3]},this.drawInDocument=function(t,e){A.save(),this.drawContent(t,e),A.restore()},this.getTransformation=function(){return D(P(i,n,r,o[2],o[3]),[1,0,0,1,-o[0],-o[1]])}},eA=function(t,e){$.call(this,t,e),this.drawInDocument=function(t,e){A.save(),!this.link||t||e||this.addLink(),this.drawContent(t,e),A.restore()},this.getTransformation=function(){return this.get("transform")}},nA=function(t,e){e&&e.isText?(MA.call(this,t,e),this.allowedChildren=["textPath","tspan","#text","#cdata-section","a"]):eA.call(this,t,e),this.link=this.attr("href")||this.attr("xlink:href"),this.addLink=function(){if(this.link.match(/^(?:[a-z][a-z0-9+.-]*:|\/\/)?/i)&&this.getChildren().length){var t=this.getBoundingShape().transform(v()).getBoundingBox();!function(t,e,n,r,i){var o=A.ref({Type:"Annot",Subtype:"Link",Rect:[t,e,n,r],Border:[0,0,0],A:{S:"URI",URI:new String(i)}});o.end(),NA.push(o)}(t[0],t[1],t[2],t[3],this.link)}}},rA=function(t,e){$.call(this,t,e);var n=this.getLength("width",this.getParentVWidth(),this.getParentVWidth()),r=this.getLength("height",this.getParentVHeight(),this.getParentVHeight()),i=this.getLength("x",this.getParentVWidth(),0),o=this.getLength("y",this.getParentVHeight(),0);e instanceof AA&&(n=e.getLength("width",e.getParentVWidth(),n),r=e.getLength("height",e.getParentVHeight(),r));var s=this.attr("preserveAspectRatio"),a=this.getViewbox("viewBox",[0,0,n,r]);this.isOuterElement&&mA&&(i=o=0,n=yA,r=vA,s=mA),this.getVWidth=function(){return a[2]},this.getVHeight=function(){return a[3]},this.drawInDocument=function(t,e){A.save(),"hidden"===this.get("overflow")&&((new X).M(i,o).L(i+n,o).L(i+n,o+r).L(i,o+r).Z().transform(this.get("transform")).insertInDocument(),A.clip()),this.drawContent(t,e),A.restore()},this.getTransformation=function(){return D(this.get("transform"),[1,0,0,1,i,o],P(s,n,r,a[2],a[3]),[1,0,0,1,-a[0],-a[1]])}},iA=function(t,e){_.call(this,t,e);var n,r=zA(this.attr("href")||this.attr("xlink:href")||""),i=this.getLength("x",this.getVWidth(),0),s=this.getLength("y",this.getVHeight(),0),a=this.getLength("width",this.getVWidth(),"auto"),c=this.getLength("height",this.getVHeight(),"auto");try{n=A.openImage(r)}catch(A){YA('SVGElemImage: failed to open image "'+r+'" in PDFKit')}n&&("auto"===a&&"auto"!==c?a=c*n.width/n.height:"auto"===c&&"auto"!==a?c=a*n.height/n.width:"auto"===a&&"auto"===c&&(a=n.width,c=n.height)),("auto"===a||a<0)&&(a=0),("auto"===c||c<0)&&(c=0),this.getTransformation=function(){return this.get("transform")},this.getBoundingShape=function(){return(new X).M(i,s).L(i+a,s).M(i+a,s+c).L(i,s+c)},this.drawInDocument=function(t,e){"hidden"!==this.get("visibility")&&n&&(A.save(),this.transform(),"hidden"===this.get("overflow")&&A.rect(i,s,a,c).clip(),this.clip(),this.mask(),A.translate(i,s),A.transform.apply(A,P(this.attr("preserveAspectRatio"),a,c,n?n.width:a,n?n.height:c)),t?(A.rect(0,0,n.width,n.height),Q(o.white).fill()):(A.fillOpacity(this.get("opacity")),A.image(n,0,0)),A.restore())}},oA=function t(e,n,r){q.call(this,e,n),this.ref=function(){var A=this.getUrl("href")||this.getUrl("xlink:href");if(A&&A.nodeName===e.nodeName)return new t(A,n,r)}.call(this);var i=this.attr;this.attr=function(A){var t=i.call(this,A);return null!=t||"href"===A||"xlink:href"===A?t:this.ref?this.ref.attr(A):null};var o=this.getChildren;this.getChildren=function(){var A=o.call(this);return A.length>0?A:this.ref?this.ref.getChildren():[]},this.getPaint=function(t,e,n,i){var o="userSpaceOnUse"!==this.attr("patternUnits"),s="objectBoundingBox"===this.attr("patternContentUnits"),a=this.getLength("x",o?1:this.getParentVWidth(),0),c=this.getLength("y",o?1:this.getParentVHeight(),0),B=this.getLength("width",o?1:this.getParentVWidth(),0),u=this.getLength("height",o?1:this.getParentVHeight(),0);s&&!o?(a=(a-t[0])/(t[2]-t[0])||0,c=(c-t[1])/(t[3]-t[1])||0,B=B/(t[2]-t[0])||0,u=u/(t[3]-t[1])||0):!s&&o&&(a=t[0]+a*(t[2]-t[0]),c=t[1]+c*(t[3]-t[1]),B*=t[2]-t[0],u*=t[3]-t[1]);var w=this.getViewbox("viewBox",[0,0,B,u]),E=D(P((this.attr("preserveAspectRatio")||"").trim(),B,u,w[2],w[3],0),[1,0,0,1,-w[0],-w[1]]),f=T(this.attr("patternTransform"));if(s&&(f=D([t[2]-t[0],0,0,t[3]-t[1],t[0],t[1]],f)),(f=Y(f=D(f,[1,0,0,1,a,c])))&&(E=Y(E))&&(B=x(B))&&(u=x(u))){var Q=g([0,0,B,u]);return A.transform.apply(A,E),this.drawChildren(n,i),l(Q),[h(Q,B,u,f),e]}return r?[r[0],r[1]*e]:void 0},this.getVWidth=function(){var A="userSpaceOnUse"!==this.attr("patternUnits"),t=this.getLength("width",A?1:this.getParentVWidth(),0);return this.getViewbox("viewBox",[0,0,t,0])[2]},this.getVHeight=function(){var A="userSpaceOnUse"!==this.attr("patternUnits"),t=this.getLength("height",A?1:this.getParentVHeight(),0);return this.getViewbox("viewBox",[0,0,0,t])[3]}},sA=function t(e,n,r){Z.call(this,e,n),this.allowedChildren=["stop"],this.ref=function(){var A=this.getUrl("href")||this.getUrl("xlink:href");if(A&&A.nodeName===e.nodeName)return new t(A,n,r)}.call(this);var i=this.attr;this.attr=function(A){var t=i.call(this,A);return null!=t||"href"===A||"xlink:href"===A?t:this.ref?this.ref.attr(A):null};var s=this.getChildren;this.getChildren=function(){var A=s.call(this);return A.length>0?A:this.ref?this.ref.getChildren():[]},this.getPaint=function(t,e,n,i){var s=this.getChildren();if(0!==s.length){if(1===s.length){var a=s[0],c=a.get("stop-color");if("none"===c)return;return p(c,a.get("stop-opacity")*e,i)}var B,g,l,u,w,h,E="userSpaceOnUse"!==this.attr("gradientUnits"),f=T(this.attr("gradientTransform")),Q=this.attr("spreadMethod"),d=0,C=0,M=1;if(E&&(f=D([t[2]-t[0],0,0,t[3]-t[1],t[0],t[1]],f)),f=Y(f)){if("linearGradient"===this.name)g=this.getLength("x1",E?1:this.getVWidth(),0),l=this.getLength("x2",E?1:this.getVWidth(),E?1:this.getVWidth()),u=this.getLength("y1",E?1:this.getVHeight(),0),w=this.getLength("y2",E?1:this.getVHeight(),0);else{l=this.getLength("cx",E?1:this.getVWidth(),E?.5:.5*this.getVWidth()),w=this.getLength("cy",E?1:this.getVHeight(),E?.5:.5*this.getVHeight()),h=this.getLength("r",E?1:this.getViewport(),E?.5:.5*this.getViewport()),g=this.getLength("fx",E?1:this.getVWidth(),l),u=this.getLength("fy",E?1:this.getVHeight(),w),h<0&&YA("SvgElemGradient: negative r value");var I=Math.sqrt(Math.pow(l-g,2)+Math.pow(w-u,2)),v=1;I>h&&(g=l+(g-l)*(v=h/I),u=w+(u-w)*v),h=Math.max(h,I*v*1.000001)}if("reflect"===Q||"repeat"===Q){var m=F(f),b=y([t[0],t[1]],m),z=y([t[2],t[1]],m),U=y([t[2],t[3]],m),S=y([t[0],t[3]],m);"linearGradient"===this.name?(d=Math.max((b[0]-l)*(l-g)+(b[1]-w)*(w-u),(z[0]-l)*(l-g)+(z[1]-w)*(w-u),(U[0]-l)*(l-g)+(U[1]-w)*(w-u),(S[0]-l)*(l-g)+(S[1]-w)*(w-u))/(Math.pow(l-g,2)+Math.pow(w-u,2)),C=Math.max((b[0]-g)*(g-l)+(b[1]-u)*(u-w),(z[0]-g)*(g-l)+(z[1]-u)*(u-w),(U[0]-g)*(g-l)+(U[1]-u)*(u-w),(S[0]-g)*(g-l)+(S[1]-u)*(u-w))/(Math.pow(l-g,2)+Math.pow(w-u,2))):d=Math.sqrt(Math.max(Math.pow(b[0]-l,2)+Math.pow(b[1]-w,2),Math.pow(z[0]-l,2)+Math.pow(z[1]-w,2),Math.pow(U[0]-l,2)+Math.pow(U[1]-w,2),Math.pow(S[0]-l,2)+Math.pow(S[1]-w,2)))/h-1,d=Math.ceil(d+.5),M=(C=Math.ceil(C+.5))+1+d}B="linearGradient"===this.name?A.linearGradient(g-C*(l-g),u-C*(w-u),l+d*(l-g),w+d*(w-u)):A.radialGradient(g,u,0,l,w,h+d*h);for(var x=0;x<M;x++)for(var P=0,N="reflect"!==Q||(x-C)%2==0,R=0;R<s.length;R++){var G=s[N?R:s.length-1-R],H=G.get("stop-color");"none"===H&&(H=o.transparent),H=p(H,G.get("stop-opacity")*e,i),P=Math.max(P,N?G.getPercent("offset",0):1-G.getPercent("offset",0)),0===R&&4===H[0].length&&(B._colorSpace="DeviceCMYK"),0===R&&P>0&&B.stop((x+0)/M,H[0],H[1]),B.stop((x+P)/(d+C+1),H[0],H[1]),R===s.length-1&&P<1&&B.stop((x+1)/M,H[0],H[1])}return B.setTransform.apply(B,f),[B,1]}return r?[r[0],r[1]*e]:void 0}}},aA=function(t,e){_.call(this,t,e),this.dashScale=1,this.getBoundingShape=function(){return this.shape},this.getTransformation=function(){return this.get("transform")},this.drawInDocument=function(t,e){if("hidden"!==this.get("visibility")&&this.shape){if(A.save(),this.transform(),this.clip(),t)this.shape.insertInDocument(),Q(o.white),A.fill(this.get("clip-rule"));else{var n;this.mask()&&(n=g(m()));var r=this.shape.getSubPaths(),i=this.getFill(t,e),s=this.getStroke(t,e),a=this.get("stroke-width"),c=this.get("stroke-linecap");if(i||s){if(i&&Q(i),s){for(var B=0;B<r.length;B++)if(U(r[B].totalLength,0)&&("square"===c||"round"===c)&&a>0&&r[B].startPoint&&r[B].startPoint.length>1){var w=r[B].startPoint[0],h=r[B].startPoint[1];Q(s),"square"===c?A.rect(w-.5*a,h-.5*a,a,a):"round"===c&&A.circle(w,h,.5*a),A.fill()}var E=this.get("stroke-dasharray"),f=this.get("stroke-dashoffset");if(S(this.dashScale,1)){for(var C=0;C<E.length;C++)E[C]*=this.dashScale;f*=this.dashScale}d(s),A.lineWidth(a).miterLimit(this.get("stroke-miterlimit")).lineJoin(this.get("stroke-linejoin")).lineCap(c).dash(E,{phase:f})}for(var M=0;M<r.length;M++)r[M].totalLength>0&&r[M].insertInDocument();i&&s?A.fillAndStroke(this.get("fill-rule")):i?A.fill(this.get("fill-rule")):s&&A.stroke()}var I=this.get("marker-start"),p=this.get("marker-mid"),D=this.get("marker-end");if("none"!==I||"none"!==p||"none"!==D){var y=this.shape.getMarkers();if("none"!==I&&new EA(I,null).drawMarker(!1,e,y[0],a),"none"!==p)for(var v=1;v<y.length-1;v++)new EA(p,null).drawMarker(!1,e,y[v],a);"none"!==D&&new EA(D,null).drawMarker(!1,e,y[y.length-1],a)}n&&(l(n),u(n))}A.restore()}}},cA=function(A,t){aA.call(this,A,t);var e=this.getLength("x",this.getVWidth(),0),n=this.getLength("y",this.getVHeight(),0),r=this.getLength("width",this.getVWidth(),0),i=this.getLength("height",this.getVHeight(),0),o=this.getLength("rx",this.getVWidth()),s=this.getLength("ry",this.getVHeight());void 0===o&&void 0===s?o=s=0:void 0===o&&void 0!==s?o=s:void 0!==o&&void 0===s&&(s=o),r>0&&i>0?o&&s?(o=Math.min(o,.5*r),s=Math.min(s,.5*i),this.shape=(new X).M(e+o,n).L(e+r-o,n).A(o,s,0,0,1,e+r,n+s).L(e+r,n+i-s).A(o,s,0,0,1,e+r-o,n+i).L(e+o,n+i).A(o,s,0,0,1,e,n+i-s).L(e,n+s).A(o,s,0,0,1,e+o,n).Z()):this.shape=(new X).M(e,n).L(e+r,n).L(e+r,n+i).L(e,n+i).Z():this.shape=new X},BA=function(A,t){aA.call(this,A,t);var e=this.getLength("cx",this.getVWidth(),0),n=this.getLength("cy",this.getVHeight(),0),r=this.getLength("r",this.getViewport(),0);this.shape=r>0?(new X).M(e+r,n).A(r,r,0,0,1,e-r,n).A(r,r,0,0,1,e+r,n).Z():new X},gA=function(A,t){aA.call(this,A,t);var e=this.getLength("cx",this.getVWidth(),0),n=this.getLength("cy",this.getVHeight(),0),r=this.getLength("rx",this.getVWidth(),0),i=this.getLength("ry",this.getVHeight(),0);this.shape=r>0&&i>0?(new X).M(e+r,n).A(r,i,0,0,1,e-r,n).A(r,i,0,0,1,e+r,n).Z():new X},lA=function(A,t){aA.call(this,A,t);var e=this.getLength("x1",this.getVWidth(),0),n=this.getLength("y1",this.getVHeight(),0),r=this.getLength("x2",this.getVWidth(),0),i=this.getLength("y2",this.getVHeight(),0);this.shape=(new X).M(e,n).L(r,i)},uA=function(A,t){aA.call(this,A,t);var e=this.getNumberList("points");this.shape=new X;for(var n=0;n<e.length-1;n+=2)0===n?this.shape.M(e[n],e[n+1]):this.shape.L(e[n],e[n+1]);e.error&&YA("SvgElemPolygon: unexpected string "+e.error),e.length%2==1&&YA("SvgElemPolyline: uneven number of coordinates")},wA=function(A,t){aA.call(this,A,t);var e=this.getNumberList("points");this.shape=new X;for(var n=0;n<e.length-1;n+=2)0===n?this.shape.M(e[n],e[n+1]):this.shape.L(e[n],e[n+1]);this.shape.Z(),e.error&&YA("SvgElemPolygon: unexpected string "+e.error),e.length%2==1&&YA("SvgElemPolygon: uneven number of coordinates")},hA=function(A,t){aA.call(this,A,t),this.shape=(new X).path(this.attr("d"));var e=this.getLength("pathLength",this.getViewport());this.pathLength=e>0?e:void 0,this.dashScale=void 0!==this.pathLength?this.shape.totalLength/this.pathLength:1},EA=function(t,e){q.call(this,t,e);var n=this.getLength("markerWidth",this.getParentVWidth(),3),r=this.getLength("markerHeight",this.getParentVHeight(),3),i=this.getViewbox("viewBox",[0,0,n,r]);this.getVWidth=function(){return i[2]},this.getVHeight=function(){return i[3]},this.drawMarker=function(t,e,o,s){A.save();var a=this.attr("orient"),c=this.attr("markerUnits"),B="auto"===a?o[2]:(parseFloat(a)||0)*Math.PI/180,w="userSpaceOnUse"===c?1:s;A.transform(Math.cos(B)*w,Math.sin(B)*w,-Math.sin(B)*w,Math.cos(B)*w,o[0],o[1]);var h,E=this.getLength("refX",this.getVWidth(),0),f=this.getLength("refY",this.getVHeight(),0),Q=P(this.attr("preserveAspectRatio"),n,r,i[2],i[3],.5);"hidden"===this.get("overflow")&&A.rect(Q[0]*(i[0]+i[2]/2-E)-n/2,Q[3]*(i[1]+i[3]/2-f)-r/2,n,r).clip(),A.transform.apply(A,Q),A.translate(-E,-f),this.get("opacity")<1&&!t&&(h=g(m())),this.drawChildren(t,e),h&&(l(h),A.fillOpacity(this.get("opacity")),u(h)),A.restore()}},fA=function(t,e){q.call(this,t,e),this.useMask=function(t){var e=g(m());A.save(),"objectBoundingBox"===this.attr("clipPathUnits")&&A.transform(t[2]-t[0],0,0,t[3]-t[1],t[0],t[1]),this.clip(),this.drawChildren(!0,!1),A.restore(),l(e),w(e,!0)}},QA=function(t,e){q.call(this,t,e),this.useMask=function(t){var e,n,r,i,o=g(m());A.save(),"userSpaceOnUse"===this.attr("maskUnits")?(e=this.getLength("x",this.getVWidth(),-.1*(t[2]-t[0])+t[0]),n=this.getLength("y",this.getVHeight(),-.1*(t[3]-t[1])+t[1]),r=this.getLength("width",this.getVWidth(),1.2*(t[2]-t[0])),i=this.getLength("height",this.getVHeight(),1.2*(t[3]-t[1]))):(e=this.getLength("x",this.getVWidth(),-.1)*(t[2]-t[0])+t[0],n=this.getLength("y",this.getVHeight(),-.1)*(t[3]-t[1])+t[1],r=this.getLength("width",this.getVWidth(),1.2)*(t[2]-t[0]),i=this.getLength("height",this.getVHeight(),1.2)*(t[3]-t[1])),A.rect(e,n,r,i).clip(),"objectBoundingBox"===this.attr("maskContentUnits")&&A.transform(t[2]-t[0],0,0,t[3]-t[1],t[0],t[1]),this.clip(),this.drawChildren(!1,!0),A.restore(),l(o),w(o,!0)}},dA=function(t,e){_.call(this,t,e),this.allowedChildren=["tspan","#text","#cdata-section","a"],this.isText=!0,this.getBoundingShape=function(){for(var A=new X,t=0;t<this._pos.length;t++){var e=this._pos[t];if(!e.hidden){var n=e.ascent*Math.sin(e.rotate),r=-e.ascent*Math.cos(e.rotate),i=e.descent*Math.sin(e.rotate),o=-e.descent*Math.cos(e.rotate),s=e.width*Math.cos(e.rotate),a=e.width*Math.sin(e.rotate);A.M(e.x+n,e.y+r).L(e.x+n+s,e.y+r+a).M(e.x+i+s,e.y+o+a).L(e.x+i,e.y+o)}}return A},this.drawTextInDocument=function(t,e){!this.link||t||e||this.addLink(),"underline"===this.get("text-decoration")&&this.decorate(.05*this._font.size,-.075*this._font.size,t,e),"overline"===this.get("text-decoration")&&this.decorate(.05*this._font.size,L(this._font.font,this._font.size)+.075*this._font.size,t,e);var n=this.getFill(t,e),r=this.getStroke(t,e),i=this.get("stroke-width");this._font.fauxBold&&(r?i+=.03*this._font.size:(r=n,i=.03*this._font.size));for(var o,s,a,c,B,g,l,u,w,h=this.getChildren(),E=0;E<h.length;E++){var C=h[E];switch(C.name){case"tspan":case"textPath":case"a":"none"!==C.get("display")&&C.drawTextInDocument(t,e);break;case"#text":case"#cdata-section":if("hidden"===this.get("visibility"))continue;if(n||r||t){n&&Q(n),r&&i&&(d(r),A.lineWidth(i).miterLimit(this.get("stroke-miterlimit")).lineJoin(this.get("stroke-linejoin")).lineCap(this.get("stroke-linecap")).dash(this.get("stroke-dasharray"),{phase:this.get("stroke-dashoffset")})),u=this._font.font,w=this._font.size,A.page.fonts[u.id]||(A.page.fonts[u.id]=u.ref()),A.addContent("BT").addContent("/"+u.id+" "+w+" Tf"),f(!!n,!!r);for(var M=0,I=C._pos;M<I.length;M++)if(!I[M].hidden&&S(I[M].width,0)){var p=Math.cos(I[M].rotate),D=Math.sin(I[M].rotate),y=this._font.fauxItalic?-.25:0;s=p*I[M].scale,a=D*I[M].scale,c=p*y-D,B=D*y+p,g=I[M].x,l=I[M].y,A.addContent(x(s)+" "+x(a)+" "+x(-c)+" "+x(-B)+" "+x(g)+" "+x(l)+" Tm"),o=I[M].glyph,A.addContent("<"+o+"> Tj")}A.addContent("ET")}}}"line-through"===this.get("text-decoration")&&this.decorate(.05*this._font.size,.5*(L(this._font.font,this._font.size)+J(this._font.font,this._font.size)),t,e)},this.decorate=function(t,e,n,r){var i=this.getFill(n,r),o=this.getStroke(n,r);i&&Q(i),o&&(d(o),A.lineWidth(this.get("stroke-width")).miterLimit(this.get("stroke-miterlimit")).lineJoin(this.get("stroke-linejoin")).lineCap(this.get("stroke-linecap")).dash(this.get("stroke-dasharray"),{phase:this.get("stroke-dashoffset")}));for(var s=0,a=this._pos;s<a.length;s++)if(!a[s].hidden&&S(a[s].width,0)){var c=(e+t/2)*Math.sin(a[s].rotate),B=-(e+t/2)*Math.cos(a[s].rotate),g=(e-t/2)*Math.sin(a[s].rotate),l=-(e-t/2)*Math.cos(a[s].rotate),u=a[s].width*Math.cos(a[s].rotate),w=a[s].width*Math.sin(a[s].rotate);(new X).M(a[s].x+c,a[s].y+B).L(a[s].x+c+u,a[s].y+B+w).L(a[s].x+g+u,a[s].y+l+w).L(a[s].x+g,a[s].y+l).Z().insertInDocument(),i&&o?A.fillAndStroke():i?A.fill():o&&A.stroke()}}},CA=function(A,t){this.name=A.nodeName,this.textContent=A.nodeValue},MA=function(A,t){dA.call(this,A,t)},IA=function(A,t){var e;if(dA.call(this,A,t),(e=this.attr("path"))&&""!==e.trim()){var n=this.getLength("pathLength",this.getViewport());this.pathObject=(new X).path(e),this.pathLength=n>0?n:this.pathObject.totalLength,this.pathScale=this.pathObject.totalLength/this.pathLength}else if((e=this.getUrl("href")||this.getUrl("xlink:href"))&&"path"===e.nodeName){var r=new hA(e,this);this.pathObject=r.shape.clone().transform(r.get("transform")),this.pathLength=this.chooseValue(r.pathLength,this.pathObject.totalLength),this.pathScale=this.pathObject.totalLength/this.pathLength}},pA=function(t,e){dA.call(this,t,e),this.allowedChildren=["textPath","tspan","#text","#cdata-section","a"],function(e){var n,r,i="",o=t.textContent,s=[],a=[],c=0,B=0;function g(){if(a.length)for(var A=a[a.length-1],t=a[0],e=A.x+A.width-t.x,i={startltr:0,middleltr:.5,endltr:1,startrtl:1,middlertl:.5,endrtl:0}[n+r]*e||0,o=0;o<a.length;o++)a[o].x-=i;a=[]}function l(A){var t=A.pathObject,e=A.pathLength,n=A.pathScale;if(t)for(var r=A.getLength("startOffset",e,0),i=0;i<A._pos.length;i++){var o=r+A._pos[i].x+.5*A._pos[i].width;if(o>e||o<0)A._pos[i].hidden=!0;else{var s=t.getPointAtLength(o*n);S(n,1)&&(A._pos[i].scale*=n,A._pos[i].width*=n),A._pos[i].x=s[0]-.5*A._pos[i].width*Math.cos(s[2])-A._pos[i].y*Math.sin(s[2]),A._pos[i].y=s[1]-.5*A._pos[i].width*Math.sin(s[2])+A._pos[i].y*Math.cos(s[2]),A._pos[i].rotate=s[2]+A._pos[i].rotate,A._pos[i].continuous=!1}}else for(var a=0;a<A._pos.length;a++)A._pos[a].hidden=!0}!function t(e,l){e._x=k(e.getLengthList("x",e.getVWidth()),l?l._x.slice(l._pos.length):[]),e._y=k(e.getLengthList("y",e.getVHeight()),l?l._y.slice(l._pos.length):[]),e._dx=k(e.getLengthList("dx",e.getVWidth()),l?l._dx.slice(l._pos.length):[]),e._dy=k(e.getLengthList("dy",e.getVHeight()),l?l._dy.slice(l._pos.length):[]),e._rot=k(e.getNumberList("rotate"),l?l._rot.slice(l._pos.length):[]),e._defRot=e.chooseValue(e._rot[e._rot.length-1],l&&l._defRot,0),"textPath"===e.name&&(e._y=[]);var u={fauxItalic:!1,fauxBold:!1},w=bA(e.get("font-family"),"bold"===e.get("font-weight"),"italic"===e.get("font-style"),u);try{A.font(w)}catch(A){YA('SVGElemText: failed to open font "'+w+'" in PDFKit')}e._pos=[],e._index=0,e._font={font:A._font,size:e.get("font-size"),fauxItalic:u.fauxItalic,fauxBold:u.fauxBold};var h=e.getLength("textLength",e.getVWidth(),void 0),E="spacingAndGlyphs"===e.attr("lengthAdjust"),f=e.get("word-spacing"),Q=e.get("letter-spacing"),d=e.get("text-anchor"),C=e.get("direction"),M=function(A,t,e,n){var r,i;switch(e){case"middle":r=.5*function(A,t){return(A.xHeight||.5*(A.ascender-A.descender))*t/1e3}(A,t);break;case"central":r=.5*(J(A,t)+L(A,t));break;case"after-edge":case"text-after-edge":r=J(A,t);break;case"alphabetic":case"auto":case"baseline":default:r=0;break;case"mathematical":r=.5*L(A,t);break;case"hanging":r=.8*L(A,t);break;case"before-edge":case"text-before-edge":r=L(A,t)}switch(n){case"baseline":i=0;break;case"super":i=.6*t;break;case"sub":i=-.6*t;break;default:i=n}return r-i}(e._font.font,e._font.size,e.get("alignment-baseline")||e.get("dominant-baseline"),e.get("baseline-shift"));"textPath"===e.name&&(g(),c=B=0);for(var I=e.getChildren(),p=0;p<I.length;p++){var D=I[p];switch(D.name){case"tspan":case"textPath":case"a":t(D,e);break;case"#text":case"#cdata-section":var y,v=D.textContent,m=v;D._font=e._font,D._pos=[],o=o.substring(v.length),"preserve"===e.get("xml:space")?m=m.replace(/[\s]/g," "):(m=m.replace(/[\s]+/g," "),i.match(/[\s]$|^$/)&&(m=m.replace(/^[\s]/,"")),o.match(/^[\s]*$/)&&(m=m.replace(/[\s]$/,""))),i+=v,y=0===f?[m]:m.split(/(\s)/);for(var F=0;F<y.length;F++){for(var Y=j(e._font.font,e._font.size,y[F]),b=0;b<Y.length;b++){var z=e._index,U=e._x[z],S=e._y[z],x=e._dx[z],T=e._dy[z],P=e._rot[z],N=!(0===F&&0===b);void 0!==U&&(N=!1,g(),c=U),void 0!==S&&(N=!1,g(),B=S),void 0!==x&&(N=!1,c+=x),void 0!==T&&(N=!1,B+=T),void 0===P&&0===e._defRot||(N=!1);var R={glyph:Y[b].glyph,rotate:Math.PI/180*e.chooseValue(P,e._defRot),x:c+Y[b].xOffset,y:B+M+Y[b].yOffset,width:Y[b].width,ascent:L(e._font.font,e._font.size),descent:J(e._font.font,e._font.size),scale:1,hidden:!1,continuous:N};a.push(R),D._pos.push(R),e._pos.push(R),e._index+=Y[b].unicode.length,1===a.length&&(n=d,r=C),c+=Y[b].xAdvance+Q,B+=Y[b].yAdvance}" "===y[F]&&(c+=f)}break;default:o=o.substring(D.textContent.length)}}if(h&&e._pos.length&&function(A,t,e){var n=A[0],r=A[A.length-1],i=n.x,o=r.x+r.width;if(e){var s=t/(o-i);if(s>0&&s<1/0)for(var a=0;a<A.length;a++)A[a].x=i+s*(A[a].x-i),A[a].scale*=s,A[a].width*=s}else if(A.length>=2)for(var B=(t-(o-i))/(A.length-1),g=0;g<A.length;g++)A[g].x+=g*B;c+=t-(o-i)}(e._pos,h,E),"textPath"!==e.name&&"text"!==e.name||g(),"textPath"===e.name){s.push(e);var G=e.pathObject;G&&(c=G.endPoint[0],B=G.endPoint[1])}l&&(l._pos=l._pos.concat(e._pos),l._index+=e._index)}(e,null);for(var u=0;u<s.length;u++)l(s[u])}(this),this.getTransformation=function(){return this.get("transform")},this.drawInDocument=function(t,e){var n;A.save(),this.transform(),this.clip(),this.mask()&&(n=g(m())),this.drawTextInDocument(t,e),n&&(l(n),u(n)),A.restore()}},DA=(r=r||{}).assumePt?1:.75,yA=(r.width||A.page.width)/DA,vA=(r.height||A.page.height)/DA,mA=r.preserveAspectRatio||null,FA=r.useCSS&&"undefined"!=typeof SVGElement&&t instanceof SVGElement&&"function"==typeof getComputedStyle,YA=r.warningCallback,bA=r.fontCallback,zA=r.imageCallback,UA=r.colorCallback,SA=r.documentCallback,xA=Math.ceil(Math.max(1,r.precision))||3,TA=[],PA={},NA=[],RA=[];if("function"!=typeof YA&&(YA=function(A){void 0!==typeof console&&console.warn}),"function"!=typeof bA&&(bA=function(t,e,n,r){if(e&&n){if(A._registeredFonts.hasOwnProperty(t+"-BoldItalic"))return t+"-BoldItalic";if(A._registeredFonts.hasOwnProperty(t+"-Italic"))return r.fauxBold=!0,t+"-Italic";if(A._registeredFonts.hasOwnProperty(t+"-Bold"))return r.fauxItalic=!0,t+"-Bold";if(A._registeredFonts.hasOwnProperty(t))return r.fauxBold=!0,r.fauxItalic=!0,t}if(e&&!n){if(A._registeredFonts.hasOwnProperty(t+"-Bold"))return t+"-Bold";if(A._registeredFonts.hasOwnProperty(t))return r.fauxBold=!0,t}if(!e&&n){if(A._registeredFonts.hasOwnProperty(t+"-Italic"))return t+"-Italic";if(A._registeredFonts.hasOwnProperty(t))return r.fauxItalic=!0,t}if(!e&&!n&&A._registeredFonts.hasOwnProperty(t))return t;if(t.match(/(?:^|,)\s*serif\s*$/)){if(e&&n)return"Times-BoldItalic";if(e&&!n)return"Times-Bold";if(!e&&n)return"Times-Italic";if(!e&&!n)return"Times-Roman"}else if(t.match(/(?:^|,)\s*monospace\s*$/)){if(e&&n)return"Courier-BoldOblique";if(e&&!n)return"Courier-Bold";if(!e&&n)return"Courier-Oblique";if(!e&&!n)return"Courier"}else{if(t.match(/(?:^|,)\s*sans-serif\s*$/),e&&n)return"Helvetica-BoldOblique";if(e&&!n)return"Helvetica-Bold";if(!e&&n)return"Helvetica-Oblique";if(!e&&!n)return"Helvetica"}}),"function"!=typeof zA&&(zA=function(A){return A.replace(/\s+/g,"")}),"function"!=typeof UA)UA=null;else for(var GA in o){var HA=UA(o[GA]);o[GA][0]=HA[0],o[GA][1]=HA[1]}if("function"!=typeof SA&&(SA=null),"string"==typeof t&&(t=C(t)),t){for(var kA=t.getElementsByTagName("style"),LA=0;LA<kA.length;LA++)RA=RA.concat(G(kA[LA].textContent));var JA=O(t,null);if("function"==typeof JA.drawInDocument){r.useCSS&&!FA&&YA("SVGtoPDF: useCSS option can only be used for SVG *elements* in compatible browsers");var jA=A._fillColor;A.save().translate(e||0,n||0).scale(DA),JA.drawInDocument();for(var OA=0;OA<NA.length;OA++)A.page.annotations.push(NA[OA]);A.restore(),A._fillColor=jA}else YA("SVGtoPDF: this element can't be rendered directly: "+t.nodeName)}else YA("SVGtoPDF: the input does not look like a valid SVG")})},9742:function(A,t){"use strict";t.byteLength=function(A){var t=s(A),e=t[0],n=t[1];return 3*(e+n)/4-n},t.toByteArray=function(A){var t,e,i=s(A),o=i[0],a=i[1],c=new r(function(A,t,e){return 3*(t+e)/4-e}(0,o,a)),B=0,g=a>0?o-4:o;for(e=0;e<g;e+=4)t=n[A.charCodeAt(e)]<<18|n[A.charCodeAt(e+1)]<<12|n[A.charCodeAt(e+2)]<<6|n[A.charCodeAt(e+3)],c[B++]=t>>16&255,c[B++]=t>>8&255,c[B++]=255&t;return 2===a&&(t=n[A.charCodeAt(e)]<<2|n[A.charCodeAt(e+1)]>>4,c[B++]=255&t),1===a&&(t=n[A.charCodeAt(e)]<<10|n[A.charCodeAt(e+1)]<<4|n[A.charCodeAt(e+2)]>>2,c[B++]=t>>8&255,c[B++]=255&t),c},t.fromByteArray=function(A){for(var t,n=A.length,r=n%3,i=[],o=16383,s=0,c=n-r;s<c;s+=o)i.push(a(A,s,s+o>c?c:s+o));return 1===r?(t=A[n-1],i.push(e[t>>2]+e[t<<4&63]+"==")):2===r&&(t=(A[n-2]<<8)+A[n-1],i.push(e[t>>10]+e[t>>4&63]+e[t<<2&63]+"=")),i.join("")};for(var e=[],n=[],r="undefined"!=typeof Uint8Array?Uint8Array:Array,i="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",o=0;o<64;++o)e[o]=i[o],n[i.charCodeAt(o)]=o;function s(A){var t=A.length;if(t%4>0)throw new Error("Invalid string. Length must be a multiple of 4");var e=A.indexOf("=");return-1===e&&(e=t),[e,e===t?0:4-e%4]}function a(A,t,n){for(var r,i,o=[],s=t;s<n;s+=3)r=(A[s]<<16&16711680)+(A[s+1]<<8&65280)+(255&A[s+2]),o.push(e[(i=r)>>18&63]+e[i>>12&63]+e[i>>6&63]+e[63&i]);return o.join("")}n["-".charCodeAt(0)]=62,n["_".charCodeAt(0)]=63},4181:function(A){var t=4096,e=new Uint32Array([0,1,3,7,15,31,63,127,255,511,1023,2047,4095,8191,16383,32767,65535,131071,262143,524287,1048575,2097151,4194303,8388607,16777215]);function n(A){this.buf_=new Uint8Array(8224),this.input_=A,this.reset()}n.READ_SIZE=t,n.IBUF_MASK=8191,n.prototype.reset=function(){this.buf_ptr_=0,this.val_=0,this.pos_=0,this.bit_pos_=0,this.bit_end_pos_=0,this.eos_=0,this.readMoreInput();for(var A=0;A<4;A++)this.val_|=this.buf_[this.pos_]<<8*A,++this.pos_;return this.bit_end_pos_>0},n.prototype.readMoreInput=function(){if(!(this.bit_end_pos_>256))if(this.eos_){if(this.bit_pos_>this.bit_end_pos_)throw new Error("Unexpected end of input "+this.bit_pos_+" "+this.bit_end_pos_)}else{var A=this.buf_ptr_,e=this.input_.read(this.buf_,A,t);if(e<0)throw new Error("Unexpected end of input");if(e<t){this.eos_=1;for(var n=0;n<32;n++)this.buf_[A+e+n]=0}if(0===A){for(n=0;n<32;n++)this.buf_[8192+n]=this.buf_[n];this.buf_ptr_=t}else this.buf_ptr_=0;this.bit_end_pos_+=e<<3}},n.prototype.fillBitWindow=function(){for(;this.bit_pos_>=8;)this.val_>>>=8,this.val_|=this.buf_[8191&this.pos_]<<24,++this.pos_,this.bit_pos_=this.bit_pos_-8>>>0,this.bit_end_pos_=this.bit_end_pos_-8>>>0},n.prototype.readBits=function(A){32-this.bit_pos_<A&&this.fillBitWindow();var t=this.val_>>>this.bit_pos_&e[A];return this.bit_pos_+=A,t},A.exports=n},7080:function(A,t){t.lookup=new Uint8Array([0,0,0,0,0,0,0,0,0,4,4,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,12,16,12,12,20,12,16,24,28,12,12,32,12,36,12,44,44,44,44,44,44,44,44,44,44,32,32,24,40,28,12,12,48,52,52,52,48,52,52,52,48,52,52,52,52,52,48,52,52,52,52,52,48,52,52,52,52,52,24,12,28,12,12,12,56,60,60,60,56,60,60,60,56,60,60,60,60,60,56,60,60,60,60,60,56,60,60,60,60,60,24,12,28,12,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,0,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,40,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,6,6,6,6,7,7,7,7,8,8,8,8,9,9,9,9,10,10,10,10,11,11,11,11,12,12,12,12,13,13,13,13,14,14,14,14,15,15,15,15,16,16,16,16,17,17,17,17,18,18,18,18,19,19,19,19,20,20,20,20,21,21,21,21,22,22,22,22,23,23,23,23,24,24,24,24,25,25,25,25,26,26,26,26,27,27,27,27,28,28,28,28,29,29,29,29,30,30,30,30,31,31,31,31,32,32,32,32,33,33,33,33,34,34,34,34,35,35,35,35,36,36,36,36,37,37,37,37,38,38,38,38,39,39,39,39,40,40,40,40,41,41,41,41,42,42,42,42,43,43,43,43,44,44,44,44,45,45,45,45,46,46,46,46,47,47,47,47,48,48,48,48,49,49,49,49,50,50,50,50,51,51,51,51,52,52,52,52,53,53,53,53,54,54,54,54,55,55,55,55,56,56,56,56,57,57,57,57,58,58,58,58,59,59,59,59,60,60,60,60,61,61,61,61,62,62,62,62,63,63,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]),t.lookupOffsets=new Uint16Array([1024,1536,1280,1536,0,256,768,512])},6450:function(A,t,e){var n=e(6154).g,r=e(6154).j,i=e(4181),o=e(5139),s=e(966).h,a=e(966).g,c=e(7080),B=e(8435),g=e(2973),l=1080,u=new Uint8Array([1,2,3,4,0,5,17,6,16,7,8,9,10,11,12,13,14,15]),w=new Uint8Array([3,2,1,0,3,3,3,3,3,3,2,2,2,2,2,2]),h=new Int8Array([0,0,0,0,-1,1,-2,2,-3,3,-1,1,-2,2,-3,3]),E=new Uint16Array([256,402,436,468,500,534,566,598,630,662,694,726,758,790,822,854,886,920,952,984,1016,1048,1080]);function f(A){var t;return 0===A.readBits(1)?16:(t=A.readBits(3))>0?17+t:(t=A.readBits(3))>0?8+t:17}function Q(A){if(A.readBits(1)){var t=A.readBits(3);return 0===t?1:A.readBits(t)+(1<<t)}return 0}function d(){this.meta_block_length=0,this.input_end=0,this.is_uncompressed=0,this.is_metadata=!1}function C(A){var t,e,n,r=new d;if(r.input_end=A.readBits(1),r.input_end&&A.readBits(1))return r;if(7===(t=A.readBits(2)+4)){if(r.is_metadata=!0,0!==A.readBits(1))throw new Error("Invalid reserved bit");if(0===(e=A.readBits(2)))return r;for(n=0;n<e;n++){var i=A.readBits(8);if(n+1===e&&e>1&&0===i)throw new Error("Invalid size byte");r.meta_block_length|=i<<8*n}}else for(n=0;n<t;++n){var o=A.readBits(4);if(n+1===t&&t>4&&0===o)throw new Error("Invalid size nibble");r.meta_block_length|=o<<4*n}return++r.meta_block_length,r.input_end||r.is_metadata||(r.is_uncompressed=A.readBits(1)),r}function M(A,t,e){var n;return e.fillBitWindow(),(n=A[t+=e.val_>>>e.bit_pos_&255].bits-8)>0&&(e.bit_pos_+=8,t+=A[t].value,t+=e.val_>>>e.bit_pos_&(1<<n)-1),e.bit_pos_+=A[t].bits,A[t].value}function I(A,t,e,n){var r,i,o=new Uint8Array(A);if(n.readMoreInput(),1===(i=n.readBits(2))){for(var c=A-1,B=0,g=new Int32Array(4),l=n.readBits(2)+1;c;)c>>=1,++B;for(w=0;w<l;++w)g[w]=n.readBits(B)%A,o[g[w]]=2;switch(o[g[0]]=1,l){case 1:break;case 3:if(g[0]===g[1]||g[0]===g[2]||g[1]===g[2])throw new Error("[ReadHuffmanCode] invalid symbols");break;case 2:if(g[0]===g[1])throw new Error("[ReadHuffmanCode] invalid symbols");o[g[1]]=1;break;case 4:if(g[0]===g[1]||g[0]===g[2]||g[0]===g[3]||g[1]===g[2]||g[1]===g[3]||g[2]===g[3])throw new Error("[ReadHuffmanCode] invalid symbols");n.readBits(1)?(o[g[2]]=3,o[g[3]]=3):o[g[0]]=2}}else{var w,h=new Uint8Array(18),E=32,f=0,Q=[new s(2,0),new s(2,4),new s(2,3),new s(3,2),new s(2,0),new s(2,4),new s(2,3),new s(4,1),new s(2,0),new s(2,4),new s(2,3),new s(3,2),new s(2,0),new s(2,4),new s(2,3),new s(4,5)];for(w=i;w<18&&E>0;++w){var d,C=u[w],M=0;n.fillBitWindow(),M+=n.val_>>>n.bit_pos_&15,n.bit_pos_+=Q[M].bits,d=Q[M].value,h[C]=d,0!==d&&(E-=32>>d,++f)}if(1!==f&&0!==E)throw new Error("[ReadHuffmanCode] invalid num_codes or space");!function(A,t,e,n){for(var r=0,i=8,o=0,c=0,B=32768,g=[],l=0;l<32;l++)g.push(new s(0,0));for(a(g,0,5,A,18);r<t&&B>0;){var u,w=0;if(n.readMoreInput(),n.fillBitWindow(),w+=n.val_>>>n.bit_pos_&31,n.bit_pos_+=g[w].bits,(u=255&g[w].value)<16)o=0,e[r++]=u,0!==u&&(i=u,B-=32768>>u);else{var h,E,f=u-14,Q=0;if(16===u&&(Q=i),c!==Q&&(o=0,c=Q),h=o,o>0&&(o-=2,o<<=f),r+(E=(o+=n.readBits(f)+3)-h)>t)throw new Error("[ReadHuffmanCodeLengths] symbol + repeat_delta > num_symbols");for(var d=0;d<E;d++)e[r+d]=c;r+=E,0!==c&&(B-=E<<15-c)}}if(0!==B)throw new Error("[ReadHuffmanCodeLengths] space = "+B);for(;r<t;r++)e[r]=0}(h,A,o,n)}if(0===(r=a(t,e,8,o,A)))throw new Error("[ReadHuffmanCode] BuildHuffmanTable failed: ");return r}function p(A,t,e){var n,r;return n=M(A,t,e),r=B.kBlockLengthPrefixCode[n].nbits,B.kBlockLengthPrefixCode[n].offset+e.readBits(r)}function D(A,t,e){var n;return A<16?(e+=w[A],n=t[e&=3]+h[A]):n=A-16+1,n}function y(A,t){for(var e=A[t],n=t;n;--n)A[n]=A[n-1];A[0]=e}function v(A,t){this.alphabet_size=A,this.num_htrees=t,this.codes=new Array(t+t*E[A+31>>>5]),this.htrees=new Uint32Array(t)}function m(A,t){var e,n,r={num_htrees:null,context_map:null},i=0;t.readMoreInput();var o=r.num_htrees=Q(t)+1,a=r.context_map=new Uint8Array(A);if(o<=1)return r;for(t.readBits(1)&&(i=t.readBits(4)+1),e=[],n=0;n<l;n++)e[n]=new s(0,0);for(I(o+i,e,0,t),n=0;n<A;){var c;if(t.readMoreInput(),0===(c=M(e,0,t)))a[n]=0,++n;else if(c<=i)for(var B=1+(1<<c)+t.readBits(c);--B;){if(n>=A)throw new Error("[DecodeContextMap] i >= context_map_size");a[n]=0,++n}else a[n]=c-i,++n}return t.readBits(1)&&function(A,t){var e,n=new Uint8Array(256);for(e=0;e<256;++e)n[e]=e;for(e=0;e<t;++e){var r=A[e];A[e]=n[r],r&&y(n,r)}}(a,A),r}function F(A,t,e,n,r,i,o){var s,a=2*e,c=e,B=M(t,e*l,o);(s=0===B?r[a+(1&i[c])]:1===B?r[a+(i[c]-1&1)]+1:B-2)>=A&&(s-=A),n[e]=s,r[a+(1&i[c])]=s,++i[c]}function Y(A,t,e,n,r,o){var s,a=r+1,c=e&r,B=o.pos_&i.IBUF_MASK;if(t<8||o.bit_pos_+(t<<3)<o.bit_end_pos_)for(;t-- >0;)o.readMoreInput(),n[c++]=o.readBits(8),c===a&&(A.write(n,a),c=0);else{if(o.bit_end_pos_<32)throw new Error("[CopyUncompressedBlockToOutput] br.bit_end_pos_ < 32");for(;o.bit_pos_<32;)n[c]=o.val_>>>o.bit_pos_,o.bit_pos_+=8,++c,--t;if(B+(s=o.bit_end_pos_-o.bit_pos_>>3)>i.IBUF_MASK){for(var g=i.IBUF_MASK+1-B,l=0;l<g;l++)n[c+l]=o.buf_[B+l];s-=g,c+=g,t-=g,B=0}for(l=0;l<s;l++)n[c+l]=o.buf_[B+l];if(t-=s,(c+=s)>=a)for(A.write(n,a),c-=a,l=0;l<c;l++)n[l]=n[a+l];for(;c+t>=a;){if(s=a-c,o.input_.read(n,c,s)<s)throw new Error("[CopyUncompressedBlockToOutput] not enough bytes");A.write(n,a),t-=s,c=0}if(o.input_.read(n,c,t)<t)throw new Error("[CopyUncompressedBlockToOutput] not enough bytes");o.reset()}}function b(A){var t=A.bit_pos_+7&-8;return 0==A.readBits(t-A.bit_pos_)}function z(A){var t=new n(A),e=new i(t);return f(e),C(e).meta_block_length}function U(A,t){var e,n,r,a,u,w,h,E,d,y,z=0,U=0,S=0,x=[16,15,11,4],T=0,P=0,N=0,R=[new v(0,0),new v(0,0),new v(0,0)],G=128+i.READ_SIZE;r=(1<<(n=f(y=new i(A))))-16,u=(a=1<<n)-1,w=new Uint8Array(a+G+o.maxDictionaryWordLength),h=a,E=[],d=[];for(var H=0;H<3240;H++)E[H]=new s(0,0),d[H]=new s(0,0);for(;!U;){var k,L,J,j,O,W,K,V,X,Z,_,q=0,$=[1<<28,1<<28,1<<28],AA=[0],tA=[1,1,1],eA=[0,1,0,1,0,1],nA=[0],rA=null,iA=null,oA=0,sA=null,aA=0,cA=0,BA=0;for(e=0;e<3;++e)R[e].codes=null,R[e].htrees=null;y.readMoreInput();var gA=C(y);if(z+(q=gA.meta_block_length)>t.buffer.length){var lA=new Uint8Array(z+q);lA.set(t.buffer),t.buffer=lA}if(U=gA.input_end,k=gA.is_uncompressed,gA.is_metadata)for(b(y);q>0;--q)y.readMoreInput(),y.readBits(8);else if(0!==q)if(k)y.bit_pos_=y.bit_pos_+7&-8,Y(t,q,z,w,u,y),z+=q;else{for(e=0;e<3;++e)tA[e]=Q(y)+1,tA[e]>=2&&(I(tA[e]+2,E,e*l,y),I(26,d,e*l,y),$[e]=p(d,e*l,y),nA[e]=1);for(y.readMoreInput(),j=(1<<(L=y.readBits(2)))-1,O=(J=16+(y.readBits(4)<<L))+(48<<L),rA=new Uint8Array(tA[0]),e=0;e<tA[0];++e)y.readMoreInput(),rA[e]=y.readBits(2)<<1;var uA=m(tA[0]<<6,y);K=uA.num_htrees,W=uA.context_map;var wA=m(tA[2]<<2,y);for(X=wA.num_htrees,V=wA.context_map,R[0]=new v(256,K),R[1]=new v(704,tA[1]),R[2]=new v(O,X),e=0;e<3;++e)R[e].decode(y);for(iA=0,sA=0,Z=rA[AA[0]],cA=c.lookupOffsets[Z],BA=c.lookupOffsets[Z+1],_=R[1].htrees[0];q>0;){var hA,EA,fA,QA,dA,CA,MA,IA,pA,DA,yA,vA;for(y.readMoreInput(),0===$[1]&&(F(tA[1],E,1,AA,eA,nA,y),$[1]=p(d,l,y),_=R[1].htrees[AA[1]]),--$[1],(EA=(hA=M(R[1].codes,_,y))>>6)>=2?(EA-=2,MA=-1):MA=0,fA=B.kInsertRangeLut[EA]+(hA>>3&7),QA=B.kCopyRangeLut[EA]+(7&hA),dA=B.kInsertLengthPrefixCode[fA].offset+y.readBits(B.kInsertLengthPrefixCode[fA].nbits),CA=B.kCopyLengthPrefixCode[QA].offset+y.readBits(B.kCopyLengthPrefixCode[QA].nbits),P=w[z-1&u],N=w[z-2&u],pA=0;pA<dA;++pA)y.readMoreInput(),0===$[0]&&(F(tA[0],E,0,AA,eA,nA,y),$[0]=p(d,0,y),iA=AA[0]<<6,Z=rA[AA[0]],cA=c.lookupOffsets[Z],BA=c.lookupOffsets[Z+1]),oA=W[iA+(c.lookup[cA+P]|c.lookup[BA+N])],--$[0],N=P,P=M(R[0].codes,R[0].htrees[oA],y),w[z&u]=P,(z&u)===u&&t.write(w,a),++z;if((q-=dA)<=0)break;if(MA<0&&(y.readMoreInput(),0===$[2]&&(F(tA[2],E,2,AA,eA,nA,y),$[2]=p(d,2160,y),sA=AA[2]<<2),--$[2],aA=V[sA+(255&(CA>4?3:CA-2))],(MA=M(R[2].codes,R[2].htrees[aA],y))>=J&&(vA=(MA-=J)&j,MA=J+((mA=(2+(1&(MA>>=L))<<(yA=1+(MA>>1)))-4)+y.readBits(yA)<<L)+vA)),(IA=D(MA,x,T))<0)throw new Error("[BrotliDecompress] invalid distance");if(DA=z&u,IA>(S=z<r&&S!==r?z:r)){if(!(CA>=o.minDictionaryWordLength&&CA<=o.maxDictionaryWordLength))throw new Error("Invalid backward reference. pos: "+z+" distance: "+IA+" len: "+CA+" bytes left: "+q);var mA=o.offsetsByLength[CA],FA=IA-S-1,YA=o.sizeBitsByLength[CA],bA=FA>>YA;if(mA+=(FA&(1<<YA)-1)*CA,!(bA<g.kNumTransforms))throw new Error("Invalid backward reference. pos: "+z+" distance: "+IA+" len: "+CA+" bytes left: "+q);var zA=g.transformDictionaryWord(w,DA,mA,CA,bA);if(z+=zA,q-=zA,(DA+=zA)>=h){t.write(w,a);for(var UA=0;UA<DA-h;UA++)w[UA]=w[h+UA]}}else{if(MA>0&&(x[3&T]=IA,++T),CA>q)throw new Error("Invalid backward reference. pos: "+z+" distance: "+IA+" len: "+CA+" bytes left: "+q);for(pA=0;pA<CA;++pA)w[z&u]=w[z-IA&u],(z&u)===u&&t.write(w,a),++z,--q}P=w[z-1&u],N=w[z-2&u]}z&=1073741823}}t.write(w,z&u)}v.prototype.decode=function(A){var t,e=0;for(t=0;t<this.num_htrees;++t)this.htrees[t]=e,e+=I(this.alphabet_size,this.codes,e,A)},t.BrotliDecompressBuffer=function(A,t){var e=new n(A);null==t&&(t=z(A));var i=new Uint8Array(t),o=new r(i);return U(e,o),o.pos<o.buffer.length&&(o.buffer=o.buffer.subarray(0,o.pos)),o.buffer},o.init()},5340:function(A,t,e){var n=e(9742);t.init=function(){return(0,e(6450).BrotliDecompressBuffer)(n.toByteArray(e(2722)))}},2722:function(A){A.exports=" "},5139:function(A,t,e){var n=e(5340);t.init=function(){t.dictionary=n.init()},t.offsetsByLength=new Uint32Array([0,0,0,0,0,4096,9216,21504,35840,44032,53248,63488,74752,87040,93696,100864,104704,106752,108928,113536,115968,118528,119872,121280,122016]),t.sizeBitsByLength=new Uint8Array([0,0,0,0,10,10,11,11,10,10,10,10,10,9,9,8,7,7,8,7,7,6,6,5,5]),t.minDictionaryWordLength=4,t.maxDictionaryWordLength=24},966:function(A,t){function e(A,t){this.bits=A,this.value=t}t.h=e;function n(A,t){for(var e=1<<t-1;A&e;)e>>=1;return(A&e-1)+e}function r(A,t,n,r,i){do{A[t+(r-=n)]=new e(i.bits,i.value)}while(r>0)}function i(A,t,e){for(var n=1<<t-e;t<15&&!((n-=A[t])<=0);)++t,n<<=1;return t-e}t.g=function(A,t,o,s,a){var c,B,g,l,u,w,h,E,f,Q,d=t,C=new Int32Array(16),M=new Int32Array(16);for(Q=new Int32Array(a),B=0;B<a;B++)C[s[B]]++;for(M[1]=0,c=1;c<15;c++)M[c+1]=M[c]+C[c];for(B=0;B<a;B++)0!==s[B]&&(Q[M[s[B]]++]=B);if(f=E=1<<(h=o),1===M[15]){for(g=0;g<f;++g)A[t+g]=new e(0,65535&Q[0]);return f}for(g=0,B=0,c=1,l=2;c<=o;++c,l<<=1)for(;C[c]>0;--C[c])r(A,t+g,l,E,new e(255&c,65535&Q[B++])),g=n(g,c);for(w=f-1,u=-1,c=o+1,l=2;c<=15;++c,l<<=1)for(;C[c]>0;--C[c])(g&w)!==u&&(t+=E,f+=E=1<<(h=i(C,c,o)),A[d+(u=g&w)]=new e(h+o&255,t-d-u&65535)),r(A,t+(g>>o),l,E,new e(c-o&255,65535&Q[B++])),g=n(g,c);return f}},8435:function(A,t){function e(A,t){this.offset=A,this.nbits=t}t.kBlockLengthPrefixCode=[new e(1,2),new e(5,2),new e(9,2),new e(13,2),new e(17,3),new e(25,3),new e(33,3),new e(41,3),new e(49,4),new e(65,4),new e(81,4),new e(97,4),new e(113,5),new e(145,5),new e(177,5),new e(209,5),new e(241,6),new e(305,6),new e(369,7),new e(497,8),new e(753,9),new e(1265,10),new e(2289,11),new e(4337,12),new e(8433,13),new e(16625,24)],t.kInsertLengthPrefixCode=[new e(0,0),new e(1,0),new e(2,0),new e(3,0),new e(4,0),new e(5,0),new e(6,1),new e(8,1),new e(10,2),new e(14,2),new e(18,3),new e(26,3),new e(34,4),new e(50,4),new e(66,5),new e(98,5),new e(130,6),new e(194,7),new e(322,8),new e(578,9),new e(1090,10),new e(2114,12),new e(6210,14),new e(22594,24)],t.kCopyLengthPrefixCode=[new e(2,0),new e(3,0),new e(4,0),new e(5,0),new e(6,0),new e(7,0),new e(8,0),new e(9,0),new e(10,1),new e(12,1),new e(14,2),new e(18,2),new e(22,3),new e(30,3),new e(38,4),new e(54,4),new e(70,5),new e(102,5),new e(134,6),new e(198,7),new e(326,8),new e(582,9),new e(1094,10),new e(2118,24)],t.kInsertRangeLut=[0,0,8,8,0,16,8,16,16],t.kCopyRangeLut=[0,8,0,8,16,0,16,8,16]},6154:function(A,t){function e(A){this.buffer=A,this.pos=0}function n(A){this.buffer=A,this.pos=0}e.prototype.read=function(A,t,e){this.pos+e>this.buffer.length&&(e=this.buffer.length-this.pos);for(var n=0;n<e;n++)A[t+n]=this.buffer[this.pos+n];return this.pos+=e,e},t.g=e,n.prototype.write=function(A,t){if(this.pos+t>this.buffer.length)throw new Error("Output buffer is not large enough");return this.buffer.set(A.subarray(0,t),this.pos),this.pos+=t,t},t.j=n},2973:function(A,t,e){var n=e(5139),r=10,i=11;function o(A,t,e){this.prefix=new Uint8Array(A.length),this.transform=t,this.suffix=new Uint8Array(e.length);for(var n=0;n<A.length;n++)this.prefix[n]=A.charCodeAt(n);for(n=0;n<e.length;n++)this.suffix[n]=e.charCodeAt(n)}var s=[new o("",0,""),new o("",0," "),new o(" ",0," "),new o("",12,""),new o("",r," "),new o("",0," the "),new o(" ",0,""),new o("s ",0," "),new o("",0," of "),new o("",r,""),new o("",0," and "),new o("",13,""),new o("",1,""),new o(", ",0," "),new o("",0,", "),new o(" ",r," "),new o("",0," in "),new o("",0," to "),new o("e ",0," "),new o("",0,'"'),new o("",0,"."),new o("",0,'">'),new o("",0,"\n"),new o("",3,""),new o("",0,"]"),new o("",0," for "),new o("",14,""),new o("",2,""),new o("",0," a "),new o("",0," that "),new o(" ",r,""),new o("",0,". "),new o(".",0,""),new o(" ",0,", "),new o("",15,""),new o("",0," with "),new o("",0,"'"),new o("",0," from "),new o("",0," by "),new o("",16,""),new o("",17,""),new o(" the ",0,""),new o("",4,""),new o("",0,". The "),new o("",i,""),new o("",0," on "),new o("",0," as "),new o("",0," is "),new o("",7,""),new o("",1,"ing "),new o("",0,"\n\t"),new o("",0,":"),new o(" ",0,". "),new o("",0,"ed "),new o("",20,""),new o("",18,""),new o("",6,""),new o("",0,"("),new o("",r,", "),new o("",8,""),new o("",0," at "),new o("",0,"ly "),new o(" the ",0," of "),new o("",5,""),new o("",9,""),new o(" ",r,", "),new o("",r,'"'),new o(".",0,"("),new o("",i," "),new o("",r,'">'),new o("",0,'="'),new o(" ",0,"."),new o(".com/",0,""),new o(" the ",0," of the "),new o("",r,"'"),new o("",0,". This "),new o("",0,","),new o(".",0," "),new o("",r,"("),new o("",r,"."),new o("",0," not "),new o(" ",0,'="'),new o("",0,"er "),new o(" ",i," "),new o("",0,"al "),new o(" ",i,""),new o("",0,"='"),new o("",i,'"'),new o("",r,". "),new o(" ",0,"("),new o("",0,"ful "),new o(" ",r,". "),new o("",0,"ive "),new o("",0,"less "),new o("",i,"'"),new o("",0,"est "),new o(" ",r,"."),new o("",i,'">'),new o(" ",0,"='"),new o("",r,","),new o("",0,"ize "),new o("",i,"."),new o("Â ",0,""),new o(" ",0,","),new o("",r,'="'),new o("",i,'="'),new o("",0,"ous "),new o("",i,", "),new o("",r,"='"),new o(" ",r,","),new o(" ",i,'="'),new o(" ",i,", "),new o("",i,","),new o("",i,"("),new o("",i,". "),new o(" ",i,"."),new o("",i,"='"),new o(" ",i,". "),new o(" ",r,'="'),new o(" ",i,"='"),new o(" ",r,"='")];function a(A,t){return A[t]<192?(A[t]>=97&&A[t]<=122&&(A[t]^=32),1):A[t]<224?(A[t+1]^=32,2):(A[t+2]^=5,3)}t.kTransforms=s,t.kNumTransforms=s.length,t.transformDictionaryWord=function(A,t,e,o,c){var B,g=s[c].prefix,l=s[c].suffix,u=s[c].transform,w=u<12?0:u-11,h=0,E=t;w>o&&(w=o);for(var f=0;f<g.length;)A[t++]=g[f++];for(e+=w,o-=w,u<=9&&(o-=u),h=0;h<o;h++)A[t++]=n.dictionary[e+h];if(B=t-o,u===r)a(A,B);else if(u===i)for(;o>0;){var Q=a(A,B);B+=Q,o-=Q}for(var d=0;d<l.length;)A[t++]=l[d++];return t-E}},7709:function(A,t,e){A.exports=e(6450).BrotliDecompressBuffer},4505:function(A,t,e){"use strict";var n=e(8823).Buffer,r=e(4155),i=e(9282),o=e(2292),s=e(405),a=e(7948),c=e(1619);for(var B in c)t[B]=c[B];function g(A){if("number"!=typeof A||A<t.DEFLATE||A>t.UNZIP)throw new TypeError("Bad argument");this.dictionary=null,this.err=0,this.flush=0,this.init_done=!1,this.level=0,this.memLevel=0,this.mode=A,this.strategy=0,this.windowBits=0,this.write_in_progress=!1,this.pending_close=!1,this.gzip_id_bytes_read=0}t.NONE=0,t.DEFLATE=1,t.INFLATE=2,t.GZIP=3,t.GUNZIP=4,t.DEFLATERAW=5,t.INFLATERAW=6,t.UNZIP=7,g.prototype.close=function(){this.write_in_progress?this.pending_close=!0:(this.pending_close=!1,i(this.init_done,"close before init"),i(this.mode<=t.UNZIP),this.mode===t.DEFLATE||this.mode===t.GZIP||this.mode===t.DEFLATERAW?s.deflateEnd(this.strm):this.mode!==t.INFLATE&&this.mode!==t.GUNZIP&&this.mode!==t.INFLATERAW&&this.mode!==t.UNZIP||a.inflateEnd(this.strm),this.mode=t.NONE,this.dictionary=null)},g.prototype.write=function(A,t,e,n,r,i,o){return this._write(!0,A,t,e,n,r,i,o)},g.prototype.writeSync=function(A,t,e,n,r,i,o){return this._write(!1,A,t,e,n,r,i,o)},g.prototype._write=function(A,e,o,s,a,c,B,g){if(i.equal(arguments.length,8),i(this.init_done,"write before init"),i(this.mode!==t.NONE,"already finalized"),i.equal(!1,this.write_in_progress,"write already in progress"),i.equal(!1,this.pending_close,"close is pending"),this.write_in_progress=!0,i.equal(!1,void 0===e,"must provide flush value"),this.write_in_progress=!0,e!==t.Z_NO_FLUSH&&e!==t.Z_PARTIAL_FLUSH&&e!==t.Z_SYNC_FLUSH&&e!==t.Z_FULL_FLUSH&&e!==t.Z_FINISH&&e!==t.Z_BLOCK)throw new Error("Invalid flush value");if(null==o&&(o=n.alloc(0),a=0,s=0),this.strm.avail_in=a,this.strm.input=o,this.strm.next_in=s,this.strm.avail_out=g,this.strm.output=c,this.strm.next_out=B,this.flush=e,!A)return this._process(),this._checkError()?this._afterSync():void 0;var l=this;return r.nextTick((function(){l._process(),l._after()})),this},g.prototype._afterSync=function(){var A=this.strm.avail_out,t=this.strm.avail_in;return this.write_in_progress=!1,[t,A]},g.prototype._process=function(){var A=null;switch(this.mode){case t.DEFLATE:case t.GZIP:case t.DEFLATERAW:this.err=s.deflate(this.strm,this.flush);break;case t.UNZIP:switch(this.strm.avail_in>0&&(A=this.strm.next_in),this.gzip_id_bytes_read){case 0:if(null===A)break;if(31!==this.strm.input[A]){this.mode=t.INFLATE;break}if(this.gzip_id_bytes_read=1,A++,1===this.strm.avail_in)break;case 1:if(null===A)break;139===this.strm.input[A]?(this.gzip_id_bytes_read=2,this.mode=t.GUNZIP):this.mode=t.INFLATE;break;default:throw new Error("invalid number of gzip magic number bytes read")}case t.INFLATE:case t.GUNZIP:case t.INFLATERAW:for(this.err=a.inflate(this.strm,this.flush),this.err===t.Z_NEED_DICT&&this.dictionary&&(this.err=a.inflateSetDictionary(this.strm,this.dictionary),this.err===t.Z_OK?this.err=a.inflate(this.strm,this.flush):this.err===t.Z_DATA_ERROR&&(this.err=t.Z_NEED_DICT));this.strm.avail_in>0&&this.mode===t.GUNZIP&&this.err===t.Z_STREAM_END&&0!==this.strm.next_in[0];)this.reset(),this.err=a.inflate(this.strm,this.flush);break;default:throw new Error("Unknown mode "+this.mode)}},g.prototype._checkError=function(){switch(this.err){case t.Z_OK:case t.Z_BUF_ERROR:if(0!==this.strm.avail_out&&this.flush===t.Z_FINISH)return this._error("unexpected end of file"),!1;break;case t.Z_STREAM_END:break;case t.Z_NEED_DICT:return null==this.dictionary?this._error("Missing dictionary"):this._error("Bad dictionary"),!1;default:return this._error("Zlib error"),!1}return!0},g.prototype._after=function(){if(this._checkError()){var A=this.strm.avail_out,t=this.strm.avail_in;this.write_in_progress=!1,this.callback(t,A),this.pending_close&&this.close()}},g.prototype._error=function(A){this.strm.msg&&(A=this.strm.msg),this.onerror(A,this.err),this.write_in_progress=!1,this.pending_close&&this.close()},g.prototype.init=function(A,e,n,r,o){i(4===arguments.length||5===arguments.length,"init(windowBits, level, memLevel, strategy, [dictionary])"),i(A>=8&&A<=15,"invalid windowBits"),i(e>=-1&&e<=9,"invalid compression level"),i(n>=1&&n<=9,"invalid memlevel"),i(r===t.Z_FILTERED||r===t.Z_HUFFMAN_ONLY||r===t.Z_RLE||r===t.Z_FIXED||r===t.Z_DEFAULT_STRATEGY,"invalid strategy"),this._init(e,A,n,r,o),this._setDictionary()},g.prototype.params=function(){throw new Error("deflateParams Not supported")},g.prototype.reset=function(){this._reset(),this._setDictionary()},g.prototype._init=function(A,e,n,r,i){switch(this.level=A,this.windowBits=e,this.memLevel=n,this.strategy=r,this.flush=t.Z_NO_FLUSH,this.err=t.Z_OK,this.mode!==t.GZIP&&this.mode!==t.GUNZIP||(this.windowBits+=16),this.mode===t.UNZIP&&(this.windowBits+=32),this.mode!==t.DEFLATERAW&&this.mode!==t.INFLATERAW||(this.windowBits=-1*this.windowBits),this.strm=new o,this.mode){case t.DEFLATE:case t.GZIP:case t.DEFLATERAW:this.err=s.deflateInit2(this.strm,this.level,t.Z_DEFLATED,this.windowBits,this.memLevel,this.strategy);break;case t.INFLATE:case t.GUNZIP:case t.INFLATERAW:case t.UNZIP:this.err=a.inflateInit2(this.strm,this.windowBits);break;default:throw new Error("Unknown mode "+this.mode)}this.err!==t.Z_OK&&this._error("Init error"),this.dictionary=i,this.write_in_progress=!1,this.init_done=!0},g.prototype._setDictionary=function(){if(null!=this.dictionary){switch(this.err=t.Z_OK,this.mode){case t.DEFLATE:case t.DEFLATERAW:this.err=s.deflateSetDictionary(this.strm,this.dictionary)}this.err!==t.Z_OK&&this._error("Failed to set dictionary")}},g.prototype._reset=function(){switch(this.err=t.Z_OK,this.mode){case t.DEFLATE:case t.DEFLATERAW:case t.GZIP:this.err=s.deflateReset(this.strm);break;case t.INFLATE:case t.INFLATERAW:case t.GUNZIP:this.err=a.inflateReset(this.strm)}this.err!==t.Z_OK&&this._error("Failed to reset stream")},t.Zlib=g},2635:function(A,t,e){"use strict";var n=e(4155),r=e(8823).Buffer,i=e(2830).Transform,o=e(4505),s=e(9539),a=e(9282).ok,c=e(8823).kMaxLength,B="Cannot create final Buffer. It would be larger than 0x"+c.toString(16)+" bytes";o.Z_MIN_WINDOWBITS=8,o.Z_MAX_WINDOWBITS=15,o.Z_DEFAULT_WINDOWBITS=15,o.Z_MIN_CHUNK=64,o.Z_MAX_CHUNK=1/0,o.Z_DEFAULT_CHUNK=16384,o.Z_MIN_MEMLEVEL=1,o.Z_MAX_MEMLEVEL=9,o.Z_DEFAULT_MEMLEVEL=8,o.Z_MIN_LEVEL=-1,o.Z_MAX_LEVEL=9,o.Z_DEFAULT_LEVEL=o.Z_DEFAULT_COMPRESSION;for(var g=Object.keys(o),l=0;l<g.length;l++){var u=g[l];u.match(/^Z/)&&Object.defineProperty(t,u,{enumerable:!0,value:o[u],writable:!1})}for(var w={Z_OK:o.Z_OK,Z_STREAM_END:o.Z_STREAM_END,Z_NEED_DICT:o.Z_NEED_DICT,Z_ERRNO:o.Z_ERRNO,Z_STREAM_ERROR:o.Z_STREAM_ERROR,Z_DATA_ERROR:o.Z_DATA_ERROR,Z_MEM_ERROR:o.Z_MEM_ERROR,Z_BUF_ERROR:o.Z_BUF_ERROR,Z_VERSION_ERROR:o.Z_VERSION_ERROR},h=Object.keys(w),E=0;E<h.length;E++){var f=h[E];w[w[f]]=f}function Q(A,t,e){var n=[],i=0;function o(){for(var t;null!==(t=A.read());)n.push(t),i+=t.length;A.once("readable",o)}function s(){var t,o=null;i>=c?o=new RangeError(B):t=r.concat(n,i),n=[],A.close(),e(o,t)}A.on("error",(function(t){A.removeListener("end",s),A.removeListener("readable",o),e(t)})),A.on("end",s),A.end(t),o()}function d(A,t){if("string"==typeof t&&(t=r.from(t)),!r.isBuffer(t))throw new TypeError("Not a string or buffer");var e=A._finishFlushFlag;return A._processChunk(t,e)}function C(A){if(!(this instanceof C))return new C(A);F.call(this,A,o.DEFLATE)}function M(A){if(!(this instanceof M))return new M(A);F.call(this,A,o.INFLATE)}function I(A){if(!(this instanceof I))return new I(A);F.call(this,A,o.GZIP)}function p(A){if(!(this instanceof p))return new p(A);F.call(this,A,o.GUNZIP)}function D(A){if(!(this instanceof D))return new D(A);F.call(this,A,o.DEFLATERAW)}function y(A){if(!(this instanceof y))return new y(A);F.call(this,A,o.INFLATERAW)}function v(A){if(!(this instanceof v))return new v(A);F.call(this,A,o.UNZIP)}function m(A){return A===o.Z_NO_FLUSH||A===o.Z_PARTIAL_FLUSH||A===o.Z_SYNC_FLUSH||A===o.Z_FULL_FLUSH||A===o.Z_FINISH||A===o.Z_BLOCK}function F(A,e){var n=this;if(this._opts=A=A||{},this._chunkSize=A.chunkSize||t.Z_DEFAULT_CHUNK,i.call(this,A),A.flush&&!m(A.flush))throw new Error("Invalid flush flag: "+A.flush);if(A.finishFlush&&!m(A.finishFlush))throw new Error("Invalid flush flag: "+A.finishFlush);if(this._flushFlag=A.flush||o.Z_NO_FLUSH,this._finishFlushFlag=void 0!==A.finishFlush?A.finishFlush:o.Z_FINISH,A.chunkSize&&(A.chunkSize<t.Z_MIN_CHUNK||A.chunkSize>t.Z_MAX_CHUNK))throw new Error("Invalid chunk size: "+A.chunkSize);if(A.windowBits&&(A.windowBits<t.Z_MIN_WINDOWBITS||A.windowBits>t.Z_MAX_WINDOWBITS))throw new Error("Invalid windowBits: "+A.windowBits);if(A.level&&(A.level<t.Z_MIN_LEVEL||A.level>t.Z_MAX_LEVEL))throw new Error("Invalid compression level: "+A.level);if(A.memLevel&&(A.memLevel<t.Z_MIN_MEMLEVEL||A.memLevel>t.Z_MAX_MEMLEVEL))throw new Error("Invalid memLevel: "+A.memLevel);if(A.strategy&&A.strategy!=t.Z_FILTERED&&A.strategy!=t.Z_HUFFMAN_ONLY&&A.strategy!=t.Z_RLE&&A.strategy!=t.Z_FIXED&&A.strategy!=t.Z_DEFAULT_STRATEGY)throw new Error("Invalid strategy: "+A.strategy);if(A.dictionary&&!r.isBuffer(A.dictionary))throw new Error("Invalid dictionary: it should be a Buffer instance");this._handle=new o.Zlib(e);var s=this;this._hadError=!1,this._handle.onerror=function(A,e){Y(s),s._hadError=!0;var n=new Error(A);n.errno=e,n.code=t.codes[e],s.emit("error",n)};var a=t.Z_DEFAULT_COMPRESSION;"number"==typeof A.level&&(a=A.level);var c=t.Z_DEFAULT_STRATEGY;"number"==typeof A.strategy&&(c=A.strategy),this._handle.init(A.windowBits||t.Z_DEFAULT_WINDOWBITS,a,A.memLevel||t.Z_DEFAULT_MEMLEVEL,c,A.dictionary),this._buffer=r.allocUnsafe(this._chunkSize),this._offset=0,this._level=a,this._strategy=c,this.once("end",this.close),Object.defineProperty(this,"_closed",{get:function(){return!n._handle},configurable:!0,enumerable:!0})}function Y(A,t){t&&n.nextTick(t),A._handle&&(A._handle.close(),A._handle=null)}function b(A){A.emit("close")}Object.defineProperty(t,"codes",{enumerable:!0,value:Object.freeze(w),writable:!1}),t.Deflate=C,t.Inflate=M,t.Gzip=I,t.Gunzip=p,t.DeflateRaw=D,t.InflateRaw=y,t.Unzip=v,t.createDeflate=function(A){return new C(A)},t.createInflate=function(A){return new M(A)},t.createDeflateRaw=function(A){return new D(A)},t.createInflateRaw=function(A){return new y(A)},t.createGzip=function(A){return new I(A)},t.createGunzip=function(A){return new p(A)},t.createUnzip=function(A){return new v(A)},t.deflate=function(A,t,e){return"function"==typeof t&&(e=t,t={}),Q(new C(t),A,e)},t.deflateSync=function(A,t){return d(new C(t),A)},t.gzip=function(A,t,e){return"function"==typeof t&&(e=t,t={}),Q(new I(t),A,e)},t.gzipSync=function(A,t){return d(new I(t),A)},t.deflateRaw=function(A,t,e){return"function"==typeof t&&(e=t,t={}),Q(new D(t),A,e)},t.deflateRawSync=function(A,t){return d(new D(t),A)},t.unzip=function(A,t,e){return"function"==typeof t&&(e=t,t={}),Q(new v(t),A,e)},t.unzipSync=function(A,t){return d(new v(t),A)},t.inflate=function(A,t,e){return"function"==typeof t&&(e=t,t={}),Q(new M(t),A,e)},t.inflateSync=function(A,t){return d(new M(t),A)},t.gunzip=function(A,t,e){return"function"==typeof t&&(e=t,t={}),Q(new p(t),A,e)},t.gunzipSync=function(A,t){return d(new p(t),A)},t.inflateRaw=function(A,t,e){return"function"==typeof t&&(e=t,t={}),Q(new y(t),A,e)},t.inflateRawSync=function(A,t){return d(new y(t),A)},s.inherits(F,i),F.prototype.params=function(A,e,r){if(A<t.Z_MIN_LEVEL||A>t.Z_MAX_LEVEL)throw new RangeError("Invalid compression level: "+A);if(e!=t.Z_FILTERED&&e!=t.Z_HUFFMAN_ONLY&&e!=t.Z_RLE&&e!=t.Z_FIXED&&e!=t.Z_DEFAULT_STRATEGY)throw new TypeError("Invalid strategy: "+e);if(this._level!==A||this._strategy!==e){var i=this;this.flush(o.Z_SYNC_FLUSH,(function(){a(i._handle,"zlib binding closed"),i._handle.params(A,e),i._hadError||(i._level=A,i._strategy=e,r&&r())}))}else n.nextTick(r)},F.prototype.reset=function(){return a(this._handle,"zlib binding closed"),this._handle.reset()},F.prototype._flush=function(A){this._transform(r.alloc(0),"",A)},F.prototype.flush=function(A,t){var e=this,i=this._writableState;("function"==typeof A||void 0===A&&!t)&&(t=A,A=o.Z_FULL_FLUSH),i.ended?t&&n.nextTick(t):i.ending?t&&this.once("end",t):i.needDrain?t&&this.once("drain",(function(){return e.flush(A,t)})):(this._flushFlag=A,this.write(r.alloc(0),"",t))},F.prototype.close=function(A){Y(this,A),n.nextTick(b,this)},F.prototype._transform=function(A,t,e){var n,i=this._writableState,s=(i.ending||i.ended)&&(!A||i.length===A.length);return null===A||r.isBuffer(A)?this._handle?(s?n=this._finishFlushFlag:(n=this._flushFlag,A.length>=i.length&&(this._flushFlag=this._opts.flush||o.Z_NO_FLUSH)),void this._processChunk(A,n,e)):e(new Error("zlib binding closed")):e(new Error("invalid input"))},F.prototype._processChunk=function(A,t,e){var n=A&&A.length,i=this._chunkSize-this._offset,o=0,s=this,g="function"==typeof e;if(!g){var l,u=[],w=0;this.on("error",(function(A){l=A})),a(this._handle,"zlib binding closed");do{var h=this._handle.writeSync(t,A,o,n,this._buffer,this._offset,i)}while(!this._hadError&&Q(h[0],h[1]));if(this._hadError)throw l;if(w>=c)throw Y(this),new RangeError(B);var E=r.concat(u,w);return Y(this),E}a(this._handle,"zlib binding closed");var f=this._handle.write(t,A,o,n,this._buffer,this._offset,i);function Q(c,B){if(this&&(this.buffer=null,this.callback=null),!s._hadError){var l=i-B;if(a(l>=0,"have should not go down"),l>0){var h=s._buffer.slice(s._offset,s._offset+l);s._offset+=l,g?s.push(h):(u.push(h),w+=h.length)}if((0===B||s._offset>=s._chunkSize)&&(i=s._chunkSize,s._offset=0,s._buffer=r.allocUnsafe(s._chunkSize)),0===B){if(o+=n-c,n=c,!g)return!0;var E=s._handle.write(t,A,o,n,s._buffer,s._offset,s._chunkSize);return E.callback=Q,void(E.buffer=A)}if(!g)return!1;e()}}f.buffer=A,f.callback=Q},s.inherits(C,F),s.inherits(M,F),s.inherits(I,F),s.inherits(p,F),s.inherits(D,F),s.inherits(y,F),s.inherits(v,F)},1924:function(A,t,e){"use strict";var n=e(210),r=e(5559),i=r(n("String.prototype.indexOf"));A.exports=function(A,t){var e=n(A,!!t);return"function"==typeof e&&i(A,".prototype.")>-1?r(e):e}},5559:function(A,t,e){"use strict";var n=e(8612),r=e(210),i=r("%Function.prototype.apply%"),o=r("%Function.prototype.call%"),s=r("%Reflect.apply%",!0)||n.call(o,i),a=r("%Object.getOwnPropertyDescriptor%",!0),c=r("%Object.defineProperty%",!0),B=r("%Math.max%");if(c)try{c({},"a",{value:1})}catch(A){c=null}A.exports=function(A){var t=s(n,o,arguments);a&&c&&(a(t,"length").configurable&&c(t,"length",{value:1+B(0,A.length-(arguments.length-1))}));return t};var g=function(){return s(n,i,arguments)};c?c(A.exports,"apply",{value:g}):A.exports.apply=g},6313:function(A,t,e){var n=e(8823).Buffer,r=function(){"use strict";function A(t,r,i,o){"object"==typeof r&&(i=r.depth,o=r.prototype,r.filter,r=r.circular);var s=[],a=[],c=void 0!==n;return void 0===r&&(r=!0),void 0===i&&(i=1/0),function t(i,B){if(null===i)return null;if(0==B)return i;var g,l;if("object"!=typeof i)return i;if(A.__isArray(i))g=[];else if(A.__isRegExp(i))g=new RegExp(i.source,e(i)),i.lastIndex&&(g.lastIndex=i.lastIndex);else if(A.__isDate(i))g=new Date(i.getTime());else{if(c&&n.isBuffer(i))return g=n.allocUnsafe?n.allocUnsafe(i.length):new n(i.length),i.copy(g),g;void 0===o?(l=Object.getPrototypeOf(i),g=Object.create(l)):(g=Object.create(o),l=o)}if(r){var u=s.indexOf(i);if(-1!=u)return a[u];s.push(i),a.push(g)}for(var w in i){var h;l&&(h=Object.getOwnPropertyDescriptor(l,w)),h&&null==h.set||(g[w]=t(i[w],B-1))}return g}(t,i)}function t(A){return Object.prototype.toString.call(A)}function e(A){var t="";return A.global&&(t+="g"),A.ignoreCase&&(t+="i"),A.multiline&&(t+="m"),t}return A.clonePrototype=function(A){if(null===A)return null;var t=function(){};return t.prototype=A,new t},A.__objToStr=t,A.__isDate=function(A){return"object"==typeof A&&"[object Date]"===t(A)},A.__isArray=function(A){return"object"==typeof A&&"[object Array]"===t(A)},A.__isRegExp=function(A){return"object"==typeof A&&"[object RegExp]"===t(A)},A.__getRegExpFlags=e,A}();A.exports&&(A.exports=r)},4667:function(A,t,e){e(2479);var n=e(857);A.exports=n.Object.values},7633:function(A,t,e){e(9170),e(6992),e(1539),e(8674),e(7922),e(4668),e(7727),e(8783);var n=e(857);A.exports=n.Promise},3867:function(A,t,e){var n=e(1150);e(8628),e(7314),e(7479),e(6290),A.exports=n},9662:function(A,t,e){var n=e(7854),r=e(614),i=e(6330),o=n.TypeError;A.exports=function(A){if(r(A))return A;throw o(i(A)+" is not a function")}},9483:function(A,t,e){var n=e(7854),r=e(4411),i=e(6330),o=n.TypeError;A.exports=function(A){if(r(A))return A;throw o(i(A)+" is not a constructor")}},6077:function(A,t,e){var n=e(7854),r=e(614),i=n.String,o=n.TypeError;A.exports=function(A){if("object"==typeof A||r(A))return A;throw o("Can't set "+i(A)+" as a prototype")}},1223:function(A,t,e){var n=e(5112),r=e(30),i=e(3070),o=n("unscopables"),s=Array.prototype;null==s[o]&&i.f(s,o,{configurable:!0,value:r(null)}),A.exports=function(A){s[o][A]=!0}},1530:function(A,t,e){"use strict";var n=e(8710).charAt;A.exports=function(A,t,e){return t+(e?n(A,t).length:1)}},5787:function(A,t,e){var n=e(7854),r=e(7976),i=n.TypeError;A.exports=function(A,t){if(r(t,A))return A;throw i("Incorrect invocation")}},9670:function(A,t,e){var n=e(7854),r=e(111),i=n.String,o=n.TypeError;A.exports=function(A){if(r(A))return A;throw o(i(A)+" is not an object")}},1048:function(A,t,e){"use strict";var n=e(7908),r=e(1400),i=e(6244),o=Math.min;A.exports=[].copyWithin||function(A,t){var e=n(this),s=i(e),a=r(A,s),c=r(t,s),B=arguments.length>2?arguments[2]:void 0,g=o((void 0===B?s:r(B,s))-c,s-a),l=1;for(c<a&&a<c+g&&(l=-1,c+=g-1,a+=g-1);g-- >0;)c in e?e[a]=e[c]:delete e[a],a+=l,c+=l;return e}},1285:function(A,t,e){"use strict";var n=e(7908),r=e(1400),i=e(6244);A.exports=function(A){for(var t=n(this),e=i(t),o=arguments.length,s=r(o>1?arguments[1]:void 0,e),a=o>2?arguments[2]:void 0,c=void 0===a?e:r(a,e);c>s;)t[s++]=A;return t}},8533:function(A,t,e){"use strict";var n=e(2092).forEach,r=e(9341)("forEach");A.exports=r?[].forEach:function(A){return n(this,A,arguments.length>1?arguments[1]:void 0)}},7745:function(A){A.exports=function(A,t){for(var e=0,n=t.length,r=new A(n);n>e;)r[e]=t[e++];return r}},8457:function(A,t,e){"use strict";var n=e(7854),r=e(9974),i=e(6916),o=e(7908),s=e(3411),a=e(7659),c=e(4411),B=e(6244),g=e(6135),l=e(8554),u=e(1246),w=n.Array;A.exports=function(A){var t=o(A),e=c(this),n=arguments.length,h=n>1?arguments[1]:void 0,E=void 0!==h;E&&(h=r(h,n>2?arguments[2]:void 0));var f,Q,d,C,M,I,p=u(t),D=0;if(!p||this==w&&a(p))for(f=B(t),Q=e?new this(f):w(f);f>D;D++)I=E?h(t[D],D):t[D],g(Q,D,I);else for(M=(C=l(t,p)).next,Q=e?new this:[];!(d=i(M,C)).done;D++)I=E?s(C,h,[d.value,D],!0):d.value,g(Q,D,I);return Q.length=D,Q}},1318:function(A,t,e){var n=e(5656),r=e(1400),i=e(6244),o=function(A){return function(t,e,o){var s,a=n(t),c=i(a),B=r(o,c);if(A&&e!=e){for(;c>B;)if((s=a[B++])!=s)return!0}else for(;c>B;B++)if((A||B in a)&&a[B]===e)return A||B||0;return!A&&-1}};A.exports={includes:o(!0),indexOf:o(!1)}},2092:function(A,t,e){var n=e(9974),r=e(1702),i=e(8361),o=e(7908),s=e(6244),a=e(5417),c=r([].push),B=function(A){var t=1==A,e=2==A,r=3==A,B=4==A,g=6==A,l=7==A,u=5==A||g;return function(w,h,E,f){for(var Q,d,C=o(w),M=i(C),I=n(h,E),p=s(M),D=0,y=f||a,v=t?y(w,p):e||l?y(w,0):void 0;p>D;D++)if((u||D in M)&&(d=I(Q=M[D],D,C),A))if(t)v[D]=d;else if(d)switch(A){case 3:return!0;case 5:return Q;case 6:return D;case 2:c(v,Q)}else switch(A){case 4:return!1;case 7:c(v,Q)}return g?-1:r||B?B:v}};A.exports={forEach:B(0),map:B(1),filter:B(2),some:B(3),every:B(4),find:B(5),findIndex:B(6),filterReject:B(7)}},6583:function(A,t,e){"use strict";var n=e(2104),r=e(5656),i=e(9303),o=e(6244),s=e(9341),a=Math.min,c=[].lastIndexOf,B=!!c&&1/[1].lastIndexOf(1,-0)<0,g=s("lastIndexOf"),l=B||!g;A.exports=l?function(A){if(B)return n(c,this,arguments)||0;var t=r(this),e=o(t),s=e-1;for(arguments.length>1&&(s=a(s,i(arguments[1]))),s<0&&(s=e+s);s>=0;s--)if(s in t&&t[s]===A)return s||0;return-1}:c},1194:function(A,t,e){var n=e(7293),r=e(5112),i=e(7392),o=r("species");A.exports=function(A){return i>=51||!n((function(){var t=[];return(t.constructor={})[o]=function(){return{foo:1}},1!==t[A](Boolean).foo}))}},9341:function(A,t,e){"use strict";var n=e(7293);A.exports=function(A,t){var e=[][A];return!!e&&n((function(){e.call(null,t||function(){throw 1},1)}))}},3671:function(A,t,e){var n=e(7854),r=e(9662),i=e(7908),o=e(8361),s=e(6244),a=n.TypeError,c=function(A){return function(t,e,n,c){r(e);var B=i(t),g=o(B),l=s(B),u=A?l-1:0,w=A?-1:1;if(n<2)for(;;){if(u in g){c=g[u],u+=w;break}if(u+=w,A?u<0:l<=u)throw a("Reduce of empty array with no initial value")}for(;A?u>=0:l>u;u+=w)u in g&&(c=e(c,g[u],u,B));return c}};A.exports={left:c(!1),right:c(!0)}},206:function(A,t,e){var n=e(1702);A.exports=n([].slice)},4362:function(A,t,e){var n=e(206),r=Math.floor,i=function(A,t){var e=A.length,a=r(e/2);return e<8?o(A,t):s(A,i(n(A,0,a),t),i(n(A,a),t),t)},o=function(A,t){for(var e,n,r=A.length,i=1;i<r;){for(n=i,e=A[i];n&&t(A[n-1],e)>0;)A[n]=A[--n];n!==i++&&(A[n]=e)}return A},s=function(A,t,e,n){for(var r=t.length,i=e.length,o=0,s=0;o<r||s<i;)A[o+s]=o<r&&s<i?n(t[o],e[s])<=0?t[o++]:e[s++]:o<r?t[o++]:e[s++];return A};A.exports=i},7475:function(A,t,e){var n=e(7854),r=e(3157),i=e(4411),o=e(111),s=e(5112)("species"),a=n.Array;A.exports=function(A){var t;return r(A)&&(t=A.constructor,(i(t)&&(t===a||r(t.prototype))||o(t)&&null===(t=t[s]))&&(t=void 0)),void 0===t?a:t}},5417:function(A,t,e){var n=e(7475);A.exports=function(A,t){return new(n(A))(0===t?0:t)}},3411:function(A,t,e){var n=e(9670),r=e(9212);A.exports=function(A,t,e,i){try{return i?t(n(e)[0],e[1]):t(e)}catch(t){r(A,"throw",t)}}},7072:function(A,t,e){var n=e(5112)("iterator"),r=!1;try{var i=0,o={next:function(){return{done:!!i++}},return:function(){r=!0}};o[n]=function(){return this},Array.from(o,(function(){throw 2}))}catch(A){}A.exports=function(A,t){if(!t&&!r)return!1;var e=!1;try{var i={};i[n]=function(){return{next:function(){return{done:e=!0}}}},A(i)}catch(A){}return e}},4326:function(A,t,e){var n=e(1702),r=n({}.toString),i=n("".slice);A.exports=function(A){return i(r(A),8,-1)}},648:function(A,t,e){var n=e(7854),r=e(1694),i=e(614),o=e(4326),s=e(5112)("toStringTag"),a=n.Object,c="Arguments"==o(function(){return arguments}());A.exports=r?o:function(A){var t,e,n;return void 0===A?"Undefined":null===A?"Null":"string"==typeof(e=function(A,t){try{return A[t]}catch(A){}}(t=a(A),s))?e:c?o(t):"Object"==(n=o(t))&&i(t.callee)?"Arguments":n}},7741:function(A,t,e){var n=e(1702),r=e(206),i=n("".replace),o=n("".split),s=n([].join),a=String(Error("zxcasd").stack),c=/\n\s*at [^:]*:[^\n]*/,B=c.test(a),g=/@[^\n]*\n/.test(a)&&!/zxcasd/.test(a);A.exports=function(A,t){if("string"!=typeof A)return A;if(B)for(;t--;)A=i(A,c,"");else if(g)return s(r(o(A,"\n"),t),"\n");return A}},5631:function(A,t,e){"use strict";var n=e(3070).f,r=e(30),i=e(2248),o=e(9974),s=e(5787),a=e(408),c=e(654),B=e(6340),g=e(9781),l=e(2423).fastKey,u=e(9909),w=u.set,h=u.getterFor;A.exports={getConstructor:function(A,t,e,c){var B=A((function(A,n){s(A,u),w(A,{type:t,index:r(null),first:void 0,last:void 0,size:0}),g||(A.size=0),null!=n&&a(n,A[c],{that:A,AS_ENTRIES:e})})),u=B.prototype,E=h(t),f=function(A,t,e){var n,r,i=E(A),o=Q(A,t);return o?o.value=e:(i.last=o={index:r=l(t,!0),key:t,value:e,previous:n=i.last,next:void 0,removed:!1},i.first||(i.first=o),n&&(n.next=o),g?i.size++:A.size++,"F"!==r&&(i.index[r]=o)),A},Q=function(A,t){var e,n=E(A),r=l(t);if("F"!==r)return n.index[r];for(e=n.first;e;e=e.next)if(e.key==t)return e};return i(u,{clear:function(){for(var A=E(this),t=A.index,e=A.first;e;)e.removed=!0,e.previous&&(e.previous=e.previous.next=void 0),delete t[e.index],e=e.next;A.first=A.last=void 0,g?A.size=0:this.size=0},delete:function(A){var t=this,e=E(t),n=Q(t,A);if(n){var r=n.next,i=n.previous;delete e.index[n.index],n.removed=!0,i&&(i.next=r),r&&(r.previous=i),e.first==n&&(e.first=r),e.last==n&&(e.last=i),g?e.size--:t.size--}return!!n},forEach:function(A){for(var t,e=E(this),n=o(A,arguments.length>1?arguments[1]:void 0);t=t?t.next:e.first;)for(n(t.value,t.key,this);t&&t.removed;)t=t.previous},has:function(A){return!!Q(this,A)}}),i(u,e?{get:function(A){var t=Q(this,A);return t&&t.value},set:function(A,t){return f(this,0===A?0:A,t)}}:{add:function(A){return f(this,A=0===A?0:A,A)}}),g&&n(u,"size",{get:function(){return E(this).size}}),B},setStrong:function(A,t,e){var n=t+" Iterator",r=h(t),i=h(n);c(A,t,(function(A,t){w(this,{type:n,target:A,state:r(A),kind:t,last:void 0})}),(function(){for(var A=i(this),t=A.kind,e=A.last;e&&e.removed;)e=e.previous;return A.target&&(A.last=e=e?e.next:A.state.first)?"keys"==t?{value:e.key,done:!1}:"values"==t?{value:e.value,done:!1}:{value:[e.key,e.value],done:!1}:(A.target=void 0,{value:void 0,done:!0})}),e?"entries":"values",!e,!0),B(t)}}},7710:function(A,t,e){"use strict";var n=e(2109),r=e(7854),i=e(1702),o=e(4705),s=e(1320),a=e(2423),c=e(408),B=e(5787),g=e(614),l=e(111),u=e(7293),w=e(7072),h=e(8003),E=e(9587);A.exports=function(A,t,e){var f=-1!==A.indexOf("Map"),Q=-1!==A.indexOf("Weak"),d=f?"set":"add",C=r[A],M=C&&C.prototype,I=C,p={},D=function(A){var t=i(M[A]);s(M,A,"add"==A?function(A){return t(this,0===A?0:A),this}:"delete"==A?function(A){return!(Q&&!l(A))&&t(this,0===A?0:A)}:"get"==A?function(A){return Q&&!l(A)?void 0:t(this,0===A?0:A)}:"has"==A?function(A){return!(Q&&!l(A))&&t(this,0===A?0:A)}:function(A,e){return t(this,0===A?0:A,e),this})};if(o(A,!g(C)||!(Q||M.forEach&&!u((function(){(new C).entries().next()})))))I=e.getConstructor(t,A,f,d),a.enable();else if(o(A,!0)){var y=new I,v=y[d](Q?{}:-0,1)!=y,m=u((function(){y.has(1)})),F=w((function(A){new C(A)})),Y=!Q&&u((function(){for(var A=new C,t=5;t--;)A[d](t,t);return!A.has(-0)}));F||((I=t((function(A,t){B(A,M);var e=E(new C,A,I);return null!=t&&c(t,e[d],{that:e,AS_ENTRIES:f}),e}))).prototype=M,M.constructor=I),(m||Y)&&(D("delete"),D("has"),f&&D("get")),(Y||v)&&D(d),Q&&M.clear&&delete M.clear}return p[A]=I,n({global:!0,forced:I!=C},p),h(I,A),Q||e.setStrong(I,A,f),I}},9920:function(A,t,e){var n=e(2597),r=e(3887),i=e(1236),o=e(3070);A.exports=function(A,t){for(var e=r(t),s=o.f,a=i.f,c=0;c<e.length;c++){var B=e[c];n(A,B)||s(A,B,a(t,B))}}},4964:function(A,t,e){var n=e(5112)("match");A.exports=function(A){var t=/./;try{"/./"[A](t)}catch(e){try{return t[n]=!1,"/./"[A](t)}catch(A){}}return!1}},8544:function(A,t,e){var n=e(7293);A.exports=!n((function(){function A(){}return A.prototype.constructor=null,Object.getPrototypeOf(new A)!==A.prototype}))},4230:function(A,t,e){var n=e(1702),r=e(4488),i=e(1340),o=/"/g,s=n("".replace);A.exports=function(A,t,e,n){var a=i(r(A)),c="<"+t;return""!==e&&(c+=" "+e+'="'+s(i(n),o,"&quot;")+'"'),c+">"+a+"</"+t+">"}},4994:function(A,t,e){"use strict";var n=e(3383).IteratorPrototype,r=e(30),i=e(9114),o=e(8003),s=e(7497),a=function(){return this};A.exports=function(A,t,e){var c=t+" Iterator";return A.prototype=r(n,{next:i(1,e)}),o(A,c,!1,!0),s[c]=a,A}},8880:function(A,t,e){var n=e(9781),r=e(3070),i=e(9114);A.exports=n?function(A,t,e){return r.f(A,t,i(1,e))}:function(A,t,e){return A[t]=e,A}},9114:function(A){A.exports=function(A,t){return{enumerable:!(1&A),configurable:!(2&A),writable:!(4&A),value:t}}},6135:function(A,t,e){"use strict";var n=e(4948),r=e(3070),i=e(9114);A.exports=function(A,t,e){var o=n(t);o in A?r.f(A,o,i(0,e)):A[o]=e}},8709:function(A,t,e){"use strict";var n=e(7854),r=e(9670),i=e(2140),o=n.TypeError;A.exports=function(A){if(r(this),"string"===A||"default"===A)A="string";else if("number"!==A)throw o("Incorrect hint");return i(this,A)}},654:function(A,t,e){"use strict";var n=e(2109),r=e(6916),i=e(1913),o=e(6530),s=e(614),a=e(4994),c=e(9518),B=e(7674),g=e(8003),l=e(8880),u=e(1320),w=e(5112),h=e(7497),E=e(3383),f=o.PROPER,Q=o.CONFIGURABLE,d=E.IteratorPrototype,C=E.BUGGY_SAFARI_ITERATORS,M=w("iterator"),I="keys",p="values",D="entries",y=function(){return this};A.exports=function(A,t,e,o,w,E,v){a(e,t,o);var m,F,Y,b=function(A){if(A===w&&T)return T;if(!C&&A in S)return S[A];switch(A){case I:case p:case D:return function(){return new e(this,A)}}return function(){return new e(this)}},z=t+" Iterator",U=!1,S=A.prototype,x=S[M]||S["@@iterator"]||w&&S[w],T=!C&&x||b(w),P="Array"==t&&S.entries||x;if(P&&(m=c(P.call(new A)))!==Object.prototype&&m.next&&(i||c(m)===d||(B?B(m,d):s(m[M])||u(m,M,y)),g(m,z,!0,!0),i&&(h[z]=y)),f&&w==p&&x&&x.name!==p&&(!i&&Q?l(S,"name",p):(U=!0,T=function(){return r(x,this)})),w)if(F={values:b(p),keys:E?T:b(I),entries:b(D)},v)for(Y in F)(C||U||!(Y in S))&&u(S,Y,F[Y]);else n({target:t,proto:!0,forced:C||U},F);return i&&!v||S[M]===T||u(S,M,T,{name:w}),h[t]=T,F}},7235:function(A,t,e){var n=e(857),r=e(2597),i=e(6061),o=e(3070).f;A.exports=function(A){var t=n.Symbol||(n.Symbol={});r(t,A)||o(t,A,{value:i.f(A)})}},9781:function(A,t,e){var n=e(7293);A.exports=!n((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]}))},317:function(A,t,e){var n=e(7854),r=e(111),i=n.document,o=r(i)&&r(i.createElement);A.exports=function(A){return o?i.createElement(A):{}}},8324:function(A){A.exports={CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0}},8509:function(A,t,e){var n=e(317)("span").classList,r=n&&n.constructor&&n.constructor.prototype;A.exports=r===Object.prototype?void 0:r},8886:function(A,t,e){var n=e(8113).match(/firefox\/(\d+)/i);A.exports=!!n&&+n[1]},7871:function(A){A.exports="object"==typeof window},256:function(A,t,e){var n=e(8113);A.exports=/MSIE|Trident/.test(n)},1528:function(A,t,e){var n=e(8113),r=e(7854);A.exports=/ipad|iphone|ipod/i.test(n)&&void 0!==r.Pebble},6833:function(A,t,e){var n=e(8113);A.exports=/(?:ipad|iphone|ipod).*applewebkit/i.test(n)},5268:function(A,t,e){var n=e(4326),r=e(7854);A.exports="process"==n(r.process)},1036:function(A,t,e){var n=e(8113);A.exports=/web0s(?!.*chrome)/i.test(n)},8113:function(A,t,e){var n=e(5005);A.exports=n("navigator","userAgent")||""},7392:function(A,t,e){var n,r,i=e(7854),o=e(8113),s=i.process,a=i.Deno,c=s&&s.versions||a&&a.version,B=c&&c.v8;B&&(r=(n=B.split("."))[0]>0&&n[0]<4?1:+(n[0]+n[1])),!r&&o&&(!(n=o.match(/Edge\/(\d+)/))||n[1]>=74)&&(n=o.match(/Chrome\/(\d+)/))&&(r=+n[1]),A.exports=r},8008:function(A,t,e){var n=e(8113).match(/AppleWebKit\/(\d+)\./);A.exports=!!n&&+n[1]},748:function(A){A.exports=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"]},2914:function(A,t,e){var n=e(7293),r=e(9114);A.exports=!n((function(){var A=Error("a");return!("stack"in A)||(Object.defineProperty(A,"stack",r(1,7)),7!==A.stack)}))},2109:function(A,t,e){var n=e(7854),r=e(1236).f,i=e(8880),o=e(1320),s=e(3505),a=e(9920),c=e(4705);A.exports=function(A,t){var e,B,g,l,u,w=A.target,h=A.global,E=A.stat;if(e=h?n:E?n[w]||s(w,{}):(n[w]||{}).prototype)for(B in t){if(l=t[B],g=A.noTargetGet?(u=r(e,B))&&u.value:e[B],!c(h?B:w+(E?".":"#")+B,A.forced)&&void 0!==g){if(typeof l==typeof g)continue;a(l,g)}(A.sham||g&&g.sham)&&i(l,"sham",!0),o(e,B,l,A)}}},7293:function(A){A.exports=function(A){try{return!!A()}catch(A){return!0}}},7007:function(A,t,e){"use strict";e(4916);var n=e(1702),r=e(1320),i=e(2261),o=e(7293),s=e(5112),a=e(8880),c=s("species"),B=RegExp.prototype;A.exports=function(A,t,e,g){var l=s(A),u=!o((function(){var t={};return t[l]=function(){return 7},7!=""[A](t)})),w=u&&!o((function(){var t=!1,e=/a/;return"split"===A&&((e={}).constructor={},e.constructor[c]=function(){return e},e.flags="",e[l]=/./[l]),e.exec=function(){return t=!0,null},e[l](""),!t}));if(!u||!w||e){var h=n(/./[l]),E=t(l,""[A],(function(A,t,e,r,o){var s=n(A),a=t.exec;return a===i||a===B.exec?u&&!o?{done:!0,value:h(t,e,r)}:{done:!0,value:s(e,t,r)}:{done:!1}}));r(String.prototype,A,E[0]),r(B,l,E[1])}g&&a(B[l],"sham",!0)}},6677:function(A,t,e){var n=e(7293);A.exports=!n((function(){return Object.isExtensible(Object.preventExtensions({}))}))},2104:function(A){var t=Function.prototype,e=t.apply,n=t.bind,r=t.call;A.exports="object"==typeof Reflect&&Reflect.apply||(n?r.bind(e):function(){return r.apply(e,arguments)})},9974:function(A,t,e){var n=e(1702),r=e(9662),i=n(n.bind);A.exports=function(A,t){return r(A),void 0===t?A:i?i(A,t):function(){return A.apply(t,arguments)}}},7065:function(A,t,e){"use strict";var n=e(7854),r=e(1702),i=e(9662),o=e(111),s=e(2597),a=e(206),c=n.Function,B=r([].concat),g=r([].join),l={};A.exports=c.bind||function(A){var t=i(this),e=t.prototype,n=a(arguments,1),r=function(){var e=B(n,a(arguments));return this instanceof r?function(A,t,e){if(!s(l,t)){for(var n=[],r=0;r<t;r++)n[r]="a["+r+"]";l[t]=c("C,a","return new C("+g(n,",")+")")}return l[t](A,e)}(t,e.length,e):t.apply(A,e)};return o(e)&&(r.prototype=e),r}},6916:function(A){var t=Function.prototype.call;A.exports=t.bind?t.bind(t):function(){return t.apply(t,arguments)}},6530:function(A,t,e){var n=e(9781),r=e(2597),i=Function.prototype,o=n&&Object.getOwnPropertyDescriptor,s=r(i,"name"),a=s&&"something"===function(){}.name,c=s&&(!n||n&&o(i,"name").configurable);A.exports={EXISTS:s,PROPER:a,CONFIGURABLE:c}},1702:function(A){var t=Function.prototype,e=t.bind,n=t.call,r=e&&e.bind(n);A.exports=e?function(A){return A&&r(n,A)}:function(A){return A&&function(){return n.apply(A,arguments)}}},5005:function(A,t,e){var n=e(7854),r=e(614);A.exports=function(A,t){return arguments.length<2?function(A){return r(A)?A:void 0}(n[A]):n[A]&&n[A][t]}},1246:function(A,t,e){var n=e(648),r=e(8173),i=e(7497),o=e(5112)("iterator");A.exports=function(A){if(null!=A)return r(A,o)||r(A,"@@iterator")||i[n(A)]}},8554:function(A,t,e){var n=e(7854),r=e(6916),i=e(9662),o=e(9670),s=e(6330),a=e(1246),c=n.TypeError;A.exports=function(A,t){var e=arguments.length<2?a(A):t;if(i(e))return o(r(e,A));throw c(s(A)+" is not iterable")}},8173:function(A,t,e){var n=e(9662);A.exports=function(A,t){var e=A[t];return null==e?void 0:n(e)}},647:function(A,t,e){var n=e(1702),r=e(7908),i=Math.floor,o=n("".charAt),s=n("".replace),a=n("".slice),c=/\$([$&'`]|\d{1,2}|<[^>]*>)/g,B=/\$([$&'`]|\d{1,2})/g;A.exports=function(A,t,e,n,g,l){var u=e+A.length,w=n.length,h=B;return void 0!==g&&(g=r(g),h=c),s(l,h,(function(r,s){var c;switch(o(s,0)){case"$":return"$";case"&":return A;case"`":return a(t,0,e);case"'":return a(t,u);case"<":c=g[a(s,1,-1)];break;default:var B=+s;if(0===B)return r;if(B>w){var l=i(B/10);return 0===l?r:l<=w?void 0===n[l-1]?o(s,1):n[l-1]+o(s,1):r}c=n[B-1]}return void 0===c?"":c}))}},7854:function(A,t,e){var n=function(A){return A&&A.Math==Math&&A};A.exports=n("object"==typeof globalThis&&globalThis)||n("object"==typeof window&&window)||n("object"==typeof self&&self)||n("object"==typeof e.g&&e.g)||function(){return this}()||Function("return this")()},2597:function(A,t,e){var n=e(1702),r=e(7908),i=n({}.hasOwnProperty);A.exports=Object.hasOwn||function(A,t){return i(r(A),t)}},3501:function(A){A.exports={}},842:function(A,t,e){var n=e(7854);A.exports=function(A,t){var e=n.console;e&&e.error&&(1==arguments.length?e.error(A):e.error(A,t))}},490:function(A,t,e){var n=e(5005);A.exports=n("document","documentElement")},4664:function(A,t,e){var n=e(9781),r=e(7293),i=e(317);A.exports=!n&&!r((function(){return 7!=Object.defineProperty(i("div"),"a",{get:function(){return 7}}).a}))},1179:function(A,t,e){var n=e(7854).Array,r=Math.abs,i=Math.pow,o=Math.floor,s=Math.log,a=Math.LN2;A.exports={pack:function(A,t,e){var c,B,g,l=n(e),u=8*e-t-1,w=(1<<u)-1,h=w>>1,E=23===t?i(2,-24)-i(2,-77):0,f=A<0||0===A&&1/A<0?1:0,Q=0;for((A=r(A))!=A||A===1/0?(B=A!=A?1:0,c=w):(c=o(s(A)/a),A*(g=i(2,-c))<1&&(c--,g*=2),(A+=c+h>=1?E/g:E*i(2,1-h))*g>=2&&(c++,g/=2),c+h>=w?(B=0,c=w):c+h>=1?(B=(A*g-1)*i(2,t),c+=h):(B=A*i(2,h-1)*i(2,t),c=0));t>=8;l[Q++]=255&B,B/=256,t-=8);for(c=c<<t|B,u+=t;u>0;l[Q++]=255&c,c/=256,u-=8);return l[--Q]|=128*f,l},unpack:function(A,t){var e,n=A.length,r=8*n-t-1,o=(1<<r)-1,s=o>>1,a=r-7,c=n-1,B=A[c--],g=127&B;for(B>>=7;a>0;g=256*g+A[c],c--,a-=8);for(e=g&(1<<-a)-1,g>>=-a,a+=t;a>0;e=256*e+A[c],c--,a-=8);if(0===g)g=1-s;else{if(g===o)return e?NaN:B?-1/0:1/0;e+=i(2,t),g-=s}return(B?-1:1)*e*i(2,g-t)}}},8361:function(A,t,e){var n=e(7854),r=e(1702),i=e(7293),o=e(4326),s=n.Object,a=r("".split);A.exports=i((function(){return!s("z").propertyIsEnumerable(0)}))?function(A){return"String"==o(A)?a(A,""):s(A)}:s},9587:function(A,t,e){var n=e(614),r=e(111),i=e(7674);A.exports=function(A,t,e){var o,s;return i&&n(o=t.constructor)&&o!==e&&r(s=o.prototype)&&s!==e.prototype&&i(A,s),A}},2788:function(A,t,e){var n=e(1702),r=e(614),i=e(5465),o=n(Function.toString);r(i.inspectSource)||(i.inspectSource=function(A){return o(A)}),A.exports=i.inspectSource},8340:function(A,t,e){var n=e(111),r=e(8880);A.exports=function(A,t){n(t)&&"cause"in t&&r(A,"cause",t.cause)}},2423:function(A,t,e){var n=e(2109),r=e(1702),i=e(3501),o=e(111),s=e(2597),a=e(3070).f,c=e(8006),B=e(1156),g=e(9711),l=e(6677),u=!1,w=g("meta"),h=0,E=Object.isExtensible||function(){return!0},f=function(A){a(A,w,{value:{objectID:"O"+h++,weakData:{}}})},Q=A.exports={enable:function(){Q.enable=function(){},u=!0;var A=c.f,t=r([].splice),e={};e[w]=1,A(e).length&&(c.f=function(e){for(var n=A(e),r=0,i=n.length;r<i;r++)if(n[r]===w){t(n,r,1);break}return n},n({target:"Object",stat:!0,forced:!0},{getOwnPropertyNames:B.f}))},fastKey:function(A,t){if(!o(A))return"symbol"==typeof A?A:("string"==typeof A?"S":"P")+A;if(!s(A,w)){if(!E(A))return"F";if(!t)return"E";f(A)}return A[w].objectID},getWeakData:function(A,t){if(!s(A,w)){if(!E(A))return!0;if(!t)return!1;f(A)}return A[w].weakData},onFreeze:function(A){return l&&u&&E(A)&&!s(A,w)&&f(A),A}};i[w]=!0},9909:function(A,t,e){var n,r,i,o=e(8536),s=e(7854),a=e(1702),c=e(111),B=e(8880),g=e(2597),l=e(5465),u=e(6200),w=e(3501),h="Object already initialized",E=s.TypeError,f=s.WeakMap;if(o||l.state){var Q=l.state||(l.state=new f),d=a(Q.get),C=a(Q.has),M=a(Q.set);n=function(A,t){if(C(Q,A))throw new E(h);return t.facade=A,M(Q,A,t),t},r=function(A){return d(Q,A)||{}},i=function(A){return C(Q,A)}}else{var I=u("state");w[I]=!0,n=function(A,t){if(g(A,I))throw new E(h);return t.facade=A,B(A,I,t),t},r=function(A){return g(A,I)?A[I]:{}},i=function(A){return g(A,I)}}A.exports={set:n,get:r,has:i,enforce:function(A){return i(A)?r(A):n(A,{})},getterFor:function(A){return function(t){var e;if(!c(t)||(e=r(t)).type!==A)throw E("Incompatible receiver, "+A+" required");return e}}}},7659:function(A,t,e){var n=e(5112),r=e(7497),i=n("iterator"),o=Array.prototype;A.exports=function(A){return void 0!==A&&(r.Array===A||o[i]===A)}},3157:function(A,t,e){var n=e(4326);A.exports=Array.isArray||function(A){return"Array"==n(A)}},614:function(A){A.exports=function(A){return"function"==typeof A}},4411:function(A,t,e){var n=e(1702),r=e(7293),i=e(614),o=e(648),s=e(5005),a=e(2788),c=function(){},B=[],g=s("Reflect","construct"),l=/^\s*(?:class|function)\b/,u=n(l.exec),w=!l.exec(c),h=function(A){if(!i(A))return!1;try{return g(c,B,A),!0}catch(A){return!1}};A.exports=!g||r((function(){var A;return h(h.call)||!h(Object)||!h((function(){A=!0}))||A}))?function(A){if(!i(A))return!1;switch(o(A)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}return w||!!u(l,a(A))}:h},4705:function(A,t,e){var n=e(7293),r=e(614),i=/#|\.prototype\./,o=function(A,t){var e=a[s(A)];return e==B||e!=c&&(r(t)?n(t):!!t)},s=o.normalize=function(A){return String(A).replace(i,".").toLowerCase()},a=o.data={},c=o.NATIVE="N",B=o.POLYFILL="P";A.exports=o},5988:function(A,t,e){var n=e(111),r=Math.floor;A.exports=Number.isInteger||function(A){return!n(A)&&isFinite(A)&&r(A)===A}},111:function(A,t,e){var n=e(614);A.exports=function(A){return"object"==typeof A?null!==A:n(A)}},1913:function(A){A.exports=!1},7850:function(A,t,e){var n=e(111),r=e(4326),i=e(5112)("match");A.exports=function(A){var t;return n(A)&&(void 0!==(t=A[i])?!!t:"RegExp"==r(A))}},2190:function(A,t,e){var n=e(7854),r=e(5005),i=e(614),o=e(7976),s=e(3307),a=n.Object;A.exports=s?function(A){return"symbol"==typeof A}:function(A){var t=r("Symbol");return i(t)&&o(t.prototype,a(A))}},408:function(A,t,e){var n=e(7854),r=e(9974),i=e(6916),o=e(9670),s=e(6330),a=e(7659),c=e(6244),B=e(7976),g=e(8554),l=e(1246),u=e(9212),w=n.TypeError,h=function(A,t){this.stopped=A,this.result=t},E=h.prototype;A.exports=function(A,t,e){var n,f,Q,d,C,M,I,p=e&&e.that,D=!(!e||!e.AS_ENTRIES),y=!(!e||!e.IS_ITERATOR),v=!(!e||!e.INTERRUPTED),m=r(t,p),F=function(A){return n&&u(n,"normal",A),new h(!0,A)},Y=function(A){return D?(o(A),v?m(A[0],A[1],F):m(A[0],A[1])):v?m(A,F):m(A)};if(y)n=A;else{if(!(f=l(A)))throw w(s(A)+" is not iterable");if(a(f)){for(Q=0,d=c(A);d>Q;Q++)if((C=Y(A[Q]))&&B(E,C))return C;return new h(!1)}n=g(A,f)}for(M=n.next;!(I=i(M,n)).done;){try{C=Y(I.value)}catch(A){u(n,"throw",A)}if("object"==typeof C&&C&&B(E,C))return C}return new h(!1)}},9212:function(A,t,e){var n=e(6916),r=e(9670),i=e(8173);A.exports=function(A,t,e){var o,s;r(A);try{if(!(o=i(A,"return"))){if("throw"===t)throw e;return e}o=n(o,A)}catch(A){s=!0,o=A}if("throw"===t)throw e;if(s)throw o;return r(o),e}},3383:function(A,t,e){"use strict";var n,r,i,o=e(7293),s=e(614),a=e(30),c=e(9518),B=e(1320),g=e(5112),l=e(1913),u=g("iterator"),w=!1;[].keys&&("next"in(i=[].keys())?(r=c(c(i)))!==Object.prototype&&(n=r):w=!0),null==n||o((function(){var A={};return n[u].call(A)!==A}))?n={}:l&&(n=a(n)),s(n[u])||B(n,u,(function(){return this})),A.exports={IteratorPrototype:n,BUGGY_SAFARI_ITERATORS:w}},7497:function(A){A.exports={}},6244:function(A,t,e){var n=e(7466);A.exports=function(A){return n(A.length)}},5948:function(A,t,e){var n,r,i,o,s,a,c,B,g=e(7854),l=e(9974),u=e(1236).f,w=e(261).set,h=e(6833),E=e(1528),f=e(1036),Q=e(5268),d=g.MutationObserver||g.WebKitMutationObserver,C=g.document,M=g.process,I=g.Promise,p=u(g,"queueMicrotask"),D=p&&p.value;D||(n=function(){var A,t;for(Q&&(A=M.domain)&&A.exit();r;){t=r.fn,r=r.next;try{t()}catch(A){throw r?o():i=void 0,A}}i=void 0,A&&A.enter()},h||Q||f||!d||!C?!E&&I&&I.resolve?((c=I.resolve(void 0)).constructor=I,B=l(c.then,c),o=function(){B(n)}):Q?o=function(){M.nextTick(n)}:(w=l(w,g),o=function(){w(n)}):(s=!0,a=C.createTextNode(""),new d(n).observe(a,{characterData:!0}),o=function(){a.data=s=!s})),A.exports=D||function(A){var t={fn:A,next:void 0};i&&(i.next=t),r||(r=t,o()),i=t}},3366:function(A,t,e){var n=e(7854);A.exports=n.Promise},133:function(A,t,e){var n=e(7392),r=e(7293);A.exports=!!Object.getOwnPropertySymbols&&!r((function(){var A=Symbol();return!String(A)||!(Object(A)instanceof Symbol)||!Symbol.sham&&n&&n<41}))},8536:function(A,t,e){var n=e(7854),r=e(614),i=e(2788),o=n.WeakMap;A.exports=r(o)&&/native code/.test(i(o))},8523:function(A,t,e){"use strict";var n=e(9662),r=function(A){var t,e;this.promise=new A((function(A,n){if(void 0!==t||void 0!==e)throw TypeError("Bad Promise constructor");t=A,e=n})),this.resolve=n(t),this.reject=n(e)};A.exports.f=function(A){return new r(A)}},6277:function(A,t,e){var n=e(1340);A.exports=function(A,t){return void 0===A?arguments.length<2?"":t:n(A)}},3929:function(A,t,e){var n=e(7854),r=e(7850),i=n.TypeError;A.exports=function(A){if(r(A))throw i("The method doesn't accept regular expressions");return A}},7023:function(A,t,e){var n=e(7854).isFinite;A.exports=Number.isFinite||function(A){return"number"==typeof A&&n(A)}},1574:function(A,t,e){"use strict";var n=e(9781),r=e(1702),i=e(6916),o=e(7293),s=e(1956),a=e(5181),c=e(5296),B=e(7908),g=e(8361),l=Object.assign,u=Object.defineProperty,w=r([].concat);A.exports=!l||o((function(){if(n&&1!==l({b:1},l(u({},"a",{enumerable:!0,get:function(){u(this,"b",{value:3,enumerable:!1})}}),{b:2})).b)return!0;var A={},t={},e=Symbol(),r="abcdefghijklmnopqrst";return A[e]=7,r.split("").forEach((function(A){t[A]=A})),7!=l({},A)[e]||s(l({},t)).join("")!=r}))?function(A,t){for(var e=B(A),r=arguments.length,o=1,l=a.f,u=c.f;r>o;)for(var h,E=g(arguments[o++]),f=l?w(s(E),l(E)):s(E),Q=f.length,d=0;Q>d;)h=f[d++],n&&!i(u,E,h)||(e[h]=E[h]);return e}:l},30:function(A,t,e){var n,r=e(9670),i=e(6048),o=e(748),s=e(3501),a=e(490),c=e(317),B=e(6200),g="prototype",l="script",u=B("IE_PROTO"),w=function(){},h=function(A){return"<"+l+">"+A+"</"+l+">"},E=function(A){A.write(h("")),A.close();var t=A.parentWindow.Object;return A=null,t},f=function(){try{n=new ActiveXObject("htmlfile")}catch(A){}var A,t,e;f="undefined"!=typeof document?document.domain&&n?E(n):(t=c("iframe"),e="java"+l+":",t.style.display="none",a.appendChild(t),t.src=String(e),(A=t.contentWindow.document).open(),A.write(h("document.F=Object")),A.close(),A.F):E(n);for(var r=o.length;r--;)delete f[g][o[r]];return f()};s[u]=!0,A.exports=Object.create||function(A,t){var e;return null!==A?(w[g]=r(A),e=new w,w[g]=null,e[u]=A):e=f(),void 0===t?e:i(e,t)}},6048:function(A,t,e){var n=e(9781),r=e(3070),i=e(9670),o=e(5656),s=e(1956);A.exports=n?Object.defineProperties:function(A,t){i(A);for(var e,n=o(t),a=s(t),c=a.length,B=0;c>B;)r.f(A,e=a[B++],n[e]);return A}},3070:function(A,t,e){var n=e(7854),r=e(9781),i=e(4664),o=e(9670),s=e(4948),a=n.TypeError,c=Object.defineProperty;t.f=r?c:function(A,t,e){if(o(A),t=s(t),o(e),i)try{return c(A,t,e)}catch(A){}if("get"in e||"set"in e)throw a("Accessors not supported");return"value"in e&&(A[t]=e.value),A}},1236:function(A,t,e){var n=e(9781),r=e(6916),i=e(5296),o=e(9114),s=e(5656),a=e(4948),c=e(2597),B=e(4664),g=Object.getOwnPropertyDescriptor;t.f=n?g:function(A,t){if(A=s(A),t=a(t),B)try{return g(A,t)}catch(A){}if(c(A,t))return o(!r(i.f,A,t),A[t])}},1156:function(A,t,e){var n=e(4326),r=e(5656),i=e(8006).f,o=e(206),s="object"==typeof window&&window&&Object.getOwnPropertyNames?Object.getOwnPropertyNames(window):[];A.exports.f=function(A){return s&&"Window"==n(A)?function(A){try{return i(A)}catch(A){return o(s)}}(A):i(r(A))}},8006:function(A,t,e){var n=e(6324),r=e(748).concat("length","prototype");t.f=Object.getOwnPropertyNames||function(A){return n(A,r)}},5181:function(A,t){t.f=Object.getOwnPropertySymbols},9518:function(A,t,e){var n=e(7854),r=e(2597),i=e(614),o=e(7908),s=e(6200),a=e(8544),c=s("IE_PROTO"),B=n.Object,g=B.prototype;A.exports=a?B.getPrototypeOf:function(A){var t=o(A);if(r(t,c))return t[c];var e=t.constructor;return i(e)&&t instanceof e?e.prototype:t instanceof B?g:null}},7976:function(A,t,e){var n=e(1702);A.exports=n({}.isPrototypeOf)},6324:function(A,t,e){var n=e(1702),r=e(2597),i=e(5656),o=e(1318).indexOf,s=e(3501),a=n([].push);A.exports=function(A,t){var e,n=i(A),c=0,B=[];for(e in n)!r(s,e)&&r(n,e)&&a(B,e);for(;t.length>c;)r(n,e=t[c++])&&(~o(B,e)||a(B,e));return B}},1956:function(A,t,e){var n=e(6324),r=e(748);A.exports=Object.keys||function(A){return n(A,r)}},5296:function(A,t){"use strict";var e={}.propertyIsEnumerable,n=Object.getOwnPropertyDescriptor,r=n&&!e.call({1:2},1);t.f=r?function(A){var t=n(this,A);return!!t&&t.enumerable}:e},7674:function(A,t,e){var n=e(1702),r=e(9670),i=e(6077);A.exports=Object.setPrototypeOf||("__proto__"in{}?function(){var A,t=!1,e={};try{(A=n(Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set))(e,[]),t=e instanceof Array}catch(A){}return function(e,n){return r(e),i(n),t?A(e,n):e.__proto__=n,e}}():void 0)},4699:function(A,t,e){var n=e(9781),r=e(1702),i=e(1956),o=e(5656),s=r(e(5296).f),a=r([].push),c=function(A){return function(t){for(var e,r=o(t),c=i(r),B=c.length,g=0,l=[];B>g;)e=c[g++],n&&!s(r,e)||a(l,A?[e,r[e]]:r[e]);return l}};A.exports={entries:c(!0),values:c(!1)}},288:function(A,t,e){"use strict";var n=e(1694),r=e(648);A.exports=n?{}.toString:function(){return"[object "+r(this)+"]"}},2140:function(A,t,e){var n=e(7854),r=e(6916),i=e(614),o=e(111),s=n.TypeError;A.exports=function(A,t){var e,n;if("string"===t&&i(e=A.toString)&&!o(n=r(e,A)))return n;if(i(e=A.valueOf)&&!o(n=r(e,A)))return n;if("string"!==t&&i(e=A.toString)&&!o(n=r(e,A)))return n;throw s("Can't convert object to primitive value")}},3887:function(A,t,e){var n=e(5005),r=e(1702),i=e(8006),o=e(5181),s=e(9670),a=r([].concat);A.exports=n("Reflect","ownKeys")||function(A){var t=i.f(s(A)),e=o.f;return e?a(t,e(A)):t}},857:function(A,t,e){var n=e(7854);A.exports=n},2534:function(A){A.exports=function(A){try{return{error:!1,value:A()}}catch(A){return{error:!0,value:A}}}},9478:function(A,t,e){var n=e(9670),r=e(111),i=e(8523);A.exports=function(A,t){if(n(A),r(t)&&t.constructor===A)return t;var e=i.f(A);return(0,e.resolve)(t),e.promise}},2248:function(A,t,e){var n=e(1320);A.exports=function(A,t,e){for(var r in t)n(A,r,t[r],e);return A}},1320:function(A,t,e){var n=e(7854),r=e(614),i=e(2597),o=e(8880),s=e(3505),a=e(2788),c=e(9909),B=e(6530).CONFIGURABLE,g=c.get,l=c.enforce,u=String(String).split("String");(A.exports=function(A,t,e,a){var c,g=!!a&&!!a.unsafe,w=!!a&&!!a.enumerable,h=!!a&&!!a.noTargetGet,E=a&&void 0!==a.name?a.name:t;r(e)&&("Symbol("===String(E).slice(0,7)&&(E="["+String(E).replace(/^Symbol\(([^)]*)\)/,"$1")+"]"),(!i(e,"name")||B&&e.name!==E)&&o(e,"name",E),(c=l(e)).source||(c.source=u.join("string"==typeof E?E:""))),A!==n?(g?!h&&A[t]&&(w=!0):delete A[t],w?A[t]=e:o(A,t,e)):w?A[t]=e:s(t,e)})(Function.prototype,"toString",(function(){return r(this)&&g(this).source||a(this)}))},7651:function(A,t,e){var n=e(7854),r=e(6916),i=e(9670),o=e(614),s=e(4326),a=e(2261),c=n.TypeError;A.exports=function(A,t){var e=A.exec;if(o(e)){var n=r(e,A,t);return null!==n&&i(n),n}if("RegExp"===s(A))return r(a,A,t);throw c("RegExp#exec called on incompatible receiver")}},2261:function(A,t,e){"use strict";var n,r,i=e(6916),o=e(1702),s=e(1340),a=e(7066),c=e(2999),B=e(2309),g=e(30),l=e(9909).get,u=e(9441),w=e(7168),h=B("native-string-replace",String.prototype.replace),E=RegExp.prototype.exec,f=E,Q=o("".charAt),d=o("".indexOf),C=o("".replace),M=o("".slice),I=(r=/b*/g,i(E,n=/a/,"a"),i(E,r,"a"),0!==n.lastIndex||0!==r.lastIndex),p=c.UNSUPPORTED_Y||c.BROKEN_CARET,D=void 0!==/()??/.exec("")[1];(I||D||p||u||w)&&(f=function(A){var t,e,n,r,o,c,B,u=this,w=l(u),y=s(A),v=w.raw;if(v)return v.lastIndex=u.lastIndex,t=i(f,v,y),u.lastIndex=v.lastIndex,t;var m=w.groups,F=p&&u.sticky,Y=i(a,u),b=u.source,z=0,U=y;if(F&&(Y=C(Y,"y",""),-1===d(Y,"g")&&(Y+="g"),U=M(y,u.lastIndex),u.lastIndex>0&&(!u.multiline||u.multiline&&"\n"!==Q(y,u.lastIndex-1))&&(b="(?: "+b+")",U=" "+U,z++),e=new RegExp("^(?:"+b+")",Y)),D&&(e=new RegExp("^"+b+"$(?!\\s)",Y)),I&&(n=u.lastIndex),r=i(E,F?e:u,U),F?r?(r.input=M(r.input,z),r[0]=M(r[0],z),r.index=u.lastIndex,u.lastIndex+=r[0].length):u.lastIndex=0:I&&r&&(u.lastIndex=u.global?r.index+r[0].length:n),D&&r&&r.length>1&&i(h,r[0],e,(function(){for(o=1;o<arguments.length-2;o++)void 0===arguments[o]&&(r[o]=void 0)})),r&&m)for(r.groups=c=g(null),o=0;o<m.length;o++)c[(B=m[o])[0]]=r[B[1]];return r}),A.exports=f},7066:function(A,t,e){"use strict";var n=e(9670);A.exports=function(){var A=n(this),t="";return A.global&&(t+="g"),A.ignoreCase&&(t+="i"),A.multiline&&(t+="m"),A.dotAll&&(t+="s"),A.unicode&&(t+="u"),A.sticky&&(t+="y"),t}},2999:function(A,t,e){var n=e(7293),r=e(7854).RegExp;t.UNSUPPORTED_Y=n((function(){var A=r("a","y");return A.lastIndex=2,null!=A.exec("abcd")})),t.BROKEN_CARET=n((function(){var A=r("^r","gy");return A.lastIndex=2,null!=A.exec("str")}))},9441:function(A,t,e){var n=e(7293),r=e(7854).RegExp;A.exports=n((function(){var A=r(".","s");return!(A.dotAll&&A.exec("\n")&&"s"===A.flags)}))},7168:function(A,t,e){var n=e(7293),r=e(7854).RegExp;A.exports=n((function(){var A=r("(?<a>b)","g");return"b"!==A.exec("b").groups.a||"bc"!=="b".replace(A,"$<a>c")}))},4488:function(A,t,e){var n=e(7854).TypeError;A.exports=function(A){if(null==A)throw n("Can't call method on "+A);return A}},3505:function(A,t,e){var n=e(7854),r=Object.defineProperty;A.exports=function(A,t){try{r(n,A,{value:t,configurable:!0,writable:!0})}catch(e){n[A]=t}return t}},6340:function(A,t,e){"use strict";var n=e(5005),r=e(3070),i=e(5112),o=e(9781),s=i("species");A.exports=function(A){var t=n(A),e=r.f;o&&t&&!t[s]&&e(t,s,{configurable:!0,get:function(){return this}})}},8003:function(A,t,e){var n=e(3070).f,r=e(2597),i=e(5112)("toStringTag");A.exports=function(A,t,e){A&&!r(A=e?A:A.prototype,i)&&n(A,i,{configurable:!0,value:t})}},6200:function(A,t,e){var n=e(2309),r=e(9711),i=n("keys");A.exports=function(A){return i[A]||(i[A]=r(A))}},5465:function(A,t,e){var n=e(7854),r=e(3505),i="__core-js_shared__",o=n[i]||r(i,{});A.exports=o},2309:function(A,t,e){var n=e(1913),r=e(5465);(A.exports=function(A,t){return r[A]||(r[A]=void 0!==t?t:{})})("versions",[]).push({version:"3.19.0",mode:n?"pure":"global",copyright:"© 2021 Denis Pushkarev (zloirock.ru)"})},6707:function(A,t,e){var n=e(9670),r=e(9483),i=e(5112)("species");A.exports=function(A,t){var e,o=n(A).constructor;return void 0===o||null==(e=n(o)[i])?t:r(e)}},3429:function(A,t,e){var n=e(7293);A.exports=function(A){return n((function(){var t=""[A]('"');return t!==t.toLowerCase()||t.split('"').length>3}))}},8710:function(A,t,e){var n=e(1702),r=e(9303),i=e(1340),o=e(4488),s=n("".charAt),a=n("".charCodeAt),c=n("".slice),B=function(A){return function(t,e){var n,B,g=i(o(t)),l=r(e),u=g.length;return l<0||l>=u?A?"":void 0:(n=a(g,l))<55296||n>56319||l+1===u||(B=a(g,l+1))<56320||B>57343?A?s(g,l):n:A?c(g,l,l+2):B-56320+(n-55296<<10)+65536}};A.exports={codeAt:B(!1),charAt:B(!0)}},8415:function(A,t,e){"use strict";var n=e(7854),r=e(9303),i=e(1340),o=e(4488),s=n.RangeError;A.exports=function(A){var t=i(o(this)),e="",n=r(A);if(n<0||n==1/0)throw s("Wrong number of repetitions");for(;n>0;(n>>>=1)&&(t+=t))1&n&&(e+=t);return e}},6091:function(A,t,e){var n=e(6530).PROPER,r=e(7293),i=e(1361);A.exports=function(A){return r((function(){return!!i[A]()||"​᠎"!=="​᠎"[A]()||n&&i[A].name!==A}))}},3111:function(A,t,e){var n=e(1702),r=e(4488),i=e(1340),o=e(1361),s=n("".replace),a="["+o+"]",c=RegExp("^"+a+a+"*"),B=RegExp(a+a+"*$"),g=function(A){return function(t){var e=i(r(t));return 1&A&&(e=s(e,c,"")),2&A&&(e=s(e,B,"")),e}};A.exports={start:g(1),end:g(2),trim:g(3)}},261:function(A,t,e){var n,r,i,o,s=e(7854),a=e(2104),c=e(9974),B=e(614),g=e(2597),l=e(7293),u=e(490),w=e(206),h=e(317),E=e(6833),f=e(5268),Q=s.setImmediate,d=s.clearImmediate,C=s.process,M=s.Dispatch,I=s.Function,p=s.MessageChannel,D=s.String,y=0,v={},m="onreadystatechange";try{n=s.location}catch(A){}var F=function(A){if(g(v,A)){var t=v[A];delete v[A],t()}},Y=function(A){return function(){F(A)}},b=function(A){F(A.data)},z=function(A){s.postMessage(D(A),n.protocol+"//"+n.host)};Q&&d||(Q=function(A){var t=w(arguments,1);return v[++y]=function(){a(B(A)?A:I(A),void 0,t)},r(y),y},d=function(A){delete v[A]},f?r=function(A){C.nextTick(Y(A))}:M&&M.now?r=function(A){M.now(Y(A))}:p&&!E?(o=(i=new p).port2,i.port1.onmessage=b,r=c(o.postMessage,o)):s.addEventListener&&B(s.postMessage)&&!s.importScripts&&n&&"file:"!==n.protocol&&!l(z)?(r=z,s.addEventListener("message",b,!1)):r=m in h("script")?function(A){u.appendChild(h("script"))[m]=function(){u.removeChild(this),F(A)}}:function(A){setTimeout(Y(A),0)}),A.exports={set:Q,clear:d}},863:function(A,t,e){var n=e(1702);A.exports=n(1..valueOf)},1400:function(A,t,e){var n=e(9303),r=Math.max,i=Math.min;A.exports=function(A,t){var e=n(A);return e<0?r(e+t,0):i(e,t)}},7067:function(A,t,e){var n=e(7854),r=e(9303),i=e(7466),o=n.RangeError;A.exports=function(A){if(void 0===A)return 0;var t=r(A),e=i(t);if(t!==e)throw o("Wrong length or index");return e}},5656:function(A,t,e){var n=e(8361),r=e(4488);A.exports=function(A){return n(r(A))}},9303:function(A){var t=Math.ceil,e=Math.floor;A.exports=function(A){var n=+A;return n!=n||0===n?0:(n>0?e:t)(n)}},7466:function(A,t,e){var n=e(9303),r=Math.min;A.exports=function(A){return A>0?r(n(A),9007199254740991):0}},7908:function(A,t,e){var n=e(7854),r=e(4488),i=n.Object;A.exports=function(A){return i(r(A))}},4590:function(A,t,e){var n=e(7854),r=e(3002),i=n.RangeError;A.exports=function(A,t){var e=r(A);if(e%t)throw i("Wrong offset");return e}},3002:function(A,t,e){var n=e(7854),r=e(9303),i=n.RangeError;A.exports=function(A){var t=r(A);if(t<0)throw i("The argument can't be less than 0");return t}},7593:function(A,t,e){var n=e(7854),r=e(6916),i=e(111),o=e(2190),s=e(8173),a=e(2140),c=e(5112),B=n.TypeError,g=c("toPrimitive");A.exports=function(A,t){if(!i(A)||o(A))return A;var e,n=s(A,g);if(n){if(void 0===t&&(t="default"),e=r(n,A,t),!i(e)||o(e))return e;throw B("Can't convert object to primitive value")}return void 0===t&&(t="number"),a(A,t)}},4948:function(A,t,e){var n=e(7593),r=e(2190);A.exports=function(A){var t=n(A,"string");return r(t)?t:t+""}},1694:function(A,t,e){var n={};n[e(5112)("toStringTag")]="z",A.exports="[object z]"===String(n)},1340:function(A,t,e){var n=e(7854),r=e(648),i=n.String;A.exports=function(A){if("Symbol"===r(A))throw TypeError("Cannot convert a Symbol value to a string");return i(A)}},6330:function(A,t,e){var n=e(7854).String;A.exports=function(A){try{return n(A)}catch(A){return"Object"}}},9843:function(A,t,e){"use strict";var n=e(2109),r=e(7854),i=e(6916),o=e(9781),s=e(3832),a=e(2094),c=e(2091),B=e(5787),g=e(9114),l=e(8880),u=e(5988),w=e(7466),h=e(7067),E=e(4590),f=e(4948),Q=e(2597),d=e(648),C=e(111),M=e(2190),I=e(30),p=e(7976),D=e(7674),y=e(8006).f,v=e(7321),m=e(2092).forEach,F=e(6340),Y=e(3070),b=e(1236),z=e(9909),U=e(9587),S=z.get,x=z.set,T=Y.f,P=b.f,N=Math.round,R=r.RangeError,G=c.ArrayBuffer,H=G.prototype,k=c.DataView,L=a.NATIVE_ARRAY_BUFFER_VIEWS,J=a.TYPED_ARRAY_CONSTRUCTOR,j=a.TYPED_ARRAY_TAG,O=a.TypedArray,W=a.TypedArrayPrototype,K=a.aTypedArrayConstructor,V=a.isTypedArray,X="BYTES_PER_ELEMENT",Z="Wrong length",_=function(A,t){K(A);for(var e=0,n=t.length,r=new A(n);n>e;)r[e]=t[e++];return r},q=function(A,t){T(A,t,{get:function(){return S(this)[t]}})},$=function(A){var t;return p(H,A)||"ArrayBuffer"==(t=d(A))||"SharedArrayBuffer"==t},AA=function(A,t){return V(A)&&!M(t)&&t in A&&u(+t)&&t>=0},tA=function(A,t){return t=f(t),AA(A,t)?g(2,A[t]):P(A,t)},eA=function(A,t,e){return t=f(t),!(AA(A,t)&&C(e)&&Q(e,"value"))||Q(e,"get")||Q(e,"set")||e.configurable||Q(e,"writable")&&!e.writable||Q(e,"enumerable")&&!e.enumerable?T(A,t,e):(A[t]=e.value,A)};o?(L||(b.f=tA,Y.f=eA,q(W,"buffer"),q(W,"byteOffset"),q(W,"byteLength"),q(W,"length")),n({target:"Object",stat:!0,forced:!L},{getOwnPropertyDescriptor:tA,defineProperty:eA}),A.exports=function(A,t,e){var o=A.match(/\d+$/)[0]/8,a=A+(e?"Clamped":"")+"Array",c="get"+A,g="set"+A,u=r[a],f=u,Q=f&&f.prototype,d={},M=function(A,t){T(A,t,{get:function(){return function(A,t){var e=S(A);return e.view[c](t*o+e.byteOffset,!0)}(this,t)},set:function(A){return function(A,t,n){var r=S(A);e&&(n=(n=N(n))<0?0:n>255?255:255&n),r.view[g](t*o+r.byteOffset,n,!0)}(this,t,A)},enumerable:!0})};L?s&&(f=t((function(A,t,e,n){return B(A,Q),U(C(t)?$(t)?void 0!==n?new u(t,E(e,o),n):void 0!==e?new u(t,E(e,o)):new u(t):V(t)?_(f,t):i(v,f,t):new u(h(t)),A,f)})),D&&D(f,O),m(y(u),(function(A){A in f||l(f,A,u[A])})),f.prototype=Q):(f=t((function(A,t,e,n){B(A,Q);var r,s,a,c=0,g=0;if(C(t)){if(!$(t))return V(t)?_(f,t):i(v,f,t);r=t,g=E(e,o);var l=t.byteLength;if(void 0===n){if(l%o)throw R(Z);if((s=l-g)<0)throw R(Z)}else if((s=w(n)*o)+g>l)throw R(Z);a=s/o}else a=h(t),r=new G(s=a*o);for(x(A,{buffer:r,byteOffset:g,byteLength:s,length:a,view:new k(r)});c<a;)M(A,c++)})),D&&D(f,O),Q=f.prototype=I(W)),Q.constructor!==f&&l(Q,"constructor",f),l(Q,J,f),j&&l(Q,j,a),d[a]=f,n({global:!0,forced:f!=u,sham:!L},d),X in f||l(f,X,o),X in Q||l(Q,X,o),F(a)}):A.exports=function(){}},3832:function(A,t,e){var n=e(7854),r=e(7293),i=e(7072),o=e(2094).NATIVE_ARRAY_BUFFER_VIEWS,s=n.ArrayBuffer,a=n.Int8Array;A.exports=!o||!r((function(){a(1)}))||!r((function(){new a(-1)}))||!i((function(A){new a,new a(null),new a(1.5),new a(A)}),!0)||r((function(){return 1!==new a(new s(2),1,void 0).length}))},3074:function(A,t,e){var n=e(7745),r=e(6304);A.exports=function(A,t){return n(r(A),t)}},7321:function(A,t,e){var n=e(9974),r=e(6916),i=e(9483),o=e(7908),s=e(6244),a=e(8554),c=e(1246),B=e(7659),g=e(2094).aTypedArrayConstructor;A.exports=function(A){var t,e,l,u,w,h,E=i(this),f=o(A),Q=arguments.length,d=Q>1?arguments[1]:void 0,C=void 0!==d,M=c(f);if(M&&!B(M))for(h=(w=a(f,M)).next,f=[];!(u=r(h,w)).done;)f.push(u.value);for(C&&Q>2&&(d=n(d,arguments[2])),e=s(f),l=new(g(E))(e),t=0;e>t;t++)l[t]=C?d(f[t],t):f[t];return l}},6304:function(A,t,e){var n=e(2094),r=e(6707),i=n.TYPED_ARRAY_CONSTRUCTOR,o=n.aTypedArrayConstructor;A.exports=function(A){return o(r(A,A[i]))}},9711:function(A,t,e){var n=e(1702),r=0,i=Math.random(),o=n(1..toString);A.exports=function(A){return"Symbol("+(void 0===A?"":A)+")_"+o(++r+i,36)}},3307:function(A,t,e){var n=e(133);A.exports=n&&!Symbol.sham&&"symbol"==typeof Symbol.iterator},6061:function(A,t,e){var n=e(5112);t.f=n},5112:function(A,t,e){var n=e(7854),r=e(2309),i=e(2597),o=e(9711),s=e(133),a=e(3307),c=r("wks"),B=n.Symbol,g=B&&B.for,l=a?B:B&&B.withoutSetter||o;A.exports=function(A){if(!i(c,A)||!s&&"string"!=typeof c[A]){var t="Symbol."+A;s&&i(B,A)?c[A]=B[A]:c[A]=a&&g?g(t):l(t)}return c[A]}},1361:function(A){A.exports="\t\n\v\f\r                　\u2028\u2029\ufeff"},9170:function(A,t,e){"use strict";var n=e(2109),r=e(7854),i=e(7976),o=e(9518),s=e(7674),a=e(9920),c=e(30),B=e(8880),g=e(9114),l=e(7741),u=e(8340),w=e(408),h=e(6277),E=e(2914),f=r.Error,Q=[].push,d=function(A,t){var e=i(C,this)?this:c(C),n=arguments.length>2?arguments[2]:void 0;s&&(e=s(new f(void 0),o(e))),B(e,"message",h(t,"")),E&&B(e,"stack",l(e.stack,1)),u(e,n);var r=[];return w(A,Q,{that:r}),B(e,"errors",r),e};s?s(d,f):a(d,f);var C=d.prototype=c(f.prototype,{constructor:g(1,d),message:g(1,""),name:g(1,"AggregateError")});n({global:!0},{AggregateError:d})},2222:function(A,t,e){"use strict";var n=e(2109),r=e(7854),i=e(7293),o=e(3157),s=e(111),a=e(7908),c=e(6244),B=e(6135),g=e(5417),l=e(1194),u=e(5112),w=e(7392),h=u("isConcatSpreadable"),E=9007199254740991,f="Maximum allowed index exceeded",Q=r.TypeError,d=w>=51||!i((function(){var A=[];return A[h]=!1,A.concat()[0]!==A})),C=l("concat"),M=function(A){if(!s(A))return!1;var t=A[h];return void 0!==t?!!t:o(A)};n({target:"Array",proto:!0,forced:!d||!C},{concat:function(A){var t,e,n,r,i,o=a(this),s=g(o,0),l=0;for(t=-1,n=arguments.length;t<n;t++)if(M(i=-1===t?o:arguments[t])){if(l+(r=c(i))>E)throw Q(f);for(e=0;e<r;e++,l++)e in i&&B(s,l,i[e])}else{if(l>=E)throw Q(f);B(s,l++,i)}return s.length=l,s}})},545:function(A,t,e){var n=e(2109),r=e(1048),i=e(1223);n({target:"Array",proto:!0},{copyWithin:r}),i("copyWithin")},3290:function(A,t,e){var n=e(2109),r=e(1285),i=e(1223);n({target:"Array",proto:!0},{fill:r}),i("fill")},7327:function(A,t,e){"use strict";var n=e(2109),r=e(2092).filter;n({target:"Array",proto:!0,forced:!e(1194)("filter")},{filter:function(A){return r(this,A,arguments.length>1?arguments[1]:void 0)}})},1038:function(A,t,e){var n=e(2109),r=e(8457);n({target:"Array",stat:!0,forced:!e(7072)((function(A){Array.from(A)}))},{from:r})},6699:function(A,t,e){"use strict";var n=e(2109),r=e(1318).includes,i=e(1223);n({target:"Array",proto:!0},{includes:function(A){return r(this,A,arguments.length>1?arguments[1]:void 0)}}),i("includes")},6992:function(A,t,e){"use strict";var n=e(5656),r=e(1223),i=e(7497),o=e(9909),s=e(654),a="Array Iterator",c=o.set,B=o.getterFor(a);A.exports=s(Array,"Array",(function(A,t){c(this,{type:a,target:n(A),index:0,kind:t})}),(function(){var A=B(this),t=A.target,e=A.kind,n=A.index++;return!t||n>=t.length?(A.target=void 0,{value:void 0,done:!0}):"keys"==e?{value:n,done:!1}:"values"==e?{value:t[n],done:!1}:{value:[n,t[n]],done:!1}}),"values"),i.Arguments=i.Array,r("keys"),r("values"),r("entries")},9600:function(A,t,e){"use strict";var n=e(2109),r=e(1702),i=e(8361),o=e(5656),s=e(9341),a=r([].join),c=i!=Object,B=s("join",",");n({target:"Array",proto:!0,forced:c||!B},{join:function(A){return a(o(this),void 0===A?",":A)}})},1249:function(A,t,e){"use strict";var n=e(2109),r=e(2092).map;n({target:"Array",proto:!0,forced:!e(1194)("map")},{map:function(A){return r(this,A,arguments.length>1?arguments[1]:void 0)}})},7042:function(A,t,e){"use strict";var n=e(2109),r=e(7854),i=e(3157),o=e(4411),s=e(111),a=e(1400),c=e(6244),B=e(5656),g=e(6135),l=e(5112),u=e(1194),w=e(206),h=u("slice"),E=l("species"),f=r.Array,Q=Math.max;n({target:"Array",proto:!0,forced:!h},{slice:function(A,t){var e,n,r,l=B(this),u=c(l),h=a(A,u),d=a(void 0===t?u:t,u);if(i(l)&&(e=l.constructor,(o(e)&&(e===f||i(e.prototype))||s(e)&&null===(e=e[E]))&&(e=void 0),e===f||void 0===e))return w(l,h,d);for(n=new(void 0===e?f:e)(Q(d-h,0)),r=0;h<d;h++,r++)h in l&&g(n,r,l[h]);return n.length=r,n}})},2707:function(A,t,e){"use strict";var n=e(2109),r=e(1702),i=e(9662),o=e(7908),s=e(6244),a=e(1340),c=e(7293),B=e(4362),g=e(9341),l=e(8886),u=e(256),w=e(7392),h=e(8008),E=[],f=r(E.sort),Q=r(E.push),d=c((function(){E.sort(void 0)})),C=c((function(){E.sort(null)})),M=g("sort"),I=!c((function(){if(w)return w<70;if(!(l&&l>3)){if(u)return!0;if(h)return h<603;var A,t,e,n,r="";for(A=65;A<76;A++){switch(t=String.fromCharCode(A),A){case 66:case 69:case 70:case 72:e=3;break;case 68:case 71:e=4;break;default:e=2}for(n=0;n<47;n++)E.push({k:t+n,v:e})}for(E.sort((function(A,t){return t.v-A.v})),n=0;n<E.length;n++)t=E[n].k.charAt(0),r.charAt(r.length-1)!==t&&(r+=t);return"DGBEFHACIJK"!==r}}));n({target:"Array",proto:!0,forced:d||!C||!M||!I},{sort:function(A){void 0!==A&&i(A);var t=o(this);if(I)return void 0===A?f(t):f(t,A);var e,n,r=[],c=s(t);for(n=0;n<c;n++)n in t&&Q(r,t[n]);for(B(r,function(A){return function(t,e){return void 0===e?-1:void 0===t?1:void 0!==A?+A(t,e)||0:a(t)>a(e)?1:-1}}(A)),e=r.length,n=0;n<e;)t[n]=r[n++];for(;n<c;)delete t[n++];return t}})},561:function(A,t,e){"use strict";var n=e(2109),r=e(7854),i=e(1400),o=e(9303),s=e(6244),a=e(7908),c=e(5417),B=e(6135),g=e(1194)("splice"),l=r.TypeError,u=Math.max,w=Math.min;n({target:"Array",proto:!0,forced:!g},{splice:function(A,t){var e,n,r,g,h,E,f=a(this),Q=s(f),d=i(A,Q),C=arguments.length;if(0===C?e=n=0:1===C?(e=0,n=Q-d):(e=C-2,n=w(u(o(t),0),Q-d)),Q+e-n>9007199254740991)throw l("Maximum allowed length exceeded");for(r=c(f,n),g=0;g<n;g++)(h=d+g)in f&&B(r,g,f[h]);if(r.length=n,e<n){for(g=d;g<Q-n;g++)E=g+e,(h=g+n)in f?f[E]=f[h]:delete f[E];for(g=Q;g>Q-n+e;g--)delete f[g-1]}else if(e>n)for(g=Q-n;g>d;g--)E=g+e-1,(h=g+n-1)in f?f[E]=f[h]:delete f[E];for(g=0;g<e;g++)f[g+d]=arguments[g+2];return f.length=Q-n+e,r}})},6078:function(A,t,e){var n=e(2597),r=e(1320),i=e(8709),o=e(5112)("toPrimitive"),s=Date.prototype;n(s,o)||r(s,o,i)},8309:function(A,t,e){var n=e(9781),r=e(6530).EXISTS,i=e(1702),o=e(3070).f,s=Function.prototype,a=i(s.toString),c=/^\s*function ([^ (]*)/,B=i(c.exec);n&&!r&&o(s,"name",{configurable:!0,get:function(){try{return B(c,a(this))[1]}catch(A){return""}}})},5837:function(A,t,e){e(2109)({global:!0},{globalThis:e(7854)})},3706:function(A,t,e){var n=e(7854);e(8003)(n.JSON,"JSON",!0)},1532:function(A,t,e){"use strict";e(7710)("Map",(function(A){return function(){return A(this,arguments.length?arguments[0]:void 0)}}),e(5631))},2703:function(A,t,e){e(8003)(Math,"Math",!0)},9653:function(A,t,e){"use strict";var n=e(9781),r=e(7854),i=e(1702),o=e(4705),s=e(1320),a=e(2597),c=e(9587),B=e(7976),g=e(2190),l=e(7593),u=e(7293),w=e(8006).f,h=e(1236).f,E=e(3070).f,f=e(863),Q=e(3111).trim,d="Number",C=r[d],M=C.prototype,I=r.TypeError,p=i("".slice),D=i("".charCodeAt),y=function(A){var t,e,n,r,i,o,s,a,c=l(A,"number");if(g(c))throw I("Cannot convert a Symbol value to a number");if("string"==typeof c&&c.length>2)if(c=Q(c),43===(t=D(c,0))||45===t){if(88===(e=D(c,2))||120===e)return NaN}else if(48===t){switch(D(c,1)){case 66:case 98:n=2,r=49;break;case 79:case 111:n=8,r=55;break;default:return+c}for(o=(i=p(c,2)).length,s=0;s<o;s++)if((a=D(i,s))<48||a>r)return NaN;return parseInt(i,n)}return+c};if(o(d,!C(" 0o1")||!C("0b1")||C("+0x1"))){for(var v,m=function(A){var t=arguments.length<1?0:C(function(A){var t=l(A,"number");return"bigint"==typeof t?t:y(t)}(A)),e=this;return B(M,e)&&u((function(){f(e)}))?c(Object(t),e,m):t},F=n?w(C):"MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,EPSILON,MAX_SAFE_INTEGER,MIN_SAFE_INTEGER,isFinite,isInteger,isNaN,isSafeInteger,parseFloat,parseInt,fromString,range".split(","),Y=0;F.length>Y;Y++)a(C,v=F[Y])&&!a(m,v)&&E(m,v,h(C,v));m.prototype=M,M.constructor=m,s(r,d,m)}},3299:function(A,t,e){e(2109)({target:"Number",stat:!0},{EPSILON:Math.pow(2,-52)})},5192:function(A,t,e){e(2109)({target:"Number",stat:!0},{isFinite:e(7023)})},3161:function(A,t,e){e(2109)({target:"Number",stat:!0},{isInteger:e(5988)})},6977:function(A,t,e){"use strict";var n=e(2109),r=e(7854),i=e(1702),o=e(9303),s=e(863),a=e(8415),c=e(7293),B=r.RangeError,g=r.String,l=Math.floor,u=i(a),w=i("".slice),h=i(1..toFixed),E=function(A,t,e){return 0===t?e:t%2==1?E(A,t-1,e*A):E(A*A,t/2,e)},f=function(A,t,e){for(var n=-1,r=e;++n<6;)r+=t*A[n],A[n]=r%1e7,r=l(r/1e7)},Q=function(A,t){for(var e=6,n=0;--e>=0;)n+=A[e],A[e]=l(n/t),n=n%t*1e7},d=function(A){for(var t=6,e="";--t>=0;)if(""!==e||0===t||0!==A[t]){var n=g(A[t]);e=""===e?n:e+u("0",7-n.length)+n}return e};n({target:"Number",proto:!0,forced:c((function(){return"0.000"!==h(8e-5,3)||"1"!==h(.9,0)||"1.25"!==h(1.255,2)||"1000000000000000128"!==h(0xde0b6b3a7640080,0)}))||!c((function(){h({})}))},{toFixed:function(A){var t,e,n,r,i=s(this),a=o(A),c=[0,0,0,0,0,0],l="",h="0";if(a<0||a>20)throw B("Incorrect fraction digits");if(i!=i)return"NaN";if(i<=-1e21||i>=1e21)return g(i);if(i<0&&(l="-",i=-i),i>1e-21)if(e=(t=function(A){for(var t=0,e=A;e>=4096;)t+=12,e/=4096;for(;e>=2;)t+=1,e/=2;return t}(i*E(2,69,1))-69)<0?i*E(2,-t,1):i/E(2,t,1),e*=4503599627370496,(t=52-t)>0){for(f(c,0,e),n=a;n>=7;)f(c,1e7,0),n-=7;for(f(c,E(10,n,1),0),n=t-1;n>=23;)Q(c,1<<23),n-=23;Q(c,1<<n),f(c,1,1),Q(c,2),h=d(c)}else f(c,0,e),f(c,1<<-t,0),h=d(c)+u("0",a);return a>0?l+((r=h.length)<=a?"0."+u("0",a-r)+h:w(h,0,r-a)+"."+w(h,r-a)):l+h}})},9601:function(A,t,e){var n=e(2109),r=e(1574);n({target:"Object",stat:!0,forced:Object.assign!==r},{assign:r})},3371:function(A,t,e){var n=e(2109),r=e(6677),i=e(7293),o=e(111),s=e(2423).onFreeze,a=Object.freeze;n({target:"Object",stat:!0,forced:i((function(){a(1)})),sham:!r},{freeze:function(A){return a&&o(A)?a(s(A)):A}})},5003:function(A,t,e){var n=e(2109),r=e(7293),i=e(5656),o=e(1236).f,s=e(9781),a=r((function(){o(1)}));n({target:"Object",stat:!0,forced:!s||a,sham:!s},{getOwnPropertyDescriptor:function(A,t){return o(i(A),t)}})},9337:function(A,t,e){var n=e(2109),r=e(9781),i=e(3887),o=e(5656),s=e(1236),a=e(6135);n({target:"Object",stat:!0,sham:!r},{getOwnPropertyDescriptors:function(A){for(var t,e,n=o(A),r=s.f,c=i(n),B={},g=0;c.length>g;)void 0!==(e=r(n,t=c[g++]))&&a(B,t,e);return B}})},489:function(A,t,e){var n=e(2109),r=e(7293),i=e(7908),o=e(9518),s=e(8544);n({target:"Object",stat:!0,forced:r((function(){o(1)})),sham:!s},{getPrototypeOf:function(A){return o(i(A))}})},7941:function(A,t,e){var n=e(2109),r=e(7908),i=e(1956);n({target:"Object",stat:!0,forced:e(7293)((function(){i(1)}))},{keys:function(A){return i(r(A))}})},1539:function(A,t,e){var n=e(1694),r=e(1320),i=e(288);n||r(Object.prototype,"toString",i,{unsafe:!0})},2479:function(A,t,e){var n=e(2109),r=e(4699).values;n({target:"Object",stat:!0},{values:function(A){return r(A)}})},7922:function(A,t,e){"use strict";var n=e(2109),r=e(6916),i=e(9662),o=e(8523),s=e(2534),a=e(408);n({target:"Promise",stat:!0},{allSettled:function(A){var t=this,e=o.f(t),n=e.resolve,c=e.reject,B=s((function(){var e=i(t.resolve),o=[],s=0,c=1;a(A,(function(A){var i=s++,a=!1;c++,r(e,t,A).then((function(A){a||(a=!0,o[i]={status:"fulfilled",value:A},--c||n(o))}),(function(A){a||(a=!0,o[i]={status:"rejected",reason:A},--c||n(o))}))})),--c||n(o)}));return B.error&&c(B.value),e.promise}})},4668:function(A,t,e){"use strict";var n=e(2109),r=e(9662),i=e(5005),o=e(6916),s=e(8523),a=e(2534),c=e(408),B="No one promise resolved";n({target:"Promise",stat:!0},{any:function(A){var t=this,e=i("AggregateError"),n=s.f(t),g=n.resolve,l=n.reject,u=a((function(){var n=r(t.resolve),i=[],s=0,a=1,u=!1;c(A,(function(A){var r=s++,c=!1;a++,o(n,t,A).then((function(A){c||u||(u=!0,g(A))}),(function(A){c||u||(c=!0,i[r]=A,--a||l(new e(i,B)))}))})),--a||l(new e(i,B))}));return u.error&&l(u.value),n.promise}})},7727:function(A,t,e){"use strict";var n=e(2109),r=e(1913),i=e(3366),o=e(7293),s=e(5005),a=e(614),c=e(6707),B=e(9478),g=e(1320);if(n({target:"Promise",proto:!0,real:!0,forced:!!i&&o((function(){i.prototype.finally.call({then:function(){}},(function(){}))}))},{finally:function(A){var t=c(this,s("Promise")),e=a(A);return this.then(e?function(e){return B(t,A()).then((function(){return e}))}:A,e?function(e){return B(t,A()).then((function(){throw e}))}:A)}}),!r&&a(i)){var l=s("Promise").prototype.finally;i.prototype.finally!==l&&g(i.prototype,"finally",l,{unsafe:!0})}},8674:function(A,t,e){"use strict";var n,r,i,o,s=e(2109),a=e(1913),c=e(7854),B=e(5005),g=e(6916),l=e(3366),u=e(1320),w=e(2248),h=e(7674),E=e(8003),f=e(6340),Q=e(9662),d=e(614),C=e(111),M=e(5787),I=e(2788),p=e(408),D=e(7072),y=e(6707),v=e(261).set,m=e(5948),F=e(9478),Y=e(842),b=e(8523),z=e(2534),U=e(9909),S=e(4705),x=e(5112),T=e(7871),P=e(5268),N=e(7392),R=x("species"),G="Promise",H=U.get,k=U.set,L=U.getterFor(G),J=l&&l.prototype,j=l,O=J,W=c.TypeError,K=c.document,V=c.process,X=b.f,Z=X,_=!!(K&&K.createEvent&&c.dispatchEvent),q=d(c.PromiseRejectionEvent),$="unhandledrejection",AA=!1,tA=S(G,(function(){var A=I(j),t=A!==String(j);if(!t&&66===N)return!0;if(a&&!O.finally)return!0;if(N>=51&&/native code/.test(A))return!1;var e=new j((function(A){A(1)})),n=function(A){A((function(){}),(function(){}))};return(e.constructor={})[R]=n,!(AA=e.then((function(){}))instanceof n)||!t&&T&&!q})),eA=tA||!D((function(A){j.all(A).catch((function(){}))})),nA=function(A){var t;return!(!C(A)||!d(t=A.then))&&t},rA=function(A,t){if(!A.notified){A.notified=!0;var e=A.reactions;m((function(){for(var n=A.value,r=1==A.state,i=0;e.length>i;){var o,s,a,c=e[i++],B=r?c.ok:c.fail,l=c.resolve,u=c.reject,w=c.domain;try{B?(r||(2===A.rejection&&aA(A),A.rejection=1),!0===B?o=n:(w&&w.enter(),o=B(n),w&&(w.exit(),a=!0)),o===c.promise?u(W("Promise-chain cycle")):(s=nA(o))?g(s,o,l,u):l(o)):u(n)}catch(A){w&&!a&&w.exit(),u(A)}}A.reactions=[],A.notified=!1,t&&!A.rejection&&oA(A)}))}},iA=function(A,t,e){var n,r;_?((n=K.createEvent("Event")).promise=t,n.reason=e,n.initEvent(A,!1,!0),c.dispatchEvent(n)):n={promise:t,reason:e},!q&&(r=c["on"+A])?r(n):A===$&&Y("Unhandled promise rejection",e)},oA=function(A){g(v,c,(function(){var t,e=A.facade,n=A.value;if(sA(A)&&(t=z((function(){P?V.emit("unhandledRejection",n,e):iA($,e,n)})),A.rejection=P||sA(A)?2:1,t.error))throw t.value}))},sA=function(A){return 1!==A.rejection&&!A.parent},aA=function(A){g(v,c,(function(){var t=A.facade;P?V.emit("rejectionHandled",t):iA("rejectionhandled",t,A.value)}))},cA=function(A,t,e){return function(n){A(t,n,e)}},BA=function(A,t,e){A.done||(A.done=!0,e&&(A=e),A.value=t,A.state=2,rA(A,!0))},gA=function(A,t,e){if(!A.done){A.done=!0,e&&(A=e);try{if(A.facade===t)throw W("Promise can't be resolved itself");var n=nA(t);n?m((function(){var e={done:!1};try{g(n,t,cA(gA,e,A),cA(BA,e,A))}catch(t){BA(e,t,A)}})):(A.value=t,A.state=1,rA(A,!1))}catch(t){BA({done:!1},t,A)}}};if(tA&&(O=(j=function(A){M(this,O),Q(A),g(n,this);var t=H(this);try{A(cA(gA,t),cA(BA,t))}catch(A){BA(t,A)}}).prototype,(n=function(A){k(this,{type:G,done:!1,notified:!1,parent:!1,reactions:[],rejection:!1,state:0,value:void 0})}).prototype=w(O,{then:function(A,t){var e=L(this),n=e.reactions,r=X(y(this,j));return r.ok=!d(A)||A,r.fail=d(t)&&t,r.domain=P?V.domain:void 0,e.parent=!0,n[n.length]=r,0!=e.state&&rA(e,!1),r.promise},catch:function(A){return this.then(void 0,A)}}),r=function(){var A=new n,t=H(A);this.promise=A,this.resolve=cA(gA,t),this.reject=cA(BA,t)},b.f=X=function(A){return A===j||A===i?new r(A):Z(A)},!a&&d(l)&&J!==Object.prototype)){o=J.then,AA||(u(J,"then",(function(A,t){var e=this;return new j((function(A,t){g(o,e,A,t)})).then(A,t)}),{unsafe:!0}),u(J,"catch",O.catch,{unsafe:!0}));try{delete J.constructor}catch(A){}h&&h(J,O)}s({global:!0,wrap:!0,forced:tA},{Promise:j}),E(j,G,!1,!0),f(G),i=B(G),s({target:G,stat:!0,forced:tA},{reject:function(A){var t=X(this);return g(t.reject,void 0,A),t.promise}}),s({target:G,stat:!0,forced:a||tA},{resolve:function(A){return F(a&&this===i?j:this,A)}}),s({target:G,stat:!0,forced:eA},{all:function(A){var t=this,e=X(t),n=e.resolve,r=e.reject,i=z((function(){var e=Q(t.resolve),i=[],o=0,s=1;p(A,(function(A){var a=o++,c=!1;s++,g(e,t,A).then((function(A){c||(c=!0,i[a]=A,--s||n(i))}),r)})),--s||n(i)}));return i.error&&r(i.value),e.promise},race:function(A){var t=this,e=X(t),n=e.reject,r=z((function(){var r=Q(t.resolve);p(A,(function(A){g(r,t,A).then(e.resolve,n)}))}));return r.error&&n(r.value),e.promise}})},2419:function(A,t,e){var n=e(2109),r=e(5005),i=e(2104),o=e(7065),s=e(9483),a=e(9670),c=e(111),B=e(30),g=e(7293),l=r("Reflect","construct"),u=Object.prototype,w=[].push,h=g((function(){function A(){}return!(l((function(){}),[],A)instanceof A)})),E=!g((function(){l((function(){}))})),f=h||E;n({target:"Reflect",stat:!0,forced:f,sham:f},{construct:function(A,t){s(A),a(t);var e=arguments.length<3?A:s(arguments[2]);if(E&&!h)return l(A,t,e);if(A==e){switch(t.length){case 0:return new A;case 1:return new A(t[0]);case 2:return new A(t[0],t[1]);case 3:return new A(t[0],t[1],t[2]);case 4:return new A(t[0],t[1],t[2],t[3])}var n=[null];return i(w,n,t),new(i(o,A,n))}var r=e.prototype,g=B(c(r)?r:u),f=i(A,g,t);return c(f)?f:g}})},4916:function(A,t,e){"use strict";var n=e(2109),r=e(2261);n({target:"RegExp",proto:!0,forced:/./.exec!==r},{exec:r})},2087:function(A,t,e){var n=e(9781),r=e(3070),i=e(7066),o=e(7293),s=RegExp.prototype;n&&o((function(){return"sy"!==Object.getOwnPropertyDescriptor(s,"flags").get.call({dotAll:!0,sticky:!0})}))&&r.f(s,"flags",{configurable:!0,get:i})},9714:function(A,t,e){"use strict";var n=e(1702),r=e(6530).PROPER,i=e(1320),o=e(9670),s=e(7976),a=e(1340),c=e(7293),B=e(7066),g="toString",l=RegExp.prototype,u=l[g],w=n(B),h=c((function(){return"/a/b"!=u.call({source:"a",flags:"b"})})),E=r&&u.name!=g;(h||E)&&i(RegExp.prototype,g,(function(){var A=o(this),t=a(A.source),e=A.flags;return"/"+t+"/"+a(void 0===e&&s(l,A)&&!("flags"in l)?w(A):e)}),{unsafe:!0})},189:function(A,t,e){"use strict";e(7710)("Set",(function(A){return function(){return A(this,arguments.length?arguments[0]:void 0)}}),e(5631))},9841:function(A,t,e){"use strict";var n=e(2109),r=e(8710).codeAt;n({target:"String",proto:!0},{codePointAt:function(A){return r(this,A)}})},4953:function(A,t,e){var n=e(2109),r=e(7854),i=e(1702),o=e(1400),s=r.RangeError,a=String.fromCharCode,c=String.fromCodePoint,B=i([].join);n({target:"String",stat:!0,forced:!!c&&1!=c.length},{fromCodePoint:function(A){for(var t,e=[],n=arguments.length,r=0;n>r;){if(t=+arguments[r++],o(t,1114111)!==t)throw s(t+" is not a valid code point");e[r]=t<65536?a(t):a(55296+((t-=65536)>>10),t%1024+56320)}return B(e,"")}})},2023:function(A,t,e){"use strict";var n=e(2109),r=e(1702),i=e(3929),o=e(4488),s=e(1340),a=e(4964),c=r("".indexOf);n({target:"String",proto:!0,forced:!a("includes")},{includes:function(A){return!!~c(s(o(this)),s(i(A)),arguments.length>1?arguments[1]:void 0)}})},8734:function(A,t,e){"use strict";var n=e(2109),r=e(4230);n({target:"String",proto:!0,forced:e(3429)("italics")},{italics:function(){return r(this,"i","","")}})},8783:function(A,t,e){"use strict";var n=e(8710).charAt,r=e(1340),i=e(9909),o=e(654),s="String Iterator",a=i.set,c=i.getterFor(s);o(String,"String",(function(A){a(this,{type:s,string:r(A),index:0})}),(function(){var A,t=c(this),e=t.string,r=t.index;return r>=e.length?{value:void 0,done:!0}:(A=n(e,r),t.index+=A.length,{value:A,done:!1})}))},9254:function(A,t,e){"use strict";var n=e(2109),r=e(4230);n({target:"String",proto:!0,forced:e(3429)("link")},{link:function(A){return r(this,"a","href",A)}})},6373:function(A,t,e){"use strict";var n=e(2109),r=e(7854),i=e(6916),o=e(1702),s=e(4994),a=e(4488),c=e(7466),B=e(1340),g=e(9670),l=e(4326),u=e(7976),w=e(7850),h=e(7066),E=e(8173),f=e(1320),Q=e(7293),d=e(5112),C=e(6707),M=e(1530),I=e(7651),p=e(9909),D=e(1913),y=d("matchAll"),v="RegExp String",m=v+" Iterator",F=p.set,Y=p.getterFor(m),b=RegExp.prototype,z=r.TypeError,U=o(h),S=o("".indexOf),x=o("".matchAll),T=!!x&&!Q((function(){x("a",/./)})),P=s((function(A,t,e,n){F(this,{type:m,regexp:A,string:t,global:e,unicode:n,done:!1})}),v,(function(){var A=Y(this);if(A.done)return{value:void 0,done:!0};var t=A.regexp,e=A.string,n=I(t,e);return null===n?{value:void 0,done:A.done=!0}:A.global?(""===B(n[0])&&(t.lastIndex=M(e,c(t.lastIndex),A.unicode)),{value:n,done:!1}):(A.done=!0,{value:n,done:!1})})),N=function(A){var t,e,n,r,i,o,s=g(this),a=B(A);return t=C(s,RegExp),void 0===(e=s.flags)&&u(b,s)&&!("flags"in b)&&(e=U(s)),n=void 0===e?"":B(e),r=new t(t===RegExp?s.source:s,n),i=!!~S(n,"g"),o=!!~S(n,"u"),r.lastIndex=c(s.lastIndex),new P(r,a,i,o)};n({target:"String",proto:!0,forced:T},{matchAll:function(A){var t,e,n,r,o=a(this);if(null!=A){if(w(A)&&(t=B(a("flags"in b?A.flags:U(A))),!~S(t,"g")))throw z("`.matchAll` does not allow non-global regexes");if(T)return x(o,A);if(void 0===(n=E(A,y))&&D&&"RegExp"==l(A)&&(n=N),n)return i(n,A,o)}else if(T)return x(o,A);return e=B(o),r=new RegExp(A,"g"),D?i(N,r,e):r[y](e)}}),D||y in b||f(b,y,N)},4723:function(A,t,e){"use strict";var n=e(6916),r=e(7007),i=e(9670),o=e(7466),s=e(1340),a=e(4488),c=e(8173),B=e(1530),g=e(7651);r("match",(function(A,t,e){return[function(t){var e=a(this),r=null==t?void 0:c(t,A);return r?n(r,t,e):new RegExp(t)[A](s(e))},function(A){var n=i(this),r=s(A),a=e(t,n,r);if(a.done)return a.value;if(!n.global)return g(n,r);var c=n.unicode;n.lastIndex=0;for(var l,u=[],w=0;null!==(l=g(n,r));){var h=s(l[0]);u[w]=h,""===h&&(n.lastIndex=B(r,o(n.lastIndex),c)),w++}return 0===w?null:u}]}))},2481:function(A,t,e){e(2109)({target:"String",proto:!0},{repeat:e(8415)})},5306:function(A,t,e){"use strict";var n=e(2104),r=e(6916),i=e(1702),o=e(7007),s=e(7293),a=e(9670),c=e(614),B=e(9303),g=e(7466),l=e(1340),u=e(4488),w=e(1530),h=e(8173),E=e(647),f=e(7651),Q=e(5112)("replace"),d=Math.max,C=Math.min,M=i([].concat),I=i([].push),p=i("".indexOf),D=i("".slice),y="$0"==="a".replace(/./,"$0"),v=!!/./[Q]&&""===/./[Q]("a","$0");o("replace",(function(A,t,e){var i=v?"$":"$0";return[function(A,e){var n=u(this),i=null==A?void 0:h(A,Q);return i?r(i,A,n,e):r(t,l(n),A,e)},function(A,r){var o=a(this),s=l(A);if("string"==typeof r&&-1===p(r,i)&&-1===p(r,"$<")){var u=e(t,o,s,r);if(u.done)return u.value}var h=c(r);h||(r=l(r));var Q=o.global;if(Q){var y=o.unicode;o.lastIndex=0}for(var v=[];;){var m=f(o,s);if(null===m)break;if(I(v,m),!Q)break;""===l(m[0])&&(o.lastIndex=w(s,g(o.lastIndex),y))}for(var F,Y="",b=0,z=0;z<v.length;z++){for(var U=l((m=v[z])[0]),S=d(C(B(m.index),s.length),0),x=[],T=1;T<m.length;T++)I(x,void 0===(F=m[T])?F:String(F));var P=m.groups;if(h){var N=M([U],x,S,s);void 0!==P&&I(N,P);var R=l(n(r,void 0,N))}else R=E(U,s,S,x,P,r);S>=b&&(Y+=D(s,b,S)+R,b=S+U.length)}return Y+D(s,b)}]}),!!s((function(){var A=/./;return A.exec=function(){var A=[];return A.groups={a:"7"},A},"7"!=="".replace(A,"$<a>")}))||!y||v)},3123:function(A,t,e){"use strict";var n=e(2104),r=e(6916),i=e(1702),o=e(7007),s=e(7850),a=e(9670),c=e(4488),B=e(6707),g=e(1530),l=e(7466),u=e(1340),w=e(8173),h=e(206),E=e(7651),f=e(2261),Q=e(2999),d=e(7293),C=Q.UNSUPPORTED_Y,M=4294967295,I=Math.min,p=[].push,D=i(/./.exec),y=i(p),v=i("".slice),m=!d((function(){var A=/(?:)/,t=A.exec;A.exec=function(){return t.apply(this,arguments)};var e="ab".split(A);return 2!==e.length||"a"!==e[0]||"b"!==e[1]}));o("split",(function(A,t,e){var i;return i="c"=="abbc".split(/(b)*/)[1]||4!="test".split(/(?:)/,-1).length||2!="ab".split(/(?:ab)*/).length||4!=".".split(/(.?)(.?)/).length||".".split(/()()/).length>1||"".split(/.?/).length?function(A,e){var i=u(c(this)),o=void 0===e?M:e>>>0;if(0===o)return[];if(void 0===A)return[i];if(!s(A))return r(t,i,A,o);for(var a,B,g,l=[],w=(A.ignoreCase?"i":"")+(A.multiline?"m":"")+(A.unicode?"u":"")+(A.sticky?"y":""),E=0,Q=new RegExp(A.source,w+"g");(a=r(f,Q,i))&&!((B=Q.lastIndex)>E&&(y(l,v(i,E,a.index)),a.length>1&&a.index<i.length&&n(p,l,h(a,1)),g=a[0].length,E=B,l.length>=o));)Q.lastIndex===a.index&&Q.lastIndex++;return E===i.length?!g&&D(Q,"")||y(l,""):y(l,v(i,E)),l.length>o?h(l,0,o):l}:"0".split(void 0,0).length?function(A,e){return void 0===A&&0===e?[]:r(t,this,A,e)}:t,[function(t,e){var n=c(this),o=null==t?void 0:w(t,A);return o?r(o,t,n,e):r(i,u(n),t,e)},function(A,n){var r=a(this),o=u(A),s=e(i,r,o,n,i!==t);if(s.done)return s.value;var c=B(r,RegExp),w=r.unicode,h=(r.ignoreCase?"i":"")+(r.multiline?"m":"")+(r.unicode?"u":"")+(C?"g":"y"),f=new c(C?"^(?:"+r.source+")":r,h),Q=void 0===n?M:n>>>0;if(0===Q)return[];if(0===o.length)return null===E(f,o)?[o]:[];for(var d=0,p=0,D=[];p<o.length;){f.lastIndex=C?0:p;var m,F=E(f,C?v(o,p):o);if(null===F||(m=I(l(f.lastIndex+(C?p:0)),o.length))===d)p=g(o,p,w);else{if(y(D,v(o,d,p)),D.length===Q)return D;for(var Y=1;Y<=F.length-1;Y++)if(y(D,F[Y]),D.length===Q)return D;p=d=m}}return y(D,v(o,d)),D}]}),!m,C)},7397:function(A,t,e){"use strict";var n=e(2109),r=e(4230);n({target:"String",proto:!0,forced:e(3429)("strike")},{strike:function(){return r(this,"strike","","")}})},3210:function(A,t,e){"use strict";var n=e(2109),r=e(3111).trim;n({target:"String",proto:!0,forced:e(6091)("trim")},{trim:function(){return r(this)}})},2443:function(A,t,e){e(7235)("asyncIterator")},1817:function(A,t,e){"use strict";var n=e(2109),r=e(9781),i=e(7854),o=e(1702),s=e(2597),a=e(614),c=e(7976),B=e(1340),g=e(3070).f,l=e(9920),u=i.Symbol,w=u&&u.prototype;if(r&&a(u)&&(!("description"in w)||void 0!==u().description)){var h={},E=function(){var A=arguments.length<1||void 0===arguments[0]?void 0:B(arguments[0]),t=c(w,this)?new u(A):void 0===A?u():u(A);return""===A&&(h[t]=!0),t};l(E,u),E.prototype=w,w.constructor=E;var f="Symbol(test)"==String(u("test")),Q=o(w.toString),d=o(w.valueOf),C=/^Symbol\((.*)\)[^)]+$/,M=o("".replace),I=o("".slice);g(w,"description",{configurable:!0,get:function(){var A=d(this),t=Q(A);if(s(h,A))return"";var e=f?I(t,7,-1):M(t,C,"$1");return""===e?void 0:e}}),n({global:!0,forced:!0},{Symbol:E})}},2165:function(A,t,e){e(7235)("iterator")},2526:function(A,t,e){"use strict";var n=e(2109),r=e(7854),i=e(5005),o=e(2104),s=e(6916),a=e(1702),c=e(1913),B=e(9781),g=e(133),l=e(7293),u=e(2597),w=e(3157),h=e(614),E=e(111),f=e(7976),Q=e(2190),d=e(9670),C=e(7908),M=e(5656),I=e(4948),p=e(1340),D=e(9114),y=e(30),v=e(1956),m=e(8006),F=e(1156),Y=e(5181),b=e(1236),z=e(3070),U=e(5296),S=e(206),x=e(1320),T=e(2309),P=e(6200),N=e(3501),R=e(9711),G=e(5112),H=e(6061),k=e(7235),L=e(8003),J=e(9909),j=e(2092).forEach,O=P("hidden"),W="Symbol",K="prototype",V=G("toPrimitive"),X=J.set,Z=J.getterFor(W),_=Object[K],q=r.Symbol,$=q&&q[K],AA=r.TypeError,tA=r.QObject,eA=i("JSON","stringify"),nA=b.f,rA=z.f,iA=F.f,oA=U.f,sA=a([].push),aA=T("symbols"),cA=T("op-symbols"),BA=T("string-to-symbol-registry"),gA=T("symbol-to-string-registry"),lA=T("wks"),uA=!tA||!tA[K]||!tA[K].findChild,wA=B&&l((function(){return 7!=y(rA({},"a",{get:function(){return rA(this,"a",{value:7}).a}})).a}))?function(A,t,e){var n=nA(_,t);n&&delete _[t],rA(A,t,e),n&&A!==_&&rA(_,t,n)}:rA,hA=function(A,t){var e=aA[A]=y($);return X(e,{type:W,tag:A,description:t}),B||(e.description=t),e},EA=function(A,t,e){A===_&&EA(cA,t,e),d(A);var n=I(t);return d(e),u(aA,n)?(e.enumerable?(u(A,O)&&A[O][n]&&(A[O][n]=!1),e=y(e,{enumerable:D(0,!1)})):(u(A,O)||rA(A,O,D(1,{})),A[O][n]=!0),wA(A,n,e)):rA(A,n,e)},fA=function(A,t){d(A);var e=M(t),n=v(e).concat(MA(e));return j(n,(function(t){B&&!s(QA,e,t)||EA(A,t,e[t])})),A},QA=function(A){var t=I(A),e=s(oA,this,t);return!(this===_&&u(aA,t)&&!u(cA,t))&&(!(e||!u(this,t)||!u(aA,t)||u(this,O)&&this[O][t])||e)},dA=function(A,t){var e=M(A),n=I(t);if(e!==_||!u(aA,n)||u(cA,n)){var r=nA(e,n);return!r||!u(aA,n)||u(e,O)&&e[O][n]||(r.enumerable=!0),r}},CA=function(A){var t=iA(M(A)),e=[];return j(t,(function(A){u(aA,A)||u(N,A)||sA(e,A)})),e},MA=function(A){var t=A===_,e=iA(t?cA:M(A)),n=[];return j(e,(function(A){!u(aA,A)||t&&!u(_,A)||sA(n,aA[A])})),n};if(g||(q=function(){if(f($,this))throw AA("Symbol is not a constructor");var A=arguments.length&&void 0!==arguments[0]?p(arguments[0]):void 0,t=R(A),e=function(A){this===_&&s(e,cA,A),u(this,O)&&u(this[O],t)&&(this[O][t]=!1),wA(this,t,D(1,A))};return B&&uA&&wA(_,t,{configurable:!0,set:e}),hA(t,A)},x($=q[K],"toString",(function(){return Z(this).tag})),x(q,"withoutSetter",(function(A){return hA(R(A),A)})),U.f=QA,z.f=EA,b.f=dA,m.f=F.f=CA,Y.f=MA,H.f=function(A){return hA(G(A),A)},B&&(rA($,"description",{configurable:!0,get:function(){return Z(this).description}}),c||x(_,"propertyIsEnumerable",QA,{unsafe:!0}))),n({global:!0,wrap:!0,forced:!g,sham:!g},{Symbol:q}),j(v(lA),(function(A){k(A)})),n({target:W,stat:!0,forced:!g},{for:function(A){var t=p(A);if(u(BA,t))return BA[t];var e=q(t);return BA[t]=e,gA[e]=t,e},keyFor:function(A){if(!Q(A))throw AA(A+" is not a symbol");if(u(gA,A))return gA[A]},useSetter:function(){uA=!0},useSimple:function(){uA=!1}}),n({target:"Object",stat:!0,forced:!g,sham:!B},{create:function(A,t){return void 0===t?y(A):fA(y(A),t)},defineProperty:EA,defineProperties:fA,getOwnPropertyDescriptor:dA}),n({target:"Object",stat:!0,forced:!g},{getOwnPropertyNames:CA,getOwnPropertySymbols:MA}),n({target:"Object",stat:!0,forced:l((function(){Y.f(1)}))},{getOwnPropertySymbols:function(A){return Y.f(C(A))}}),eA&&n({target:"JSON",stat:!0,forced:!g||l((function(){var A=q();return"[null]"!=eA([A])||"{}"!=eA({a:A})||"{}"!=eA(Object(A))}))},{stringify:function(A,t,e){var n=S(arguments),r=t;if((E(t)||void 0!==A)&&!Q(A))return w(t)||(t=function(A,t){if(h(r)&&(t=s(r,this,A,t)),!Q(t))return t}),n[1]=t,o(eA,null,n)}}),!$[V]){var IA=$.valueOf;x($,V,(function(A){return s(IA,this)}))}L(q,W),N[O]=!0},6649:function(A,t,e){e(7235)("toPrimitive")},3680:function(A,t,e){e(7235)("toStringTag")},2990:function(A,t,e){"use strict";var n=e(1702),r=e(2094),i=n(e(1048)),o=r.aTypedArray;(0,r.exportTypedArrayMethod)("copyWithin",(function(A,t){return i(o(this),A,t,arguments.length>2?arguments[2]:void 0)}))},8927:function(A,t,e){"use strict";var n=e(2094),r=e(2092).every,i=n.aTypedArray;(0,n.exportTypedArrayMethod)("every",(function(A){return r(i(this),A,arguments.length>1?arguments[1]:void 0)}))},3105:function(A,t,e){"use strict";var n=e(2094),r=e(6916),i=e(1285),o=n.aTypedArray;(0,n.exportTypedArrayMethod)("fill",(function(A){var t=arguments.length;return r(i,o(this),A,t>1?arguments[1]:void 0,t>2?arguments[2]:void 0)}))},5035:function(A,t,e){"use strict";var n=e(2094),r=e(2092).filter,i=e(3074),o=n.aTypedArray;(0,n.exportTypedArrayMethod)("filter",(function(A){var t=r(o(this),A,arguments.length>1?arguments[1]:void 0);return i(this,t)}))},7174:function(A,t,e){"use strict";var n=e(2094),r=e(2092).findIndex,i=n.aTypedArray;(0,n.exportTypedArrayMethod)("findIndex",(function(A){return r(i(this),A,arguments.length>1?arguments[1]:void 0)}))},4345:function(A,t,e){"use strict";var n=e(2094),r=e(2092).find,i=n.aTypedArray;(0,n.exportTypedArrayMethod)("find",(function(A){return r(i(this),A,arguments.length>1?arguments[1]:void 0)}))},4197:function(A,t,e){e(9843)("Float32",(function(A){return function(t,e,n){return A(this,t,e,n)}}))},6495:function(A,t,e){e(9843)("Float64",(function(A){return function(t,e,n){return A(this,t,e,n)}}))},2846:function(A,t,e){"use strict";var n=e(2094),r=e(2092).forEach,i=n.aTypedArray;(0,n.exportTypedArrayMethod)("forEach",(function(A){r(i(this),A,arguments.length>1?arguments[1]:void 0)}))},8145:function(A,t,e){"use strict";var n=e(3832);(0,e(2094).exportTypedArrayStaticMethod)("from",e(7321),n)},4731:function(A,t,e){"use strict";var n=e(2094),r=e(1318).includes,i=n.aTypedArray;(0,n.exportTypedArrayMethod)("includes",(function(A){return r(i(this),A,arguments.length>1?arguments[1]:void 0)}))},7209:function(A,t,e){"use strict";var n=e(2094),r=e(1318).indexOf,i=n.aTypedArray;(0,n.exportTypedArrayMethod)("indexOf",(function(A){return r(i(this),A,arguments.length>1?arguments[1]:void 0)}))},5109:function(A,t,e){e(9843)("Int16",(function(A){return function(t,e,n){return A(this,t,e,n)}}))},5125:function(A,t,e){e(9843)("Int32",(function(A){return function(t,e,n){return A(this,t,e,n)}}))},7145:function(A,t,e){e(9843)("Int8",(function(A){return function(t,e,n){return A(this,t,e,n)}}))},6319:function(A,t,e){"use strict";var n=e(7854),r=e(1702),i=e(6530).PROPER,o=e(2094),s=e(6992),a=e(5112)("iterator"),c=n.Uint8Array,B=r(s.values),g=r(s.keys),l=r(s.entries),u=o.aTypedArray,w=o.exportTypedArrayMethod,h=c&&c.prototype[a],E=!!h&&"values"===h.name,f=function(){return B(u(this))};w("entries",(function(){return l(u(this))})),w("keys",(function(){return g(u(this))})),w("values",f,i&&!E),w(a,f,i&&!E)},8867:function(A,t,e){"use strict";var n=e(2094),r=e(1702),i=n.aTypedArray,o=n.exportTypedArrayMethod,s=r([].join);o("join",(function(A){return s(i(this),A)}))},7789:function(A,t,e){"use strict";var n=e(2094),r=e(2104),i=e(6583),o=n.aTypedArray;(0,n.exportTypedArrayMethod)("lastIndexOf",(function(A){var t=arguments.length;return r(i,o(this),t>1?[A,arguments[1]]:[A])}))},3739:function(A,t,e){"use strict";var n=e(2094),r=e(2092).map,i=e(6304),o=n.aTypedArray;(0,n.exportTypedArrayMethod)("map",(function(A){return r(o(this),A,arguments.length>1?arguments[1]:void 0,(function(A,t){return new(i(A))(t)}))}))},4483:function(A,t,e){"use strict";var n=e(2094),r=e(3671).right,i=n.aTypedArray;(0,n.exportTypedArrayMethod)("reduceRight",(function(A){var t=arguments.length;return r(i(this),A,t,t>1?arguments[1]:void 0)}))},9368:function(A,t,e){"use strict";var n=e(2094),r=e(3671).left,i=n.aTypedArray;(0,n.exportTypedArrayMethod)("reduce",(function(A){var t=arguments.length;return r(i(this),A,t,t>1?arguments[1]:void 0)}))},2056:function(A,t,e){"use strict";var n=e(2094),r=n.aTypedArray,i=n.exportTypedArrayMethod,o=Math.floor;i("reverse",(function(){for(var A,t=this,e=r(t).length,n=o(e/2),i=0;i<n;)A=t[i],t[i++]=t[--e],t[e]=A;return t}))},3462:function(A,t,e){"use strict";var n=e(7854),r=e(2094),i=e(6244),o=e(4590),s=e(7908),a=e(7293),c=n.RangeError,B=r.aTypedArray;(0,r.exportTypedArrayMethod)("set",(function(A){B(this);var t=o(arguments.length>1?arguments[1]:void 0,1),e=this.length,n=s(A),r=i(n),a=0;if(r+t>e)throw c("Wrong length");for(;a<r;)this[t+a]=n[a++]}),a((function(){new Int8Array(1).set({})})))},678:function(A,t,e){"use strict";var n=e(2094),r=e(6304),i=e(7293),o=e(206),s=n.aTypedArray;(0,n.exportTypedArrayMethod)("slice",(function(A,t){for(var e=o(s(this),A,t),n=r(this),i=0,a=e.length,c=new n(a);a>i;)c[i]=e[i++];return c}),i((function(){new Int8Array(1).slice()})))},7462:function(A,t,e){"use strict";var n=e(2094),r=e(2092).some,i=n.aTypedArray;(0,n.exportTypedArrayMethod)("some",(function(A){return r(i(this),A,arguments.length>1?arguments[1]:void 0)}))},3824:function(A,t,e){"use strict";var n=e(7854),r=e(1702),i=e(7293),o=e(9662),s=e(4362),a=e(2094),c=e(8886),B=e(256),g=e(7392),l=e(8008),u=n.Array,w=a.aTypedArray,h=a.exportTypedArrayMethod,E=n.Uint16Array,f=E&&r(E.prototype.sort),Q=!(!f||i((function(){f(new E(2),null)}))&&i((function(){f(new E(2),{})}))),d=!!f&&!i((function(){if(g)return g<74;if(c)return c<67;if(B)return!0;if(l)return l<602;var A,t,e=new E(516),n=u(516);for(A=0;A<516;A++)t=A%4,e[A]=515-A,n[A]=A-2*t+3;for(f(e,(function(A,t){return(A/4|0)-(t/4|0)})),A=0;A<516;A++)if(e[A]!==n[A])return!0}));h("sort",(function(A){return void 0!==A&&o(A),d?f(this,A):s(w(this),function(A){return function(t,e){return void 0!==A?+A(t,e)||0:e!=e?-1:t!=t?1:0===t&&0===e?1/t>0&&1/e<0?1:-1:t>e}}(A))}),!d||Q)},5021:function(A,t,e){"use strict";var n=e(2094),r=e(7466),i=e(1400),o=e(6304),s=n.aTypedArray;(0,n.exportTypedArrayMethod)("subarray",(function(A,t){var e=s(this),n=e.length,a=i(A,n);return new(o(e))(e.buffer,e.byteOffset+a*e.BYTES_PER_ELEMENT,r((void 0===t?n:i(t,n))-a))}))},2974:function(A,t,e){"use strict";var n=e(7854),r=e(2104),i=e(2094),o=e(7293),s=e(206),a=n.Int8Array,c=i.aTypedArray,B=i.exportTypedArrayMethod,g=[].toLocaleString,l=!!a&&o((function(){g.call(new a(1))}));B("toLocaleString",(function(){return r(g,l?s(c(this)):c(this),s(arguments))}),o((function(){return[1,2].toLocaleString()!=new a([1,2]).toLocaleString()}))||!o((function(){a.prototype.toLocaleString.call([1,2])})))},5016:function(A,t,e){"use strict";var n=e(2094).exportTypedArrayMethod,r=e(7293),i=e(7854),o=e(1702),s=i.Uint8Array,a=s&&s.prototype||{},c=[].toString,B=o([].join);r((function(){c.call({})}))&&(c=function(){return B(this)});var g=a.toString!=c;n("toString",c,g)},8255:function(A,t,e){e(9843)("Uint16",(function(A){return function(t,e,n){return A(this,t,e,n)}}))},9135:function(A,t,e){e(9843)("Uint32",(function(A){return function(t,e,n){return A(this,t,e,n)}}))},2472:function(A,t,e){e(9843)("Uint8",(function(A){return function(t,e,n){return A(this,t,e,n)}}))},9743:function(A,t,e){e(9843)("Uint8",(function(A){return function(t,e,n){return A(this,t,e,n)}}),!0)},8628:function(A,t,e){e(9170)},5743:function(A,t,e){e(5837)},7314:function(A,t,e){e(7922)},6290:function(A,t,e){e(4668)},7479:function(A,t,e){"use strict";var n=e(2109),r=e(8523),i=e(2534);n({target:"Promise",stat:!0},{try:function(A){var t=r.f(this),e=i(A);return(e.error?t.reject:t.resolve)(e.value),t.promise}})},3728:function(A,t,e){e(6373)},4747:function(A,t,e){var n=e(7854),r=e(8324),i=e(8509),o=e(8533),s=e(8880),a=function(A){if(A&&A.forEach!==o)try{s(A,"forEach",o)}catch(t){A.forEach=o}};for(var c in r)r[c]&&a(n[c]&&n[c].prototype);a(i)},3948:function(A,t,e){var n=e(7854),r=e(8324),i=e(8509),o=e(6992),s=e(8880),a=e(5112),c=a("iterator"),B=a("toStringTag"),g=o.values,l=function(A,t){if(A){if(A[c]!==g)try{s(A,c,g)}catch(t){A[c]=g}if(A[B]||s(A,B,t),r[t])for(var e in o)if(A[e]!==o[e])try{s(A,e,o[e])}catch(t){A[e]=o[e]}}};for(var u in r)l(n[u]&&n[u].prototype,u);l(i,"DOMTokenList")},3753:function(A,t,e){"use strict";var n=e(2109),r=e(6916);n({target:"URL",proto:!0,enumerable:!0},{toJSON:function(){return r(URL.prototype.toString,this)}})},1150:function(A,t,e){var n=e(7633);e(3948),A.exports=n},251:function(A,t,e){var n=e(2215),r=e(2584),i=e(609),o=e(8420),s=e(2847),a=e(8923),c=Date.prototype.getTime;function B(A){return null==A}function g(A){return!(!A||"object"!=typeof A||"number"!=typeof A.length||"function"!=typeof A.copy||"function"!=typeof A.slice||A.length>0&&"number"!=typeof A[0])}A.exports=function A(t,e,l){var u=l||{};return!!(u.strict?i(t,e):t===e)||(!t||!e||"object"!=typeof t&&"object"!=typeof e?u.strict?i(t,e):t==e:function(t,e,i){var l,u;if(typeof t!=typeof e)return!1;if(B(t)||B(e))return!1;if(t.prototype!==e.prototype)return!1;if(r(t)!==r(e))return!1;var w=o(t),h=o(e);if(w!==h)return!1;if(w||h)return t.source===e.source&&s(t)===s(e);if(a(t)&&a(e))return c.call(t)===c.call(e);var E=g(t),f=g(e);if(E!==f)return!1;if(E||f){if(t.length!==e.length)return!1;for(l=0;l<t.length;l++)if(t[l]!==e[l])return!1;return!0}if(typeof t!=typeof e)return!1;try{var Q=n(t),d=n(e)}catch(t){return!1}if(Q.length!==d.length)return!1;for(Q.sort(),d.sort(),l=Q.length-1;l>=0;l--)if(Q[l]!=d[l])return!1;for(l=Q.length-1;l>=0;l--)if(!A(t[u=Q[l]],e[u],i))return!1;return!0}(t,e,u))}},4289:function(A,t,e){"use strict";var n=e(2215),r="function"==typeof Symbol&&"symbol"==typeof Symbol("foo"),i=Object.prototype.toString,o=Array.prototype.concat,s=Object.defineProperty,a=e(1044)(),c=s&&a,B=function(A,t,e,n){var r;(!(t in A)||"function"==typeof(r=n)&&"[object Function]"===i.call(r)&&n())&&(c?s(A,t,{configurable:!0,enumerable:!1,value:e,writable:!0}):A[t]=e)},g=function(A,t){var e=arguments.length>2?arguments[2]:{},i=n(t);r&&(i=o.call(i,Object.getOwnPropertySymbols(t)));for(var s=0;s<i.length;s+=1)B(A,i[s],t[i[s]],e[i[s]])};g.supportsDescriptors=!!c,A.exports=g},8091:function(A){"use strict";function t(A,t){if(null==A)throw new TypeError("Cannot convert first argument to object");for(var e=Object(A),n=1;n<arguments.length;n++){var r=arguments[n];if(null!=r)for(var i=Object.keys(Object(r)),o=0,s=i.length;o<s;o++){var a=i[o],c=Object.getOwnPropertyDescriptor(r,a);void 0!==c&&c.enumerable&&(e[a]=r[a])}}return e}A.exports={assign:t,polyfill:function(){Object.assign||Object.defineProperty(Object,"assign",{enumerable:!1,configurable:!0,writable:!0,value:t})}}},7187:function(A){"use strict";var t,e="object"==typeof Reflect?Reflect:null,n=e&&"function"==typeof e.apply?e.apply:function(A,t,e){return Function.prototype.apply.call(A,t,e)};t=e&&"function"==typeof e.ownKeys?e.ownKeys:Object.getOwnPropertySymbols?function(A){return Object.getOwnPropertyNames(A).concat(Object.getOwnPropertySymbols(A))}:function(A){return Object.getOwnPropertyNames(A)};var r=Number.isNaN||function(A){return A!=A};function i(){i.init.call(this)}A.exports=i,A.exports.once=function(A,t){return new Promise((function(e,n){function r(e){A.removeListener(t,i),n(e)}function i(){"function"==typeof A.removeListener&&A.removeListener("error",r),e([].slice.call(arguments))}h(A,t,i,{once:!0}),"error"!==t&&function(A,t,e){"function"==typeof A.on&&h(A,"error",t,e)}(A,r,{once:!0})}))},i.EventEmitter=i,i.prototype._events=void 0,i.prototype._eventsCount=0,i.prototype._maxListeners=void 0;var o=10;function s(A){if("function"!=typeof A)throw new TypeError('The "listener" argument must be of type Function. Received type '+typeof A)}function a(A){return void 0===A._maxListeners?i.defaultMaxListeners:A._maxListeners}function c(A,t,e,n){var r,i,o;if(s(e),void 0===(i=A._events)?(i=A._events=Object.create(null),A._eventsCount=0):(void 0!==i.newListener&&(A.emit("newListener",t,e.listener?e.listener:e),i=A._events),o=i[t]),void 0===o)o=i[t]=e,++A._eventsCount;else if("function"==typeof o?o=i[t]=n?[e,o]:[o,e]:n?o.unshift(e):o.push(e),(r=a(A))>0&&o.length>r&&!o.warned){o.warned=!0;var c=new Error("Possible EventEmitter memory leak detected. "+o.length+" "+String(t)+" listeners added. Use emitter.setMaxListeners() to increase limit");c.name="MaxListenersExceededWarning",c.emitter=A,c.type=t,c.count=o.length,console&&console.warn}return A}function B(){if(!this.fired)return this.target.removeListener(this.type,this.wrapFn),this.fired=!0,0===arguments.length?this.listener.call(this.target):this.listener.apply(this.target,arguments)}function g(A,t,e){var n={fired:!1,wrapFn:void 0,target:A,type:t,listener:e},r=B.bind(n);return r.listener=e,n.wrapFn=r,r}function l(A,t,e){var n=A._events;if(void 0===n)return[];var r=n[t];return void 0===r?[]:"function"==typeof r?e?[r.listener||r]:[r]:e?function(A){for(var t=new Array(A.length),e=0;e<t.length;++e)t[e]=A[e].listener||A[e];return t}(r):w(r,r.length)}function u(A){var t=this._events;if(void 0!==t){var e=t[A];if("function"==typeof e)return 1;if(void 0!==e)return e.length}return 0}function w(A,t){for(var e=new Array(t),n=0;n<t;++n)e[n]=A[n];return e}function h(A,t,e,n){if("function"==typeof A.on)n.once?A.once(t,e):A.on(t,e);else{if("function"!=typeof A.addEventListener)throw new TypeError('The "emitter" argument must be of type EventEmitter. Received type '+typeof A);A.addEventListener(t,(function r(i){n.once&&A.removeEventListener(t,r),e(i)}))}}Object.defineProperty(i,"defaultMaxListeners",{enumerable:!0,get:function(){return o},set:function(A){if("number"!=typeof A||A<0||r(A))throw new RangeError('The value of "defaultMaxListeners" is out of range. It must be a non-negative number. Received '+A+".");o=A}}),i.init=function(){void 0!==this._events&&this._events!==Object.getPrototypeOf(this)._events||(this._events=Object.create(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0},i.prototype.setMaxListeners=function(A){if("number"!=typeof A||A<0||r(A))throw new RangeError('The value of "n" is out of range. It must be a non-negative number. Received '+A+".");return this._maxListeners=A,this},i.prototype.getMaxListeners=function(){return a(this)},i.prototype.emit=function(A){for(var t=[],e=1;e<arguments.length;e++)t.push(arguments[e]);var r="error"===A,i=this._events;if(void 0!==i)r=r&&void 0===i.error;else if(!r)return!1;if(r){var o;if(t.length>0&&(o=t[0]),o instanceof Error)throw o;var s=new Error("Unhandled error."+(o?" ("+o.message+")":""));throw s.context=o,s}var a=i[A];if(void 0===a)return!1;if("function"==typeof a)n(a,this,t);else{var c=a.length,B=w(a,c);for(e=0;e<c;++e)n(B[e],this,t)}return!0},i.prototype.addListener=function(A,t){return c(this,A,t,!1)},i.prototype.on=i.prototype.addListener,i.prototype.prependListener=function(A,t){return c(this,A,t,!0)},i.prototype.once=function(A,t){return s(t),this.on(A,g(this,A,t)),this},i.prototype.prependOnceListener=function(A,t){return s(t),this.prependListener(A,g(this,A,t)),this},i.prototype.removeListener=function(A,t){var e,n,r,i,o;if(s(t),void 0===(n=this._events))return this;if(void 0===(e=n[A]))return this;if(e===t||e.listener===t)0==--this._eventsCount?this._events=Object.create(null):(delete n[A],n.removeListener&&this.emit("removeListener",A,e.listener||t));else if("function"!=typeof e){for(r=-1,i=e.length-1;i>=0;i--)if(e[i]===t||e[i].listener===t){o=e[i].listener,r=i;break}if(r<0)return this;0===r?e.shift():function(A,t){for(;t+1<A.length;t++)A[t]=A[t+1];A.pop()}(e,r),1===e.length&&(n[A]=e[0]),void 0!==n.removeListener&&this.emit("removeListener",A,o||t)}return this},i.prototype.off=i.prototype.removeListener,i.prototype.removeAllListeners=function(A){var t,e,n;if(void 0===(e=this._events))return this;if(void 0===e.removeListener)return 0===arguments.length?(this._events=Object.create(null),this._eventsCount=0):void 0!==e[A]&&(0==--this._eventsCount?this._events=Object.create(null):delete e[A]),this;if(0===arguments.length){var r,i=Object.keys(e);for(n=0;n<i.length;++n)"removeListener"!==(r=i[n])&&this.removeAllListeners(r);return this.removeAllListeners("removeListener"),this._events=Object.create(null),this._eventsCount=0,this}if("function"==typeof(t=e[A]))this.removeListener(A,t);else if(void 0!==t)for(n=t.length-1;n>=0;n--)this.removeListener(A,t[n]);return this},i.prototype.listeners=function(A){return l(this,A,!0)},i.prototype.rawListeners=function(A){return l(this,A,!1)},i.listenerCount=function(A,t){return"function"==typeof A.listenerCount?A.listenerCount(t):u.call(A,t)},i.prototype.listenerCount=u,i.prototype.eventNames=function(){return this._eventsCount>0?t(this._events):[]}},2536:function(A,t,e){var n=e(4275),r=e(7672);void 0===r.pdfMake&&(r.pdfMake=n),A.exports=n},7672:function(A,t,e){"use strict";A.exports=function(){if("object"==typeof globalThis)return globalThis;var A;try{A=this||new Function("return this")()}catch(A){if("object"==typeof window)return window;if("object"==typeof self)return self;if(void 0!==e.g)return e.g}return A}()},4029:function(A,t,e){"use strict";var n=e(5320),r=Object.prototype.toString,i=Object.prototype.hasOwnProperty,o=function(A,t,e){for(var n=0,r=A.length;n<r;n++)i.call(A,n)&&(null==e?t(A[n],n,A):t.call(e,A[n],n,A))},s=function(A,t,e){for(var n in A)i.call(A,n)&&(null==e?t(A[n],n,A):t.call(e,A[n],n,A))};A.exports=function(A,t,e){if(!n(t))throw new TypeError("iterator must be a function");var i;arguments.length>=3&&(i=e),"[object Array]"===r.call(A)?o(A,t,i):"string"==typeof A?function(A,t,e){for(var n=0,r=A.length;n<r;n++)null==e?t(A.charAt(n),n,A):t.call(e,A.charAt(n),n,A)}(A,t,i):s(A,t,i)}},7648:function(A){"use strict";var t=Array.prototype.slice,e=Object.prototype.toString;A.exports=function(A){var n=this;if("function"!=typeof n||"[object Function]"!==e.call(n))throw new TypeError("Function.prototype.bind called on incompatible "+n);for(var r,i=t.call(arguments,1),o=Math.max(0,n.length-i.length),s=[],a=0;a<o;a++)s.push("$"+a);if(r=Function("binder","return function ("+s.join(",")+"){ return binder.apply(this,arguments); }")((function(){if(this instanceof r){var e=n.apply(this,i.concat(t.call(arguments)));return Object(e)===e?e:this}return n.apply(A,i.concat(t.call(arguments)))})),n.prototype){var c=function(){};c.prototype=n.prototype,r.prototype=new c,c.prototype=null}return r}},8612:function(A,t,e){"use strict";var n=e(7648);A.exports=Function.prototype.bind||n},5972:function(A){"use strict";var t=function(){return"string"==typeof function(){}.name},e=Object.getOwnPropertyDescriptor;if(e)try{e([],"length")}catch(A){e=null}t.functionsHaveConfigurableNames=function(){if(!t()||!e)return!1;var A=e((function(){}),"name");return!!A&&!!A.configurable};var n=Function.prototype.bind;t.boundFunctionsHaveNames=function(){return t()&&"function"==typeof n&&""!==function(){}.bind().name},A.exports=t},210:function(A,t,e){"use strict";var n,r=SyntaxError,i=Function,o=TypeError,s=function(A){try{return i('"use strict"; return ('+A+").constructor;")()}catch(A){}},a=Object.getOwnPropertyDescriptor;if(a)try{a({},"")}catch(A){a=null}var c=function(){throw new o},B=a?function(){try{return c}catch(A){try{return a(arguments,"callee").get}catch(A){return c}}}():c,g=e(1405)(),l=Object.getPrototypeOf||function(A){return A.__proto__},u={},w="undefined"==typeof Uint8Array?n:l(Uint8Array),h={"%AggregateError%":"undefined"==typeof AggregateError?n:AggregateError,"%Array%":Array,"%ArrayBuffer%":"undefined"==typeof ArrayBuffer?n:ArrayBuffer,"%ArrayIteratorPrototype%":g?l([][Symbol.iterator]()):n,"%AsyncFromSyncIteratorPrototype%":n,"%AsyncFunction%":u,"%AsyncGenerator%":u,"%AsyncGeneratorFunction%":u,"%AsyncIteratorPrototype%":u,"%Atomics%":"undefined"==typeof Atomics?n:Atomics,"%BigInt%":"undefined"==typeof BigInt?n:BigInt,"%Boolean%":Boolean,"%DataView%":"undefined"==typeof DataView?n:DataView,"%Date%":Date,"%decodeURI%":decodeURI,"%decodeURIComponent%":decodeURIComponent,"%encodeURI%":encodeURI,"%encodeURIComponent%":encodeURIComponent,"%Error%":Error,"%eval%":eval,"%EvalError%":EvalError,"%Float32Array%":"undefined"==typeof Float32Array?n:Float32Array,"%Float64Array%":"undefined"==typeof Float64Array?n:Float64Array,"%FinalizationRegistry%":"undefined"==typeof FinalizationRegistry?n:FinalizationRegistry,"%Function%":i,"%GeneratorFunction%":u,"%Int8Array%":"undefined"==typeof Int8Array?n:Int8Array,"%Int16Array%":"undefined"==typeof Int16Array?n:Int16Array,"%Int32Array%":"undefined"==typeof Int32Array?n:Int32Array,"%isFinite%":isFinite,"%isNaN%":isNaN,"%IteratorPrototype%":g?l(l([][Symbol.iterator]())):n,"%JSON%":"object"==typeof JSON?JSON:n,"%Map%":"undefined"==typeof Map?n:Map,"%MapIteratorPrototype%":"undefined"!=typeof Map&&g?l((new Map)[Symbol.iterator]()):n,"%Math%":Math,"%Number%":Number,"%Object%":Object,"%parseFloat%":parseFloat,"%parseInt%":parseInt,"%Promise%":"undefined"==typeof Promise?n:Promise,"%Proxy%":"undefined"==typeof Proxy?n:Proxy,"%RangeError%":RangeError,"%ReferenceError%":ReferenceError,"%Reflect%":"undefined"==typeof Reflect?n:Reflect,"%RegExp%":RegExp,"%Set%":"undefined"==typeof Set?n:Set,"%SetIteratorPrototype%":"undefined"!=typeof Set&&g?l((new Set)[Symbol.iterator]()):n,"%SharedArrayBuffer%":"undefined"==typeof SharedArrayBuffer?n:SharedArrayBuffer,"%String%":String,"%StringIteratorPrototype%":g?l(""[Symbol.iterator]()):n,"%Symbol%":g?Symbol:n,"%SyntaxError%":r,"%ThrowTypeError%":B,"%TypedArray%":w,"%TypeError%":o,"%Uint8Array%":"undefined"==typeof Uint8Array?n:Uint8Array,"%Uint8ClampedArray%":"undefined"==typeof Uint8ClampedArray?n:Uint8ClampedArray,"%Uint16Array%":"undefined"==typeof Uint16Array?n:Uint16Array,"%Uint32Array%":"undefined"==typeof Uint32Array?n:Uint32Array,"%URIError%":URIError,"%WeakMap%":"undefined"==typeof WeakMap?n:WeakMap,"%WeakRef%":"undefined"==typeof WeakRef?n:WeakRef,"%WeakSet%":"undefined"==typeof WeakSet?n:WeakSet},E=function A(t){var e;if("%AsyncFunction%"===t)e=s("async function () {}");else if("%GeneratorFunction%"===t)e=s("function* () {}");else if("%AsyncGeneratorFunction%"===t)e=s("async function* () {}");else if("%AsyncGenerator%"===t){var n=A("%AsyncGeneratorFunction%");n&&(e=n.prototype)}else if("%AsyncIteratorPrototype%"===t){var r=A("%AsyncGenerator%");r&&(e=l(r.prototype))}return h[t]=e,e},f={"%ArrayBufferPrototype%":["ArrayBuffer","prototype"],"%ArrayPrototype%":["Array","prototype"],"%ArrayProto_entries%":["Array","prototype","entries"],"%ArrayProto_forEach%":["Array","prototype","forEach"],"%ArrayProto_keys%":["Array","prototype","keys"],"%ArrayProto_values%":["Array","prototype","values"],"%AsyncFunctionPrototype%":["AsyncFunction","prototype"],"%AsyncGenerator%":["AsyncGeneratorFunction","prototype"],"%AsyncGeneratorPrototype%":["AsyncGeneratorFunction","prototype","prototype"],"%BooleanPrototype%":["Boolean","prototype"],"%DataViewPrototype%":["DataView","prototype"],"%DatePrototype%":["Date","prototype"],"%ErrorPrototype%":["Error","prototype"],"%EvalErrorPrototype%":["EvalError","prototype"],"%Float32ArrayPrototype%":["Float32Array","prototype"],"%Float64ArrayPrototype%":["Float64Array","prototype"],"%FunctionPrototype%":["Function","prototype"],"%Generator%":["GeneratorFunction","prototype"],"%GeneratorPrototype%":["GeneratorFunction","prototype","prototype"],"%Int8ArrayPrototype%":["Int8Array","prototype"],"%Int16ArrayPrototype%":["Int16Array","prototype"],"%Int32ArrayPrototype%":["Int32Array","prototype"],"%JSONParse%":["JSON","parse"],"%JSONStringify%":["JSON","stringify"],"%MapPrototype%":["Map","prototype"],"%NumberPrototype%":["Number","prototype"],"%ObjectPrototype%":["Object","prototype"],"%ObjProto_toString%":["Object","prototype","toString"],"%ObjProto_valueOf%":["Object","prototype","valueOf"],"%PromisePrototype%":["Promise","prototype"],"%PromiseProto_then%":["Promise","prototype","then"],"%Promise_all%":["Promise","all"],"%Promise_reject%":["Promise","reject"],"%Promise_resolve%":["Promise","resolve"],"%RangeErrorPrototype%":["RangeError","prototype"],"%ReferenceErrorPrototype%":["ReferenceError","prototype"],"%RegExpPrototype%":["RegExp","prototype"],"%SetPrototype%":["Set","prototype"],"%SharedArrayBufferPrototype%":["SharedArrayBuffer","prototype"],"%StringPrototype%":["String","prototype"],"%SymbolPrototype%":["Symbol","prototype"],"%SyntaxErrorPrototype%":["SyntaxError","prototype"],"%TypedArrayPrototype%":["TypedArray","prototype"],"%TypeErrorPrototype%":["TypeError","prototype"],"%Uint8ArrayPrototype%":["Uint8Array","prototype"],"%Uint8ClampedArrayPrototype%":["Uint8ClampedArray","prototype"],"%Uint16ArrayPrototype%":["Uint16Array","prototype"],"%Uint32ArrayPrototype%":["Uint32Array","prototype"],"%URIErrorPrototype%":["URIError","prototype"],"%WeakMapPrototype%":["WeakMap","prototype"],"%WeakSetPrototype%":["WeakSet","prototype"]},Q=e(8612),d=e(7642),C=Q.call(Function.call,Array.prototype.concat),M=Q.call(Function.apply,Array.prototype.splice),I=Q.call(Function.call,String.prototype.replace),p=Q.call(Function.call,String.prototype.slice),D=Q.call(Function.call,RegExp.prototype.exec),y=/[^%.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|%$))/g,v=/\\(\\)?/g,m=function(A){var t=p(A,0,1),e=p(A,-1);if("%"===t&&"%"!==e)throw new r("invalid intrinsic syntax, expected closing `%`");if("%"===e&&"%"!==t)throw new r("invalid intrinsic syntax, expected opening `%`");var n=[];return I(A,y,(function(A,t,e,r){n[n.length]=e?I(r,v,"$1"):t||A})),n},F=function(A,t){var e,n=A;if(d(f,n)&&(n="%"+(e=f[n])[0]+"%"),d(h,n)){var i=h[n];if(i===u&&(i=E(n)),void 0===i&&!t)throw new o("intrinsic "+A+" exists, but is not available. Please file an issue!");return{alias:e,name:n,value:i}}throw new r("intrinsic "+A+" does not exist!")};A.exports=function(A,t){if("string"!=typeof A||0===A.length)throw new o("intrinsic name must be a non-empty string");if(arguments.length>1&&"boolean"!=typeof t)throw new o('"allowMissing" argument must be a boolean');if(null===D(/^%?[^%]*%?$/,A))throw new r("`%` may not be present anywhere but at the beginning and end of the intrinsic name");var e=m(A),n=e.length>0?e[0]:"",i=F("%"+n+"%",t),s=i.name,c=i.value,B=!1,g=i.alias;g&&(n=g[0],M(e,C([0,1],g)));for(var l=1,u=!0;l<e.length;l+=1){var w=e[l],E=p(w,0,1),f=p(w,-1);if(('"'===E||"'"===E||"`"===E||'"'===f||"'"===f||"`"===f)&&E!==f)throw new r("property names with quotes must have matching quotes");if("constructor"!==w&&u||(B=!0),d(h,s="%"+(n+="."+w)+"%"))c=h[s];else if(null!=c){if(!(w in c)){if(!t)throw new o("base intrinsic for "+A+" exists, but the property is not available.");return}if(a&&l+1>=e.length){var Q=a(c,w);c=(u=!!Q)&&"get"in Q&&!("originalValue"in Q.get)?Q.get:c[w]}else u=d(c,w),c=c[w];u&&!B&&(h[s]=c)}}return c}},7296:function(A,t,e){"use strict";var n=e(210)("%Object.getOwnPropertyDescriptor%",!0);if(n)try{n([],"length")}catch(A){n=null}A.exports=n},1044:function(A,t,e){"use strict";var n=e(210)("%Object.defineProperty%",!0),r=function(){if(n)try{return n({},"a",{value:1}),!0}catch(A){return!1}return!1};r.hasArrayLengthDefineBug=function(){if(!r())return null;try{return 1!==n([],"length",{value:1}).length}catch(A){return!0}},A.exports=r},1405:function(A,t,e){"use strict";var n="undefined"!=typeof Symbol&&Symbol,r=e(5419);A.exports=function(){return"function"==typeof n&&"function"==typeof Symbol&&"symbol"==typeof n("foo")&&"symbol"==typeof Symbol("bar")&&r()}},5419:function(A){"use strict";A.exports=function(){if("function"!=typeof Symbol||"function"!=typeof Object.getOwnPropertySymbols)return!1;if("symbol"==typeof Symbol.iterator)return!0;var A={},t=Symbol("test"),e=Object(t);if("string"==typeof t)return!1;if("[object Symbol]"!==Object.prototype.toString.call(t))return!1;if("[object Symbol]"!==Object.prototype.toString.call(e))return!1;for(t in A[t]=42,A)return!1;if("function"==typeof Object.keys&&0!==Object.keys(A).length)return!1;if("function"==typeof Object.getOwnPropertyNames&&0!==Object.getOwnPropertyNames(A).length)return!1;var n=Object.getOwnPropertySymbols(A);if(1!==n.length||n[0]!==t)return!1;if(!Object.prototype.propertyIsEnumerable.call(A,t))return!1;if("function"==typeof Object.getOwnPropertyDescriptor){var r=Object.getOwnPropertyDescriptor(A,t);if(42!==r.value||!0!==r.enumerable)return!1}return!0}},6410:function(A,t,e){"use strict";var n=e(5419);A.exports=function(){return n()&&!!Symbol.toStringTag}},7642:function(A,t,e){"use strict";var n=e(8612);A.exports=n.call(Function.call,Object.prototype.hasOwnProperty)},688:function(A,t,e){"use strict";var n=e(7103).Buffer;t._dbcs=c;for(var r=-1,i=-10,o=-1e3,s=new Array(256),a=0;a<256;a++)s[a]=r;function c(A,t){if(this.encodingName=A.encodingName,!A)throw new Error("DBCS codec is called without the data.");if(!A.table)throw new Error("Encoding '"+this.encodingName+"' has no data.");var e=A.table();this.decodeTables=[],this.decodeTables[0]=s.slice(0),this.decodeTableSeq=[];for(var n=0;n<e.length;n++)this._addDecodeChunk(e[n]);if("function"==typeof A.gb18030){this.gb18030=A.gb18030();var i=this.decodeTables.length;this.decodeTables.push(s.slice(0));var a=this.decodeTables.length;this.decodeTables.push(s.slice(0));var c=this.decodeTables[0];for(n=129;n<=254;n++)for(var B=this.decodeTables[o-c[n]],g=48;g<=57;g++){if(B[g]===r)B[g]=o-i;else if(B[g]>o)throw new Error("gb18030 decode tables conflict at byte 2");for(var l=this.decodeTables[o-B[g]],u=129;u<=254;u++){if(l[u]===r)l[u]=o-a;else{if(l[u]===o-a)continue;if(l[u]>o)throw new Error("gb18030 decode tables conflict at byte 3")}for(var w=this.decodeTables[o-l[u]],h=48;h<=57;h++)w[h]===r&&(w[h]=-2)}}}this.defaultCharUnicode=t.defaultCharUnicode,this.encodeTable=[],this.encodeTableSeq=[];var E={};if(A.encodeSkipVals)for(n=0;n<A.encodeSkipVals.length;n++){var f=A.encodeSkipVals[n];if("number"==typeof f)E[f]=!0;else for(g=f.from;g<=f.to;g++)E[g]=!0}if(this._fillEncodeTable(0,0,E),A.encodeAdd)for(var Q in A.encodeAdd)Object.prototype.hasOwnProperty.call(A.encodeAdd,Q)&&this._setEncodeChar(Q.charCodeAt(0),A.encodeAdd[Q]);this.defCharSB=this.encodeTable[0][t.defaultCharSingleByte.charCodeAt(0)],this.defCharSB===r&&(this.defCharSB=this.encodeTable[0]["?"]),this.defCharSB===r&&(this.defCharSB="?".charCodeAt(0))}function B(A,t){this.leadSurrogate=-1,this.seqObj=void 0,this.encodeTable=t.encodeTable,this.encodeTableSeq=t.encodeTableSeq,this.defaultCharSingleByte=t.defCharSB,this.gb18030=t.gb18030}function g(A,t){this.nodeIdx=0,this.prevBytes=[],this.decodeTables=t.decodeTables,this.decodeTableSeq=t.decodeTableSeq,this.defaultCharUnicode=t.defaultCharUnicode,this.gb18030=t.gb18030}function l(A,t){if(A[0]>t)return-1;for(var e=0,n=A.length;e<n-1;){var r=e+(n-e+1>>1);A[r]<=t?e=r:n=r}return e}c.prototype.encoder=B,c.prototype.decoder=g,c.prototype._getDecodeTrieNode=function(A){for(var t=[];A>0;A>>>=8)t.push(255&A);0==t.length&&t.push(0);for(var e=this.decodeTables[0],n=t.length-1;n>0;n--){var i=e[t[n]];if(i==r)e[t[n]]=o-this.decodeTables.length,this.decodeTables.push(e=s.slice(0));else{if(!(i<=o))throw new Error("Overwrite byte in "+this.encodingName+", addr: "+A.toString(16));e=this.decodeTables[o-i]}}return e},c.prototype._addDecodeChunk=function(A){var t=parseInt(A[0],16),e=this._getDecodeTrieNode(t);t&=255;for(var n=1;n<A.length;n++){var r=A[n];if("string"==typeof r)for(var o=0;o<r.length;){var s=r.charCodeAt(o++);if(55296<=s&&s<56320){var a=r.charCodeAt(o++);if(!(56320<=a&&a<57344))throw new Error("Incorrect surrogate pair in "+this.encodingName+" at chunk "+A[0]);e[t++]=65536+1024*(s-55296)+(a-56320)}else if(4080<s&&s<=4095){for(var c=4095-s+2,B=[],g=0;g<c;g++)B.push(r.charCodeAt(o++));e[t++]=i-this.decodeTableSeq.length,this.decodeTableSeq.push(B)}else e[t++]=s}else{if("number"!=typeof r)throw new Error("Incorrect type '"+typeof r+"' given in "+this.encodingName+" at chunk "+A[0]);var l=e[t-1]+1;for(o=0;o<r;o++)e[t++]=l++}}if(t>255)throw new Error("Incorrect chunk in "+this.encodingName+" at addr "+A[0]+": too long"+t)},c.prototype._getEncodeBucket=function(A){var t=A>>8;return void 0===this.encodeTable[t]&&(this.encodeTable[t]=s.slice(0)),this.encodeTable[t]},c.prototype._setEncodeChar=function(A,t){var e=this._getEncodeBucket(A),n=255&A;e[n]<=i?this.encodeTableSeq[i-e[n]][-1]=t:e[n]==r&&(e[n]=t)},c.prototype._setEncodeSequence=function(A,t){var e,n=A[0],o=this._getEncodeBucket(n),s=255&n;o[s]<=i?e=this.encodeTableSeq[i-o[s]]:(e={},o[s]!==r&&(e[-1]=o[s]),o[s]=i-this.encodeTableSeq.length,this.encodeTableSeq.push(e));for(var a=1;a<A.length-1;a++){var c=e[n];"object"==typeof c?e=c:(e=e[n]={},void 0!==c&&(e[-1]=c))}e[n=A[A.length-1]]=t},c.prototype._fillEncodeTable=function(A,t,e){for(var n=this.decodeTables[A],r=!1,s={},a=0;a<256;a++){var c=n[a],B=t+a;if(!e[B])if(c>=0)this._setEncodeChar(c,B),r=!0;else if(c<=o){var g=o-c;if(!s[g]){var l=B<<8>>>0;this._fillEncodeTable(g,l,e)?r=!0:s[g]=!0}}else c<=i&&(this._setEncodeSequence(this.decodeTableSeq[i-c],B),r=!0)}return r},B.prototype.write=function(A){for(var t=n.alloc(A.length*(this.gb18030?4:3)),e=this.leadSurrogate,o=this.seqObj,s=-1,a=0,c=0;;){if(-1===s){if(a==A.length)break;var B=A.charCodeAt(a++)}else B=s,s=-1;if(55296<=B&&B<57344)if(B<56320){if(-1===e){e=B;continue}e=B,B=r}else-1!==e?(B=65536+1024*(e-55296)+(B-56320),e=-1):B=r;else-1!==e&&(s=B,B=r,e=-1);var g=r;if(void 0!==o&&B!=r){var u=o[B];if("object"==typeof u){o=u;continue}"number"==typeof u?g=u:null==u&&void 0!==(u=o[-1])&&(g=u,s=B),o=void 0}else if(B>=0){var w=this.encodeTable[B>>8];if(void 0!==w&&(g=w[255&B]),g<=i){o=this.encodeTableSeq[i-g];continue}if(g==r&&this.gb18030){var h=l(this.gb18030.uChars,B);if(-1!=h){g=this.gb18030.gbChars[h]+(B-this.gb18030.uChars[h]),t[c++]=129+Math.floor(g/12600),g%=12600,t[c++]=48+Math.floor(g/1260),g%=1260,t[c++]=129+Math.floor(g/10),g%=10,t[c++]=48+g;continue}}}g===r&&(g=this.defaultCharSingleByte),g<256?t[c++]=g:g<65536?(t[c++]=g>>8,t[c++]=255&g):g<16777216?(t[c++]=g>>16,t[c++]=g>>8&255,t[c++]=255&g):(t[c++]=g>>>24,t[c++]=g>>>16&255,t[c++]=g>>>8&255,t[c++]=255&g)}return this.seqObj=o,this.leadSurrogate=e,t.slice(0,c)},B.prototype.end=function(){if(-1!==this.leadSurrogate||void 0!==this.seqObj){var A=n.alloc(10),t=0;if(this.seqObj){var e=this.seqObj[-1];void 0!==e&&(e<256?A[t++]=e:(A[t++]=e>>8,A[t++]=255&e)),this.seqObj=void 0}return-1!==this.leadSurrogate&&(A[t++]=this.defaultCharSingleByte,this.leadSurrogate=-1),A.slice(0,t)}},B.prototype.findIdx=l,g.prototype.write=function(A){for(var t=n.alloc(2*A.length),e=this.nodeIdx,s=this.prevBytes,a=this.prevBytes.length,c=-this.prevBytes.length,B=0,g=0;B<A.length;B++){var u,w=B>=0?A[B]:s[B+a];if((u=this.decodeTables[e][w])>=0);else if(u===r)u=this.defaultCharUnicode.charCodeAt(0),B=c;else if(-2===u){if(B>=3)var h=12600*(A[B-3]-129)+1260*(A[B-2]-48)+10*(A[B-1]-129)+(w-48);else h=12600*(s[B-3+a]-129)+1260*((B-2>=0?A[B-2]:s[B-2+a])-48)+10*((B-1>=0?A[B-1]:s[B-1+a])-129)+(w-48);var E=l(this.gb18030.gbChars,h);u=this.gb18030.uChars[E]+h-this.gb18030.gbChars[E]}else{if(u<=o){e=o-u;continue}if(!(u<=i))throw new Error("iconv-lite internal error: invalid decoding table value "+u+" at "+e+"/"+w);for(var f=this.decodeTableSeq[i-u],Q=0;Q<f.length-1;Q++)u=f[Q],t[g++]=255&u,t[g++]=u>>8;u=f[f.length-1]}if(u>=65536){var d=55296|(u-=65536)>>10;t[g++]=255&d,t[g++]=d>>8,u=56320|1023&u}t[g++]=255&u,t[g++]=u>>8,e=0,c=B+1}return this.nodeIdx=e,this.prevBytes=c>=0?Array.prototype.slice.call(A,c):s.slice(c+a).concat(Array.prototype.slice.call(A)),t.slice(0,g).toString("ucs2")},g.prototype.end=function(){for(var A="";this.prevBytes.length>0;){A+=this.defaultCharUnicode;var t=this.prevBytes.slice(1);this.prevBytes=[],this.nodeIdx=0,t.length>0&&(A+=this.write(t))}return this.prevBytes=[],this.nodeIdx=0,A}},5990:function(A,t,e){"use strict";A.exports={shiftjis:{type:"_dbcs",table:function(){return e(7014)},encodeAdd:{"¥":92,"‾":126},encodeSkipVals:[{from:60736,to:63808}]},csshiftjis:"shiftjis",mskanji:"shiftjis",sjis:"shiftjis",windows31j:"shiftjis",ms31j:"shiftjis",xsjis:"shiftjis",windows932:"shiftjis",ms932:"shiftjis",932:"shiftjis",cp932:"shiftjis",eucjp:{type:"_dbcs",table:function(){return e(5633)},encodeAdd:{"¥":92,"‾":126}},gb2312:"cp936",gb231280:"cp936",gb23121980:"cp936",csgb2312:"cp936",csiso58gb231280:"cp936",euccn:"cp936",windows936:"cp936",ms936:"cp936",936:"cp936",cp936:{type:"_dbcs",table:function(){return e(3336)}},gbk:{type:"_dbcs",table:function(){return e(3336).concat(e(4346))}},xgbk:"gbk",isoir58:"gbk",gb18030:{type:"_dbcs",table:function(){return e(3336).concat(e(4346))},gb18030:function(){return e(6258)},encodeSkipVals:[128],encodeAdd:{"€":41699}},chinese:"gb18030",windows949:"cp949",ms949:"cp949",949:"cp949",cp949:{type:"_dbcs",table:function(){return e(7348)}},cseuckr:"cp949",csksc56011987:"cp949",euckr:"cp949",isoir149:"cp949",korean:"cp949",ksc56011987:"cp949",ksc56011989:"cp949",ksc5601:"cp949",windows950:"cp950",ms950:"cp950",950:"cp950",cp950:{type:"_dbcs",table:function(){return e(4284)}},big5:"big5hkscs",big5hkscs:{type:"_dbcs",table:function(){return e(4284).concat(e(3480))},encodeSkipVals:[36457,36463,36478,36523,36532,36557,36560,36695,36713,36718,36811,36862,36973,36986,37060,37084,37105,37311,37551,37552,37553,37554,37585,37959,38090,38361,38652,39285,39798,39800,39803,39878,39902,39916,39926,40002,40019,40034,40040,40043,40055,40124,40125,40144,40279,40282,40388,40431,40443,40617,40687,40701,40800,40907,41079,41180,41183,36812,37576,38468,38637,41636,41637,41639,41638,41676,41678]},cnbig5:"big5hkscs",csbig5:"big5hkscs",xxbig5:"big5hkscs"}},6934:function(A,t,e){"use strict";for(var n=[e(1025),e(7688),e(1279),e(758),e(9068),e(3769),e(7018),e(688),e(5990)],r=0;r<n.length;r++){var i=n[r];for(var o in i)Object.prototype.hasOwnProperty.call(i,o)&&(t[o]=i[o])}},1025:function(A,t,e){"use strict";var n=e(7103).Buffer;function r(A,t){this.enc=A.encodingName,this.bomAware=A.bomAware,"base64"===this.enc?this.encoder=a:"cesu8"===this.enc&&(this.enc="utf8",this.encoder=c,"💩"!==n.from("eda0bdedb2a9","hex").toString()&&(this.decoder=B,this.defaultCharUnicode=t.defaultCharUnicode))}A.exports={utf8:{type:"_internal",bomAware:!0},cesu8:{type:"_internal",bomAware:!0},unicode11utf8:"utf8",ucs2:{type:"_internal",bomAware:!0},utf16le:"ucs2",binary:{type:"_internal"},base64:{type:"_internal"},hex:{type:"_internal"},_internal:r},r.prototype.encoder=s,r.prototype.decoder=o;var i=e(2553).s;function o(A,t){this.decoder=new i(t.enc)}function s(A,t){this.enc=t.enc}function a(A,t){this.prevStr=""}function c(A,t){}function B(A,t){this.acc=0,this.contBytes=0,this.accBytes=0,this.defaultCharUnicode=t.defaultCharUnicode}i.prototype.end||(i.prototype.end=function(){}),o.prototype.write=function(A){return n.isBuffer(A)||(A=n.from(A)),this.decoder.write(A)},o.prototype.end=function(){return this.decoder.end()},s.prototype.write=function(A){return n.from(A,this.enc)},s.prototype.end=function(){},a.prototype.write=function(A){var t=(A=this.prevStr+A).length-A.length%4;return this.prevStr=A.slice(t),A=A.slice(0,t),n.from(A,"base64")},a.prototype.end=function(){return n.from(this.prevStr,"base64")},c.prototype.write=function(A){for(var t=n.alloc(3*A.length),e=0,r=0;r<A.length;r++){var i=A.charCodeAt(r);i<128?t[e++]=i:i<2048?(t[e++]=192+(i>>>6),t[e++]=128+(63&i)):(t[e++]=224+(i>>>12),t[e++]=128+(i>>>6&63),t[e++]=128+(63&i))}return t.slice(0,e)},c.prototype.end=function(){},B.prototype.write=function(A){for(var t=this.acc,e=this.contBytes,n=this.accBytes,r="",i=0;i<A.length;i++){var o=A[i];128!=(192&o)?(e>0&&(r+=this.defaultCharUnicode,e=0),o<128?r+=String.fromCharCode(o):o<224?(t=31&o,e=1,n=1):o<240?(t=15&o,e=2,n=1):r+=this.defaultCharUnicode):e>0?(t=t<<6|63&o,n++,0==--e&&(r+=2===n&&t<128&&t>0||3===n&&t<2048?this.defaultCharUnicode:String.fromCharCode(t))):r+=this.defaultCharUnicode}return this.acc=t,this.contBytes=e,this.accBytes=n,r},B.prototype.end=function(){var A=0;return this.contBytes>0&&(A+=this.defaultCharUnicode),A}},9068:function(A,t,e){"use strict";var n=e(7103).Buffer;function r(A,t){if(!A)throw new Error("SBCS codec is called without the data.");if(!A.chars||128!==A.chars.length&&256!==A.chars.length)throw new Error("Encoding '"+A.type+"' has incorrect 'chars' (must be of len 128 or 256)");if(128===A.chars.length){for(var e="",r=0;r<128;r++)e+=String.fromCharCode(r);A.chars=e+A.chars}this.decodeBuf=n.from(A.chars,"ucs2");var i=n.alloc(65536,t.defaultCharSingleByte.charCodeAt(0));for(r=0;r<A.chars.length;r++)i[A.chars.charCodeAt(r)]=r;this.encodeBuf=i}function i(A,t){this.encodeBuf=t.encodeBuf}function o(A,t){this.decodeBuf=t.decodeBuf}t._sbcs=r,r.prototype.encoder=i,r.prototype.decoder=o,i.prototype.write=function(A){for(var t=n.alloc(A.length),e=0;e<A.length;e++)t[e]=this.encodeBuf[A.charCodeAt(e)];return t},i.prototype.end=function(){},o.prototype.write=function(A){for(var t=this.decodeBuf,e=n.alloc(2*A.length),r=0,i=0,o=0;o<A.length;o++)r=2*A[o],e[i=2*o]=t[r],e[i+1]=t[r+1];return e.toString("ucs2")},o.prototype.end=function(){}},7018:function(A){"use strict";A.exports={437:"cp437",737:"cp737",775:"cp775",850:"cp850",852:"cp852",855:"cp855",856:"cp856",857:"cp857",858:"cp858",860:"cp860",861:"cp861",862:"cp862",863:"cp863",864:"cp864",865:"cp865",866:"cp866",869:"cp869",874:"windows874",922:"cp922",1046:"cp1046",1124:"cp1124",1125:"cp1125",1129:"cp1129",1133:"cp1133",1161:"cp1161",1162:"cp1162",1163:"cp1163",1250:"windows1250",1251:"windows1251",1252:"windows1252",1253:"windows1253",1254:"windows1254",1255:"windows1255",1256:"windows1256",1257:"windows1257",1258:"windows1258",28591:"iso88591",28592:"iso88592",28593:"iso88593",28594:"iso88594",28595:"iso88595",28596:"iso88596",28597:"iso88597",28598:"iso88598",28599:"iso88599",28600:"iso885910",28601:"iso885911",28603:"iso885913",28604:"iso885914",28605:"iso885915",28606:"iso885916",windows874:{type:"_sbcs",chars:"€����…�����������‘’“”•–—�������� กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู����฿เแโใไๅๆ็่้๊๋์ํ๎๏๐๑๒๓๔๕๖๗๘๙๚๛����"},win874:"windows874",cp874:"windows874",windows1250:{type:"_sbcs",chars:"€�‚�„…†‡�‰Š‹ŚŤŽŹ�‘’“”•–—�™š›śťžź ˇ˘Ł¤Ą¦§¨©Ş«¬­®Ż°±˛ł´µ¶·¸ąş»Ľ˝ľżŔÁÂĂÄĹĆÇČÉĘËĚÍÎĎĐŃŇÓÔŐÖ×ŘŮÚŰÜÝŢßŕáâăäĺćçčéęëěíîďđńňóôőö÷řůúűüýţ˙"},win1250:"windows1250",cp1250:"windows1250",windows1251:{type:"_sbcs",chars:"ЂЃ‚ѓ„…†‡€‰Љ‹ЊЌЋЏђ‘’“”•–—�™љ›њќћџ ЎўЈ¤Ґ¦§Ё©Є«¬­®Ї°±Ііґµ¶·ё№є»јЅѕїАБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя"},win1251:"windows1251",cp1251:"windows1251",windows1252:{type:"_sbcs",chars:"€�‚ƒ„…†‡ˆ‰Š‹Œ�Ž��‘’“”•–—˜™š›œ�žŸ ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖ×ØÙÚÛÜÝÞßàáâãäåæçèéêëìíîïðñòóôõö÷øùúûüýþÿ"},win1252:"windows1252",cp1252:"windows1252",windows1253:{type:"_sbcs",chars:"€�‚ƒ„…†‡�‰�‹�����‘’“”•–—�™�›���� ΅Ά£¤¥¦§¨©�«¬­®―°±²³΄µ¶·ΈΉΊ»Ό½ΎΏΐΑΒΓΔΕΖΗΘΙΚΛΜΝΞΟΠΡ�ΣΤΥΦΧΨΩΪΫάέήίΰαβγδεζηθικλμνξοπρςστυφχψωϊϋόύώ�"},win1253:"windows1253",cp1253:"windows1253",windows1254:{type:"_sbcs",chars:"€�‚ƒ„…†‡ˆ‰Š‹Œ����‘’“”•–—˜™š›œ��Ÿ ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏĞÑÒÓÔÕÖ×ØÙÚÛÜİŞßàáâãäåæçèéêëìíîïğñòóôõö÷øùúûüışÿ"},win1254:"windows1254",cp1254:"windows1254",windows1255:{type:"_sbcs",chars:"€�‚ƒ„…†‡ˆ‰�‹�����‘’“”•–—˜™�›���� ¡¢£₪¥¦§¨©×«¬­®¯°±²³´µ¶·¸¹÷»¼½¾¿ְֱֲֳִֵֶַָֹֺֻּֽ־ֿ׀ׁׂ׃װױײ׳״�������אבגדהוזחטיךכלםמןנסעףפץצקרשת��‎‏�"},win1255:"windows1255",cp1255:"windows1255",windows1256:{type:"_sbcs",chars:"€پ‚ƒ„…†‡ˆ‰ٹ‹Œچژڈگ‘’“”•–—ک™ڑ›œ‌‍ں ،¢£¤¥¦§¨©ھ«¬­®¯°±²³´µ¶·¸¹؛»¼½¾؟ہءآأؤإئابةتثجحخدذرزسشصض×طظعغـفقكàلâمنهوçèéêëىيîïًٌٍَôُِ÷ّùْûü‎‏ے"},win1256:"windows1256",cp1256:"windows1256",windows1257:{type:"_sbcs",chars:"€�‚�„…†‡�‰�‹�¨ˇ¸�‘’“”•–—�™�›�¯˛� �¢£¤�¦§Ø©Ŗ«¬­®Æ°±²³´µ¶·ø¹ŗ»¼½¾æĄĮĀĆÄÅĘĒČÉŹĖĢĶĪĻŠŃŅÓŌÕÖ×ŲŁŚŪÜŻŽßąįāćäåęēčéźėģķīļšńņóōõö÷ųłśūüżž˙"},win1257:"windows1257",cp1257:"windows1257",windows1258:{type:"_sbcs",chars:"€�‚ƒ„…†‡ˆ‰�‹Œ����‘’“”•–—˜™�›œ��Ÿ ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂĂÄÅÆÇÈÉÊË̀ÍÎÏĐÑ̉ÓÔƠÖ×ØÙÚÛÜỮßàáâăäåæçèéêë́íîïđṇ̃óôơö÷øùúûüư₫ÿ"},win1258:"windows1258",cp1258:"windows1258",iso88591:{type:"_sbcs",chars:" ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖ×ØÙÚÛÜÝÞßàáâãäåæçèéêëìíîïðñòóôõö÷øùúûüýþÿ"},cp28591:"iso88591",iso88592:{type:"_sbcs",chars:" Ą˘Ł¤ĽŚ§¨ŠŞŤŹ­ŽŻ°ą˛ł´ľśˇ¸šşťź˝žżŔÁÂĂÄĹĆÇČÉĘËĚÍÎĎĐŃŇÓÔŐÖ×ŘŮÚŰÜÝŢßŕáâăäĺćçčéęëěíîďđńňóôőö÷řůúűüýţ˙"},cp28592:"iso88592",iso88593:{type:"_sbcs",chars:" Ħ˘£¤�Ĥ§¨İŞĞĴ­�Ż°ħ²³´µĥ·¸ışğĵ½�żÀÁÂ�ÄĊĈÇÈÉÊËÌÍÎÏ�ÑÒÓÔĠÖ×ĜÙÚÛÜŬŜßàáâ�äċĉçèéêëìíîï�ñòóôġö÷ĝùúûüŭŝ˙"},cp28593:"iso88593",iso88594:{type:"_sbcs",chars:" ĄĸŖ¤ĨĻ§¨ŠĒĢŦ­Ž¯°ą˛ŗ´ĩļˇ¸šēģŧŊžŋĀÁÂÃÄÅÆĮČÉĘËĖÍÎĪĐŅŌĶÔÕÖ×ØŲÚÛÜŨŪßāáâãäåæįčéęëėíîīđņōķôõö÷øųúûüũū˙"},cp28594:"iso88594",iso88595:{type:"_sbcs",chars:" ЁЂЃЄЅІЇЈЉЊЋЌ­ЎЏАБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя№ёђѓєѕіїјљњћќ§ўџ"},cp28595:"iso88595",iso88596:{type:"_sbcs",chars:" ���¤�������،­�������������؛���؟�ءآأؤإئابةتثجحخدذرزسشصضطظعغ�����ـفقكلمنهوىيًٌٍَُِّْ�������������"},cp28596:"iso88596",iso88597:{type:"_sbcs",chars:" ‘’£€₯¦§¨©ͺ«¬­�―°±²³΄΅Ά·ΈΉΊ»Ό½ΎΏΐΑΒΓΔΕΖΗΘΙΚΛΜΝΞΟΠΡ�ΣΤΥΦΧΨΩΪΫάέήίΰαβγδεζηθικλμνξοπρςστυφχψωϊϋόύώ�"},cp28597:"iso88597",iso88598:{type:"_sbcs",chars:" �¢£¤¥¦§¨©×«¬­®¯°±²³´µ¶·¸¹÷»¼½¾��������������������������������‗אבגדהוזחטיךכלםמןנסעףפץצקרשת��‎‏�"},cp28598:"iso88598",iso88599:{type:"_sbcs",chars:" ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏĞÑÒÓÔÕÖ×ØÙÚÛÜİŞßàáâãäåæçèéêëìíîïğñòóôõö÷øùúûüışÿ"},cp28599:"iso88599",iso885910:{type:"_sbcs",chars:" ĄĒĢĪĨĶ§ĻĐŠŦŽ­ŪŊ°ąēģīĩķ·ļđšŧž―ūŋĀÁÂÃÄÅÆĮČÉĘËĖÍÎÏÐŅŌÓÔÕÖŨØŲÚÛÜÝÞßāáâãäåæįčéęëėíîïðņōóôõöũøųúûüýþĸ"},cp28600:"iso885910",iso885911:{type:"_sbcs",chars:" กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู����฿เแโใไๅๆ็่้๊๋์ํ๎๏๐๑๒๓๔๕๖๗๘๙๚๛����"},cp28601:"iso885911",iso885913:{type:"_sbcs",chars:" ”¢£¤„¦§Ø©Ŗ«¬­®Æ°±²³“µ¶·ø¹ŗ»¼½¾æĄĮĀĆÄÅĘĒČÉŹĖĢĶĪĻŠŃŅÓŌÕÖ×ŲŁŚŪÜŻŽßąįāćäåęēčéźėģķīļšńņóōõö÷ųłśūüżž’"},cp28603:"iso885913",iso885914:{type:"_sbcs",chars:" Ḃḃ£ĊċḊ§Ẁ©ẂḋỲ­®ŸḞḟĠġṀṁ¶ṖẁṗẃṠỳẄẅṡÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏŴÑÒÓÔÕÖṪØÙÚÛÜÝŶßàáâãäåæçèéêëìíîïŵñòóôõöṫøùúûüýŷÿ"},cp28604:"iso885914",iso885915:{type:"_sbcs",chars:" ¡¢£€¥Š§š©ª«¬­®¯°±²³Žµ¶·ž¹º»ŒœŸ¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖ×ØÙÚÛÜÝÞßàáâãäåæçèéêëìíîïðñòóôõö÷øùúûüýþÿ"},cp28605:"iso885915",iso885916:{type:"_sbcs",chars:" ĄąŁ€„Š§š©Ș«Ź­źŻ°±ČłŽ”¶·žčș»ŒœŸżÀÁÂĂÄĆÆÇÈÉÊËÌÍÎÏĐŃÒÓÔŐÖŚŰÙÚÛÜĘȚßàáâăäćæçèéêëìíîïđńòóôőöśűùúûüęțÿ"},cp28606:"iso885916",cp437:{type:"_sbcs",chars:"ÇüéâäàåçêëèïîìÄÅÉæÆôöòûùÿÖÜ¢£¥₧ƒáíóúñÑªº¿⌐¬½¼¡«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "},ibm437:"cp437",csibm437:"cp437",cp737:{type:"_sbcs",chars:"ΑΒΓΔΕΖΗΘΙΚΛΜΝΞΟΠΡΣΤΥΦΧΨΩαβγδεζηθικλμνξοπρσςτυφχψ░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀ωάέήϊίόύϋώΆΈΉΊΌΎΏ±≥≤ΪΫ÷≈°∙·√ⁿ²■ "},ibm737:"cp737",csibm737:"cp737",cp775:{type:"_sbcs",chars:"ĆüéāäģåćłēŖŗīŹÄÅÉæÆōöĢ¢ŚśÖÜø£Ø×¤ĀĪóŻżź”¦©®¬½¼Ł«»░▒▓│┤ĄČĘĖ╣║╗╝ĮŠ┐└┴┬├─┼ŲŪ╚╔╩╦╠═╬Žąčęėįšųūž┘┌█▄▌▐▀ÓßŌŃõÕµńĶķĻļņĒŅ’­±“¾¶§÷„°∙·¹³²■ "},ibm775:"cp775",csibm775:"cp775",cp850:{type:"_sbcs",chars:"ÇüéâäàåçêëèïîìÄÅÉæÆôöòûùÿÖÜø£Ø×ƒáíóúñÑªº¿®¬½¼¡«»░▒▓│┤ÁÂÀ©╣║╗╝¢¥┐└┴┬├─┼ãÃ╚╔╩╦╠═╬¤ðÐÊËÈıÍÎÏ┘┌█▄¦Ì▀ÓßÔÒõÕµþÞÚÛÙýÝ¯´­±‗¾¶§÷¸°¨·¹³²■ "},ibm850:"cp850",csibm850:"cp850",cp852:{type:"_sbcs",chars:"ÇüéâäůćçłëŐőîŹÄĆÉĹĺôöĽľŚśÖÜŤťŁ×čáíóúĄąŽžĘę¬źČş«»░▒▓│┤ÁÂĚŞ╣║╗╝Żż┐└┴┬├─┼Ăă╚╔╩╦╠═╬¤đĐĎËďŇÍÎě┘┌█▄ŢŮ▀ÓßÔŃńňŠšŔÚŕŰýÝţ´­˝˛ˇ˘§÷¸°¨˙űŘř■ "},ibm852:"cp852",csibm852:"cp852",cp855:{type:"_sbcs",chars:"ђЂѓЃёЁєЄѕЅіІїЇјЈљЉњЊћЋќЌўЎџЏюЮъЪаАбБцЦдДеЕфФгГ«»░▒▓│┤хХиИ╣║╗╝йЙ┐└┴┬├─┼кК╚╔╩╦╠═╬¤лЛмМнНоОп┘┌█▄Пя▀ЯрРсСтТуУжЖвВьЬ№­ыЫзЗшШэЭщЩчЧ§■ "},ibm855:"cp855",csibm855:"cp855",cp856:{type:"_sbcs",chars:"אבגדהוזחטיךכלםמןנסעףפץצקרשת�£�×����������®¬½¼�«»░▒▓│┤���©╣║╗╝¢¥┐└┴┬├─┼��╚╔╩╦╠═╬¤���������┘┌█▄¦�▀������µ�������¯´­±‗¾¶§÷¸°¨·¹³²■ "},ibm856:"cp856",csibm856:"cp856",cp857:{type:"_sbcs",chars:"ÇüéâäàåçêëèïîıÄÅÉæÆôöòûùİÖÜø£ØŞşáíóúñÑĞğ¿®¬½¼¡«»░▒▓│┤ÁÂÀ©╣║╗╝¢¥┐└┴┬├─┼ãÃ╚╔╩╦╠═╬¤ºªÊËÈ�ÍÎÏ┘┌█▄¦Ì▀ÓßÔÒõÕµ�×ÚÛÙìÿ¯´­±�¾¶§÷¸°¨·¹³²■ "},ibm857:"cp857",csibm857:"cp857",cp858:{type:"_sbcs",chars:"ÇüéâäàåçêëèïîìÄÅÉæÆôöòûùÿÖÜø£Ø×ƒáíóúñÑªº¿®¬½¼¡«»░▒▓│┤ÁÂÀ©╣║╗╝¢¥┐└┴┬├─┼ãÃ╚╔╩╦╠═╬¤ðÐÊËÈ€ÍÎÏ┘┌█▄¦Ì▀ÓßÔÒõÕµþÞÚÛÙýÝ¯´­±‗¾¶§÷¸°¨·¹³²■ "},ibm858:"cp858",csibm858:"cp858",cp860:{type:"_sbcs",chars:"ÇüéâãàÁçêÊèÍÔìÃÂÉÀÈôõòÚùÌÕÜ¢£Ù₧ÓáíóúñÑªº¿Ò¬½¼¡«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "},ibm860:"cp860",csibm860:"cp860",cp861:{type:"_sbcs",chars:"ÇüéâäàåçêëèÐðÞÄÅÉæÆôöþûÝýÖÜø£Ø₧ƒáíóúÁÍÓÚ¿⌐¬½¼¡«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "},ibm861:"cp861",csibm861:"cp861",cp862:{type:"_sbcs",chars:"אבגדהוזחטיךכלםמןנסעףפץצקרשת¢£¥₧ƒáíóúñÑªº¿⌐¬½¼¡«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "},ibm862:"cp862",csibm862:"cp862",cp863:{type:"_sbcs",chars:"ÇüéâÂà¶çêëèïî‗À§ÉÈÊôËÏûù¤ÔÜ¢£ÙÛƒ¦´óú¨¸³¯Î⌐¬½¼¾«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "},ibm863:"cp863",csibm863:"cp863",cp864:{type:"_sbcs",chars:"\0\b\t\n\v\f\r !\"#$٪&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~°·∙√▒─│┼┤┬├┴┐┌└┘β∞φ±½¼≈«»ﻷﻸ��ﻻﻼ� ­ﺂ£¤ﺄ��ﺎﺏﺕﺙ،ﺝﺡﺥ٠١٢٣٤٥٦٧٨٩ﻑ؛ﺱﺵﺹ؟¢ﺀﺁﺃﺅﻊﺋﺍﺑﺓﺗﺛﺟﺣﺧﺩﺫﺭﺯﺳﺷﺻﺿﻁﻅﻋﻏ¦¬÷×ﻉـﻓﻗﻛﻟﻣﻧﻫﻭﻯﻳﺽﻌﻎﻍﻡﹽّﻥﻩﻬﻰﻲﻐﻕﻵﻶﻝﻙﻱ■�"},ibm864:"cp864",csibm864:"cp864",cp865:{type:"_sbcs",chars:"ÇüéâäàåçêëèïîìÄÅÉæÆôöòûùÿÖÜø£Ø₧ƒáíóúñÑªº¿⌐¬½¼¡«¤░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "},ibm865:"cp865",csibm865:"cp865",cp866:{type:"_sbcs",chars:"АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмноп░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀рстуфхцчшщъыьэюяЁёЄєЇїЎў°∙·√№¤■ "},ibm866:"cp866",csibm866:"cp866",cp869:{type:"_sbcs",chars:"������Ά�·¬¦‘’Έ―ΉΊΪΌ��ΎΫ©Ώ²³ά£έήίϊΐόύΑΒΓΔΕΖΗ½ΘΙ«»░▒▓│┤ΚΛΜΝ╣║╗╝ΞΟ┐└┴┬├─┼ΠΡ╚╔╩╦╠═╬ΣΤΥΦΧΨΩαβγ┘┌█▄δε▀ζηθικλμνξοπρσςτ΄­±υφχ§ψ΅°¨ωϋΰώ■ "},ibm869:"cp869",csibm869:"cp869",cp922:{type:"_sbcs",chars:" ¡¢£¤¥¦§¨©ª«¬­®‾°±²³´µ¶·¸¹º»¼½¾¿ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏŠÑÒÓÔÕÖ×ØÙÚÛÜÝŽßàáâãäåæçèéêëìíîïšñòóôõö÷øùúûüýžÿ"},ibm922:"cp922",csibm922:"cp922",cp1046:{type:"_sbcs",chars:"ﺈ×÷ﹱ■│─┐┌└┘ﹹﹻﹽﹿﹷﺊﻰﻳﻲﻎﻏﻐﻶﻸﻺﻼ ¤ﺋﺑﺗﺛﺟﺣ،­ﺧﺳ٠١٢٣٤٥٦٧٨٩ﺷ؛ﺻﺿﻊ؟ﻋءآأؤإئابةتثجحخدذرزسشصضطﻇعغﻌﺂﺄﺎﻓـفقكلمنهوىيًٌٍَُِّْﻗﻛﻟﻵﻷﻹﻻﻣﻧﻬﻩ�"},ibm1046:"cp1046",csibm1046:"cp1046",cp1124:{type:"_sbcs",chars:" ЁЂҐЄЅІЇЈЉЊЋЌ­ЎЏАБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя№ёђґєѕіїјљњћќ§ўџ"},ibm1124:"cp1124",csibm1124:"cp1124",cp1125:{type:"_sbcs",chars:"АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмноп░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀рстуфхцчшщъыьэюяЁёҐґЄєІіЇї·√№¤■ "},ibm1125:"cp1125",csibm1125:"cp1125",cp1129:{type:"_sbcs",chars:" ¡¢£¤¥¦§œ©ª«¬­®¯°±²³Ÿµ¶·Œ¹º»¼½¾¿ÀÁÂĂÄÅÆÇÈÉÊË̀ÍÎÏĐÑ̉ÓÔƠÖ×ØÙÚÛÜỮßàáâăäåæçèéêë́íîïđṇ̃óôơö÷øùúûüư₫ÿ"},ibm1129:"cp1129",csibm1129:"cp1129",cp1133:{type:"_sbcs",chars:" ກຂຄງຈສຊຍດຕຖທນບປຜຝພຟມຢຣລວຫອຮ���ຯະາຳິີຶືຸູຼັົຽ���ເແໂໃໄ່້໊໋໌ໍໆ�ໜໝ₭����������������໐໑໒໓໔໕໖໗໘໙��¢¬¦�"},ibm1133:"cp1133",csibm1133:"cp1133",cp1161:{type:"_sbcs",chars:"��������������������������������่กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู้๊๋€฿เแโใไๅๆ็่้๊๋์ํ๎๏๐๑๒๓๔๕๖๗๘๙๚๛¢¬¦ "},ibm1161:"cp1161",csibm1161:"cp1161",cp1162:{type:"_sbcs",chars:"€…‘’“”•–— กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู����฿เแโใไๅๆ็่้๊๋์ํ๎๏๐๑๒๓๔๕๖๗๘๙๚๛����"},ibm1162:"cp1162",csibm1162:"cp1162",cp1163:{type:"_sbcs",chars:" ¡¢£€¥¦§œ©ª«¬­®¯°±²³Ÿµ¶·Œ¹º»¼½¾¿ÀÁÂĂÄÅÆÇÈÉÊË̀ÍÎÏĐÑ̉ÓÔƠÖ×ØÙÚÛÜỮßàáâăäåæçèéêë́íîïđṇ̃óôơö÷øùúûüư₫ÿ"},ibm1163:"cp1163",csibm1163:"cp1163",maccroatian:{type:"_sbcs",chars:"ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûü†°¢£§•¶ß®Š™´¨≠ŽØ∞±≤≥∆µ∂∑∏š∫ªºΩžø¿¡¬√ƒ≈Ć«Č… ÀÃÕŒœĐ—“”‘’÷◊�©⁄¤‹›Æ»–·‚„‰ÂćÁčÈÍÎÏÌÓÔđÒÚÛÙıˆ˜¯πË˚¸Êæˇ"},maccyrillic:{type:"_sbcs",chars:"АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ†°¢£§•¶І®©™Ђђ≠Ѓѓ∞±≤≥іµ∂ЈЄєЇїЉљЊњјЅ¬√ƒ≈∆«»… ЋћЌќѕ–—“”‘’÷„ЎўЏџ№Ёёяабвгдежзийклмнопрстуфхцчшщъыьэю¤"},macgreek:{type:"_sbcs",chars:"Ä¹²É³ÖÜ΅àâä΄¨çéèêë£™îï•½‰ôö¦­ùûü†ΓΔΘΛΞΠß®©ΣΪ§≠°·Α±≤≥¥ΒΕΖΗΙΚΜΦΫΨΩάΝ¬ΟΡ≈Τ«»… ΥΧΆΈœ–―“”‘’÷ΉΊΌΎέήίόΏύαβψδεφγηιξκλμνοπώρστθωςχυζϊϋΐΰ�"},maciceland:{type:"_sbcs",chars:"ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûüÝ°¢£§•¶ß®©™´¨≠ÆØ∞±≤≥¥µ∂∑∏π∫ªºΩæø¿¡¬√ƒ≈∆«»… ÀÃÕŒœ–—“”‘’÷◊ÿŸ⁄¤ÐðÞþý·‚„‰ÂÊÁËÈÍÎÏÌÓÔ�ÒÚÛÙıˆ˜¯˘˙˚¸˝˛ˇ"},macroman:{type:"_sbcs",chars:"ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûü†°¢£§•¶ß®©™´¨≠ÆØ∞±≤≥¥µ∂∑∏π∫ªºΩæø¿¡¬√ƒ≈∆«»… ÀÃÕŒœ–—“”‘’÷◊ÿŸ⁄¤‹›ﬁﬂ‡·‚„‰ÂÊÁËÈÍÎÏÌÓÔ�ÒÚÛÙıˆ˜¯˘˙˚¸˝˛ˇ"},macromania:{type:"_sbcs",chars:"ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûü†°¢£§•¶ß®©™´¨≠ĂŞ∞±≤≥¥µ∂∑∏π∫ªºΩăş¿¡¬√ƒ≈∆«»… ÀÃÕŒœ–—“”‘’÷◊ÿŸ⁄¤‹›Ţţ‡·‚„‰ÂÊÁËÈÍÎÏÌÓÔ�ÒÚÛÙıˆ˜¯˘˙˚¸˝˛ˇ"},macthai:{type:"_sbcs",chars:"«»…“”�•‘’� กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู\ufeff​–—฿เแโใไๅๆ็่้๊๋์ํ™๏๐๑๒๓๔๕๖๗๘๙®©����"},macturkish:{type:"_sbcs",chars:"ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûü†°¢£§•¶ß®©™´¨≠ÆØ∞±≤≥¥µ∂∑∏π∫ªºΩæø¿¡¬√ƒ≈∆«»… ÀÃÕŒœ–—“”‘’÷◊ÿŸĞğİıŞş‡·‚„‰ÂÊÁËÈÍÎÏÌÓÔ�ÒÚÛÙ�ˆ˜¯˘˙˚¸˝˛ˇ"},macukraine:{type:"_sbcs",chars:"АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ†°Ґ£§•¶І®©™Ђђ≠Ѓѓ∞±≤≥іµґЈЄєЇїЉљЊњјЅ¬√ƒ≈∆«»… ЋћЌќѕ–—“”‘’÷„ЎўЏџ№Ёёяабвгдежзийклмнопрстуфхцчшщъыьэю¤"},koi8r:{type:"_sbcs",chars:"─│┌┐└┘├┤┬┴┼▀▄█▌▐░▒▓⌠■∙√≈≤≥ ⌡°²·÷═║╒ё╓╔╕╖╗╘╙╚╛╜╝╞╟╠╡Ё╢╣╤╥╦╧╨╩╪╫╬©юабцдефгхийклмнопярстужвьызшэщчъЮАБЦДЕФГХИЙКЛМНОПЯРСТУЖВЬЫЗШЭЩЧЪ"},koi8u:{type:"_sbcs",chars:"─│┌┐└┘├┤┬┴┼▀▄█▌▐░▒▓⌠■∙√≈≤≥ ⌡°²·÷═║╒ёє╔ії╗╘╙╚╛ґ╝╞╟╠╡ЁЄ╣ІЇ╦╧╨╩╪Ґ╬©юабцдефгхийклмнопярстужвьызшэщчъЮАБЦДЕФГХИЙКЛМНОПЯРСТУЖВЬЫЗШЭЩЧЪ"},koi8ru:{type:"_sbcs",chars:"─│┌┐└┘├┤┬┴┼▀▄█▌▐░▒▓⌠■∙√≈≤≥ ⌡°²·÷═║╒ёє╔ії╗╘╙╚╛ґў╞╟╠╡ЁЄ╣ІЇ╦╧╨╩╪ҐЎ©юабцдефгхийклмнопярстужвьызшэщчъЮАБЦДЕФГХИЙКЛМНОПЯРСТУЖВЬЫЗШЭЩЧЪ"},koi8t:{type:"_sbcs",chars:"қғ‚Ғ„…†‡�‰ҳ‹ҲҷҶ�Қ‘’“”•–—�™�›�����ӯӮё¤ӣ¦§���«¬­®�°±²Ё�Ӣ¶·�№�»���©юабцдефгхийклмнопярстужвьызшэщчъЮАБЦДЕФГХИЙКЛМНОПЯРСТУЖВЬЫЗШЭЩЧЪ"},armscii8:{type:"_sbcs",chars:" �և։)(»«—.՝,-֊…՜՛՞ԱաԲբԳգԴդԵեԶզԷէԸըԹթԺժԻիԼլԽխԾծԿկՀհՁձՂղՃճՄմՅյՆնՇշՈոՉչՊպՋջՌռՍսՎվՏտՐրՑցՒւՓփՔքՕօՖֆ՚�"},rk1048:{type:"_sbcs",chars:"ЂЃ‚ѓ„…†‡€‰Љ‹ЊҚҺЏђ‘’“”•–—�™љ›њқһџ ҰұӘ¤Ө¦§Ё©Ғ«¬­®Ү°±Ііөµ¶·ё№ғ»әҢңүАБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя"},tcvn:{type:"_sbcs",chars:"\0ÚỤỪỬỮ\b\t\n\v\f\rỨỰỲỶỸÝỴ !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~ÀẢÃÁẠẶẬÈẺẼÉẸỆÌỈĨÍỊÒỎÕÓỌỘỜỞỠỚỢÙỦŨ ĂÂÊÔƠƯĐăâêôơưđẶ̀̀̉̃́àảãáạẲằẳẵắẴẮẦẨẪẤỀặầẩẫấậèỂẻẽéẹềểễếệìỉỄẾỒĩíịòỔỏõóọồổỗốộờởỡớợùỖủũúụừửữứựỳỷỹýỵỐ"},georgianacademy:{type:"_sbcs",chars:"‚ƒ„…†‡ˆ‰Š‹Œ‘’“”•–—˜™š›œŸ ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿აბგდევზთიკლმნოპჟრსტუფქღყშჩცძწჭხჯჰჱჲჳჴჵჶçèéêëìíîïðñòóôõö÷øùúûüýþÿ"},georgianps:{type:"_sbcs",chars:"‚ƒ„…†‡ˆ‰Š‹Œ‘’“”•–—˜™š›œŸ ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿აბგდევზჱთიკლმნჲოპჟრსტჳუფქღყშჩცძწჭხჴჯჰჵæçèéêëìíîïðñòóôõö÷øùúûüýþÿ"},pt154:{type:"_sbcs",chars:"ҖҒӮғ„…ҶҮҲүҠӢҢҚҺҸҗ‘’“”•–—ҳҷҡӣңқһҹ ЎўЈӨҘҰ§Ё©Ә«¬ӯ®Ҝ°ұІіҙө¶·ё№ә»јҪҫҝАБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя"},viscii:{type:"_sbcs",chars:"\0ẲẴẪ\b\t\n\v\f\rỶỸỴ !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~ẠẮẰẶẤẦẨẬẼẸẾỀỂỄỆỐỒỔỖỘỢỚỜỞỊỎỌỈỦŨỤỲÕắằặấầẩậẽẹếềểễệốồổỗỠƠộờởịỰỨỪỬơớƯÀÁÂÃẢĂẳẵÈÉÊẺÌÍĨỳĐứÒÓÔạỷừửÙÚỹỵÝỡưàáâãảăữẫèéêẻìíĩỉđựòóôõỏọụùúũủýợỮ"},iso646cn:{type:"_sbcs",chars:"\0\b\t\n\v\f\r !\"#¥%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}‾��������������������������������������������������������������������������������������������������������������������������������"},iso646jp:{type:"_sbcs",chars:"\0\b\t\n\v\f\r !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[¥]^_`abcdefghijklmnopqrstuvwxyz{|}‾��������������������������������������������������������������������������������������������������������������������������������"},hproman8:{type:"_sbcs",chars:" ÀÂÈÊËÎÏ´ˋˆ¨˜ÙÛ₤¯Ýý°ÇçÑñ¡¿¤£¥§ƒ¢âêôûáéóúàèòùäëöüÅîØÆåíøæÄìÖÜÉïßÔÁÃãÐðÍÌÓÒÕõŠšÚŸÿÞþ·µ¶¾—¼½ªº«■»±�"},macintosh:{type:"_sbcs",chars:"ÄÅÇÉÑÖÜáàâäãåçéèêëíìîïñóòôöõúùûü†°¢£§•¶ß®©™´¨≠ÆØ∞±≤≥¥µ∂∑∏π∫ªºΩæø¿¡¬√ƒ≈∆«»… ÀÃÕŒœ–—“”‘’÷◊ÿŸ⁄¤‹›ﬁﬂ‡·‚„‰ÂÊÁËÈÍÎÏÌÓÔ�ÒÚÛÙıˆ˜¯˘˙˚¸˝˛ˇ"},ascii:{type:"_sbcs",chars:"��������������������������������������������������������������������������������������������������������������������������������"},tis620:{type:"_sbcs",chars:"���������������������������������กขฃคฅฆงจฉชซฌญฎฏฐฑฒณดตถทธนบปผฝพฟภมยรฤลฦวศษสหฬอฮฯะัาำิีึืฺุู����฿เแโใไๅๆ็่้๊๋์ํ๎๏๐๑๒๓๔๕๖๗๘๙๚๛����"}}},3769:function(A){"use strict";A.exports={10029:"maccenteuro",maccenteuro:{type:"_sbcs",chars:"ÄĀāÉĄÖÜáąČäčĆćéŹźĎíďĒēĖóėôöõúĚěü†°Ę£§•¶ß®©™ę¨≠ģĮįĪ≤≥īĶ∂∑łĻļĽľĹĺŅņŃ¬√ńŇ∆«»… ňŐÕőŌ–—“”‘’÷◊ōŔŕŘ‹›řŖŗŠ‚„šŚśÁŤťÍŽžŪÓÔūŮÚůŰűŲųÝýķŻŁżĢˇ"},808:"cp808",ibm808:"cp808",cp808:{type:"_sbcs",chars:"АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмноп░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀рстуфхцчшщъыьэюяЁёЄєЇїЎў°∙·√№€■ "},mik:{type:"_sbcs",chars:"АБВГДЕЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдежзийклмнопрстуфхцчшщъыьэюя└┴┬├─┼╣║╚╔╩╦╠═╬┐░▒▓│┤№§╗╝┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞φε∩≡±≥≤⌠⌡÷≈°∙·√ⁿ²■ "},cp720:{type:"_sbcs",chars:"éâàçêëèïîّْô¤ـûùءآأؤ£إئابةتثجحخدذرزسشص«»░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└┴┬├─┼╞╟╚╔╩╦╠═╬╧╨╤╥╙╘╒╓╫╪┘┌█▄▌▐▀ضطظعغفµقكلمنهوىي≡ًٌٍَُِ≈°∙·√ⁿ²■ "},ascii8bit:"ascii",usascii:"ascii",ansix34:"ascii",ansix341968:"ascii",ansix341986:"ascii",csascii:"ascii",cp367:"ascii",ibm367:"ascii",isoir6:"ascii",iso646us:"ascii",iso646irv:"ascii",us:"ascii",latin1:"iso88591",latin2:"iso88592",latin3:"iso88593",latin4:"iso88594",latin5:"iso88599",latin6:"iso885910",latin7:"iso885913",latin8:"iso885914",latin9:"iso885915",latin10:"iso885916",csisolatin1:"iso88591",csisolatin2:"iso88592",csisolatin3:"iso88593",csisolatin4:"iso88594",csisolatincyrillic:"iso88595",csisolatinarabic:"iso88596",csisolatingreek:"iso88597",csisolatinhebrew:"iso88598",csisolatin5:"iso88599",csisolatin6:"iso885910",l1:"iso88591",l2:"iso88592",l3:"iso88593",l4:"iso88594",l5:"iso88599",l6:"iso885910",l7:"iso885913",l8:"iso885914",l9:"iso885915",l10:"iso885916",isoir14:"iso646jp",isoir57:"iso646cn",isoir100:"iso88591",isoir101:"iso88592",isoir109:"iso88593",isoir110:"iso88594",isoir144:"iso88595",isoir127:"iso88596",isoir126:"iso88597",isoir138:"iso88598",isoir148:"iso88599",isoir157:"iso885910",isoir166:"tis620",isoir179:"iso885913",isoir199:"iso885914",isoir203:"iso885915",isoir226:"iso885916",cp819:"iso88591",ibm819:"iso88591",cyrillic:"iso88595",arabic:"iso88596",arabic8:"iso88596",ecma114:"iso88596",asmo708:"iso88596",greek:"iso88597",greek8:"iso88597",ecma118:"iso88597",elot928:"iso88597",hebrew:"iso88598",hebrew8:"iso88598",turkish:"iso88599",turkish8:"iso88599",thai:"iso885911",thai8:"iso885911",celtic:"iso885914",celtic8:"iso885914",isoceltic:"iso885914",tis6200:"tis620",tis62025291:"tis620",tis62025330:"tis620",1e4:"macroman",10006:"macgreek",10007:"maccyrillic",10079:"maciceland",10081:"macturkish",cspc8codepage437:"cp437",cspc775baltic:"cp775",cspc850multilingual:"cp850",cspcp852:"cp852",cspc862latinhebrew:"cp862",cpgr:"cp869",msee:"cp1250",mscyrl:"cp1251",msansi:"cp1252",msgreek:"cp1253",msturk:"cp1254",mshebr:"cp1255",msarab:"cp1256",winbaltrim:"cp1257",cp20866:"koi8r",20866:"koi8r",ibm878:"koi8r",cskoi8r:"koi8r",cp21866:"koi8u",21866:"koi8u",ibm1168:"koi8u",strk10482002:"rk1048",tcvn5712:"tcvn",tcvn57121:"tcvn",gb198880:"iso646cn",cn:"iso646cn",csiso14jisc6220ro:"iso646jp",jisc62201969ro:"iso646jp",jp:"iso646jp",cshproman8:"hproman8",r8:"hproman8",roman8:"hproman8",xroman8:"hproman8",ibm1051:"hproman8",mac:"macintosh",csmacintosh:"macintosh"}},1279:function(A,t,e){"use strict";var n=e(7103).Buffer;function r(){}function i(){}function o(){this.overflowByte=-1}function s(A,t){this.iconv=t}function a(A,t){void 0===(A=A||{}).addBOM&&(A.addBOM=!0),this.encoder=t.iconv.getEncoder("utf-16le",A)}function c(A,t){this.decoder=null,this.initialBufs=[],this.initialBufsLen=0,this.options=A||{},this.iconv=t.iconv}function B(A,t){var e=[],n=0,r=0,i=0;A:for(var o=0;o<A.length;o++)for(var s=A[o],a=0;a<s.length;a++)if(e.push(s[a]),2===e.length){if(0===n){if(255===e[0]&&254===e[1])return"utf-16le";if(254===e[0]&&255===e[1])return"utf-16be"}if(0===e[0]&&0!==e[1]&&i++,0!==e[0]&&0===e[1]&&r++,e.length=0,++n>=100)break A}return i>r?"utf-16be":i<r?"utf-16le":t||"utf-16le"}t.utf16be=r,r.prototype.encoder=i,r.prototype.decoder=o,r.prototype.bomAware=!0,i.prototype.write=function(A){for(var t=n.from(A,"ucs2"),e=0;e<t.length;e+=2){var r=t[e];t[e]=t[e+1],t[e+1]=r}return t},i.prototype.end=function(){},o.prototype.write=function(A){if(0==A.length)return"";var t=n.alloc(A.length+1),e=0,r=0;for(-1!==this.overflowByte&&(t[0]=A[0],t[1]=this.overflowByte,e=1,r=2);e<A.length-1;e+=2,r+=2)t[r]=A[e+1],t[r+1]=A[e];return this.overflowByte=e==A.length-1?A[A.length-1]:-1,t.slice(0,r).toString("ucs2")},o.prototype.end=function(){this.overflowByte=-1},t.utf16=s,s.prototype.encoder=a,s.prototype.decoder=c,a.prototype.write=function(A){return this.encoder.write(A)},a.prototype.end=function(){return this.encoder.end()},c.prototype.write=function(A){if(!this.decoder){if(this.initialBufs.push(A),this.initialBufsLen+=A.length,this.initialBufsLen<16)return"";var t=B(this.initialBufs,this.options.defaultEncoding);this.decoder=this.iconv.getDecoder(t,this.options);for(var e="",n=0;n<this.initialBufs.length;n++)e+=this.decoder.write(this.initialBufs[n]);return this.initialBufs.length=this.initialBufsLen=0,e}return this.decoder.write(A)},c.prototype.end=function(){if(!this.decoder){var A=B(this.initialBufs,this.options.defaultEncoding);this.decoder=this.iconv.getDecoder(A,this.options);for(var t="",e=0;e<this.initialBufs.length;e++)t+=this.decoder.write(this.initialBufs[e]);var n=this.decoder.end();return n&&(t+=n),this.initialBufs.length=this.initialBufsLen=0,t}return this.decoder.end()}},7688:function(A,t,e){"use strict";var n=e(7103).Buffer;function r(A,t){this.iconv=t,this.bomAware=!0,this.isLE=A.isLE}function i(A,t){this.isLE=t.isLE,this.highSurrogate=0}function o(A,t){this.isLE=t.isLE,this.badChar=t.iconv.defaultCharUnicode.charCodeAt(0),this.overflow=[]}function s(A,t,e,n){if((e<0||e>1114111)&&(e=n),e>=65536){var r=55296|(e-=65536)>>10;A[t++]=255&r,A[t++]=r>>8,e=56320|1023&e}return A[t++]=255&e,A[t++]=e>>8,t}function a(A,t){this.iconv=t}function c(A,t){void 0===(A=A||{}).addBOM&&(A.addBOM=!0),this.encoder=t.iconv.getEncoder(A.defaultEncoding||"utf-32le",A)}function B(A,t){this.decoder=null,this.initialBufs=[],this.initialBufsLen=0,this.options=A||{},this.iconv=t.iconv}function g(A,t){var e=[],n=0,r=0,i=0,o=0,s=0;A:for(var a=0;a<A.length;a++)for(var c=A[a],B=0;B<c.length;B++)if(e.push(c[B]),4===e.length){if(0===n){if(255===e[0]&&254===e[1]&&0===e[2]&&0===e[3])return"utf-32le";if(0===e[0]&&0===e[1]&&254===e[2]&&255===e[3])return"utf-32be"}if((0!==e[0]||e[1]>16)&&i++,(0!==e[3]||e[2]>16)&&r++,0!==e[0]||0!==e[1]||0===e[2]&&0===e[3]||s++,0===e[0]&&0===e[1]||0!==e[2]||0!==e[3]||o++,e.length=0,++n>=100)break A}return s-i>o-r?"utf-32be":s-i<o-r?"utf-32le":t||"utf-32le"}t._utf32=r,t.utf32le={type:"_utf32",isLE:!0},t.utf32be={type:"_utf32",isLE:!1},t.ucs4le="utf32le",t.ucs4be="utf32be",r.prototype.encoder=i,r.prototype.decoder=o,i.prototype.write=function(A){for(var t=n.from(A,"ucs2"),e=n.alloc(2*t.length),r=this.isLE?e.writeUInt32LE:e.writeUInt32BE,i=0,o=0;o<t.length;o+=2){var s=t.readUInt16LE(o),a=55296<=s&&s<56320,c=56320<=s&&s<57344;if(this.highSurrogate){if(!a&&c){var B=65536+(this.highSurrogate-55296<<10|s-56320);r.call(e,B,i),i+=4,this.highSurrogate=0;continue}r.call(e,this.highSurrogate,i),i+=4}a?this.highSurrogate=s:(r.call(e,s,i),i+=4,this.highSurrogate=0)}return i<e.length&&(e=e.slice(0,i)),e},i.prototype.end=function(){if(this.highSurrogate){var A=n.alloc(4);return this.isLE?A.writeUInt32LE(this.highSurrogate,0):A.writeUInt32BE(this.highSurrogate,0),this.highSurrogate=0,A}},o.prototype.write=function(A){if(0===A.length)return"";var t=0,e=0,r=n.alloc(A.length+4),i=0,o=this.isLE,a=this.overflow,c=this.badChar;if(a.length>0){for(;t<A.length&&a.length<4;t++)a.push(A[t]);4===a.length&&(e=o?a[t]|a[t+1]<<8|a[t+2]<<16|a[t+3]<<24:a[t+3]|a[t+2]<<8|a[t+1]<<16|a[t]<<24,a.length=0,i=s(r,i,e,c))}for(;t<A.length-3;t+=4)i=s(r,i,e=o?A[t]|A[t+1]<<8|A[t+2]<<16|A[t+3]<<24:A[t+3]|A[t+2]<<8|A[t+1]<<16|A[t]<<24,c);for(;t<A.length;t++)a.push(A[t]);return r.slice(0,i).toString("ucs2")},o.prototype.end=function(){this.overflow.length=0},t.utf32=a,t.ucs4="utf32",a.prototype.encoder=c,a.prototype.decoder=B,c.prototype.write=function(A){return this.encoder.write(A)},c.prototype.end=function(){return this.encoder.end()},B.prototype.write=function(A){if(!this.decoder){if(this.initialBufs.push(A),this.initialBufsLen+=A.length,this.initialBufsLen<32)return"";var t=g(this.initialBufs,this.options.defaultEncoding);this.decoder=this.iconv.getDecoder(t,this.options);for(var e="",n=0;n<this.initialBufs.length;n++)e+=this.decoder.write(this.initialBufs[n]);return this.initialBufs.length=this.initialBufsLen=0,e}return this.decoder.write(A)},B.prototype.end=function(){if(!this.decoder){var A=g(this.initialBufs,this.options.defaultEncoding);this.decoder=this.iconv.getDecoder(A,this.options);for(var t="",e=0;e<this.initialBufs.length;e++)t+=this.decoder.write(this.initialBufs[e]);var n=this.decoder.end();return n&&(t+=n),this.initialBufs.length=this.initialBufsLen=0,t}return this.decoder.end()}},758:function(A,t,e){"use strict";var n=e(7103).Buffer;function r(A,t){this.iconv=t}t.utf7=r,t.unicode11utf7="utf7",r.prototype.encoder=o,r.prototype.decoder=s,r.prototype.bomAware=!0;var i=/[^A-Za-z0-9'\(\),-\.\/:\? \n\r\t]+/g;function o(A,t){this.iconv=t.iconv}function s(A,t){this.iconv=t.iconv,this.inBase64=!1,this.base64Accum=""}o.prototype.write=function(A){return n.from(A.replace(i,function(A){return"+"+("+"===A?"":this.iconv.encode(A,"utf16-be").toString("base64").replace(/=+$/,""))+"-"}.bind(this)))},o.prototype.end=function(){};for(var a=/[A-Za-z0-9\/+]/,c=[],B=0;B<256;B++)c[B]=a.test(String.fromCharCode(B));var g="+".charCodeAt(0),l="-".charCodeAt(0),u="&".charCodeAt(0);function w(A,t){this.iconv=t}function h(A,t){this.iconv=t.iconv,this.inBase64=!1,this.base64Accum=n.alloc(6),this.base64AccumIdx=0}function E(A,t){this.iconv=t.iconv,this.inBase64=!1,this.base64Accum=""}s.prototype.write=function(A){for(var t="",e=0,r=this.inBase64,i=this.base64Accum,o=0;o<A.length;o++)if(r){if(!c[A[o]]){if(o==e&&A[o]==l)t+="+";else{var s=i+this.iconv.decode(A.slice(e,o),"ascii");t+=this.iconv.decode(n.from(s,"base64"),"utf16-be")}A[o]!=l&&o--,e=o+1,r=!1,i=""}}else A[o]==g&&(t+=this.iconv.decode(A.slice(e,o),"ascii"),e=o+1,r=!0);if(r){var a=(s=i+this.iconv.decode(A.slice(e),"ascii")).length-s.length%8;i=s.slice(a),s=s.slice(0,a),t+=this.iconv.decode(n.from(s,"base64"),"utf16-be")}else t+=this.iconv.decode(A.slice(e),"ascii");return this.inBase64=r,this.base64Accum=i,t},s.prototype.end=function(){var A="";return this.inBase64&&this.base64Accum.length>0&&(A=this.iconv.decode(n.from(this.base64Accum,"base64"),"utf16-be")),this.inBase64=!1,this.base64Accum="",A},t.utf7imap=w,w.prototype.encoder=h,w.prototype.decoder=E,w.prototype.bomAware=!0,h.prototype.write=function(A){for(var t=this.inBase64,e=this.base64Accum,r=this.base64AccumIdx,i=n.alloc(5*A.length+10),o=0,s=0;s<A.length;s++){var a=A.charCodeAt(s);32<=a&&a<=126?(t&&(r>0&&(o+=i.write(e.slice(0,r).toString("base64").replace(/\//g,",").replace(/=+$/,""),o),r=0),i[o++]=l,t=!1),t||(i[o++]=a,a===u&&(i[o++]=l))):(t||(i[o++]=u,t=!0),t&&(e[r++]=a>>8,e[r++]=255&a,r==e.length&&(o+=i.write(e.toString("base64").replace(/\//g,","),o),r=0)))}return this.inBase64=t,this.base64AccumIdx=r,i.slice(0,o)},h.prototype.end=function(){var A=n.alloc(10),t=0;return this.inBase64&&(this.base64AccumIdx>0&&(t+=A.write(this.base64Accum.slice(0,this.base64AccumIdx).toString("base64").replace(/\//g,",").replace(/=+$/,""),t),this.base64AccumIdx=0),A[t++]=l,this.inBase64=!1),A.slice(0,t)};var f=c.slice();f[",".charCodeAt(0)]=!0,E.prototype.write=function(A){for(var t="",e=0,r=this.inBase64,i=this.base64Accum,o=0;o<A.length;o++)if(r){if(!f[A[o]]){if(o==e&&A[o]==l)t+="&";else{var s=i+this.iconv.decode(A.slice(e,o),"ascii").replace(/,/g,"/");t+=this.iconv.decode(n.from(s,"base64"),"utf16-be")}A[o]!=l&&o--,e=o+1,r=!1,i=""}}else A[o]==u&&(t+=this.iconv.decode(A.slice(e,o),"ascii"),e=o+1,r=!0);if(r){var a=(s=i+this.iconv.decode(A.slice(e),"ascii").replace(/,/g,"/")).length-s.length%8;i=s.slice(a),s=s.slice(0,a),t+=this.iconv.decode(n.from(s,"base64"),"utf16-be")}else t+=this.iconv.decode(A.slice(e),"ascii");return this.inBase64=r,this.base64Accum=i,t},E.prototype.end=function(){var A="";return this.inBase64&&this.base64Accum.length>0&&(A=this.iconv.decode(n.from(this.base64Accum,"base64"),"utf16-be")),this.inBase64=!1,this.base64Accum="",A}},5395:function(A,t){"use strict";function e(A,t){this.encoder=A,this.addBOM=!0}function n(A,t){this.decoder=A,this.pass=!1,this.options=t||{}}t.PrependBOM=e,e.prototype.write=function(A){return this.addBOM&&(A="\ufeff"+A,this.addBOM=!1),this.encoder.write(A)},e.prototype.end=function(){return this.encoder.end()},t.StripBOM=n,n.prototype.write=function(A){var t=this.decoder.write(A);return this.pass||!t||("\ufeff"===t[0]&&(t=t.slice(1),"function"==typeof this.options.stripBOM&&this.options.stripBOM()),this.pass=!0),t},n.prototype.end=function(){return this.decoder.end()}},4914:function(A,t,e){"use strict";var n,r=e(7103).Buffer,i=e(5395),o=A.exports;o.encodings=null,o.defaultCharUnicode="�",o.defaultCharSingleByte="?",o.encode=function(A,t,e){A=""+(A||"");var n=o.getEncoder(t,e),i=n.write(A),s=n.end();return s&&s.length>0?r.concat([i,s]):i},o.decode=function(A,t,e){"string"==typeof A&&(o.skipDecodeWarning||(o.skipDecodeWarning=!0),A=r.from(""+(A||""),"binary"));var n=o.getDecoder(t,e),i=n.write(A),s=n.end();return s?i+s:i},o.encodingExists=function(A){try{return o.getCodec(A),!0}catch(A){return!1}},o.toEncoding=o.encode,o.fromEncoding=o.decode,o._codecDataCache={},o.getCodec=function(A){o.encodings||(o.encodings=e(6934));for(var t=o._canonicalizeEncoding(A),n={};;){var r=o._codecDataCache[t];if(r)return r;var i=o.encodings[t];switch(typeof i){case"string":t=i;break;case"object":for(var s in i)n[s]=i[s];n.encodingName||(n.encodingName=t),t=i.type;break;case"function":return n.encodingName||(n.encodingName=t),r=new i(n,o),o._codecDataCache[n.encodingName]=r,r;default:throw new Error("Encoding not recognized: '"+A+"' (searched as: '"+t+"')")}}},o._canonicalizeEncoding=function(A){return(""+A).toLowerCase().replace(/:\d{4}$|[^0-9a-z]/g,"")},o.getEncoder=function(A,t){var e=o.getCodec(A),n=new e.encoder(t,e);return e.bomAware&&t&&t.addBOM&&(n=new i.PrependBOM(n,t)),n},o.getDecoder=function(A,t){var e=o.getCodec(A),n=new e.decoder(t,e);return!e.bomAware||t&&!1===t.stripBOM||(n=new i.StripBOM(n,t)),n},o.enableStreamingAPI=function(A){if(!o.supportsStreams){var t=e(8044)(A);o.IconvLiteEncoderStream=t.IconvLiteEncoderStream,o.IconvLiteDecoderStream=t.IconvLiteDecoderStream,o.encodeStream=function(A,t){return new o.IconvLiteEncoderStream(o.getEncoder(A,t),t)},o.decodeStream=function(A,t){return new o.IconvLiteDecoderStream(o.getDecoder(A,t),t)},o.supportsStreams=!0}};try{n=e(5832)}catch(A){}n&&n.Transform?o.enableStreamingAPI(n):o.encodeStream=o.decodeStream=function(){throw new Error("iconv-lite Streaming API is not enabled. Use iconv.enableStreamingAPI(require('stream')); to enable it.")}},8044:function(A,t,e){"use strict";var n=e(7103).Buffer;A.exports=function(A){var t=A.Transform;function e(A,e){this.conv=A,(e=e||{}).decodeStrings=!1,t.call(this,e)}function r(A,e){this.conv=A,(e=e||{}).encoding=this.encoding="utf8",t.call(this,e)}return e.prototype=Object.create(t.prototype,{constructor:{value:e}}),e.prototype._transform=function(A,t,e){if("string"!=typeof A)return e(new Error("Iconv encoding stream needs strings as its input."));try{var n=this.conv.write(A);n&&n.length&&this.push(n),e()}catch(A){e(A)}},e.prototype._flush=function(A){try{var t=this.conv.end();t&&t.length&&this.push(t),A()}catch(t){A(t)}},e.prototype.collect=function(A){var t=[];return this.on("error",A),this.on("data",(function(A){t.push(A)})),this.on("end",(function(){A(null,n.concat(t))})),this},r.prototype=Object.create(t.prototype,{constructor:{value:r}}),r.prototype._transform=function(A,t,e){if(!(n.isBuffer(A)||A instanceof Uint8Array))return e(new Error("Iconv decoding stream needs buffers as its input."));try{var r=this.conv.write(A);r&&r.length&&this.push(r,this.encoding),e()}catch(A){e(A)}},r.prototype._flush=function(A){try{var t=this.conv.end();t&&t.length&&this.push(t,this.encoding),A()}catch(t){A(t)}},r.prototype.collect=function(A){var t="";return this.on("error",A),this.on("data",(function(A){t+=A})),this.on("end",(function(){A(null,t)})),this},{IconvLiteEncoderStream:e,IconvLiteDecoderStream:r}}},645:function(A,t){t.read=function(A,t,e,n,r){var i,o,s=8*r-n-1,a=(1<<s)-1,c=a>>1,B=-7,g=e?r-1:0,l=e?-1:1,u=A[t+g];for(g+=l,i=u&(1<<-B)-1,u>>=-B,B+=s;B>0;i=256*i+A[t+g],g+=l,B-=8);for(o=i&(1<<-B)-1,i>>=-B,B+=n;B>0;o=256*o+A[t+g],g+=l,B-=8);if(0===i)i=1-c;else{if(i===a)return o?NaN:1/0*(u?-1:1);o+=Math.pow(2,n),i-=c}return(u?-1:1)*o*Math.pow(2,i-n)},t.write=function(A,t,e,n,r,i){var o,s,a,c=8*i-r-1,B=(1<<c)-1,g=B>>1,l=23===r?Math.pow(2,-24)-Math.pow(2,-77):0,u=n?0:i-1,w=n?1:-1,h=t<0||0===t&&1/t<0?1:0;for(t=Math.abs(t),isNaN(t)||t===1/0?(s=isNaN(t)?1:0,o=B):(o=Math.floor(Math.log(t)/Math.LN2),t*(a=Math.pow(2,-o))<1&&(o--,a*=2),(t+=o+g>=1?l/a:l*Math.pow(2,1-g))*a>=2&&(o++,a/=2),o+g>=B?(s=0,o=B):o+g>=1?(s=(t*a-1)*Math.pow(2,r),o+=g):(s=t*Math.pow(2,g-1)*Math.pow(2,r),o=0));r>=8;A[e+u]=255&s,u+=w,s/=256,r-=8);for(o=o<<r|s,c+=r;c>0;A[e+u]=255&o,u+=w,o/=256,c-=8);A[e+u-w]|=128*h}},5717:function(A){"function"==typeof Object.create?A.exports=function(A,t){t&&(A.super_=t,A.prototype=Object.create(t.prototype,{constructor:{value:A,enumerable:!1,writable:!0,configurable:!0}}))}:A.exports=function(A,t){if(t){A.super_=t;var e=function(){};e.prototype=t.prototype,A.prototype=new e,A.prototype.constructor=A}}},2584:function(A,t,e){"use strict";var n=e(6410)(),r=e(1924)("Object.prototype.toString"),i=function(A){return!(n&&A&&"object"==typeof A&&Symbol.toStringTag in A)&&"[object Arguments]"===r(A)},o=function(A){return!!i(A)||null!==A&&"object"==typeof A&&"number"==typeof A.length&&A.length>=0&&"[object Array]"!==r(A)&&"[object Function]"===r(A.callee)},s=function(){return i(arguments)}();i.isLegacyArguments=o,A.exports=s?i:o},5320:function(A){"use strict";var t,e,n=Function.prototype.toString,r="object"==typeof Reflect&&null!==Reflect&&Reflect.apply;if("function"==typeof r&&"function"==typeof Object.defineProperty)try{t=Object.defineProperty({},"length",{get:function(){throw e}}),e={},r((function(){throw 42}),null,t)}catch(A){A!==e&&(r=null)}else r=null;var i=/^\s*class\b/,o=function(A){try{var t=n.call(A);return i.test(t)}catch(A){return!1}},s=function(A){try{return!o(A)&&(n.call(A),!0)}catch(A){return!1}},a=Object.prototype.toString,c="function"==typeof Symbol&&!!Symbol.toStringTag,B=!(0 in[,]),g=function(){return!1};if("object"==typeof document){var l=document.all;a.call(l)===a.call(document.all)&&(g=function(A){if((B||!A)&&(void 0===A||"object"==typeof A))try{var t=a.call(A);return("[object HTMLAllCollection]"===t||"[object HTML document.all class]"===t||"[object HTMLCollection]"===t||"[object Object]"===t)&&null==A("")}catch(A){}return!1})}A.exports=r?function(A){if(g(A))return!0;if(!A)return!1;if("function"!=typeof A&&"object"!=typeof A)return!1;try{r(A,null,t)}catch(A){if(A!==e)return!1}return!o(A)&&s(A)}:function(A){if(g(A))return!0;if(!A)return!1;if("function"!=typeof A&&"object"!=typeof A)return!1;if(c)return s(A);if(o(A))return!1;var t=a.call(A);return!("[object Function]"!==t&&"[object GeneratorFunction]"!==t&&!/^\[object HTML/.test(t))&&s(A)}},8923:function(A,t,e){"use strict";var n=Date.prototype.getDay,r=Object.prototype.toString,i=e(6410)();A.exports=function(A){return"object"==typeof A&&null!==A&&(i?function(A){try{return n.call(A),!0}catch(A){return!1}}(A):"[object Date]"===r.call(A))}},8662:function(A,t,e){"use strict";var n,r=Object.prototype.toString,i=Function.prototype.toString,o=/^\s*(?:function)?\*/,s=e(6410)(),a=Object.getPrototypeOf;A.exports=function(A){if("function"!=typeof A)return!1;if(o.test(i.call(A)))return!0;if(!s)return"[object GeneratorFunction]"===r.call(A);if(!a)return!1;if(void 0===n){var t=function(){if(!s)return!1;try{return Function("return function*() {}")()}catch(A){}}();n=!!t&&a(t)}return a(A)===n}},8611:function(A){"use strict";A.exports=function(A){return A!=A}},360:function(A,t,e){"use strict";var n=e(5559),r=e(4289),i=e(8611),o=e(9415),s=e(6743),a=n(o(),Number);r(a,{getPolyfill:o,implementation:i,shim:s}),A.exports=a},9415:function(A,t,e){"use strict";var n=e(8611);A.exports=function(){return Number.isNaN&&Number.isNaN(NaN)&&!Number.isNaN("a")?Number.isNaN:n}},6743:function(A,t,e){"use strict";var n=e(4289),r=e(9415);A.exports=function(){var A=r();return n(Number,{isNaN:A},{isNaN:function(){return Number.isNaN!==A}}),A}},8420:function(A,t,e){"use strict";var n,r,i,o,s=e(1924),a=e(6410)();if(a){n=s("Object.prototype.hasOwnProperty"),r=s("RegExp.prototype.exec"),i={};var c=function(){throw i};o={toString:c,valueOf:c},"symbol"==typeof Symbol.toPrimitive&&(o[Symbol.toPrimitive]=c)}var B=s("Object.prototype.toString"),g=Object.getOwnPropertyDescriptor;A.exports=a?function(A){if(!A||"object"!=typeof A)return!1;var t=g(A,"lastIndex");if(!t||!n(t,"value"))return!1;try{r(A,o)}catch(A){return A===i}}:function(A){return!(!A||"object"!=typeof A&&"function"!=typeof A)&&"[object RegExp]"===B(A)}},5692:function(A,t,e){"use strict";var n=e(4029),r=e(3083),i=e(1924),o=i("Object.prototype.toString"),s=e(6410)(),a=e(7296),c="undefined"==typeof globalThis?e.g:globalThis,B=r(),g=i("Array.prototype.indexOf",!0)||function(A,t){for(var e=0;e<A.length;e+=1)if(A[e]===t)return e;return-1},l=i("String.prototype.slice"),u={},w=Object.getPrototypeOf;s&&a&&w&&n(B,(function(A){var t=new c[A];if(Symbol.toStringTag in t){var e=w(t),n=a(e,Symbol.toStringTag);if(!n){var r=w(e);n=a(r,Symbol.toStringTag)}u[A]=n.get}})),A.exports=function(A){if(!A||"object"!=typeof A)return!1;if(!s||!(Symbol.toStringTag in A)){var t=l(o(A),8,-1);return g(B,t)>-1}return!!a&&function(A){var t=!1;return n(u,(function(e,n){if(!t)try{t=e.call(A)===n}catch(A){}})),t}(A)}},4244:function(A){"use strict";var t=function(A){return A!=A};A.exports=function(A,e){return 0===A&&0===e?1/A==1/e:A===e||!(!t(A)||!t(e))}},609:function(A,t,e){"use strict";var n=e(4289),r=e(5559),i=e(4244),o=e(5624),s=e(2281),a=r(o(),Object);n(a,{getPolyfill:o,implementation:i,shim:s}),A.exports=a},5624:function(A,t,e){"use strict";var n=e(4244);A.exports=function(){return"function"==typeof Object.is?Object.is:n}},2281:function(A,t,e){"use strict";var n=e(5624),r=e(4289);A.exports=function(){var A=n();return r(Object,{is:A},{is:function(){return Object.is!==A}}),A}},8987:function(A,t,e){"use strict";var n;if(!Object.keys){var r=Object.prototype.hasOwnProperty,i=Object.prototype.toString,o=e(1414),s=Object.prototype.propertyIsEnumerable,a=!s.call({toString:null},"toString"),c=s.call((function(){}),"prototype"),B=["toString","toLocaleString","valueOf","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","constructor"],g=function(A){var t=A.constructor;return t&&t.prototype===A},l={$applicationCache:!0,$console:!0,$external:!0,$frame:!0,$frameElement:!0,$frames:!0,$innerHeight:!0,$innerWidth:!0,$onmozfullscreenchange:!0,$onmozfullscreenerror:!0,$outerHeight:!0,$outerWidth:!0,$pageXOffset:!0,$pageYOffset:!0,$parent:!0,$scrollLeft:!0,$scrollTop:!0,$scrollX:!0,$scrollY:!0,$self:!0,$webkitIndexedDB:!0,$webkitStorageInfo:!0,$window:!0},u=function(){if("undefined"==typeof window)return!1;for(var A in window)try{if(!l["$"+A]&&r.call(window,A)&&null!==window[A]&&"object"==typeof window[A])try{g(window[A])}catch(A){return!0}}catch(A){return!0}return!1}();n=function(A){var t=null!==A&&"object"==typeof A,e="[object Function]"===i.call(A),n=o(A),s=t&&"[object String]"===i.call(A),l=[];if(!t&&!e&&!n)throw new TypeError("Object.keys called on a non-object");var w=c&&e;if(s&&A.length>0&&!r.call(A,0))for(var h=0;h<A.length;++h)l.push(String(h));if(n&&A.length>0)for(var E=0;E<A.length;++E)l.push(String(E));else for(var f in A)w&&"prototype"===f||!r.call(A,f)||l.push(String(f));if(a)for(var Q=function(A){if("undefined"==typeof window||!u)return g(A);try{return g(A)}catch(A){return!1}}(A),d=0;d<B.length;++d)Q&&"constructor"===B[d]||!r.call(A,B[d])||l.push(B[d]);return l}}A.exports=n},2215:function(A,t,e){"use strict";var n=Array.prototype.slice,r=e(1414),i=Object.keys,o=i?function(A){return i(A)}:e(8987),s=Object.keys;o.shim=function(){if(Object.keys){var A=function(){var A=Object.keys(arguments);return A&&A.length===arguments.length}(1,2);A||(Object.keys=function(A){return r(A)?s(n.call(A)):s(A)})}else Object.keys=o;return Object.keys||o},A.exports=o},1414:function(A){"use strict";var t=Object.prototype.toString;A.exports=function(A){var e=t.call(A),n="[object Arguments]"===e;return n||(n="[object Array]"!==e&&null!==A&&"object"==typeof A&&"number"==typeof A.length&&A.length>=0&&"[object Function]"===t.call(A.callee)),n}},4236:function(A,t){"use strict";var e="undefined"!=typeof Uint8Array&&"undefined"!=typeof Uint16Array&&"undefined"!=typeof Int32Array;function n(A,t){return Object.prototype.hasOwnProperty.call(A,t)}t.assign=function(A){for(var t=Array.prototype.slice.call(arguments,1);t.length;){var e=t.shift();if(e){if("object"!=typeof e)throw new TypeError(e+"must be non-object");for(var r in e)n(e,r)&&(A[r]=e[r])}}return A},t.shrinkBuf=function(A,t){return A.length===t?A:A.subarray?A.subarray(0,t):(A.length=t,A)};var r={arraySet:function(A,t,e,n,r){if(t.subarray&&A.subarray)A.set(t.subarray(e,e+n),r);else for(var i=0;i<n;i++)A[r+i]=t[e+i]},flattenChunks:function(A){var t,e,n,r,i,o;for(n=0,t=0,e=A.length;t<e;t++)n+=A[t].length;for(o=new Uint8Array(n),r=0,t=0,e=A.length;t<e;t++)i=A[t],o.set(i,r),r+=i.length;return o}},i={arraySet:function(A,t,e,n,r){for(var i=0;i<n;i++)A[r+i]=t[e+i]},flattenChunks:function(A){return[].concat.apply([],A)}};t.setTyped=function(A){A?(t.Buf8=Uint8Array,t.Buf16=Uint16Array,t.Buf32=Int32Array,t.assign(t,r)):(t.Buf8=Array,t.Buf16=Array,t.Buf32=Array,t.assign(t,i))},t.setTyped(e)},6069:function(A){"use strict";A.exports=function(A,t,e,n){for(var r=65535&A|0,i=A>>>16&65535|0,o=0;0!==e;){e-=o=e>2e3?2e3:e;do{i=i+(r=r+t[n++]|0)|0}while(--o);r%=65521,i%=65521}return r|i<<16|0}},1619:function(A){"use strict";A.exports={Z_NO_FLUSH:0,Z_PARTIAL_FLUSH:1,Z_SYNC_FLUSH:2,Z_FULL_FLUSH:3,Z_FINISH:4,Z_BLOCK:5,Z_TREES:6,Z_OK:0,Z_STREAM_END:1,Z_NEED_DICT:2,Z_ERRNO:-1,Z_STREAM_ERROR:-2,Z_DATA_ERROR:-3,Z_BUF_ERROR:-5,Z_NO_COMPRESSION:0,Z_BEST_SPEED:1,Z_BEST_COMPRESSION:9,Z_DEFAULT_COMPRESSION:-1,Z_FILTERED:1,Z_HUFFMAN_ONLY:2,Z_RLE:3,Z_FIXED:4,Z_DEFAULT_STRATEGY:0,Z_BINARY:0,Z_TEXT:1,Z_UNKNOWN:2,Z_DEFLATED:8}},2869:function(A){"use strict";var t=function(){for(var A,t=[],e=0;e<256;e++){A=e;for(var n=0;n<8;n++)A=1&A?3988292384^A>>>1:A>>>1;t[e]=A}return t}();A.exports=function(A,e,n,r){var i=t,o=r+n;A^=-1;for(var s=r;s<o;s++)A=A>>>8^i[255&(A^e[s])];return-1^A}},405:function(A,t,e){"use strict";var n,r=e(4236),i=e(342),o=e(6069),s=e(2869),a=e(8898),c=-2,B=258,g=262,l=103,u=113,w=666;function h(A,t){return A.msg=a[t],t}function E(A){return(A<<1)-(A>4?9:0)}function f(A){for(var t=A.length;--t>=0;)A[t]=0}function Q(A){var t=A.state,e=t.pending;e>A.avail_out&&(e=A.avail_out),0!==e&&(r.arraySet(A.output,t.pending_buf,t.pending_out,e,A.next_out),A.next_out+=e,t.pending_out+=e,A.total_out+=e,A.avail_out-=e,t.pending-=e,0===t.pending&&(t.pending_out=0))}function d(A,t){i._tr_flush_block(A,A.block_start>=0?A.block_start:-1,A.strstart-A.block_start,t),A.block_start=A.strstart,Q(A.strm)}function C(A,t){A.pending_buf[A.pending++]=t}function M(A,t){A.pending_buf[A.pending++]=t>>>8&255,A.pending_buf[A.pending++]=255&t}function I(A,t){var e,n,r=A.max_chain_length,i=A.strstart,o=A.prev_length,s=A.nice_match,a=A.strstart>A.w_size-g?A.strstart-(A.w_size-g):0,c=A.window,l=A.w_mask,u=A.prev,w=A.strstart+B,h=c[i+o-1],E=c[i+o];A.prev_length>=A.good_match&&(r>>=2),s>A.lookahead&&(s=A.lookahead);do{if(c[(e=t)+o]===E&&c[e+o-1]===h&&c[e]===c[i]&&c[++e]===c[i+1]){i+=2,e++;do{}while(c[++i]===c[++e]&&c[++i]===c[++e]&&c[++i]===c[++e]&&c[++i]===c[++e]&&c[++i]===c[++e]&&c[++i]===c[++e]&&c[++i]===c[++e]&&c[++i]===c[++e]&&i<w);if(n=B-(w-i),i=w-B,n>o){if(A.match_start=t,o=n,n>=s)break;h=c[i+o-1],E=c[i+o]}}}while((t=u[t&l])>a&&0!=--r);return o<=A.lookahead?o:A.lookahead}function p(A){var t,e,n,i,a,c,B,l,u,w,h=A.w_size;do{if(i=A.window_size-A.lookahead-A.strstart,A.strstart>=h+(h-g)){r.arraySet(A.window,A.window,h,h,0),A.match_start-=h,A.strstart-=h,A.block_start-=h,t=e=A.hash_size;do{n=A.head[--t],A.head[t]=n>=h?n-h:0}while(--e);t=e=h;do{n=A.prev[--t],A.prev[t]=n>=h?n-h:0}while(--e);i+=h}if(0===A.strm.avail_in)break;if(c=A.strm,B=A.window,l=A.strstart+A.lookahead,u=i,w=void 0,(w=c.avail_in)>u&&(w=u),e=0===w?0:(c.avail_in-=w,r.arraySet(B,c.input,c.next_in,w,l),1===c.state.wrap?c.adler=o(c.adler,B,w,l):2===c.state.wrap&&(c.adler=s(c.adler,B,w,l)),c.next_in+=w,c.total_in+=w,w),A.lookahead+=e,A.lookahead+A.insert>=3)for(a=A.strstart-A.insert,A.ins_h=A.window[a],A.ins_h=(A.ins_h<<A.hash_shift^A.window[a+1])&A.hash_mask;A.insert&&(A.ins_h=(A.ins_h<<A.hash_shift^A.window[a+3-1])&A.hash_mask,A.prev[a&A.w_mask]=A.head[A.ins_h],A.head[A.ins_h]=a,a++,A.insert--,!(A.lookahead+A.insert<3)););}while(A.lookahead<g&&0!==A.strm.avail_in)}function D(A,t){for(var e,n;;){if(A.lookahead<g){if(p(A),A.lookahead<g&&0===t)return 1;if(0===A.lookahead)break}if(e=0,A.lookahead>=3&&(A.ins_h=(A.ins_h<<A.hash_shift^A.window[A.strstart+3-1])&A.hash_mask,e=A.prev[A.strstart&A.w_mask]=A.head[A.ins_h],A.head[A.ins_h]=A.strstart),0!==e&&A.strstart-e<=A.w_size-g&&(A.match_length=I(A,e)),A.match_length>=3)if(n=i._tr_tally(A,A.strstart-A.match_start,A.match_length-3),A.lookahead-=A.match_length,A.match_length<=A.max_lazy_match&&A.lookahead>=3){A.match_length--;do{A.strstart++,A.ins_h=(A.ins_h<<A.hash_shift^A.window[A.strstart+3-1])&A.hash_mask,e=A.prev[A.strstart&A.w_mask]=A.head[A.ins_h],A.head[A.ins_h]=A.strstart}while(0!=--A.match_length);A.strstart++}else A.strstart+=A.match_length,A.match_length=0,A.ins_h=A.window[A.strstart],A.ins_h=(A.ins_h<<A.hash_shift^A.window[A.strstart+1])&A.hash_mask;else n=i._tr_tally(A,0,A.window[A.strstart]),A.lookahead--,A.strstart++;if(n&&(d(A,!1),0===A.strm.avail_out))return 1}return A.insert=A.strstart<2?A.strstart:2,4===t?(d(A,!0),0===A.strm.avail_out?3:4):A.last_lit&&(d(A,!1),0===A.strm.avail_out)?1:2}function y(A,t){for(var e,n,r;;){if(A.lookahead<g){if(p(A),A.lookahead<g&&0===t)return 1;if(0===A.lookahead)break}if(e=0,A.lookahead>=3&&(A.ins_h=(A.ins_h<<A.hash_shift^A.window[A.strstart+3-1])&A.hash_mask,e=A.prev[A.strstart&A.w_mask]=A.head[A.ins_h],A.head[A.ins_h]=A.strstart),A.prev_length=A.match_length,A.prev_match=A.match_start,A.match_length=2,0!==e&&A.prev_length<A.max_lazy_match&&A.strstart-e<=A.w_size-g&&(A.match_length=I(A,e),A.match_length<=5&&(1===A.strategy||3===A.match_length&&A.strstart-A.match_start>4096)&&(A.match_length=2)),A.prev_length>=3&&A.match_length<=A.prev_length){r=A.strstart+A.lookahead-3,n=i._tr_tally(A,A.strstart-1-A.prev_match,A.prev_length-3),A.lookahead-=A.prev_length-1,A.prev_length-=2;do{++A.strstart<=r&&(A.ins_h=(A.ins_h<<A.hash_shift^A.window[A.strstart+3-1])&A.hash_mask,e=A.prev[A.strstart&A.w_mask]=A.head[A.ins_h],A.head[A.ins_h]=A.strstart)}while(0!=--A.prev_length);if(A.match_available=0,A.match_length=2,A.strstart++,n&&(d(A,!1),0===A.strm.avail_out))return 1}else if(A.match_available){if((n=i._tr_tally(A,0,A.window[A.strstart-1]))&&d(A,!1),A.strstart++,A.lookahead--,0===A.strm.avail_out)return 1}else A.match_available=1,A.strstart++,A.lookahead--}return A.match_available&&(n=i._tr_tally(A,0,A.window[A.strstart-1]),A.match_available=0),A.insert=A.strstart<2?A.strstart:2,4===t?(d(A,!0),0===A.strm.avail_out?3:4):A.last_lit&&(d(A,!1),0===A.strm.avail_out)?1:2}function v(A,t,e,n,r){this.good_length=A,this.max_lazy=t,this.nice_length=e,this.max_chain=n,this.func=r}function m(){this.strm=null,this.status=0,this.pending_buf=null,this.pending_buf_size=0,this.pending_out=0,this.pending=0,this.wrap=0,this.gzhead=null,this.gzindex=0,this.method=8,this.last_flush=-1,this.w_size=0,this.w_bits=0,this.w_mask=0,this.window=null,this.window_size=0,this.prev=null,this.head=null,this.ins_h=0,this.hash_size=0,this.hash_bits=0,this.hash_mask=0,this.hash_shift=0,this.block_start=0,this.match_length=0,this.prev_match=0,this.match_available=0,this.strstart=0,this.match_start=0,this.lookahead=0,this.prev_length=0,this.max_chain_length=0,this.max_lazy_match=0,this.level=0,this.strategy=0,this.good_match=0,this.nice_match=0,this.dyn_ltree=new r.Buf16(1146),this.dyn_dtree=new r.Buf16(122),this.bl_tree=new r.Buf16(78),f(this.dyn_ltree),f(this.dyn_dtree),f(this.bl_tree),this.l_desc=null,this.d_desc=null,this.bl_desc=null,this.bl_count=new r.Buf16(16),this.heap=new r.Buf16(573),f(this.heap),this.heap_len=0,this.heap_max=0,this.depth=new r.Buf16(573),f(this.depth),this.l_buf=0,this.lit_bufsize=0,this.last_lit=0,this.d_buf=0,this.opt_len=0,this.static_len=0,this.matches=0,this.insert=0,this.bi_buf=0,this.bi_valid=0}function F(A){var t;return A&&A.state?(A.total_in=A.total_out=0,A.data_type=2,(t=A.state).pending=0,t.pending_out=0,t.wrap<0&&(t.wrap=-t.wrap),t.status=t.wrap?42:u,A.adler=2===t.wrap?0:1,t.last_flush=0,i._tr_init(t),0):h(A,c)}function Y(A){var t=F(A);return 0===t&&function(A){A.window_size=2*A.w_size,f(A.head),A.max_lazy_match=n[A.level].max_lazy,A.good_match=n[A.level].good_length,A.nice_match=n[A.level].nice_length,A.max_chain_length=n[A.level].max_chain,A.strstart=0,A.block_start=0,A.lookahead=0,A.insert=0,A.match_length=A.prev_length=2,A.match_available=0,A.ins_h=0}(A.state),t}function b(A,t,e,n,i,o){if(!A)return c;var s=1;if(-1===t&&(t=6),n<0?(s=0,n=-n):n>15&&(s=2,n-=16),i<1||i>9||8!==e||n<8||n>15||t<0||t>9||o<0||o>4)return h(A,c);8===n&&(n=9);var a=new m;return A.state=a,a.strm=A,a.wrap=s,a.gzhead=null,a.w_bits=n,a.w_size=1<<a.w_bits,a.w_mask=a.w_size-1,a.hash_bits=i+7,a.hash_size=1<<a.hash_bits,a.hash_mask=a.hash_size-1,a.hash_shift=~~((a.hash_bits+3-1)/3),a.window=new r.Buf8(2*a.w_size),a.head=new r.Buf16(a.hash_size),a.prev=new r.Buf16(a.w_size),a.lit_bufsize=1<<i+6,a.pending_buf_size=4*a.lit_bufsize,a.pending_buf=new r.Buf8(a.pending_buf_size),a.d_buf=1*a.lit_bufsize,a.l_buf=3*a.lit_bufsize,a.level=t,a.strategy=o,a.method=e,Y(A)}n=[new v(0,0,0,0,(function(A,t){var e=65535;for(e>A.pending_buf_size-5&&(e=A.pending_buf_size-5);;){if(A.lookahead<=1){if(p(A),0===A.lookahead&&0===t)return 1;if(0===A.lookahead)break}A.strstart+=A.lookahead,A.lookahead=0;var n=A.block_start+e;if((0===A.strstart||A.strstart>=n)&&(A.lookahead=A.strstart-n,A.strstart=n,d(A,!1),0===A.strm.avail_out))return 1;if(A.strstart-A.block_start>=A.w_size-g&&(d(A,!1),0===A.strm.avail_out))return 1}return A.insert=0,4===t?(d(A,!0),0===A.strm.avail_out?3:4):(A.strstart>A.block_start&&(d(A,!1),A.strm.avail_out),1)})),new v(4,4,8,4,D),new v(4,5,16,8,D),new v(4,6,32,32,D),new v(4,4,16,16,y),new v(8,16,32,32,y),new v(8,16,128,128,y),new v(8,32,128,256,y),new v(32,128,258,1024,y),new v(32,258,258,4096,y)],t.deflateInit=function(A,t){return b(A,t,8,15,8,0)},t.deflateInit2=b,t.deflateReset=Y,t.deflateResetKeep=F,t.deflateSetHeader=function(A,t){return A&&A.state?2!==A.state.wrap?c:(A.state.gzhead=t,0):c},t.deflate=function(A,t){var e,r,o,a;if(!A||!A.state||t>5||t<0)return A?h(A,c):c;if(r=A.state,!A.output||!A.input&&0!==A.avail_in||r.status===w&&4!==t)return h(A,0===A.avail_out?-5:c);if(r.strm=A,e=r.last_flush,r.last_flush=t,42===r.status)if(2===r.wrap)A.adler=0,C(r,31),C(r,139),C(r,8),r.gzhead?(C(r,(r.gzhead.text?1:0)+(r.gzhead.hcrc?2:0)+(r.gzhead.extra?4:0)+(r.gzhead.name?8:0)+(r.gzhead.comment?16:0)),C(r,255&r.gzhead.time),C(r,r.gzhead.time>>8&255),C(r,r.gzhead.time>>16&255),C(r,r.gzhead.time>>24&255),C(r,9===r.level?2:r.strategy>=2||r.level<2?4:0),C(r,255&r.gzhead.os),r.gzhead.extra&&r.gzhead.extra.length&&(C(r,255&r.gzhead.extra.length),C(r,r.gzhead.extra.length>>8&255)),r.gzhead.hcrc&&(A.adler=s(A.adler,r.pending_buf,r.pending,0)),r.gzindex=0,r.status=69):(C(r,0),C(r,0),C(r,0),C(r,0),C(r,0),C(r,9===r.level?2:r.strategy>=2||r.level<2?4:0),C(r,3),r.status=u);else{var g=8+(r.w_bits-8<<4)<<8;g|=(r.strategy>=2||r.level<2?0:r.level<6?1:6===r.level?2:3)<<6,0!==r.strstart&&(g|=32),g+=31-g%31,r.status=u,M(r,g),0!==r.strstart&&(M(r,A.adler>>>16),M(r,65535&A.adler)),A.adler=1}if(69===r.status)if(r.gzhead.extra){for(o=r.pending;r.gzindex<(65535&r.gzhead.extra.length)&&(r.pending!==r.pending_buf_size||(r.gzhead.hcrc&&r.pending>o&&(A.adler=s(A.adler,r.pending_buf,r.pending-o,o)),Q(A),o=r.pending,r.pending!==r.pending_buf_size));)C(r,255&r.gzhead.extra[r.gzindex]),r.gzindex++;r.gzhead.hcrc&&r.pending>o&&(A.adler=s(A.adler,r.pending_buf,r.pending-o,o)),r.gzindex===r.gzhead.extra.length&&(r.gzindex=0,r.status=73)}else r.status=73;if(73===r.status)if(r.gzhead.name){o=r.pending;do{if(r.pending===r.pending_buf_size&&(r.gzhead.hcrc&&r.pending>o&&(A.adler=s(A.adler,r.pending_buf,r.pending-o,o)),Q(A),o=r.pending,r.pending===r.pending_buf_size)){a=1;break}a=r.gzindex<r.gzhead.name.length?255&r.gzhead.name.charCodeAt(r.gzindex++):0,C(r,a)}while(0!==a);r.gzhead.hcrc&&r.pending>o&&(A.adler=s(A.adler,r.pending_buf,r.pending-o,o)),0===a&&(r.gzindex=0,r.status=91)}else r.status=91;if(91===r.status)if(r.gzhead.comment){o=r.pending;do{if(r.pending===r.pending_buf_size&&(r.gzhead.hcrc&&r.pending>o&&(A.adler=s(A.adler,r.pending_buf,r.pending-o,o)),Q(A),o=r.pending,r.pending===r.pending_buf_size)){a=1;break}a=r.gzindex<r.gzhead.comment.length?255&r.gzhead.comment.charCodeAt(r.gzindex++):0,C(r,a)}while(0!==a);r.gzhead.hcrc&&r.pending>o&&(A.adler=s(A.adler,r.pending_buf,r.pending-o,o)),0===a&&(r.status=l)}else r.status=l;if(r.status===l&&(r.gzhead.hcrc?(r.pending+2>r.pending_buf_size&&Q(A),r.pending+2<=r.pending_buf_size&&(C(r,255&A.adler),C(r,A.adler>>8&255),A.adler=0,r.status=u)):r.status=u),0!==r.pending){if(Q(A),0===A.avail_out)return r.last_flush=-1,0}else if(0===A.avail_in&&E(t)<=E(e)&&4!==t)return h(A,-5);if(r.status===w&&0!==A.avail_in)return h(A,-5);if(0!==A.avail_in||0!==r.lookahead||0!==t&&r.status!==w){var I=2===r.strategy?function(A,t){for(var e;;){if(0===A.lookahead&&(p(A),0===A.lookahead)){if(0===t)return 1;break}if(A.match_length=0,e=i._tr_tally(A,0,A.window[A.strstart]),A.lookahead--,A.strstart++,e&&(d(A,!1),0===A.strm.avail_out))return 1}return A.insert=0,4===t?(d(A,!0),0===A.strm.avail_out?3:4):A.last_lit&&(d(A,!1),0===A.strm.avail_out)?1:2}(r,t):3===r.strategy?function(A,t){for(var e,n,r,o,s=A.window;;){if(A.lookahead<=B){if(p(A),A.lookahead<=B&&0===t)return 1;if(0===A.lookahead)break}if(A.match_length=0,A.lookahead>=3&&A.strstart>0&&(n=s[r=A.strstart-1])===s[++r]&&n===s[++r]&&n===s[++r]){o=A.strstart+B;do{}while(n===s[++r]&&n===s[++r]&&n===s[++r]&&n===s[++r]&&n===s[++r]&&n===s[++r]&&n===s[++r]&&n===s[++r]&&r<o);A.match_length=B-(o-r),A.match_length>A.lookahead&&(A.match_length=A.lookahead)}if(A.match_length>=3?(e=i._tr_tally(A,1,A.match_length-3),A.lookahead-=A.match_length,A.strstart+=A.match_length,A.match_length=0):(e=i._tr_tally(A,0,A.window[A.strstart]),A.lookahead--,A.strstart++),e&&(d(A,!1),0===A.strm.avail_out))return 1}return A.insert=0,4===t?(d(A,!0),0===A.strm.avail_out?3:4):A.last_lit&&(d(A,!1),0===A.strm.avail_out)?1:2}(r,t):n[r.level].func(r,t);if(3!==I&&4!==I||(r.status=w),1===I||3===I)return 0===A.avail_out&&(r.last_flush=-1),0;if(2===I&&(1===t?i._tr_align(r):5!==t&&(i._tr_stored_block(r,0,0,!1),3===t&&(f(r.head),0===r.lookahead&&(r.strstart=0,r.block_start=0,r.insert=0))),Q(A),0===A.avail_out))return r.last_flush=-1,0}return 4!==t?0:r.wrap<=0?1:(2===r.wrap?(C(r,255&A.adler),C(r,A.adler>>8&255),C(r,A.adler>>16&255),C(r,A.adler>>24&255),C(r,255&A.total_in),C(r,A.total_in>>8&255),C(r,A.total_in>>16&255),C(r,A.total_in>>24&255)):(M(r,A.adler>>>16),M(r,65535&A.adler)),Q(A),r.wrap>0&&(r.wrap=-r.wrap),0!==r.pending?0:1)},t.deflateEnd=function(A){var t;return A&&A.state?42!==(t=A.state.status)&&69!==t&&73!==t&&91!==t&&t!==l&&t!==u&&t!==w?h(A,c):(A.state=null,t===u?h(A,-3):0):c},t.deflateSetDictionary=function(A,t){var e,n,i,s,a,B,g,l,u=t.length;if(!A||!A.state)return c;if(2===(s=(e=A.state).wrap)||1===s&&42!==e.status||e.lookahead)return c;for(1===s&&(A.adler=o(A.adler,t,u,0)),e.wrap=0,u>=e.w_size&&(0===s&&(f(e.head),e.strstart=0,e.block_start=0,e.insert=0),l=new r.Buf8(e.w_size),r.arraySet(l,t,u-e.w_size,e.w_size,0),t=l,u=e.w_size),a=A.avail_in,B=A.next_in,g=A.input,A.avail_in=u,A.next_in=0,A.input=t,p(e);e.lookahead>=3;){n=e.strstart,i=e.lookahead-2;do{e.ins_h=(e.ins_h<<e.hash_shift^e.window[n+3-1])&e.hash_mask,e.prev[n&e.w_mask]=e.head[e.ins_h],e.head[e.ins_h]=n,n++}while(--i);e.strstart=n,e.lookahead=2,p(e)}return e.strstart+=e.lookahead,e.block_start=e.strstart,e.insert=e.lookahead,e.lookahead=0,e.match_length=e.prev_length=2,e.match_available=0,A.next_in=B,A.input=g,A.avail_in=a,e.wrap=s,0},t.deflateInfo="pako deflate (from Nodeca project)"},4264:function(A){"use strict";A.exports=function(A,t){var e,n,r,i,o,s,a,c,B,g,l,u,w,h,E,f,Q,d,C,M,I,p,D,y,v;e=A.state,n=A.next_in,y=A.input,r=n+(A.avail_in-5),i=A.next_out,v=A.output,o=i-(t-A.avail_out),s=i+(A.avail_out-257),a=e.dmax,c=e.wsize,B=e.whave,g=e.wnext,l=e.window,u=e.hold,w=e.bits,h=e.lencode,E=e.distcode,f=(1<<e.lenbits)-1,Q=(1<<e.distbits)-1;A:do{w<15&&(u+=y[n++]<<w,w+=8,u+=y[n++]<<w,w+=8),d=h[u&f];t:for(;;){if(u>>>=C=d>>>24,w-=C,0==(C=d>>>16&255))v[i++]=65535&d;else{if(!(16&C)){if(0==(64&C)){d=h[(65535&d)+(u&(1<<C)-1)];continue t}if(32&C){e.mode=12;break A}A.msg="invalid literal/length code",e.mode=30;break A}M=65535&d,(C&=15)&&(w<C&&(u+=y[n++]<<w,w+=8),M+=u&(1<<C)-1,u>>>=C,w-=C),w<15&&(u+=y[n++]<<w,w+=8,u+=y[n++]<<w,w+=8),d=E[u&Q];e:for(;;){if(u>>>=C=d>>>24,w-=C,!(16&(C=d>>>16&255))){if(0==(64&C)){d=E[(65535&d)+(u&(1<<C)-1)];continue e}A.msg="invalid distance code",e.mode=30;break A}if(I=65535&d,w<(C&=15)&&(u+=y[n++]<<w,(w+=8)<C&&(u+=y[n++]<<w,w+=8)),(I+=u&(1<<C)-1)>a){A.msg="invalid distance too far back",e.mode=30;break A}if(u>>>=C,w-=C,I>(C=i-o)){if((C=I-C)>B&&e.sane){A.msg="invalid distance too far back",e.mode=30;break A}if(p=0,D=l,0===g){if(p+=c-C,C<M){M-=C;do{v[i++]=l[p++]}while(--C);p=i-I,D=v}}else if(g<C){if(p+=c+g-C,(C-=g)<M){M-=C;do{v[i++]=l[p++]}while(--C);if(p=0,g<M){M-=C=g;do{v[i++]=l[p++]}while(--C);p=i-I,D=v}}}else if(p+=g-C,C<M){M-=C;do{v[i++]=l[p++]}while(--C);p=i-I,D=v}for(;M>2;)v[i++]=D[p++],v[i++]=D[p++],v[i++]=D[p++],M-=3;M&&(v[i++]=D[p++],M>1&&(v[i++]=D[p++]))}else{p=i-I;do{v[i++]=v[p++],v[i++]=v[p++],v[i++]=v[p++],M-=3}while(M>2);M&&(v[i++]=v[p++],M>1&&(v[i++]=v[p++]))}break}}break}}while(n<r&&i<s);n-=M=w>>3,u&=(1<<(w-=M<<3))-1,A.next_in=n,A.next_out=i,A.avail_in=n<r?r-n+5:5-(n-r),A.avail_out=i<s?s-i+257:257-(i-s),e.hold=u,e.bits=w}},7948:function(A,t,e){"use strict";var n=e(4236),r=e(6069),i=e(2869),o=e(4264),s=e(9241),a=-2,c=12,B=30;function g(A){return(A>>>24&255)+(A>>>8&65280)+((65280&A)<<8)+((255&A)<<24)}function l(){this.mode=0,this.last=!1,this.wrap=0,this.havedict=!1,this.flags=0,this.dmax=0,this.check=0,this.total=0,this.head=null,this.wbits=0,this.wsize=0,this.whave=0,this.wnext=0,this.window=null,this.hold=0,this.bits=0,this.length=0,this.offset=0,this.extra=0,this.lencode=null,this.distcode=null,this.lenbits=0,this.distbits=0,this.ncode=0,this.nlen=0,this.ndist=0,this.have=0,this.next=null,this.lens=new n.Buf16(320),this.work=new n.Buf16(288),this.lendyn=null,this.distdyn=null,this.sane=0,this.back=0,this.was=0}function u(A){var t;return A&&A.state?(t=A.state,A.total_in=A.total_out=t.total=0,A.msg="",t.wrap&&(A.adler=1&t.wrap),t.mode=1,t.last=0,t.havedict=0,t.dmax=32768,t.head=null,t.hold=0,t.bits=0,t.lencode=t.lendyn=new n.Buf32(852),t.distcode=t.distdyn=new n.Buf32(592),t.sane=1,t.back=-1,0):a}function w(A){var t;return A&&A.state?((t=A.state).wsize=0,t.whave=0,t.wnext=0,u(A)):a}function h(A,t){var e,n;return A&&A.state?(n=A.state,t<0?(e=0,t=-t):(e=1+(t>>4),t<48&&(t&=15)),t&&(t<8||t>15)?a:(null!==n.window&&n.wbits!==t&&(n.window=null),n.wrap=e,n.wbits=t,w(A))):a}function E(A,t){var e,n;return A?(n=new l,A.state=n,n.window=null,0!==(e=h(A,t))&&(A.state=null),e):a}var f,Q,d=!0;function C(A){if(d){var t;for(f=new n.Buf32(512),Q=new n.Buf32(32),t=0;t<144;)A.lens[t++]=8;for(;t<256;)A.lens[t++]=9;for(;t<280;)A.lens[t++]=7;for(;t<288;)A.lens[t++]=8;for(s(1,A.lens,0,288,f,0,A.work,{bits:9}),t=0;t<32;)A.lens[t++]=5;s(2,A.lens,0,32,Q,0,A.work,{bits:5}),d=!1}A.lencode=f,A.lenbits=9,A.distcode=Q,A.distbits=5}function M(A,t,e,r){var i,o=A.state;return null===o.window&&(o.wsize=1<<o.wbits,o.wnext=0,o.whave=0,o.window=new n.Buf8(o.wsize)),r>=o.wsize?(n.arraySet(o.window,t,e-o.wsize,o.wsize,0),o.wnext=0,o.whave=o.wsize):((i=o.wsize-o.wnext)>r&&(i=r),n.arraySet(o.window,t,e-r,i,o.wnext),(r-=i)?(n.arraySet(o.window,t,e-r,r,0),o.wnext=r,o.whave=o.wsize):(o.wnext+=i,o.wnext===o.wsize&&(o.wnext=0),o.whave<o.wsize&&(o.whave+=i))),0}t.inflateReset=w,t.inflateReset2=h,t.inflateResetKeep=u,t.inflateInit=function(A){return E(A,15)},t.inflateInit2=E,t.inflate=function(A,t){var e,l,u,w,h,E,f,Q,d,I,p,D,y,v,m,F,Y,b,z,U,S,x,T,P,N=0,R=new n.Buf8(4),G=[16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15];if(!A||!A.state||!A.output||!A.input&&0!==A.avail_in)return a;(e=A.state).mode===c&&(e.mode=13),h=A.next_out,u=A.output,f=A.avail_out,w=A.next_in,l=A.input,E=A.avail_in,Q=e.hold,d=e.bits,I=E,p=f,x=0;A:for(;;)switch(e.mode){case 1:if(0===e.wrap){e.mode=13;break}for(;d<16;){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}if(2&e.wrap&&35615===Q){e.check=0,R[0]=255&Q,R[1]=Q>>>8&255,e.check=i(e.check,R,2,0),Q=0,d=0,e.mode=2;break}if(e.flags=0,e.head&&(e.head.done=!1),!(1&e.wrap)||(((255&Q)<<8)+(Q>>8))%31){A.msg="incorrect header check",e.mode=B;break}if(8!=(15&Q)){A.msg="unknown compression method",e.mode=B;break}if(d-=4,S=8+(15&(Q>>>=4)),0===e.wbits)e.wbits=S;else if(S>e.wbits){A.msg="invalid window size",e.mode=B;break}e.dmax=1<<S,A.adler=e.check=1,e.mode=512&Q?10:c,Q=0,d=0;break;case 2:for(;d<16;){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}if(e.flags=Q,8!=(255&e.flags)){A.msg="unknown compression method",e.mode=B;break}if(57344&e.flags){A.msg="unknown header flags set",e.mode=B;break}e.head&&(e.head.text=Q>>8&1),512&e.flags&&(R[0]=255&Q,R[1]=Q>>>8&255,e.check=i(e.check,R,2,0)),Q=0,d=0,e.mode=3;case 3:for(;d<32;){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}e.head&&(e.head.time=Q),512&e.flags&&(R[0]=255&Q,R[1]=Q>>>8&255,R[2]=Q>>>16&255,R[3]=Q>>>24&255,e.check=i(e.check,R,4,0)),Q=0,d=0,e.mode=4;case 4:for(;d<16;){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}e.head&&(e.head.xflags=255&Q,e.head.os=Q>>8),512&e.flags&&(R[0]=255&Q,R[1]=Q>>>8&255,e.check=i(e.check,R,2,0)),Q=0,d=0,e.mode=5;case 5:if(1024&e.flags){for(;d<16;){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}e.length=Q,e.head&&(e.head.extra_len=Q),512&e.flags&&(R[0]=255&Q,R[1]=Q>>>8&255,e.check=i(e.check,R,2,0)),Q=0,d=0}else e.head&&(e.head.extra=null);e.mode=6;case 6:if(1024&e.flags&&((D=e.length)>E&&(D=E),D&&(e.head&&(S=e.head.extra_len-e.length,e.head.extra||(e.head.extra=new Array(e.head.extra_len)),n.arraySet(e.head.extra,l,w,D,S)),512&e.flags&&(e.check=i(e.check,l,D,w)),E-=D,w+=D,e.length-=D),e.length))break A;e.length=0,e.mode=7;case 7:if(2048&e.flags){if(0===E)break A;D=0;do{S=l[w+D++],e.head&&S&&e.length<65536&&(e.head.name+=String.fromCharCode(S))}while(S&&D<E);if(512&e.flags&&(e.check=i(e.check,l,D,w)),E-=D,w+=D,S)break A}else e.head&&(e.head.name=null);e.length=0,e.mode=8;case 8:if(4096&e.flags){if(0===E)break A;D=0;do{S=l[w+D++],e.head&&S&&e.length<65536&&(e.head.comment+=String.fromCharCode(S))}while(S&&D<E);if(512&e.flags&&(e.check=i(e.check,l,D,w)),E-=D,w+=D,S)break A}else e.head&&(e.head.comment=null);e.mode=9;case 9:if(512&e.flags){for(;d<16;){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}if(Q!==(65535&e.check)){A.msg="header crc mismatch",e.mode=B;break}Q=0,d=0}e.head&&(e.head.hcrc=e.flags>>9&1,e.head.done=!0),A.adler=e.check=0,e.mode=c;break;case 10:for(;d<32;){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}A.adler=e.check=g(Q),Q=0,d=0,e.mode=11;case 11:if(0===e.havedict)return A.next_out=h,A.avail_out=f,A.next_in=w,A.avail_in=E,e.hold=Q,e.bits=d,2;A.adler=e.check=1,e.mode=c;case c:if(5===t||6===t)break A;case 13:if(e.last){Q>>>=7&d,d-=7&d,e.mode=27;break}for(;d<3;){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}switch(e.last=1&Q,d-=1,3&(Q>>>=1)){case 0:e.mode=14;break;case 1:if(C(e),e.mode=20,6===t){Q>>>=2,d-=2;break A}break;case 2:e.mode=17;break;case 3:A.msg="invalid block type",e.mode=B}Q>>>=2,d-=2;break;case 14:for(Q>>>=7&d,d-=7&d;d<32;){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}if((65535&Q)!=(Q>>>16^65535)){A.msg="invalid stored block lengths",e.mode=B;break}if(e.length=65535&Q,Q=0,d=0,e.mode=15,6===t)break A;case 15:e.mode=16;case 16:if(D=e.length){if(D>E&&(D=E),D>f&&(D=f),0===D)break A;n.arraySet(u,l,w,D,h),E-=D,w+=D,f-=D,h+=D,e.length-=D;break}e.mode=c;break;case 17:for(;d<14;){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}if(e.nlen=257+(31&Q),Q>>>=5,d-=5,e.ndist=1+(31&Q),Q>>>=5,d-=5,e.ncode=4+(15&Q),Q>>>=4,d-=4,e.nlen>286||e.ndist>30){A.msg="too many length or distance symbols",e.mode=B;break}e.have=0,e.mode=18;case 18:for(;e.have<e.ncode;){for(;d<3;){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}e.lens[G[e.have++]]=7&Q,Q>>>=3,d-=3}for(;e.have<19;)e.lens[G[e.have++]]=0;if(e.lencode=e.lendyn,e.lenbits=7,T={bits:e.lenbits},x=s(0,e.lens,0,19,e.lencode,0,e.work,T),e.lenbits=T.bits,x){A.msg="invalid code lengths set",e.mode=B;break}e.have=0,e.mode=19;case 19:for(;e.have<e.nlen+e.ndist;){for(;F=(N=e.lencode[Q&(1<<e.lenbits)-1])>>>16&255,Y=65535&N,!((m=N>>>24)<=d);){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}if(Y<16)Q>>>=m,d-=m,e.lens[e.have++]=Y;else{if(16===Y){for(P=m+2;d<P;){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}if(Q>>>=m,d-=m,0===e.have){A.msg="invalid bit length repeat",e.mode=B;break}S=e.lens[e.have-1],D=3+(3&Q),Q>>>=2,d-=2}else if(17===Y){for(P=m+3;d<P;){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}d-=m,S=0,D=3+(7&(Q>>>=m)),Q>>>=3,d-=3}else{for(P=m+7;d<P;){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}d-=m,S=0,D=11+(127&(Q>>>=m)),Q>>>=7,d-=7}if(e.have+D>e.nlen+e.ndist){A.msg="invalid bit length repeat",e.mode=B;break}for(;D--;)e.lens[e.have++]=S}}if(e.mode===B)break;if(0===e.lens[256]){A.msg="invalid code -- missing end-of-block",e.mode=B;break}if(e.lenbits=9,T={bits:e.lenbits},x=s(1,e.lens,0,e.nlen,e.lencode,0,e.work,T),e.lenbits=T.bits,x){A.msg="invalid literal/lengths set",e.mode=B;break}if(e.distbits=6,e.distcode=e.distdyn,T={bits:e.distbits},x=s(2,e.lens,e.nlen,e.ndist,e.distcode,0,e.work,T),e.distbits=T.bits,x){A.msg="invalid distances set",e.mode=B;break}if(e.mode=20,6===t)break A;case 20:e.mode=21;case 21:if(E>=6&&f>=258){A.next_out=h,A.avail_out=f,A.next_in=w,A.avail_in=E,e.hold=Q,e.bits=d,o(A,p),h=A.next_out,u=A.output,f=A.avail_out,w=A.next_in,l=A.input,E=A.avail_in,Q=e.hold,d=e.bits,e.mode===c&&(e.back=-1);break}for(e.back=0;F=(N=e.lencode[Q&(1<<e.lenbits)-1])>>>16&255,Y=65535&N,!((m=N>>>24)<=d);){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}if(F&&0==(240&F)){for(b=m,z=F,U=Y;F=(N=e.lencode[U+((Q&(1<<b+z)-1)>>b)])>>>16&255,Y=65535&N,!(b+(m=N>>>24)<=d);){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}Q>>>=b,d-=b,e.back+=b}if(Q>>>=m,d-=m,e.back+=m,e.length=Y,0===F){e.mode=26;break}if(32&F){e.back=-1,e.mode=c;break}if(64&F){A.msg="invalid literal/length code",e.mode=B;break}e.extra=15&F,e.mode=22;case 22:if(e.extra){for(P=e.extra;d<P;){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}e.length+=Q&(1<<e.extra)-1,Q>>>=e.extra,d-=e.extra,e.back+=e.extra}e.was=e.length,e.mode=23;case 23:for(;F=(N=e.distcode[Q&(1<<e.distbits)-1])>>>16&255,Y=65535&N,!((m=N>>>24)<=d);){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}if(0==(240&F)){for(b=m,z=F,U=Y;F=(N=e.distcode[U+((Q&(1<<b+z)-1)>>b)])>>>16&255,Y=65535&N,!(b+(m=N>>>24)<=d);){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}Q>>>=b,d-=b,e.back+=b}if(Q>>>=m,d-=m,e.back+=m,64&F){A.msg="invalid distance code",e.mode=B;break}e.offset=Y,e.extra=15&F,e.mode=24;case 24:if(e.extra){for(P=e.extra;d<P;){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}e.offset+=Q&(1<<e.extra)-1,Q>>>=e.extra,d-=e.extra,e.back+=e.extra}if(e.offset>e.dmax){A.msg="invalid distance too far back",e.mode=B;break}e.mode=25;case 25:if(0===f)break A;if(D=p-f,e.offset>D){if((D=e.offset-D)>e.whave&&e.sane){A.msg="invalid distance too far back",e.mode=B;break}D>e.wnext?(D-=e.wnext,y=e.wsize-D):y=e.wnext-D,D>e.length&&(D=e.length),v=e.window}else v=u,y=h-e.offset,D=e.length;D>f&&(D=f),f-=D,e.length-=D;do{u[h++]=v[y++]}while(--D);0===e.length&&(e.mode=21);break;case 26:if(0===f)break A;u[h++]=e.length,f--,e.mode=21;break;case 27:if(e.wrap){for(;d<32;){if(0===E)break A;E--,Q|=l[w++]<<d,d+=8}if(p-=f,A.total_out+=p,e.total+=p,p&&(A.adler=e.check=e.flags?i(e.check,u,p,h-p):r(e.check,u,p,h-p)),p=f,(e.flags?Q:g(Q))!==e.check){A.msg="incorrect data check",e.mode=B;break}Q=0,d=0}e.mode=28;case 28:if(e.wrap&&e.flags){for(;d<32;){if(0===E)break A;E--,Q+=l[w++]<<d,d+=8}if(Q!==(4294967295&e.total)){A.msg="incorrect length check",e.mode=B;break}Q=0,d=0}e.mode=29;case 29:x=1;break A;case B:x=-3;break A;case 31:return-4;default:return a}return A.next_out=h,A.avail_out=f,A.next_in=w,A.avail_in=E,e.hold=Q,e.bits=d,(e.wsize||p!==A.avail_out&&e.mode<B&&(e.mode<27||4!==t))&&M(A,A.output,A.next_out,p-A.avail_out)?(e.mode=31,-4):(I-=A.avail_in,p-=A.avail_out,A.total_in+=I,A.total_out+=p,e.total+=p,e.wrap&&p&&(A.adler=e.check=e.flags?i(e.check,u,p,A.next_out-p):r(e.check,u,p,A.next_out-p)),A.data_type=e.bits+(e.last?64:0)+(e.mode===c?128:0)+(20===e.mode||15===e.mode?256:0),(0===I&&0===p||4===t)&&0===x&&(x=-5),x)},t.inflateEnd=function(A){if(!A||!A.state)return a;var t=A.state;return t.window&&(t.window=null),A.state=null,0},t.inflateGetHeader=function(A,t){var e;return A&&A.state?0==(2&(e=A.state).wrap)?a:(e.head=t,t.done=!1,0):a},t.inflateSetDictionary=function(A,t){var e,n=t.length;return A&&A.state?0!==(e=A.state).wrap&&11!==e.mode?a:11===e.mode&&r(1,t,n,0)!==e.check?-3:M(A,t,n,n)?(e.mode=31,-4):(e.havedict=1,0):a},t.inflateInfo="pako inflate (from Nodeca project)"},9241:function(A,t,e){"use strict";var n=e(4236),r=[3,4,5,6,7,8,9,10,11,13,15,17,19,23,27,31,35,43,51,59,67,83,99,115,131,163,195,227,258,0,0],i=[16,16,16,16,16,16,16,16,17,17,17,17,18,18,18,18,19,19,19,19,20,20,20,20,21,21,21,21,16,72,78],o=[1,2,3,4,5,7,9,13,17,25,33,49,65,97,129,193,257,385,513,769,1025,1537,2049,3073,4097,6145,8193,12289,16385,24577,0,0],s=[16,16,16,16,17,17,18,18,19,19,20,20,21,21,22,22,23,23,24,24,25,25,26,26,27,27,28,28,29,29,64,64];A.exports=function(A,t,e,a,c,B,g,l){var u,w,h,E,f,Q,d,C,M,I=l.bits,p=0,D=0,y=0,v=0,m=0,F=0,Y=0,b=0,z=0,U=0,S=null,x=0,T=new n.Buf16(16),P=new n.Buf16(16),N=null,R=0;for(p=0;p<=15;p++)T[p]=0;for(D=0;D<a;D++)T[t[e+D]]++;for(m=I,v=15;v>=1&&0===T[v];v--);if(m>v&&(m=v),0===v)return c[B++]=20971520,c[B++]=20971520,l.bits=1,0;for(y=1;y<v&&0===T[y];y++);for(m<y&&(m=y),b=1,p=1;p<=15;p++)if(b<<=1,(b-=T[p])<0)return-1;if(b>0&&(0===A||1!==v))return-1;for(P[1]=0,p=1;p<15;p++)P[p+1]=P[p]+T[p];for(D=0;D<a;D++)0!==t[e+D]&&(g[P[t[e+D]]++]=D);if(0===A?(S=N=g,Q=19):1===A?(S=r,x-=257,N=i,R-=257,Q=256):(S=o,N=s,Q=-1),U=0,D=0,p=y,f=B,F=m,Y=0,h=-1,E=(z=1<<m)-1,1===A&&z>852||2===A&&z>592)return 1;for(;;){d=p-Y,g[D]<Q?(C=0,M=g[D]):g[D]>Q?(C=N[R+g[D]],M=S[x+g[D]]):(C=96,M=0),u=1<<p-Y,y=w=1<<F;do{c[f+(U>>Y)+(w-=u)]=d<<24|C<<16|M|0}while(0!==w);for(u=1<<p-1;U&u;)u>>=1;if(0!==u?(U&=u-1,U+=u):U=0,D++,0==--T[p]){if(p===v)break;p=t[e+g[D]]}if(p>m&&(U&E)!==h){for(0===Y&&(Y=m),f+=y,b=1<<(F=p-Y);F+Y<v&&!((b-=T[F+Y])<=0);)F++,b<<=1;if(z+=1<<F,1===A&&z>852||2===A&&z>592)return 1;c[h=U&E]=m<<24|F<<16|f-B|0}}return 0!==U&&(c[f+U]=p-Y<<24|64<<16|0),l.bits=m,0}},8898:function(A){"use strict";A.exports={2:"need dictionary",1:"stream end",0:"","-1":"file error","-2":"stream error","-3":"data error","-4":"insufficient memory","-5":"buffer error","-6":"incompatible version"}},342:function(A,t,e){"use strict";var n=e(4236);function r(A){for(var t=A.length;--t>=0;)A[t]=0}var i=15,o=[0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,0],s=[0,0,0,0,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13],a=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,7],c=[16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15],B=new Array(576);r(B);var g=new Array(60);r(g);var l=new Array(512);r(l);var u=new Array(256);r(u);var w=new Array(29);r(w);var h,E,f,Q=new Array(30);function d(A,t,e,n,r){this.static_tree=A,this.extra_bits=t,this.extra_base=e,this.elems=n,this.max_length=r,this.has_stree=A&&A.length}function C(A,t){this.dyn_tree=A,this.max_code=0,this.stat_desc=t}function M(A){return A<256?l[A]:l[256+(A>>>7)]}function I(A,t){A.pending_buf[A.pending++]=255&t,A.pending_buf[A.pending++]=t>>>8&255}function p(A,t,e){A.bi_valid>16-e?(A.bi_buf|=t<<A.bi_valid&65535,I(A,A.bi_buf),A.bi_buf=t>>16-A.bi_valid,A.bi_valid+=e-16):(A.bi_buf|=t<<A.bi_valid&65535,A.bi_valid+=e)}function D(A,t,e){p(A,e[2*t],e[2*t+1])}function y(A,t){var e=0;do{e|=1&A,A>>>=1,e<<=1}while(--t>0);return e>>>1}function v(A,t,e){var n,r,o=new Array(16),s=0;for(n=1;n<=i;n++)o[n]=s=s+e[n-1]<<1;for(r=0;r<=t;r++){var a=A[2*r+1];0!==a&&(A[2*r]=y(o[a]++,a))}}function m(A){var t;for(t=0;t<286;t++)A.dyn_ltree[2*t]=0;for(t=0;t<30;t++)A.dyn_dtree[2*t]=0;for(t=0;t<19;t++)A.bl_tree[2*t]=0;A.dyn_ltree[512]=1,A.opt_len=A.static_len=0,A.last_lit=A.matches=0}function F(A){A.bi_valid>8?I(A,A.bi_buf):A.bi_valid>0&&(A.pending_buf[A.pending++]=A.bi_buf),A.bi_buf=0,A.bi_valid=0}function Y(A,t,e,n){var r=2*t,i=2*e;return A[r]<A[i]||A[r]===A[i]&&n[t]<=n[e]}function b(A,t,e){for(var n=A.heap[e],r=e<<1;r<=A.heap_len&&(r<A.heap_len&&Y(t,A.heap[r+1],A.heap[r],A.depth)&&r++,!Y(t,n,A.heap[r],A.depth));)A.heap[e]=A.heap[r],e=r,r<<=1;A.heap[e]=n}function z(A,t,e){var n,r,i,a,c=0;if(0!==A.last_lit)do{n=A.pending_buf[A.d_buf+2*c]<<8|A.pending_buf[A.d_buf+2*c+1],r=A.pending_buf[A.l_buf+c],c++,0===n?D(A,r,t):(D(A,(i=u[r])+256+1,t),0!==(a=o[i])&&p(A,r-=w[i],a),D(A,i=M(--n),e),0!==(a=s[i])&&p(A,n-=Q[i],a))}while(c<A.last_lit);D(A,256,t)}function U(A,t){var e,n,r,o=t.dyn_tree,s=t.stat_desc.static_tree,a=t.stat_desc.has_stree,c=t.stat_desc.elems,B=-1;for(A.heap_len=0,A.heap_max=573,e=0;e<c;e++)0!==o[2*e]?(A.heap[++A.heap_len]=B=e,A.depth[e]=0):o[2*e+1]=0;for(;A.heap_len<2;)o[2*(r=A.heap[++A.heap_len]=B<2?++B:0)]=1,A.depth[r]=0,A.opt_len--,a&&(A.static_len-=s[2*r+1]);for(t.max_code=B,e=A.heap_len>>1;e>=1;e--)b(A,o,e);r=c;do{e=A.heap[1],A.heap[1]=A.heap[A.heap_len--],b(A,o,1),n=A.heap[1],A.heap[--A.heap_max]=e,A.heap[--A.heap_max]=n,o[2*r]=o[2*e]+o[2*n],A.depth[r]=(A.depth[e]>=A.depth[n]?A.depth[e]:A.depth[n])+1,o[2*e+1]=o[2*n+1]=r,A.heap[1]=r++,b(A,o,1)}while(A.heap_len>=2);A.heap[--A.heap_max]=A.heap[1],function(A,t){var e,n,r,o,s,a,c=t.dyn_tree,B=t.max_code,g=t.stat_desc.static_tree,l=t.stat_desc.has_stree,u=t.stat_desc.extra_bits,w=t.stat_desc.extra_base,h=t.stat_desc.max_length,E=0;for(o=0;o<=i;o++)A.bl_count[o]=0;for(c[2*A.heap[A.heap_max]+1]=0,e=A.heap_max+1;e<573;e++)(o=c[2*c[2*(n=A.heap[e])+1]+1]+1)>h&&(o=h,E++),c[2*n+1]=o,n>B||(A.bl_count[o]++,s=0,n>=w&&(s=u[n-w]),a=c[2*n],A.opt_len+=a*(o+s),l&&(A.static_len+=a*(g[2*n+1]+s)));if(0!==E){do{for(o=h-1;0===A.bl_count[o];)o--;A.bl_count[o]--,A.bl_count[o+1]+=2,A.bl_count[h]--,E-=2}while(E>0);for(o=h;0!==o;o--)for(n=A.bl_count[o];0!==n;)(r=A.heap[--e])>B||(c[2*r+1]!==o&&(A.opt_len+=(o-c[2*r+1])*c[2*r],c[2*r+1]=o),n--)}}(A,t),v(o,B,A.bl_count)}function S(A,t,e){var n,r,i=-1,o=t[1],s=0,a=7,c=4;for(0===o&&(a=138,c=3),t[2*(e+1)+1]=65535,n=0;n<=e;n++)r=o,o=t[2*(n+1)+1],++s<a&&r===o||(s<c?A.bl_tree[2*r]+=s:0!==r?(r!==i&&A.bl_tree[2*r]++,A.bl_tree[32]++):s<=10?A.bl_tree[34]++:A.bl_tree[36]++,s=0,i=r,0===o?(a=138,c=3):r===o?(a=6,c=3):(a=7,c=4))}function x(A,t,e){var n,r,i=-1,o=t[1],s=0,a=7,c=4;for(0===o&&(a=138,c=3),n=0;n<=e;n++)if(r=o,o=t[2*(n+1)+1],!(++s<a&&r===o)){if(s<c)do{D(A,r,A.bl_tree)}while(0!=--s);else 0!==r?(r!==i&&(D(A,r,A.bl_tree),s--),D(A,16,A.bl_tree),p(A,s-3,2)):s<=10?(D(A,17,A.bl_tree),p(A,s-3,3)):(D(A,18,A.bl_tree),p(A,s-11,7));s=0,i=r,0===o?(a=138,c=3):r===o?(a=6,c=3):(a=7,c=4)}}r(Q);var T=!1;function P(A,t,e,r){p(A,0+(r?1:0),3),function(A,t,e,r){F(A),r&&(I(A,e),I(A,~e)),n.arraySet(A.pending_buf,A.window,t,e,A.pending),A.pending+=e}(A,t,e,!0)}t._tr_init=function(A){T||(function(){var A,t,e,n,r,c=new Array(16);for(e=0,n=0;n<28;n++)for(w[n]=e,A=0;A<1<<o[n];A++)u[e++]=n;for(u[e-1]=n,r=0,n=0;n<16;n++)for(Q[n]=r,A=0;A<1<<s[n];A++)l[r++]=n;for(r>>=7;n<30;n++)for(Q[n]=r<<7,A=0;A<1<<s[n]-7;A++)l[256+r++]=n;for(t=0;t<=i;t++)c[t]=0;for(A=0;A<=143;)B[2*A+1]=8,A++,c[8]++;for(;A<=255;)B[2*A+1]=9,A++,c[9]++;for(;A<=279;)B[2*A+1]=7,A++,c[7]++;for(;A<=287;)B[2*A+1]=8,A++,c[8]++;for(v(B,287,c),A=0;A<30;A++)g[2*A+1]=5,g[2*A]=y(A,5);h=new d(B,o,257,286,i),E=new d(g,s,0,30,i),f=new d(new Array(0),a,0,19,7)}(),T=!0),A.l_desc=new C(A.dyn_ltree,h),A.d_desc=new C(A.dyn_dtree,E),A.bl_desc=new C(A.bl_tree,f),A.bi_buf=0,A.bi_valid=0,m(A)},t._tr_stored_block=P,t._tr_flush_block=function(A,t,e,n){var r,i,o=0;A.level>0?(2===A.strm.data_type&&(A.strm.data_type=function(A){var t,e=4093624447;for(t=0;t<=31;t++,e>>>=1)if(1&e&&0!==A.dyn_ltree[2*t])return 0;if(0!==A.dyn_ltree[18]||0!==A.dyn_ltree[20]||0!==A.dyn_ltree[26])return 1;for(t=32;t<256;t++)if(0!==A.dyn_ltree[2*t])return 1;return 0}(A)),U(A,A.l_desc),U(A,A.d_desc),o=function(A){var t;for(S(A,A.dyn_ltree,A.l_desc.max_code),S(A,A.dyn_dtree,A.d_desc.max_code),U(A,A.bl_desc),t=18;t>=3&&0===A.bl_tree[2*c[t]+1];t--);return A.opt_len+=3*(t+1)+5+5+4,t}(A),r=A.opt_len+3+7>>>3,(i=A.static_len+3+7>>>3)<=r&&(r=i)):r=i=e+5,e+4<=r&&-1!==t?P(A,t,e,n):4===A.strategy||i===r?(p(A,2+(n?1:0),3),z(A,B,g)):(p(A,4+(n?1:0),3),function(A,t,e,n){var r;for(p(A,t-257,5),p(A,e-1,5),p(A,n-4,4),r=0;r<n;r++)p(A,A.bl_tree[2*c[r]+1],3);x(A,A.dyn_ltree,t-1),x(A,A.dyn_dtree,e-1)}(A,A.l_desc.max_code+1,A.d_desc.max_code+1,o+1),z(A,A.dyn_ltree,A.dyn_dtree)),m(A),n&&F(A)},t._tr_tally=function(A,t,e){return A.pending_buf[A.d_buf+2*A.last_lit]=t>>>8&255,A.pending_buf[A.d_buf+2*A.last_lit+1]=255&t,A.pending_buf[A.l_buf+A.last_lit]=255&e,A.last_lit++,0===t?A.dyn_ltree[2*e]++:(A.matches++,t--,A.dyn_ltree[2*(u[e]+256+1)]++,A.dyn_dtree[2*M(t)]++),A.last_lit===A.lit_bufsize-1},t._tr_align=function(A){p(A,2,3),D(A,256,B),function(A){16===A.bi_valid?(I(A,A.bi_buf),A.bi_buf=0,A.bi_valid=0):A.bi_valid>=8&&(A.pending_buf[A.pending++]=255&A.bi_buf,A.bi_buf>>=8,A.bi_valid-=8)}(A)}},2292:function(A){"use strict";A.exports=function(){this.input=null,this.next_in=0,this.avail_in=0,this.total_in=0,this.output=null,this.next_out=0,this.avail_out=0,this.total_out=0,this.msg="",this.state=null,this.data_type=2,this.adler=0}},4155:function(A){var t,e,n=A.exports={};function r(){throw new Error("setTimeout has not been defined")}function i(){throw new Error("clearTimeout has not been defined")}function o(A){if(t===setTimeout)return setTimeout(A,0);if((t===r||!t)&&setTimeout)return t=setTimeout,setTimeout(A,0);try{return t(A,0)}catch(e){try{return t.call(null,A,0)}catch(e){return t.call(this,A,0)}}}!function(){try{t="function"==typeof setTimeout?setTimeout:r}catch(A){t=r}try{e="function"==typeof clearTimeout?clearTimeout:i}catch(A){e=i}}();var s,a=[],c=!1,B=-1;function g(){c&&s&&(c=!1,s.length?a=s.concat(a):B=-1,a.length&&l())}function l(){if(!c){var A=o(g);c=!0;for(var t=a.length;t;){for(s=a,a=[];++B<t;)s&&s[B].run();B=-1,t=a.length}s=null,c=!1,function(A){if(e===clearTimeout)return clearTimeout(A);if((e===i||!e)&&clearTimeout)return e=clearTimeout,clearTimeout(A);try{return e(A)}catch(t){try{return e.call(null,A)}catch(t){return e.call(this,A)}}}(A)}}function u(A,t){this.fun=A,this.array=t}function w(){}n.nextTick=function(A){var t=new Array(arguments.length-1);if(arguments.length>1)for(var e=1;e<arguments.length;e++)t[e-1]=arguments[e];a.push(new u(A,t)),1!==a.length||c||o(l)},u.prototype.run=function(){this.fun.apply(null,this.array)},n.title="browser",n.browser=!0,n.env={},n.argv=[],n.version="",n.versions={},n.on=w,n.addListener=w,n.once=w,n.off=w,n.removeListener=w,n.removeAllListeners=w,n.emit=w,n.prependListener=w,n.prependOnceListener=w,n.listeners=function(A){return[]},n.binding=function(A){throw new Error("process.binding is not supported")},n.cwd=function(){return"/"},n.chdir=function(A){throw new Error("process.chdir is not supported")},n.umask=function(){return 0}},3697:function(A,t,e){"use strict";var n=e(5972).functionsHaveConfigurableNames(),r=Object,i=TypeError;A.exports=function(){if(null!=this&&this!==r(this))throw new i("RegExp.prototype.flags getter called on non-object");var A="";return this.hasIndices&&(A+="d"),this.global&&(A+="g"),this.ignoreCase&&(A+="i"),this.multiline&&(A+="m"),this.dotAll&&(A+="s"),this.unicode&&(A+="u"),this.sticky&&(A+="y"),A},n&&Object.defineProperty&&Object.defineProperty(A.exports,"name",{value:"get flags"})},2847:function(A,t,e){"use strict";var n=e(4289),r=e(5559),i=e(3697),o=e(1721),s=e(2753),a=r(o());n(a,{getPolyfill:o,implementation:i,shim:s}),A.exports=a},1721:function(A,t,e){"use strict";var n=e(3697),r=e(4289).supportsDescriptors,i=Object.getOwnPropertyDescriptor;A.exports=function(){if(r&&"gim"===/a/gim.flags){var A=i(RegExp.prototype,"flags");if(A&&"function"==typeof A.get&&"boolean"==typeof RegExp.prototype.dotAll&&"boolean"==typeof RegExp.prototype.hasIndices){var t="",e={};if(Object.defineProperty(e,"hasIndices",{get:function(){t+="d"}}),Object.defineProperty(e,"sticky",{get:function(){t+="y"}}),"dy"===t)return A.get}}return n}},2753:function(A,t,e){"use strict";var n=e(4289).supportsDescriptors,r=e(1721),i=Object.getOwnPropertyDescriptor,o=Object.defineProperty,s=TypeError,a=Object.getPrototypeOf,c=/a/;A.exports=function(){if(!n||!a)throw new s("RegExp.prototype.flags requires a true ES5 environment that supports property descriptors");var A=r(),t=a(c),e=i(t,"flags");return e&&e.get===A||o(t,"flags",{configurable:!0,enumerable:!1,get:A}),A}},6099:function(A,t,e){var n=e(8823).Buffer;!function(A){A.parser=function(A,t){return new i(A,t)},A.SAXParser=i,A.SAXStream=s,A.createStream=function(A,t){return new s(A,t)},A.MAX_BUFFER_LENGTH=65536;var t,r=["comment","sgmlDecl","textNode","tagName","doctype","procInstName","procInstBody","entity","attribName","attribValue","cdata","script"];function i(t,e){if(!(this instanceof i))return new i(t,e);var n=this;!function(A){for(var t=0,e=r.length;t<e;t++)A[r[t]]=""}(n),n.q=n.c="",n.bufferCheckPosition=A.MAX_BUFFER_LENGTH,n.opt=e||{},n.opt.lowercase=n.opt.lowercase||n.opt.lowercasetags,n.looseCase=n.opt.lowercase?"toLowerCase":"toUpperCase",n.tags=[],n.closed=n.closedRoot=n.sawRoot=!1,n.tag=n.error=null,n.strict=!!t,n.noscript=!(!t&&!n.opt.noscript),n.state=p.BEGIN,n.strictEntities=n.opt.strictEntities,n.ENTITIES=n.strictEntities?Object.create(A.XML_ENTITIES):Object.create(A.ENTITIES),n.attribList=[],n.opt.xmlns&&(n.ns=Object.create(B)),n.trackPosition=!1!==n.opt.position,n.trackPosition&&(n.position=n.line=n.column=0),y(n,"onready")}A.EVENTS=["text","processinginstruction","sgmldeclaration","doctype","comment","opentagstart","attribute","opentag","closetag","opencdata","cdata","closecdata","error","end","ready","script","opennamespace","closenamespace"],Object.create||(Object.create=function(A){function t(){}return t.prototype=A,new t}),Object.keys||(Object.keys=function(A){var t=[];for(var e in A)A.hasOwnProperty(e)&&t.push(e);return t}),i.prototype={end:function(){b(this)},write:function(t){var e=this;if(this.error)throw this.error;if(e.closed)return Y(e,"Cannot write after close. Assign an onready handler.");if(null===t)return b(e);"object"==typeof t&&(t=t.toString());for(var n=0,i="";i=G(t,n++),e.c=i,i;)switch(e.trackPosition&&(e.position++,"\n"===i?(e.line++,e.column=0):e.column++),e.state){case p.BEGIN:if(e.state=p.BEGIN_WHITESPACE,"\ufeff"===i)continue;R(e,i);continue;case p.BEGIN_WHITESPACE:R(e,i);continue;case p.TEXT:if(e.sawRoot&&!e.closedRoot){for(var o=n-1;i&&"<"!==i&&"&"!==i;)(i=G(t,n++))&&e.trackPosition&&(e.position++,"\n"===i?(e.line++,e.column=0):e.column++);e.textNode+=t.substring(o,n-1)}"<"!==i||e.sawRoot&&e.closedRoot&&!e.strict?(h(i)||e.sawRoot&&!e.closedRoot||z(e,"Text data outside of root node."),"&"===i?e.state=p.TEXT_ENTITY:e.textNode+=i):(e.state=p.OPEN_WAKA,e.startTagPosition=e.position);continue;case p.SCRIPT:"<"===i?e.state=p.SCRIPT_ENDING:e.script+=i;continue;case p.SCRIPT_ENDING:"/"===i?e.state=p.CLOSE_TAG:(e.script+="<"+i,e.state=p.SCRIPT);continue;case p.OPEN_WAKA:if("!"===i)e.state=p.SGML_DECL,e.sgmlDecl="";else if(h(i));else if(Q(g,i))e.state=p.OPEN_TAG,e.tagName=i;else if("/"===i)e.state=p.CLOSE_TAG,e.tagName="";else if("?"===i)e.state=p.PROC_INST,e.procInstName=e.procInstBody="";else{if(z(e,"Unencoded <"),e.startTagPosition+1<e.position){var s=e.position-e.startTagPosition;i=new Array(s).join(" ")+i}e.textNode+="<"+i,e.state=p.TEXT}continue;case p.SGML_DECL:"[CDATA["===(e.sgmlDecl+i).toUpperCase()?(v(e,"onopencdata"),e.state=p.CDATA,e.sgmlDecl="",e.cdata=""):e.sgmlDecl+i==="--"?(e.state=p.COMMENT,e.comment="",e.sgmlDecl=""):"DOCTYPE"===(e.sgmlDecl+i).toUpperCase()?(e.state=p.DOCTYPE,(e.doctype||e.sawRoot)&&z(e,"Inappropriately located doctype declaration"),e.doctype="",e.sgmlDecl=""):">"===i?(v(e,"onsgmldeclaration",e.sgmlDecl),e.sgmlDecl="",e.state=p.TEXT):E(i)?(e.state=p.SGML_DECL_QUOTED,e.sgmlDecl+=i):e.sgmlDecl+=i;continue;case p.SGML_DECL_QUOTED:i===e.q&&(e.state=p.SGML_DECL,e.q=""),e.sgmlDecl+=i;continue;case p.DOCTYPE:">"===i?(e.state=p.TEXT,v(e,"ondoctype",e.doctype),e.doctype=!0):(e.doctype+=i,"["===i?e.state=p.DOCTYPE_DTD:E(i)&&(e.state=p.DOCTYPE_QUOTED,e.q=i));continue;case p.DOCTYPE_QUOTED:e.doctype+=i,i===e.q&&(e.q="",e.state=p.DOCTYPE);continue;case p.DOCTYPE_DTD:e.doctype+=i,"]"===i?e.state=p.DOCTYPE:E(i)&&(e.state=p.DOCTYPE_DTD_QUOTED,e.q=i);continue;case p.DOCTYPE_DTD_QUOTED:e.doctype+=i,i===e.q&&(e.state=p.DOCTYPE_DTD,e.q="");continue;case p.COMMENT:"-"===i?e.state=p.COMMENT_ENDING:e.comment+=i;continue;case p.COMMENT_ENDING:"-"===i?(e.state=p.COMMENT_ENDED,e.comment=F(e.opt,e.comment),e.comment&&v(e,"oncomment",e.comment),e.comment=""):(e.comment+="-"+i,e.state=p.COMMENT);continue;case p.COMMENT_ENDED:">"!==i?(z(e,"Malformed comment"),e.comment+="--"+i,e.state=p.COMMENT):e.state=p.TEXT;continue;case p.CDATA:"]"===i?e.state=p.CDATA_ENDING:e.cdata+=i;continue;case p.CDATA_ENDING:"]"===i?e.state=p.CDATA_ENDING_2:(e.cdata+="]"+i,e.state=p.CDATA);continue;case p.CDATA_ENDING_2:">"===i?(e.cdata&&v(e,"oncdata",e.cdata),v(e,"onclosecdata"),e.cdata="",e.state=p.TEXT):"]"===i?e.cdata+="]":(e.cdata+="]]"+i,e.state=p.CDATA);continue;case p.PROC_INST:"?"===i?e.state=p.PROC_INST_ENDING:h(i)?e.state=p.PROC_INST_BODY:e.procInstName+=i;continue;case p.PROC_INST_BODY:if(!e.procInstBody&&h(i))continue;"?"===i?e.state=p.PROC_INST_ENDING:e.procInstBody+=i;continue;case p.PROC_INST_ENDING:">"===i?(v(e,"onprocessinginstruction",{name:e.procInstName,body:e.procInstBody}),e.procInstName=e.procInstBody="",e.state=p.TEXT):(e.procInstBody+="?"+i,e.state=p.PROC_INST_BODY);continue;case p.OPEN_TAG:Q(l,i)?e.tagName+=i:(U(e),">"===i?T(e):"/"===i?e.state=p.OPEN_TAG_SLASH:(h(i)||z(e,"Invalid character in tag name"),e.state=p.ATTRIB));continue;case p.OPEN_TAG_SLASH:">"===i?(T(e,!0),P(e)):(z(e,"Forward-slash in opening tag not followed by >"),e.state=p.ATTRIB);continue;case p.ATTRIB:if(h(i))continue;">"===i?T(e):"/"===i?e.state=p.OPEN_TAG_SLASH:Q(g,i)?(e.attribName=i,e.attribValue="",e.state=p.ATTRIB_NAME):z(e,"Invalid attribute name");continue;case p.ATTRIB_NAME:"="===i?e.state=p.ATTRIB_VALUE:">"===i?(z(e,"Attribute without value"),e.attribValue=e.attribName,x(e),T(e)):h(i)?e.state=p.ATTRIB_NAME_SAW_WHITE:Q(l,i)?e.attribName+=i:z(e,"Invalid attribute name");continue;case p.ATTRIB_NAME_SAW_WHITE:if("="===i)e.state=p.ATTRIB_VALUE;else{if(h(i))continue;z(e,"Attribute without value"),e.tag.attributes[e.attribName]="",e.attribValue="",v(e,"onattribute",{name:e.attribName,value:""}),e.attribName="",">"===i?T(e):Q(g,i)?(e.attribName=i,e.state=p.ATTRIB_NAME):(z(e,"Invalid attribute name"),e.state=p.ATTRIB)}continue;case p.ATTRIB_VALUE:if(h(i))continue;E(i)?(e.q=i,e.state=p.ATTRIB_VALUE_QUOTED):(z(e,"Unquoted attribute value"),e.state=p.ATTRIB_VALUE_UNQUOTED,e.attribValue=i);continue;case p.ATTRIB_VALUE_QUOTED:if(i!==e.q){"&"===i?e.state=p.ATTRIB_VALUE_ENTITY_Q:e.attribValue+=i;continue}x(e),e.q="",e.state=p.ATTRIB_VALUE_CLOSED;continue;case p.ATTRIB_VALUE_CLOSED:h(i)?e.state=p.ATTRIB:">"===i?T(e):"/"===i?e.state=p.OPEN_TAG_SLASH:Q(g,i)?(z(e,"No whitespace between attributes"),e.attribName=i,e.attribValue="",e.state=p.ATTRIB_NAME):z(e,"Invalid attribute name");continue;case p.ATTRIB_VALUE_UNQUOTED:if(!f(i)){"&"===i?e.state=p.ATTRIB_VALUE_ENTITY_U:e.attribValue+=i;continue}x(e),">"===i?T(e):e.state=p.ATTRIB;continue;case p.CLOSE_TAG:if(e.tagName)">"===i?P(e):Q(l,i)?e.tagName+=i:e.script?(e.script+="</"+e.tagName,e.tagName="",e.state=p.SCRIPT):(h(i)||z(e,"Invalid tagname in closing tag"),e.state=p.CLOSE_TAG_SAW_WHITE);else{if(h(i))continue;d(g,i)?e.script?(e.script+="</"+i,e.state=p.SCRIPT):z(e,"Invalid tagname in closing tag."):e.tagName=i}continue;case p.CLOSE_TAG_SAW_WHITE:if(h(i))continue;">"===i?P(e):z(e,"Invalid characters in closing tag");continue;case p.TEXT_ENTITY:case p.ATTRIB_VALUE_ENTITY_Q:case p.ATTRIB_VALUE_ENTITY_U:var a,c;switch(e.state){case p.TEXT_ENTITY:a=p.TEXT,c="textNode";break;case p.ATTRIB_VALUE_ENTITY_Q:a=p.ATTRIB_VALUE_QUOTED,c="attribValue";break;case p.ATTRIB_VALUE_ENTITY_U:a=p.ATTRIB_VALUE_UNQUOTED,c="attribValue"}";"===i?(e[c]+=N(e),e.entity="",e.state=a):Q(e.entity.length?w:u,i)?e.entity+=i:(z(e,"Invalid character in entity name"),e[c]+="&"+e.entity+i,e.entity="",e.state=a);continue;default:throw new Error(e,"Unknown state: "+e.state)}return e.position>=e.bufferCheckPosition&&function(t){for(var e=Math.max(A.MAX_BUFFER_LENGTH,10),n=0,i=0,o=r.length;i<o;i++){var s=t[r[i]].length;if(s>e)switch(r[i]){case"textNode":m(t);break;case"cdata":v(t,"oncdata",t.cdata),t.cdata="";break;case"script":v(t,"onscript",t.script),t.script="";break;default:Y(t,"Max buffer length exceeded: "+r[i])}n=Math.max(n,s)}var a=A.MAX_BUFFER_LENGTH-n;t.bufferCheckPosition=a+t.position}(e),e},resume:function(){return this.error=null,this},close:function(){return this.write(null)},flush:function(){!function(A){m(A),""!==A.cdata&&(v(A,"oncdata",A.cdata),A.cdata=""),""!==A.script&&(v(A,"onscript",A.script),A.script="")}(this)}};try{t=e(2830).Stream}catch(A){t=function(){}}var o=A.EVENTS.filter((function(A){return"error"!==A&&"end"!==A}));function s(A,e){if(!(this instanceof s))return new s(A,e);t.apply(this),this._parser=new i(A,e),this.writable=!0,this.readable=!0;var n=this;this._parser.onend=function(){n.emit("end")},this._parser.onerror=function(A){n.emit("error",A),n._parser.error=null},this._decoder=null,o.forEach((function(A){Object.defineProperty(n,"on"+A,{get:function(){return n._parser["on"+A]},set:function(t){if(!t)return n.removeAllListeners(A),n._parser["on"+A]=t,t;n.on(A,t)},enumerable:!0,configurable:!1})}))}s.prototype=Object.create(t.prototype,{constructor:{value:s}}),s.prototype.write=function(A){if("function"==typeof n&&"function"==typeof n.isBuffer&&n.isBuffer(A)){if(!this._decoder){var t=e(2553).s;this._decoder=new t("utf8")}A=this._decoder.write(A)}return this._parser.write(A.toString()),this.emit("data",A),!0},s.prototype.end=function(A){return A&&A.length&&this.write(A),this._parser.end(),!0},s.prototype.on=function(A,e){var n=this;return n._parser["on"+A]||-1===o.indexOf(A)||(n._parser["on"+A]=function(){var t=1===arguments.length?[arguments[0]]:Array.apply(null,arguments);t.splice(0,0,A),n.emit.apply(n,t)}),t.prototype.on.call(n,A,e)};var a="http://www.w3.org/XML/1998/namespace",c="http://www.w3.org/2000/xmlns/",B={xml:a,xmlns:c},g=/[:_A-Za-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD]/,l=/[:_A-Za-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\u00B7\u0300-\u036F\u203F-\u2040.\d-]/,u=/[#:_A-Za-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD]/,w=/[#:_A-Za-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\u00B7\u0300-\u036F\u203F-\u2040.\d-]/;function h(A){return" "===A||"\n"===A||"\r"===A||"\t"===A}function E(A){return'"'===A||"'"===A}function f(A){return">"===A||h(A)}function Q(A,t){return A.test(t)}function d(A,t){return!Q(A,t)}var C,M,I,p=0;for(var D in A.STATE={BEGIN:p++,BEGIN_WHITESPACE:p++,TEXT:p++,TEXT_ENTITY:p++,OPEN_WAKA:p++,SGML_DECL:p++,SGML_DECL_QUOTED:p++,DOCTYPE:p++,DOCTYPE_QUOTED:p++,DOCTYPE_DTD:p++,DOCTYPE_DTD_QUOTED:p++,COMMENT_STARTING:p++,COMMENT:p++,COMMENT_ENDING:p++,COMMENT_ENDED:p++,CDATA:p++,CDATA_ENDING:p++,CDATA_ENDING_2:p++,PROC_INST:p++,PROC_INST_BODY:p++,PROC_INST_ENDING:p++,OPEN_TAG:p++,OPEN_TAG_SLASH:p++,ATTRIB:p++,ATTRIB_NAME:p++,ATTRIB_NAME_SAW_WHITE:p++,ATTRIB_VALUE:p++,ATTRIB_VALUE_QUOTED:p++,ATTRIB_VALUE_CLOSED:p++,ATTRIB_VALUE_UNQUOTED:p++,ATTRIB_VALUE_ENTITY_Q:p++,ATTRIB_VALUE_ENTITY_U:p++,CLOSE_TAG:p++,CLOSE_TAG_SAW_WHITE:p++,SCRIPT:p++,SCRIPT_ENDING:p++},A.XML_ENTITIES={amp:"&",gt:">",lt:"<",quot:'"',apos:"'"},A.ENTITIES={amp:"&",gt:">",lt:"<",quot:'"',apos:"'",AElig:198,Aacute:193,Acirc:194,Agrave:192,Aring:197,Atilde:195,Auml:196,Ccedil:199,ETH:208,Eacute:201,Ecirc:202,Egrave:200,Euml:203,Iacute:205,Icirc:206,Igrave:204,Iuml:207,Ntilde:209,Oacute:211,Ocirc:212,Ograve:210,Oslash:216,Otilde:213,Ouml:214,THORN:222,Uacute:218,Ucirc:219,Ugrave:217,Uuml:220,Yacute:221,aacute:225,acirc:226,aelig:230,agrave:224,aring:229,atilde:227,auml:228,ccedil:231,eacute:233,ecirc:234,egrave:232,eth:240,euml:235,iacute:237,icirc:238,igrave:236,iuml:239,ntilde:241,oacute:243,ocirc:244,ograve:242,oslash:248,otilde:245,ouml:246,szlig:223,thorn:254,uacute:250,ucirc:251,ugrave:249,uuml:252,yacute:253,yuml:255,copy:169,reg:174,nbsp:160,iexcl:161,cent:162,pound:163,curren:164,yen:165,brvbar:166,sect:167,uml:168,ordf:170,laquo:171,not:172,shy:173,macr:175,deg:176,plusmn:177,sup1:185,sup2:178,sup3:179,acute:180,micro:181,para:182,middot:183,cedil:184,ordm:186,raquo:187,frac14:188,frac12:189,frac34:190,iquest:191,times:215,divide:247,OElig:338,oelig:339,Scaron:352,scaron:353,Yuml:376,fnof:402,circ:710,tilde:732,Alpha:913,Beta:914,Gamma:915,Delta:916,Epsilon:917,Zeta:918,Eta:919,Theta:920,Iota:921,Kappa:922,Lambda:923,Mu:924,Nu:925,Xi:926,Omicron:927,Pi:928,Rho:929,Sigma:931,Tau:932,Upsilon:933,Phi:934,Chi:935,Psi:936,Omega:937,alpha:945,beta:946,gamma:947,delta:948,epsilon:949,zeta:950,eta:951,theta:952,iota:953,kappa:954,lambda:955,mu:956,nu:957,xi:958,omicron:959,pi:960,rho:961,sigmaf:962,sigma:963,tau:964,upsilon:965,phi:966,chi:967,psi:968,omega:969,thetasym:977,upsih:978,piv:982,ensp:8194,emsp:8195,thinsp:8201,zwnj:8204,zwj:8205,lrm:8206,rlm:8207,ndash:8211,mdash:8212,lsquo:8216,rsquo:8217,sbquo:8218,ldquo:8220,rdquo:8221,bdquo:8222,dagger:8224,Dagger:8225,bull:8226,hellip:8230,permil:8240,prime:8242,Prime:8243,lsaquo:8249,rsaquo:8250,oline:8254,frasl:8260,euro:8364,image:8465,weierp:8472,real:8476,trade:8482,alefsym:8501,larr:8592,uarr:8593,rarr:8594,darr:8595,harr:8596,crarr:8629,lArr:8656,uArr:8657,rArr:8658,dArr:8659,hArr:8660,forall:8704,part:8706,exist:8707,empty:8709,nabla:8711,isin:8712,notin:8713,ni:8715,prod:8719,sum:8721,minus:8722,lowast:8727,radic:8730,prop:8733,infin:8734,ang:8736,and:8743,or:8744,cap:8745,cup:8746,int:8747,there4:8756,sim:8764,cong:8773,asymp:8776,ne:8800,equiv:8801,le:8804,ge:8805,sub:8834,sup:8835,nsub:8836,sube:8838,supe:8839,oplus:8853,otimes:8855,perp:8869,sdot:8901,lceil:8968,rceil:8969,lfloor:8970,rfloor:8971,lang:9001,rang:9002,loz:9674,spades:9824,clubs:9827,hearts:9829,diams:9830},Object.keys(A.ENTITIES).forEach((function(t){var e=A.ENTITIES[t],n="number"==typeof e?String.fromCharCode(e):e;A.ENTITIES[t]=n})),A.STATE)A.STATE[A.STATE[D]]=D;function y(A,t,e){A[t]&&A[t](e)}function v(A,t,e){A.textNode&&m(A),y(A,t,e)}function m(A){A.textNode=F(A.opt,A.textNode),A.textNode&&y(A,"ontext",A.textNode),A.textNode=""}function F(A,t){return A.trim&&(t=t.trim()),A.normalize&&(t=t.replace(/\s+/g," ")),t}function Y(A,t){return m(A),A.trackPosition&&(t+="\nLine: "+A.line+"\nColumn: "+A.column+"\nChar: "+A.c),t=new Error(t),A.error=t,y(A,"onerror",t),A}function b(A){return A.sawRoot&&!A.closedRoot&&z(A,"Unclosed root tag"),A.state!==p.BEGIN&&A.state!==p.BEGIN_WHITESPACE&&A.state!==p.TEXT&&Y(A,"Unexpected end"),m(A),A.c="",A.closed=!0,y(A,"onend"),i.call(A,A.strict,A.opt),A}function z(A,t){if("object"!=typeof A||!(A instanceof i))throw new Error("bad call to strictFail");A.strict&&Y(A,t)}function U(A){A.strict||(A.tagName=A.tagName[A.looseCase]());var t=A.tags[A.tags.length-1]||A,e=A.tag={name:A.tagName,attributes:{}};A.opt.xmlns&&(e.ns=t.ns),A.attribList.length=0,v(A,"onopentagstart",e)}function S(A,t){var e=A.indexOf(":")<0?["",A]:A.split(":"),n=e[0],r=e[1];return t&&"xmlns"===A&&(n="xmlns",r=""),{prefix:n,local:r}}function x(A){if(A.strict||(A.attribName=A.attribName[A.looseCase]()),-1!==A.attribList.indexOf(A.attribName)||A.tag.attributes.hasOwnProperty(A.attribName))A.attribName=A.attribValue="";else{if(A.opt.xmlns){var t=S(A.attribName,!0),e=t.prefix,n=t.local;if("xmlns"===e)if("xml"===n&&A.attribValue!==a)z(A,"xml: prefix must be bound to "+a+"\nActual: "+A.attribValue);else if("xmlns"===n&&A.attribValue!==c)z(A,"xmlns: prefix must be bound to "+c+"\nActual: "+A.attribValue);else{var r=A.tag,i=A.tags[A.tags.length-1]||A;r.ns===i.ns&&(r.ns=Object.create(i.ns)),r.ns[n]=A.attribValue}A.attribList.push([A.attribName,A.attribValue])}else A.tag.attributes[A.attribName]=A.attribValue,v(A,"onattribute",{name:A.attribName,value:A.attribValue});A.attribName=A.attribValue=""}}function T(A,t){if(A.opt.xmlns){var e=A.tag,n=S(A.tagName);e.prefix=n.prefix,e.local=n.local,e.uri=e.ns[n.prefix]||"",e.prefix&&!e.uri&&(z(A,"Unbound namespace prefix: "+JSON.stringify(A.tagName)),e.uri=n.prefix);var r=A.tags[A.tags.length-1]||A;e.ns&&r.ns!==e.ns&&Object.keys(e.ns).forEach((function(t){v(A,"onopennamespace",{prefix:t,uri:e.ns[t]})}));for(var i=0,o=A.attribList.length;i<o;i++){var s=A.attribList[i],a=s[0],c=s[1],B=S(a,!0),g=B.prefix,l=B.local,u=""===g?"":e.ns[g]||"",w={name:a,value:c,prefix:g,local:l,uri:u};g&&"xmlns"!==g&&!u&&(z(A,"Unbound namespace prefix: "+JSON.stringify(g)),w.uri=g),A.tag.attributes[a]=w,v(A,"onattribute",w)}A.attribList.length=0}A.tag.isSelfClosing=!!t,A.sawRoot=!0,A.tags.push(A.tag),v(A,"onopentag",A.tag),t||(A.noscript||"script"!==A.tagName.toLowerCase()?A.state=p.TEXT:A.state=p.SCRIPT,A.tag=null,A.tagName=""),A.attribName=A.attribValue="",A.attribList.length=0}function P(A){if(!A.tagName)return z(A,"Weird empty close tag."),A.textNode+="</>",void(A.state=p.TEXT);if(A.script){if("script"!==A.tagName)return A.script+="</"+A.tagName+">",A.tagName="",void(A.state=p.SCRIPT);v(A,"onscript",A.script),A.script=""}var t=A.tags.length,e=A.tagName;A.strict||(e=e[A.looseCase]());for(var n=e;t--&&A.tags[t].name!==n;)z(A,"Unexpected close tag");if(t<0)return z(A,"Unmatched closing tag: "+A.tagName),A.textNode+="</"+A.tagName+">",void(A.state=p.TEXT);A.tagName=e;for(var r=A.tags.length;r-- >t;){var i=A.tag=A.tags.pop();A.tagName=A.tag.name,v(A,"onclosetag",A.tagName);var o={};for(var s in i.ns)o[s]=i.ns[s];var a=A.tags[A.tags.length-1]||A;A.opt.xmlns&&i.ns!==a.ns&&Object.keys(i.ns).forEach((function(t){var e=i.ns[t];v(A,"onclosenamespace",{prefix:t,uri:e})}))}0===t&&(A.closedRoot=!0),A.tagName=A.attribValue=A.attribName="",A.attribList.length=0,A.state=p.TEXT}function N(A){var t,e=A.entity,n=e.toLowerCase(),r="";return A.ENTITIES[e]?A.ENTITIES[e]:A.ENTITIES[n]?A.ENTITIES[n]:("#"===(e=n).charAt(0)&&("x"===e.charAt(1)?(e=e.slice(2),r=(t=parseInt(e,16)).toString(16)):(e=e.slice(1),r=(t=parseInt(e,10)).toString(10))),e=e.replace(/^0+/,""),isNaN(t)||r.toLowerCase()!==e?(z(A,"Invalid character entity"),"&"+A.entity+";"):String.fromCodePoint(t))}function R(A,t){"<"===t?(A.state=p.OPEN_WAKA,A.startTagPosition=A.position):h(t)||(z(A,"Non-whitespace before first tag."),A.textNode=t,A.state=p.TEXT)}function G(A,t){var e="";return t<A.length&&(e=A.charAt(t)),e}p=A.STATE,String.fromCodePoint||(C=String.fromCharCode,M=Math.floor,I=function(){var A,t,e=[],n=-1,r=arguments.length;if(!r)return"";for(var i="";++n<r;){var o=Number(arguments[n]);if(!isFinite(o)||o<0||o>1114111||M(o)!==o)throw RangeError("Invalid code point: "+o);o<=65535?e.push(o):(A=55296+((o-=65536)>>10),t=o%1024+56320,e.push(A,t)),(n+1===r||e.length>16384)&&(i+=C.apply(null,e),e.length=0)}return i},Object.defineProperty?Object.defineProperty(String,"fromCodePoint",{value:I,configurable:!0,writable:!0}):String.fromCodePoint=I)}(t)},2830:function(A,t,e){A.exports=r;var n=e(7187).EventEmitter;function r(){n.call(this)}e(5717)(r,n),r.Readable=e(6577),r.Writable=e(323),r.Duplex=e(8656),r.Transform=e(4473),r.PassThrough=e(2366),r.finished=e(1086),r.pipeline=e(6472),r.Stream=r,r.prototype.pipe=function(A,t){var e=this;function r(t){A.writable&&!1===A.write(t)&&e.pause&&e.pause()}function i(){e.readable&&e.resume&&e.resume()}e.on("data",r),A.on("drain",i),A._isStdio||t&&!1===t.end||(e.on("end",s),e.on("close",a));var o=!1;function s(){o||(o=!0,A.end())}function a(){o||(o=!0,"function"==typeof A.destroy&&A.destroy())}function c(A){if(B(),0===n.listenerCount(this,"error"))throw A}function B(){e.removeListener("data",r),A.removeListener("drain",i),e.removeListener("end",s),e.removeListener("close",a),e.removeListener("error",c),A.removeListener("error",c),e.removeListener("end",B),e.removeListener("close",B),A.removeListener("close",B)}return e.on("error",c),A.on("error",c),e.on("end",B),e.on("close",B),A.on("close",B),A.emit("pipe",e),A}},8106:function(A){"use strict";var t={};function e(A,e,n){n||(n=Error);var r=function(A){function t(t,n,r){return A.call(this,function(A,t,n){return"string"==typeof e?e:e(A,t,n)}(t,n,r))||this}return function(A,t){A.prototype=Object.create(t.prototype),A.prototype.constructor=A,A.__proto__=t}(t,A),t}(n);r.prototype.name=n.name,r.prototype.code=A,t[A]=r}function n(A,t){if(Array.isArray(A)){var e=A.length;return A=A.map((function(A){return String(A)})),e>2?"one of ".concat(t," ").concat(A.slice(0,e-1).join(", "),", or ")+A[e-1]:2===e?"one of ".concat(t," ").concat(A[0]," or ").concat(A[1]):"of ".concat(t," ").concat(A[0])}return"of ".concat(t," ").concat(String(A))}e("ERR_INVALID_OPT_VALUE",(function(A,t){return'The value "'+t+'" is invalid for option "'+A+'"'}),TypeError),e("ERR_INVALID_ARG_TYPE",(function(A,t,e){var r,i;if("string"==typeof t&&function(A,t,e){return A.substr(!e||e<0?0:+e,t.length)===t}(t,"not ")?(r="must not be",t=t.replace(/^not /,"")):r="must be",function(A,t,e){return(void 0===e||e>A.length)&&(e=A.length),A.substring(e-t.length,e)===t}(A," argument"))i="The ".concat(A," ").concat(r," ").concat(n(t,"type"));else{var o=function(A,t,e){return"number"!=typeof e&&(e=0),!(e+t.length>A.length)&&-1!==A.indexOf(t,e)}(A,".")?"property":"argument";i='The "'.concat(A,'" ').concat(o," ").concat(r," ").concat(n(t,"type"))}return i+". Received type ".concat(typeof e)}),TypeError),e("ERR_STREAM_PUSH_AFTER_EOF","stream.push() after EOF"),e("ERR_METHOD_NOT_IMPLEMENTED",(function(A){return"The "+A+" method is not implemented"})),e("ERR_STREAM_PREMATURE_CLOSE","Premature close"),e("ERR_STREAM_DESTROYED",(function(A){return"Cannot call "+A+" after a stream was destroyed"})),e("ERR_MULTIPLE_CALLBACK","Callback called multiple times"),e("ERR_STREAM_CANNOT_PIPE","Cannot pipe, not readable"),e("ERR_STREAM_WRITE_AFTER_END","write after end"),e("ERR_STREAM_NULL_VALUES","May not write null values to stream",TypeError),e("ERR_UNKNOWN_ENCODING",(function(A){return"Unknown encoding: "+A}),TypeError),e("ERR_STREAM_UNSHIFT_AFTER_END_EVENT","stream.unshift() after end event"),A.exports.q=t},8656:function(A,t,e){"use strict";var n=e(4155),r=Object.keys||function(A){var t=[];for(var e in A)t.push(e);return t};A.exports=B;var i=e(6577),o=e(323);e(5717)(B,i);for(var s=r(o.prototype),a=0;a<s.length;a++){var c=s[a];B.prototype[c]||(B.prototype[c]=o.prototype[c])}function B(A){if(!(this instanceof B))return new B(A);i.call(this,A),o.call(this,A),this.allowHalfOpen=!0,A&&(!1===A.readable&&(this.readable=!1),!1===A.writable&&(this.writable=!1),!1===A.allowHalfOpen&&(this.allowHalfOpen=!1,this.once("end",g)))}function g(){this._writableState.ended||n.nextTick(l,this)}function l(A){A.end()}Object.defineProperty(B.prototype,"writableHighWaterMark",{enumerable:!1,get:function(){return this._writableState.highWaterMark}}),Object.defineProperty(B.prototype,"writableBuffer",{enumerable:!1,get:function(){return this._writableState&&this._writableState.getBuffer()}}),Object.defineProperty(B.prototype,"writableLength",{enumerable:!1,get:function(){return this._writableState.length}}),Object.defineProperty(B.prototype,"destroyed",{enumerable:!1,get:function(){return void 0!==this._readableState&&void 0!==this._writableState&&this._readableState.destroyed&&this._writableState.destroyed},set:function(A){void 0!==this._readableState&&void 0!==this._writableState&&(this._readableState.destroyed=A,this._writableState.destroyed=A)}})},2366:function(A,t,e){"use strict";A.exports=r;var n=e(4473);function r(A){if(!(this instanceof r))return new r(A);n.call(this,A)}e(5717)(r,n),r.prototype._transform=function(A,t,e){e(null,A)}},6577:function(A,t,e){"use strict";var n,r=e(4155);A.exports=y,y.ReadableState=D,e(7187).EventEmitter;var i,o=function(A,t){return A.listeners(t).length},s=e(3194),a=e(8823).Buffer,c=e.g.Uint8Array||function(){},B=e(964);i=B&&B.debuglog?B.debuglog("stream"):function(){};var g,l,u,w=e(3361),h=e(1029),E=e(94).getHighWaterMark,f=e(8106).q,Q=f.ERR_INVALID_ARG_TYPE,d=f.ERR_STREAM_PUSH_AFTER_EOF,C=f.ERR_METHOD_NOT_IMPLEMENTED,M=f.ERR_STREAM_UNSHIFT_AFTER_END_EVENT;e(5717)(y,s);var I=h.errorOrDestroy,p=["error","close","destroy","pause","resume"];function D(A,t,r){n=n||e(8656),A=A||{},"boolean"!=typeof r&&(r=t instanceof n),this.objectMode=!!A.objectMode,r&&(this.objectMode=this.objectMode||!!A.readableObjectMode),this.highWaterMark=E(this,A,"readableHighWaterMark",r),this.buffer=new w,this.length=0,this.pipes=null,this.pipesCount=0,this.flowing=null,this.ended=!1,this.endEmitted=!1,this.reading=!1,this.sync=!0,this.needReadable=!1,this.emittedReadable=!1,this.readableListening=!1,this.resumeScheduled=!1,this.paused=!0,this.emitClose=!1!==A.emitClose,this.autoDestroy=!!A.autoDestroy,this.destroyed=!1,this.defaultEncoding=A.defaultEncoding||"utf8",this.awaitDrain=0,this.readingMore=!1,this.decoder=null,this.encoding=null,A.encoding&&(g||(g=e(2553).s),this.decoder=new g(A.encoding),this.encoding=A.encoding)}function y(A){if(n=n||e(8656),!(this instanceof y))return new y(A);var t=this instanceof n;this._readableState=new D(A,this,t),this.readable=!0,A&&("function"==typeof A.read&&(this._read=A.read),"function"==typeof A.destroy&&(this._destroy=A.destroy)),s.call(this)}function v(A,t,e,n,r){i("readableAddChunk",t);var o,s=A._readableState;if(null===t)s.reading=!1,function(A,t){if(i("onEofChunk"),!t.ended){if(t.decoder){var e=t.decoder.end();e&&e.length&&(t.buffer.push(e),t.length+=t.objectMode?1:e.length)}t.ended=!0,t.sync?b(A):(t.needReadable=!1,t.emittedReadable||(t.emittedReadable=!0,z(A)))}}(A,s);else if(r||(o=function(A,t){var e;return function(A){return a.isBuffer(A)||A instanceof c}(t)||"string"==typeof t||void 0===t||A.objectMode||(e=new Q("chunk",["string","Buffer","Uint8Array"],t)),e}(s,t)),o)I(A,o);else if(s.objectMode||t&&t.length>0)if("string"==typeof t||s.objectMode||Object.getPrototypeOf(t)===a.prototype||(t=function(A){return a.from(A)}(t)),n)s.endEmitted?I(A,new M):m(A,s,t,!0);else if(s.ended)I(A,new d);else{if(s.destroyed)return!1;s.reading=!1,s.decoder&&!e?(t=s.decoder.write(t),s.objectMode||0!==t.length?m(A,s,t,!1):U(A,s)):m(A,s,t,!1)}else n||(s.reading=!1,U(A,s));return!s.ended&&(s.length<s.highWaterMark||0===s.length)}function m(A,t,e,n){t.flowing&&0===t.length&&!t.sync?(t.awaitDrain=0,A.emit("data",e)):(t.length+=t.objectMode?1:e.length,n?t.buffer.unshift(e):t.buffer.push(e),t.needReadable&&b(A)),U(A,t)}Object.defineProperty(y.prototype,"destroyed",{enumerable:!1,get:function(){return void 0!==this._readableState&&this._readableState.destroyed},set:function(A){this._readableState&&(this._readableState.destroyed=A)}}),y.prototype.destroy=h.destroy,y.prototype._undestroy=h.undestroy,y.prototype._destroy=function(A,t){t(A)},y.prototype.push=function(A,t){var e,n=this._readableState;return n.objectMode?e=!0:"string"==typeof A&&((t=t||n.defaultEncoding)!==n.encoding&&(A=a.from(A,t),t=""),e=!0),v(this,A,t,!1,e)},y.prototype.unshift=function(A){return v(this,A,null,!0,!1)},y.prototype.isPaused=function(){return!1===this._readableState.flowing},y.prototype.setEncoding=function(A){g||(g=e(2553).s);var t=new g(A);this._readableState.decoder=t,this._readableState.encoding=this._readableState.decoder.encoding;for(var n=this._readableState.buffer.head,r="";null!==n;)r+=t.write(n.data),n=n.next;return this._readableState.buffer.clear(),""!==r&&this._readableState.buffer.push(r),this._readableState.length=r.length,this};var F=1073741824;function Y(A,t){return A<=0||0===t.length&&t.ended?0:t.objectMode?1:A!=A?t.flowing&&t.length?t.buffer.head.data.length:t.length:(A>t.highWaterMark&&(t.highWaterMark=function(A){return A>=F?A=F:(A--,A|=A>>>1,A|=A>>>2,A|=A>>>4,A|=A>>>8,A|=A>>>16,A++),A}(A)),A<=t.length?A:t.ended?t.length:(t.needReadable=!0,0))}function b(A){var t=A._readableState;i("emitReadable",t.needReadable,t.emittedReadable),t.needReadable=!1,t.emittedReadable||(i("emitReadable",t.flowing),t.emittedReadable=!0,r.nextTick(z,A))}function z(A){var t=A._readableState;i("emitReadable_",t.destroyed,t.length,t.ended),t.destroyed||!t.length&&!t.ended||(A.emit("readable"),t.emittedReadable=!1),t.needReadable=!t.flowing&&!t.ended&&t.length<=t.highWaterMark,N(A)}function U(A,t){t.readingMore||(t.readingMore=!0,r.nextTick(S,A,t))}function S(A,t){for(;!t.reading&&!t.ended&&(t.length<t.highWaterMark||t.flowing&&0===t.length);){var e=t.length;if(i("maybeReadMore read 0"),A.read(0),e===t.length)break}t.readingMore=!1}function x(A){var t=A._readableState;t.readableListening=A.listenerCount("readable")>0,t.resumeScheduled&&!t.paused?t.flowing=!0:A.listenerCount("data")>0&&A.resume()}function T(A){i("readable nexttick read 0"),A.read(0)}function P(A,t){i("resume",t.reading),t.reading||A.read(0),t.resumeScheduled=!1,A.emit("resume"),N(A),t.flowing&&!t.reading&&A.read(0)}function N(A){var t=A._readableState;for(i("flow",t.flowing);t.flowing&&null!==A.read(););}function R(A,t){return 0===t.length?null:(t.objectMode?e=t.buffer.shift():!A||A>=t.length?(e=t.decoder?t.buffer.join(""):1===t.buffer.length?t.buffer.first():t.buffer.concat(t.length),t.buffer.clear()):e=t.buffer.consume(A,t.decoder),e);var e}function G(A){var t=A._readableState;i("endReadable",t.endEmitted),t.endEmitted||(t.ended=!0,r.nextTick(H,t,A))}function H(A,t){if(i("endReadableNT",A.endEmitted,A.length),!A.endEmitted&&0===A.length&&(A.endEmitted=!0,t.readable=!1,t.emit("end"),A.autoDestroy)){var e=t._writableState;(!e||e.autoDestroy&&e.finished)&&t.destroy()}}function k(A,t){for(var e=0,n=A.length;e<n;e++)if(A[e]===t)return e;return-1}y.prototype.read=function(A){i("read",A),A=parseInt(A,10);var t=this._readableState,e=A;if(0!==A&&(t.emittedReadable=!1),0===A&&t.needReadable&&((0!==t.highWaterMark?t.length>=t.highWaterMark:t.length>0)||t.ended))return i("read: emitReadable",t.length,t.ended),0===t.length&&t.ended?G(this):b(this),null;if(0===(A=Y(A,t))&&t.ended)return 0===t.length&&G(this),null;var n,r=t.needReadable;return i("need readable",r),(0===t.length||t.length-A<t.highWaterMark)&&i("length less than watermark",r=!0),t.ended||t.reading?i("reading or ended",r=!1):r&&(i("do read"),t.reading=!0,t.sync=!0,0===t.length&&(t.needReadable=!0),this._read(t.highWaterMark),t.sync=!1,t.reading||(A=Y(e,t))),null===(n=A>0?R(A,t):null)?(t.needReadable=t.length<=t.highWaterMark,A=0):(t.length-=A,t.awaitDrain=0),0===t.length&&(t.ended||(t.needReadable=!0),e!==A&&t.ended&&G(this)),null!==n&&this.emit("data",n),n},y.prototype._read=function(A){I(this,new C("_read()"))},y.prototype.pipe=function(A,t){var e=this,n=this._readableState;switch(n.pipesCount){case 0:n.pipes=A;break;case 1:n.pipes=[n.pipes,A];break;default:n.pipes.push(A)}n.pipesCount+=1,i("pipe count=%d opts=%j",n.pipesCount,t);var s=t&&!1===t.end||A===r.stdout||A===r.stderr?h:a;function a(){i("onend"),A.end()}n.endEmitted?r.nextTick(s):e.once("end",s),A.on("unpipe",(function t(r,o){i("onunpipe"),r===e&&o&&!1===o.hasUnpiped&&(o.hasUnpiped=!0,i("cleanup"),A.removeListener("close",u),A.removeListener("finish",w),A.removeListener("drain",c),A.removeListener("error",l),A.removeListener("unpipe",t),e.removeListener("end",a),e.removeListener("end",h),e.removeListener("data",g),B=!0,!n.awaitDrain||A._writableState&&!A._writableState.needDrain||c())}));var c=function(A){return function(){var t=A._readableState;i("pipeOnDrain",t.awaitDrain),t.awaitDrain&&t.awaitDrain--,0===t.awaitDrain&&o(A,"data")&&(t.flowing=!0,N(A))}}(e);A.on("drain",c);var B=!1;function g(t){i("ondata");var r=A.write(t);i("dest.write",r),!1===r&&((1===n.pipesCount&&n.pipes===A||n.pipesCount>1&&-1!==k(n.pipes,A))&&!B&&(i("false write response, pause",n.awaitDrain),n.awaitDrain++),e.pause())}function l(t){i("onerror",t),h(),A.removeListener("error",l),0===o(A,"error")&&I(A,t)}function u(){A.removeListener("finish",w),h()}function w(){i("onfinish"),A.removeListener("close",u),h()}function h(){i("unpipe"),e.unpipe(A)}return e.on("data",g),function(A,t,e){if("function"==typeof A.prependListener)return A.prependListener(t,e);A._events&&A._events[t]?Array.isArray(A._events[t])?A._events[t].unshift(e):A._events[t]=[e,A._events[t]]:A.on(t,e)}(A,"error",l),A.once("close",u),A.once("finish",w),A.emit("pipe",e),n.flowing||(i("pipe resume"),e.resume()),A},y.prototype.unpipe=function(A){var t=this._readableState,e={hasUnpiped:!1};if(0===t.pipesCount)return this;if(1===t.pipesCount)return A&&A!==t.pipes||(A||(A=t.pipes),t.pipes=null,t.pipesCount=0,t.flowing=!1,A&&A.emit("unpipe",this,e)),this;if(!A){var n=t.pipes,r=t.pipesCount;t.pipes=null,t.pipesCount=0,t.flowing=!1;for(var i=0;i<r;i++)n[i].emit("unpipe",this,{hasUnpiped:!1});return this}var o=k(t.pipes,A);return-1===o||(t.pipes.splice(o,1),t.pipesCount-=1,1===t.pipesCount&&(t.pipes=t.pipes[0]),A.emit("unpipe",this,e)),this},y.prototype.on=function(A,t){var e=s.prototype.on.call(this,A,t),n=this._readableState;return"data"===A?(n.readableListening=this.listenerCount("readable")>0,!1!==n.flowing&&this.resume()):"readable"===A&&(n.endEmitted||n.readableListening||(n.readableListening=n.needReadable=!0,n.flowing=!1,n.emittedReadable=!1,i("on readable",n.length,n.reading),n.length?b(this):n.reading||r.nextTick(T,this))),e},y.prototype.addListener=y.prototype.on,y.prototype.removeListener=function(A,t){var e=s.prototype.removeListener.call(this,A,t);return"readable"===A&&r.nextTick(x,this),e},y.prototype.removeAllListeners=function(A){var t=s.prototype.removeAllListeners.apply(this,arguments);return"readable"!==A&&void 0!==A||r.nextTick(x,this),t},y.prototype.resume=function(){var A=this._readableState;return A.flowing||(i("resume"),A.flowing=!A.readableListening,function(A,t){t.resumeScheduled||(t.resumeScheduled=!0,r.nextTick(P,A,t))}(this,A)),A.paused=!1,this},y.prototype.pause=function(){return i("call pause flowing=%j",this._readableState.flowing),!1!==this._readableState.flowing&&(i("pause"),this._readableState.flowing=!1,this.emit("pause")),this._readableState.paused=!0,this},y.prototype.wrap=function(A){var t=this,e=this._readableState,n=!1;for(var r in A.on("end",(function(){if(i("wrapped end"),e.decoder&&!e.ended){var A=e.decoder.end();A&&A.length&&t.push(A)}t.push(null)})),A.on("data",(function(r){i("wrapped data"),e.decoder&&(r=e.decoder.write(r)),e.objectMode&&null==r||(e.objectMode||r&&r.length)&&(t.push(r)||(n=!0,A.pause()))})),A)void 0===this[r]&&"function"==typeof A[r]&&(this[r]=function(t){return function(){return A[t].apply(A,arguments)}}(r));for(var o=0;o<p.length;o++)A.on(p[o],this.emit.bind(this,p[o]));return this._read=function(t){i("wrapped _read",t),n&&(n=!1,A.resume())},this},"function"==typeof Symbol&&(y.prototype[Symbol.asyncIterator]=function(){return void 0===l&&(l=e(828)),l(this)}),Object.defineProperty(y.prototype,"readableHighWaterMark",{enumerable:!1,get:function(){return this._readableState.highWaterMark}}),Object.defineProperty(y.prototype,"readableBuffer",{enumerable:!1,get:function(){return this._readableState&&this._readableState.buffer}}),Object.defineProperty(y.prototype,"readableFlowing",{enumerable:!1,get:function(){return this._readableState.flowing},set:function(A){this._readableState&&(this._readableState.flowing=A)}}),y._fromList=R,Object.defineProperty(y.prototype,"readableLength",{enumerable:!1,get:function(){return this._readableState.length}}),"function"==typeof Symbol&&(y.from=function(A,t){return void 0===u&&(u=e(1265)),u(y,A,t)})},4473:function(A,t,e){"use strict";A.exports=B;var n=e(8106).q,r=n.ERR_METHOD_NOT_IMPLEMENTED,i=n.ERR_MULTIPLE_CALLBACK,o=n.ERR_TRANSFORM_ALREADY_TRANSFORMING,s=n.ERR_TRANSFORM_WITH_LENGTH_0,a=e(8656);function c(A,t){var e=this._transformState;e.transforming=!1;var n=e.writecb;if(null===n)return this.emit("error",new i);e.writechunk=null,e.writecb=null,null!=t&&this.push(t),n(A);var r=this._readableState;r.reading=!1,(r.needReadable||r.length<r.highWaterMark)&&this._read(r.highWaterMark)}function B(A){if(!(this instanceof B))return new B(A);a.call(this,A),this._transformState={afterTransform:c.bind(this),needTransform:!1,transforming:!1,writecb:null,writechunk:null,writeencoding:null},this._readableState.needReadable=!0,this._readableState.sync=!1,A&&("function"==typeof A.transform&&(this._transform=A.transform),"function"==typeof A.flush&&(this._flush=A.flush)),this.on("prefinish",g)}function g(){var A=this;"function"!=typeof this._flush||this._readableState.destroyed?l(this,null,null):this._flush((function(t,e){l(A,t,e)}))}function l(A,t,e){if(t)return A.emit("error",t);if(null!=e&&A.push(e),A._writableState.length)throw new s;if(A._transformState.transforming)throw new o;return A.push(null)}e(5717)(B,a),B.prototype.push=function(A,t){return this._transformState.needTransform=!1,a.prototype.push.call(this,A,t)},B.prototype._transform=function(A,t,e){e(new r("_transform()"))},B.prototype._write=function(A,t,e){var n=this._transformState;if(n.writecb=e,n.writechunk=A,n.writeencoding=t,!n.transforming){var r=this._readableState;(n.needTransform||r.needReadable||r.length<r.highWaterMark)&&this._read(r.highWaterMark)}},B.prototype._read=function(A){var t=this._transformState;null===t.writechunk||t.transforming?t.needTransform=!0:(t.transforming=!0,this._transform(t.writechunk,t.writeencoding,t.afterTransform))},B.prototype._destroy=function(A,t){a.prototype._destroy.call(this,A,(function(A){t(A)}))}},323:function(A,t,e){"use strict";var n,r=e(4155);function i(A){var t=this;this.next=null,this.entry=null,this.finish=function(){!function(A,t,e){var n=A.entry;for(A.entry=null;n;){var r=n.callback;t.pendingcb--,r(e),n=n.next}t.corkedRequestsFree.next=A}(t,A)}}A.exports=y,y.WritableState=D;var o,s={deprecate:e(4927)},a=e(3194),c=e(8823).Buffer,B=e.g.Uint8Array||function(){},g=e(1029),l=e(94).getHighWaterMark,u=e(8106).q,w=u.ERR_INVALID_ARG_TYPE,h=u.ERR_METHOD_NOT_IMPLEMENTED,E=u.ERR_MULTIPLE_CALLBACK,f=u.ERR_STREAM_CANNOT_PIPE,Q=u.ERR_STREAM_DESTROYED,d=u.ERR_STREAM_NULL_VALUES,C=u.ERR_STREAM_WRITE_AFTER_END,M=u.ERR_UNKNOWN_ENCODING,I=g.errorOrDestroy;function p(){}function D(A,t,o){n=n||e(8656),A=A||{},"boolean"!=typeof o&&(o=t instanceof n),this.objectMode=!!A.objectMode,o&&(this.objectMode=this.objectMode||!!A.writableObjectMode),this.highWaterMark=l(this,A,"writableHighWaterMark",o),this.finalCalled=!1,this.needDrain=!1,this.ending=!1,this.ended=!1,this.finished=!1,this.destroyed=!1;var s=!1===A.decodeStrings;this.decodeStrings=!s,this.defaultEncoding=A.defaultEncoding||"utf8",this.length=0,this.writing=!1,this.corked=0,this.sync=!0,this.bufferProcessing=!1,this.onwrite=function(A){!function(A,t){var e=A._writableState,n=e.sync,i=e.writecb;if("function"!=typeof i)throw new E;if(function(A){A.writing=!1,A.writecb=null,A.length-=A.writelen,A.writelen=0}(e),t)!function(A,t,e,n,i){--t.pendingcb,e?(r.nextTick(i,n),r.nextTick(z,A,t),A._writableState.errorEmitted=!0,I(A,n)):(i(n),A._writableState.errorEmitted=!0,I(A,n),z(A,t))}(A,e,n,t,i);else{var o=Y(e)||A.destroyed;o||e.corked||e.bufferProcessing||!e.bufferedRequest||F(A,e),n?r.nextTick(m,A,e,o,i):m(A,e,o,i)}}(t,A)},this.writecb=null,this.writelen=0,this.bufferedRequest=null,this.lastBufferedRequest=null,this.pendingcb=0,this.prefinished=!1,this.errorEmitted=!1,this.emitClose=!1!==A.emitClose,this.autoDestroy=!!A.autoDestroy,this.bufferedRequestCount=0,this.corkedRequestsFree=new i(this)}function y(A){var t=this instanceof(n=n||e(8656));if(!t&&!o.call(y,this))return new y(A);this._writableState=new D(A,this,t),this.writable=!0,A&&("function"==typeof A.write&&(this._write=A.write),"function"==typeof A.writev&&(this._writev=A.writev),"function"==typeof A.destroy&&(this._destroy=A.destroy),"function"==typeof A.final&&(this._final=A.final)),a.call(this)}function v(A,t,e,n,r,i,o){t.writelen=n,t.writecb=o,t.writing=!0,t.sync=!0,t.destroyed?t.onwrite(new Q("write")):e?A._writev(r,t.onwrite):A._write(r,i,t.onwrite),t.sync=!1}function m(A,t,e,n){e||function(A,t){0===t.length&&t.needDrain&&(t.needDrain=!1,A.emit("drain"))}(A,t),t.pendingcb--,n(),z(A,t)}function F(A,t){t.bufferProcessing=!0;var e=t.bufferedRequest;if(A._writev&&e&&e.next){var n=t.bufferedRequestCount,r=new Array(n),o=t.corkedRequestsFree;o.entry=e;for(var s=0,a=!0;e;)r[s]=e,e.isBuf||(a=!1),e=e.next,s+=1;r.allBuffers=a,v(A,t,!0,t.length,r,"",o.finish),t.pendingcb++,t.lastBufferedRequest=null,o.next?(t.corkedRequestsFree=o.next,o.next=null):t.corkedRequestsFree=new i(t),t.bufferedRequestCount=0}else{for(;e;){var c=e.chunk,B=e.encoding,g=e.callback;if(v(A,t,!1,t.objectMode?1:c.length,c,B,g),e=e.next,t.bufferedRequestCount--,t.writing)break}null===e&&(t.lastBufferedRequest=null)}t.bufferedRequest=e,t.bufferProcessing=!1}function Y(A){return A.ending&&0===A.length&&null===A.bufferedRequest&&!A.finished&&!A.writing}function b(A,t){A._final((function(e){t.pendingcb--,e&&I(A,e),t.prefinished=!0,A.emit("prefinish"),z(A,t)}))}function z(A,t){var e=Y(t);if(e&&(function(A,t){t.prefinished||t.finalCalled||("function"!=typeof A._final||t.destroyed?(t.prefinished=!0,A.emit("prefinish")):(t.pendingcb++,t.finalCalled=!0,r.nextTick(b,A,t)))}(A,t),0===t.pendingcb&&(t.finished=!0,A.emit("finish"),t.autoDestroy))){var n=A._readableState;(!n||n.autoDestroy&&n.endEmitted)&&A.destroy()}return e}e(5717)(y,a),D.prototype.getBuffer=function(){for(var A=this.bufferedRequest,t=[];A;)t.push(A),A=A.next;return t},function(){try{Object.defineProperty(D.prototype,"buffer",{get:s.deprecate((function(){return this.getBuffer()}),"_writableState.buffer is deprecated. Use _writableState.getBuffer instead.","DEP0003")})}catch(A){}}(),"function"==typeof Symbol&&Symbol.hasInstance&&"function"==typeof Function.prototype[Symbol.hasInstance]?(o=Function.prototype[Symbol.hasInstance],Object.defineProperty(y,Symbol.hasInstance,{value:function(A){return!!o.call(this,A)||this===y&&A&&A._writableState instanceof D}})):o=function(A){return A instanceof this},y.prototype.pipe=function(){I(this,new f)},y.prototype.write=function(A,t,e){var n=this._writableState,i=!1,o=!n.objectMode&&function(A){return c.isBuffer(A)||A instanceof B}(A);return o&&!c.isBuffer(A)&&(A=function(A){return c.from(A)}(A)),"function"==typeof t&&(e=t,t=null),o?t="buffer":t||(t=n.defaultEncoding),"function"!=typeof e&&(e=p),n.ending?function(A,t){var e=new C;I(A,e),r.nextTick(t,e)}(this,e):(o||function(A,t,e,n){var i;return null===e?i=new d:"string"==typeof e||t.objectMode||(i=new w("chunk",["string","Buffer"],e)),!i||(I(A,i),r.nextTick(n,i),!1)}(this,n,A,e))&&(n.pendingcb++,i=function(A,t,e,n,r,i){if(!e){var o=function(A,t,e){return A.objectMode||!1===A.decodeStrings||"string"!=typeof t||(t=c.from(t,e)),t}(t,n,r);n!==o&&(e=!0,r="buffer",n=o)}var s=t.objectMode?1:n.length;t.length+=s;var a=t.length<t.highWaterMark;if(a||(t.needDrain=!0),t.writing||t.corked){var B=t.lastBufferedRequest;t.lastBufferedRequest={chunk:n,encoding:r,isBuf:e,callback:i,next:null},B?B.next=t.lastBufferedRequest:t.bufferedRequest=t.lastBufferedRequest,t.bufferedRequestCount+=1}else v(A,t,!1,s,n,r,i);return a}(this,n,o,A,t,e)),i},y.prototype.cork=function(){this._writableState.corked++},y.prototype.uncork=function(){var A=this._writableState;A.corked&&(A.corked--,A.writing||A.corked||A.bufferProcessing||!A.bufferedRequest||F(this,A))},y.prototype.setDefaultEncoding=function(A){if("string"==typeof A&&(A=A.toLowerCase()),!(["hex","utf8","utf-8","ascii","binary","base64","ucs2","ucs-2","utf16le","utf-16le","raw"].indexOf((A+"").toLowerCase())>-1))throw new M(A);return this._writableState.defaultEncoding=A,this},Object.defineProperty(y.prototype,"writableBuffer",{enumerable:!1,get:function(){return this._writableState&&this._writableState.getBuffer()}}),Object.defineProperty(y.prototype,"writableHighWaterMark",{enumerable:!1,get:function(){return this._writableState.highWaterMark}}),y.prototype._write=function(A,t,e){e(new h("_write()"))},y.prototype._writev=null,y.prototype.end=function(A,t,e){var n=this._writableState;return"function"==typeof A?(e=A,A=null,t=null):"function"==typeof t&&(e=t,t=null),null!=A&&this.write(A,t),n.corked&&(n.corked=1,this.uncork()),n.ending||function(A,t,e){t.ending=!0,z(A,t),e&&(t.finished?r.nextTick(e):A.once("finish",e)),t.ended=!0,A.writable=!1}(this,n,e),this},Object.defineProperty(y.prototype,"writableLength",{enumerable:!1,get:function(){return this._writableState.length}}),Object.defineProperty(y.prototype,"destroyed",{enumerable:!1,get:function(){return void 0!==this._writableState&&this._writableState.destroyed},set:function(A){this._writableState&&(this._writableState.destroyed=A)}}),y.prototype.destroy=g.destroy,y.prototype._undestroy=g.undestroy,y.prototype._destroy=function(A,t){t(A)}},828:function(A,t,e){"use strict";var n,r=e(4155);function i(A,t,e){return t in A?Object.defineProperty(A,t,{value:e,enumerable:!0,configurable:!0,writable:!0}):A[t]=e,A}var o=e(1086),s=Symbol("lastResolve"),a=Symbol("lastReject"),c=Symbol("error"),B=Symbol("ended"),g=Symbol("lastPromise"),l=Symbol("handlePromise"),u=Symbol("stream");function w(A,t){return{value:A,done:t}}function h(A){var t=A[s];if(null!==t){var e=A[u].read();null!==e&&(A[g]=null,A[s]=null,A[a]=null,t(w(e,!1)))}}function E(A){r.nextTick(h,A)}var f=Object.getPrototypeOf((function(){})),Q=Object.setPrototypeOf((i(n={get stream(){return this[u]},next:function(){var A=this,t=this[c];if(null!==t)return Promise.reject(t);if(this[B])return Promise.resolve(w(void 0,!0));if(this[u].destroyed)return new Promise((function(t,e){r.nextTick((function(){A[c]?e(A[c]):t(w(void 0,!0))}))}));var e,n=this[g];if(n)e=new Promise(function(A,t){return function(e,n){A.then((function(){t[B]?e(w(void 0,!0)):t[l](e,n)}),n)}}(n,this));else{var i=this[u].read();if(null!==i)return Promise.resolve(w(i,!1));e=new Promise(this[l])}return this[g]=e,e}},Symbol.asyncIterator,(function(){return this})),i(n,"return",(function(){var A=this;return new Promise((function(t,e){A[u].destroy(null,(function(A){A?e(A):t(w(void 0,!0))}))}))})),n),f);A.exports=function(A){var t,e=Object.create(Q,(i(t={},u,{value:A,writable:!0}),i(t,s,{value:null,writable:!0}),i(t,a,{value:null,writable:!0}),i(t,c,{value:null,writable:!0}),i(t,B,{value:A._readableState.endEmitted,writable:!0}),i(t,l,{value:function(A,t){var n=e[u].read();n?(e[g]=null,e[s]=null,e[a]=null,A(w(n,!1))):(e[s]=A,e[a]=t)},writable:!0}),t));return e[g]=null,o(A,(function(A){if(A&&"ERR_STREAM_PREMATURE_CLOSE"!==A.code){var t=e[a];return null!==t&&(e[g]=null,e[s]=null,e[a]=null,t(A)),void(e[c]=A)}var n=e[s];null!==n&&(e[g]=null,e[s]=null,e[a]=null,n(w(void 0,!0))),e[B]=!0})),A.on("readable",E.bind(null,e)),e}},1029:function(A,t,e){"use strict";var n=e(4155);function r(A,t){o(A,t),i(A)}function i(A){A._writableState&&!A._writableState.emitClose||A._readableState&&!A._readableState.emitClose||A.emit("close")}function o(A,t){A.emit("error",t)}A.exports={destroy:function(A,t){var e=this,s=this._readableState&&this._readableState.destroyed,a=this._writableState&&this._writableState.destroyed;return s||a?(t?t(A):A&&(this._writableState?this._writableState.errorEmitted||(this._writableState.errorEmitted=!0,n.nextTick(o,this,A)):n.nextTick(o,this,A)),this):(this._readableState&&(this._readableState.destroyed=!0),this._writableState&&(this._writableState.destroyed=!0),this._destroy(A||null,(function(A){!t&&A?e._writableState?e._writableState.errorEmitted?n.nextTick(i,e):(e._writableState.errorEmitted=!0,n.nextTick(r,e,A)):n.nextTick(r,e,A):t?(n.nextTick(i,e),t(A)):n.nextTick(i,e)})),this)},undestroy:function(){this._readableState&&(this._readableState.destroyed=!1,this._readableState.reading=!1,this._readableState.ended=!1,this._readableState.endEmitted=!1),this._writableState&&(this._writableState.destroyed=!1,this._writableState.ended=!1,this._writableState.ending=!1,this._writableState.finalCalled=!1,this._writableState.prefinished=!1,this._writableState.finished=!1,this._writableState.errorEmitted=!1)},errorOrDestroy:function(A,t){var e=A._readableState,n=A._writableState;e&&e.autoDestroy||n&&n.autoDestroy?A.destroy(t):A.emit("error",t)}}},1086:function(A,t,e){"use strict";var n=e(8106).q.ERR_STREAM_PREMATURE_CLOSE;function r(){}A.exports=function A(t,e,i){if("function"==typeof e)return A(t,null,e);e||(e={}),i=function(A){var t=!1;return function(){if(!t){t=!0;for(var e=arguments.length,n=new Array(e),r=0;r<e;r++)n[r]=arguments[r];A.apply(this,n)}}}(i||r);var o=e.readable||!1!==e.readable&&t.readable,s=e.writable||!1!==e.writable&&t.writable,a=function(){t.writable||B()},c=t._writableState&&t._writableState.finished,B=function(){s=!1,c=!0,o||i.call(t)},g=t._readableState&&t._readableState.endEmitted,l=function(){o=!1,g=!0,s||i.call(t)},u=function(A){i.call(t,A)},w=function(){var A;return o&&!g?(t._readableState&&t._readableState.ended||(A=new n),i.call(t,A)):s&&!c?(t._writableState&&t._writableState.ended||(A=new n),i.call(t,A)):void 0},h=function(){t.req.on("finish",B)};return function(A){return A.setHeader&&"function"==typeof A.abort}(t)?(t.on("complete",B),t.on("abort",w),t.req?h():t.on("request",h)):s&&!t._writableState&&(t.on("end",a),t.on("close",a)),t.on("end",l),t.on("finish",B),!1!==e.error&&t.on("error",u),t.on("close",w),function(){t.removeListener("complete",B),t.removeListener("abort",w),t.removeListener("request",h),t.req&&t.req.removeListener("finish",B),t.removeListener("end",a),t.removeListener("close",a),t.removeListener("finish",B),t.removeListener("end",l),t.removeListener("error",u),t.removeListener("close",w)}}},1265:function(A){A.exports=function(){throw new Error("Readable.from is not available in the browser")}},6472:function(A,t,e){"use strict";var n,r=e(8106).q,i=r.ERR_MISSING_ARGS,o=r.ERR_STREAM_DESTROYED;function s(A){if(A)throw A}function a(A,t,r,i){i=function(A){var t=!1;return function(){t||(t=!0,A.apply(void 0,arguments))}}(i);var s=!1;A.on("close",(function(){s=!0})),void 0===n&&(n=e(1086)),n(A,{readable:t,writable:r},(function(A){if(A)return i(A);s=!0,i()}));var a=!1;return function(t){if(!s&&!a)return a=!0,function(A){return A.setHeader&&"function"==typeof A.abort}(A)?A.abort():"function"==typeof A.destroy?A.destroy():void i(t||new o("pipe"))}}function c(A){A()}function B(A,t){return A.pipe(t)}A.exports=function(){for(var A=arguments.length,t=new Array(A),e=0;e<A;e++)t[e]=arguments[e];var n,r=function(A){return A.length?"function"!=typeof A[A.length-1]?s:A.pop():s}(t);if(Array.isArray(t[0])&&(t=t[0]),t.length<2)throw new i("streams");var o=t.map((function(A,e){var i=e<t.length-1;return a(A,i,e>0,(function(A){n||(n=A),A&&o.forEach(c),i||(o.forEach(c),r(n))}))}));return t.reduce(B)}},94:function(A,t,e){"use strict";var n=e(8106).q.ERR_INVALID_OPT_VALUE;A.exports={getHighWaterMark:function(A,t,e,r){var i=function(A,t,e){return null!=A.highWaterMark?A.highWaterMark:t?A[e]:null}(t,r,e);if(null!=i){if(!isFinite(i)||Math.floor(i)!==i||i<0)throw new n(r?e:"highWaterMark",i);return Math.floor(i)}return A.objectMode?16:16384}}},3194:function(A,t,e){A.exports=e(7187).EventEmitter},2984:function(A,t,e){var n,r;void 0===(r="function"==typeof(n=function(){"use strict";function t(A,t,e){var n=new XMLHttpRequest;n.open("GET",A),n.responseType="blob",n.onload=function(){s(n.response,t,e)},n.onerror=function(){},n.send()}function n(A){var t=new XMLHttpRequest;t.open("HEAD",A,!1);try{t.send()}catch(A){}return 200<=t.status&&299>=t.status}function r(A){try{A.dispatchEvent(new MouseEvent("click"))}catch(e){var t=document.createEvent("MouseEvents");t.initMouseEvent("click",!0,!0,window,0,0,0,80,20,!1,!1,!1,!1,0,null),A.dispatchEvent(t)}}var i="object"==typeof window&&window.window===window?window:"object"==typeof self&&self.self===self?self:"object"==typeof e.g&&e.g.global===e.g?e.g:void 0,o=i.navigator&&/Macintosh/.test(navigator.userAgent)&&/AppleWebKit/.test(navigator.userAgent)&&!/Safari/.test(navigator.userAgent),s=i.saveAs||("object"!=typeof window||window!==i?function(){}:"undefined"!=typeof HTMLAnchorElement&&"download"in HTMLAnchorElement.prototype&&!o?function(A,e,o){var s=i.URL||i.webkitURL,a=document.createElement("a");e=e||A.name||"download",a.download=e,a.rel="noopener","string"==typeof A?(a.href=A,a.origin===location.origin?r(a):n(a.href)?t(A,e,o):r(a,a.target="_blank")):(a.href=s.createObjectURL(A),setTimeout((function(){s.revokeObjectURL(a.href)}),4e4),setTimeout((function(){r(a)}),0))}:"msSaveOrOpenBlob"in navigator?function(A,e,i){if(e=e||A.name||"download","string"!=typeof A)navigator.msSaveOrOpenBlob(function(A,t){return void 0===t?t={autoBom:!1}:"object"!=typeof t&&(t={autoBom:!t}),t.autoBom&&/^\s*(?:text\/\S*|application\/xml|\S*\/\S*\+xml)\s*;.*charset\s*=\s*utf-8/i.test(A.type)?new Blob(["\ufeff",A],{type:A.type}):A}(A,i),e);else if(n(A))t(A,e,i);else{var o=document.createElement("a");o.href=A,o.target="_blank",setTimeout((function(){r(o)}))}}:function(A,e,n,r){if((r=r||open("","_blank"))&&(r.document.title=r.document.body.innerText="downloading..."),"string"==typeof A)return t(A,e,n);var s="application/octet-stream"===A.type,a=/constructor/i.test(i.HTMLElement)||i.safari,c=/CriOS\/[\d]+/.test(navigator.userAgent);if((c||s&&a||o)&&"undefined"!=typeof FileReader){var B=new FileReader;B.onloadend=function(){var A=B.result;A=c?A:A.replace(/^data:[^;]*;/,"data:attachment/file;"),r?r.location.href=A:location=A,r=null},B.readAsDataURL(A)}else{var g=i.URL||i.webkitURL,l=g.createObjectURL(A);r?r.location=l:location.href=l,r=null,setTimeout((function(){g.revokeObjectURL(l)}),4e4)}});i.saveAs=s.saveAs=s,A.exports=s})?n.apply(t,[]):n)||(A.exports=r)},2553:function(A,t,e){"use strict";var n=e(4559).Buffer,r=n.isEncoding||function(A){switch((A=""+A)&&A.toLowerCase()){case"hex":case"utf8":case"utf-8":case"ascii":case"binary":case"base64":case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":case"raw":return!0;default:return!1}};function i(A){var t;switch(this.encoding=function(A){var t=function(A){if(!A)return"utf8";for(var t;;)switch(A){case"utf8":case"utf-8":return"utf8";case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return"utf16le";case"latin1":case"binary":return"latin1";case"base64":case"ascii":case"hex":return A;default:if(t)return;A=(""+A).toLowerCase(),t=!0}}(A);if("string"!=typeof t&&(n.isEncoding===r||!r(A)))throw new Error("Unknown encoding: "+A);return t||A}(A),this.encoding){case"utf16le":this.text=a,this.end=c,t=4;break;case"utf8":this.fillLast=s,t=4;break;case"base64":this.text=B,this.end=g,t=3;break;default:return this.write=l,void(this.end=u)}this.lastNeed=0,this.lastTotal=0,this.lastChar=n.allocUnsafe(t)}function o(A){return A<=127?0:A>>5==6?2:A>>4==14?3:A>>3==30?4:A>>6==2?-1:-2}function s(A){var t=this.lastTotal-this.lastNeed,e=function(A,t,e){if(128!=(192&t[0]))return A.lastNeed=0,"�";if(A.lastNeed>1&&t.length>1){if(128!=(192&t[1]))return A.lastNeed=1,"�";if(A.lastNeed>2&&t.length>2&&128!=(192&t[2]))return A.lastNeed=2,"�"}}(this,A);return void 0!==e?e:this.lastNeed<=A.length?(A.copy(this.lastChar,t,0,this.lastNeed),this.lastChar.toString(this.encoding,0,this.lastTotal)):(A.copy(this.lastChar,t,0,A.length),void(this.lastNeed-=A.length))}function a(A,t){if((A.length-t)%2==0){var e=A.toString("utf16le",t);if(e){var n=e.charCodeAt(e.length-1);if(n>=55296&&n<=56319)return this.lastNeed=2,this.lastTotal=4,this.lastChar[0]=A[A.length-2],this.lastChar[1]=A[A.length-1],e.slice(0,-1)}return e}return this.lastNeed=1,this.lastTotal=2,this.lastChar[0]=A[A.length-1],A.toString("utf16le",t,A.length-1)}function c(A){var t=A&&A.length?this.write(A):"";if(this.lastNeed){var e=this.lastTotal-this.lastNeed;return t+this.lastChar.toString("utf16le",0,e)}return t}function B(A,t){var e=(A.length-t)%3;return 0===e?A.toString("base64",t):(this.lastNeed=3-e,this.lastTotal=3,1===e?this.lastChar[0]=A[A.length-1]:(this.lastChar[0]=A[A.length-2],this.lastChar[1]=A[A.length-1]),A.toString("base64",t,A.length-e))}function g(A){var t=A&&A.length?this.write(A):"";return this.lastNeed?t+this.lastChar.toString("base64",0,3-this.lastNeed):t}function l(A){return A.toString(this.encoding)}function u(A){return A&&A.length?this.write(A):""}t.s=i,i.prototype.write=function(A){if(0===A.length)return"";var t,e;if(this.lastNeed){if(void 0===(t=this.fillLast(A)))return"";e=this.lastNeed,this.lastNeed=0}else e=0;return e<A.length?t?t+this.text(A,e):this.text(A,e):t||""},i.prototype.end=function(A){var t=A&&A.length?this.write(A):"";return this.lastNeed?t+"�":t},i.prototype.text=function(A,t){var e=function(A,t,e){var n=t.length-1;if(n<e)return 0;var r=o(t[n]);return r>=0?(r>0&&(A.lastNeed=r-1),r):--n<e||-2===r?0:(r=o(t[n]))>=0?(r>0&&(A.lastNeed=r-2),r):--n<e||-2===r?0:(r=o(t[n]))>=0?(r>0&&(2===r?r=0:A.lastNeed=r-3),r):0}(this,A,t);if(!this.lastNeed)return A.toString("utf8",t);this.lastTotal=e;var n=A.length-(e-this.lastNeed);return A.copy(this.lastChar,0,n),A.toString("utf8",t,n)},i.prototype.fillLast=function(A){if(this.lastNeed<=A.length)return A.copy(this.lastChar,this.lastTotal-this.lastNeed,0,this.lastNeed),this.lastChar.toString(this.encoding,0,this.lastTotal);A.copy(this.lastChar,this.lastTotal-this.lastNeed,0,A.length),this.lastNeed-=A.length}},311:function(A){function t(){this.table=new Uint16Array(16),this.trans=new Uint16Array(288)}function e(A,e){this.source=A,this.sourceIndex=0,this.tag=0,this.bitcount=0,this.dest=e,this.destLen=0,this.ltree=new t,this.dtree=new t}var n=new t,r=new t,i=new Uint8Array(30),o=new Uint16Array(30),s=new Uint8Array(30),a=new Uint16Array(30),c=new Uint8Array([16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15]),B=new t,g=new Uint8Array(320);function l(A,t,e,n){var r,i;for(r=0;r<e;++r)A[r]=0;for(r=0;r<30-e;++r)A[r+e]=r/e|0;for(i=n,r=0;r<30;++r)t[r]=i,i+=1<<A[r]}var u=new Uint16Array(16);function w(A,t,e,n){var r,i;for(r=0;r<16;++r)A.table[r]=0;for(r=0;r<n;++r)A.table[t[e+r]]++;for(A.table[0]=0,i=0,r=0;r<16;++r)u[r]=i,i+=A.table[r];for(r=0;r<n;++r)t[e+r]&&(A.trans[u[t[e+r]]++]=r)}function h(A){A.bitcount--||(A.tag=A.source[A.sourceIndex++],A.bitcount=7);var t=1&A.tag;return A.tag>>>=1,t}function E(A,t,e){if(!t)return e;for(;A.bitcount<24;)A.tag|=A.source[A.sourceIndex++]<<A.bitcount,A.bitcount+=8;var n=A.tag&65535>>>16-t;return A.tag>>>=t,A.bitcount-=t,n+e}function f(A,t){for(;A.bitcount<24;)A.tag|=A.source[A.sourceIndex++]<<A.bitcount,A.bitcount+=8;var e=0,n=0,r=0,i=A.tag;do{n=2*n+(1&i),i>>>=1,++r,e+=t.table[r],n-=t.table[r]}while(n>=0);return A.tag=i,A.bitcount-=r,t.trans[e+n]}function Q(A,t,e){var n,r,i,o,s,a;for(n=E(A,5,257),r=E(A,5,1),i=E(A,4,4),o=0;o<19;++o)g[o]=0;for(o=0;o<i;++o){var l=E(A,3,0);g[c[o]]=l}for(w(B,g,0,19),s=0;s<n+r;){var u=f(A,B);switch(u){case 16:var h=g[s-1];for(a=E(A,2,3);a;--a)g[s++]=h;break;case 17:for(a=E(A,3,3);a;--a)g[s++]=0;break;case 18:for(a=E(A,7,11);a;--a)g[s++]=0;break;default:g[s++]=u}}w(t,g,0,n),w(e,g,n,r)}function d(A,t,e){for(;;){var n,r,c,B,g=f(A,t);if(256===g)return 0;if(g<256)A.dest[A.destLen++]=g;else for(n=E(A,i[g-=257],o[g]),r=f(A,e),B=c=A.destLen-E(A,s[r],a[r]);B<c+n;++B)A.dest[A.destLen++]=A.dest[B]}}function C(A){for(var t,e;A.bitcount>8;)A.sourceIndex--,A.bitcount-=8;if((t=256*(t=A.source[A.sourceIndex+1])+A.source[A.sourceIndex])!==(65535&~(256*A.source[A.sourceIndex+3]+A.source[A.sourceIndex+2])))return-3;for(A.sourceIndex+=4,e=t;e;--e)A.dest[A.destLen++]=A.source[A.sourceIndex++];return A.bitcount=0,0}!function(A,t){var e;for(e=0;e<7;++e)A.table[e]=0;for(A.table[7]=24,A.table[8]=152,A.table[9]=112,e=0;e<24;++e)A.trans[e]=256+e;for(e=0;e<144;++e)A.trans[24+e]=e;for(e=0;e<8;++e)A.trans[168+e]=280+e;for(e=0;e<112;++e)A.trans[176+e]=144+e;for(e=0;e<5;++e)t.table[e]=0;for(t.table[5]=32,e=0;e<32;++e)t.trans[e]=e}(n,r),l(i,o,4,3),l(s,a,2,1),i[28]=0,o[28]=258,A.exports=function(A,t){var i,o,s=new e(A,t);do{switch(i=h(s),E(s,2,0)){case 0:o=C(s);break;case 1:o=d(s,n,r);break;case 2:Q(s,s.ltree,s.dtree),o=d(s,s.ltree,s.dtree);break;default:o=-3}if(0!==o)throw new Error("Data error")}while(!i);return s.destLen<s.dest.length?"function"==typeof s.dest.slice?s.dest.slice(0,s.destLen):s.dest.subarray(0,s.destLen):s.dest}},1917:function(A,t,e){"use strict";var n,r=e(8823).Buffer;function i(A,t){for(var e=0;e<t.length;e++){var n=t[e];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(A,(void 0,"symbol"==typeof(r=function(A,t){if("object"!=typeof A||null===A)return A;var e=A[Symbol.toPrimitive];if(void 0!==e){var n=e.call(A,t||"default");if("object"!=typeof n)return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return("string"===t?String:Number)(A)}(n.key,"string"))?r:String(r)),n)}var r}function o(A,t,e){return t&&i(A.prototype,t),e&&i(A,e),Object.defineProperty(A,"prototype",{writable:!1}),A}function s(A,t){A.prototype=Object.create(t.prototype),A.prototype.constructor=A,a(A,t)}function a(A,t){return a=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(A,t){return A.__proto__=t,A},a(A,t)}function c(A,t){var e="undefined"!=typeof Symbol&&A[Symbol.iterator]||A["@@iterator"];if(e)return(e=e.call(A)).next.bind(e);if(Array.isArray(A)||(e=function(A,t){if(A){if("string"==typeof A)return B(A,t);var e=Object.prototype.toString.call(A).slice(8,-1);return"Object"===e&&A.constructor&&(e=A.constructor.name),"Map"===e||"Set"===e?Array.from(A):"Arguments"===e||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(e)?B(A,t):void 0}}(A))||t&&A&&"number"==typeof A.length){e&&(A=e);var n=0;return function(){return n>=A.length?{done:!0}:{done:!1,value:A[n++]}}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}function B(A,t){(null==t||t>A.length)&&(t=A.length);for(var e=0,n=new Array(t);e<t;e++)n[e]=A[e];return n}function g(A){return A&&"object"==typeof A&&"default"in A?A.default:A}e(2526),e(1817),e(2165),e(6649),e(6078),e(1539),e(4747),e(7941),e(7042),e(6992),e(1532),e(8783),e(3948),e(2222),e(9653),e(1249),e(2087),e(8309),e(9601),e(4953),e(8674),e(5003),e(189),e(561),e(2481),e(2707),e(4916),e(4723),e(1038),e(9600),e(3371),e(3290),e(3299),e(8255),e(2990),e(8927),e(3105),e(5035),e(4345),e(7174),e(2846),e(4731),e(7209),e(6319),e(8867),e(7789),e(3739),e(9368),e(4483),e(2056),e(3462),e(678),e(7462),e(3824),e(5021),e(2974),e(5016),e(5109),e(9714),e(3210);var l=g(e(5106)),u=e(6610),w=g(e(251)),h=g(e(3631)),E=g(e(4781)),f=g(e(9811)),Q=g(e(6313)),d=g(e(311)),C=g(e(7709)),M=e(3857),I={logErrors:!1},p=[];function D(A,t,e){return t in A?Object.defineProperty(A,t,{value:e,enumerable:!0,configurable:!0,writable:!0}):A[t]=e,A}function y(A,t,e,n,r){var i={};return Object.keys(n).forEach((function(A){i[A]=n[A]})),i.enumerable=!!i.enumerable,i.configurable=!!i.configurable,("value"in i||i.initializer)&&(i.writable=!0),i=e.slice().reverse().reduce((function(e,n){return n(A,t,e)||e}),i),r&&void 0!==i.initializer&&(i.value=i.initializer?i.initializer.call(r):void 0,i.initializer=void 0),void 0===i.initializer&&(Object.defineProperty(A,t,i),i=null),i}function v(A,t,e){if(e.get){var n=e.get;e.get=function(){var A=n.call(this);return Object.defineProperty(this,t,{value:A}),A}}else if("function"==typeof e.value){var r=e.value;return{get:function(){var A=new Map;function e(){for(var t=arguments.length,e=new Array(t),n=0;n<t;n++)e[n]=arguments[n];var i=e.length>0?e[0]:"value";if(A.has(i))return A.get(i);var o=r.apply(this,e);return A.set(i,o),o}return Object.defineProperty(this,t,{value:e}),e}}}}I.registerFormat=function(A){p.push(A)},I.openSync=function(A,t){var e=M.readFileSync(A);return I.create(e,t)},I.open=function(A,t,e){"function"==typeof t&&(e=t,t=null),M.readFile(A,(function(A,n){if(A)return e(A);try{var r=I.create(n,t)}catch(A){return e(A)}return e(null,r)}))},I.create=function(A,t){for(var e=0;e<p.length;e++){var n=p[e];if(n.probe(A)){var r=new n(new l.DecodeStream(A));return t?r.getFont(t):r}}throw new Error("Unknown font format")},I.defaultLanguage="en",I.setDefaultLanguage=function(A){void 0===A&&(A="en"),I.defaultLanguage=A};var m=new l.Struct({firstCode:l.uint16,entryCount:l.uint16,idDelta:l.int16,idRangeOffset:l.uint16}),F=new l.Struct({startCharCode:l.uint32,endCharCode:l.uint32,glyphID:l.uint32}),Y=new l.Struct({startUnicodeValue:l.uint24,additionalCount:l.uint8}),b=new l.Struct({unicodeValue:l.uint24,glyphID:l.uint16}),z=new l.Array(Y,l.uint32),U=new l.Array(b,l.uint32),S=new l.Struct({varSelector:l.uint24,defaultUVS:new l.Pointer(l.uint32,z,{type:"parent"}),nonDefaultUVS:new l.Pointer(l.uint32,U,{type:"parent"})}),x=new l.VersionedStruct(l.uint16,{0:{length:l.uint16,language:l.uint16,codeMap:new l.LazyArray(l.uint8,256)},2:{length:l.uint16,language:l.uint16,subHeaderKeys:new l.Array(l.uint16,256),subHeaderCount:function(A){return Math.max.apply(Math,A.subHeaderKeys)},subHeaders:new l.LazyArray(m,"subHeaderCount"),glyphIndexArray:new l.LazyArray(l.uint16,"subHeaderCount")},4:{length:l.uint16,language:l.uint16,segCountX2:l.uint16,segCount:function(A){return A.segCountX2>>1},searchRange:l.uint16,entrySelector:l.uint16,rangeShift:l.uint16,endCode:new l.LazyArray(l.uint16,"segCount"),reservedPad:new l.Reserved(l.uint16),startCode:new l.LazyArray(l.uint16,"segCount"),idDelta:new l.LazyArray(l.int16,"segCount"),idRangeOffset:new l.LazyArray(l.uint16,"segCount"),glyphIndexArray:new l.LazyArray(l.uint16,(function(A){return(A.length-A._currentOffset)/2}))},6:{length:l.uint16,language:l.uint16,firstCode:l.uint16,entryCount:l.uint16,glyphIndices:new l.LazyArray(l.uint16,"entryCount")},8:{reserved:new l.Reserved(l.uint16),length:l.uint32,language:l.uint16,is32:new l.LazyArray(l.uint8,8192),nGroups:l.uint32,groups:new l.LazyArray(F,"nGroups")},10:{reserved:new l.Reserved(l.uint16),length:l.uint32,language:l.uint32,firstCode:l.uint32,entryCount:l.uint32,glyphIndices:new l.LazyArray(l.uint16,"numChars")},12:{reserved:new l.Reserved(l.uint16),length:l.uint32,language:l.uint32,nGroups:l.uint32,groups:new l.LazyArray(F,"nGroups")},13:{reserved:new l.Reserved(l.uint16),length:l.uint32,language:l.uint32,nGroups:l.uint32,groups:new l.LazyArray(F,"nGroups")},14:{length:l.uint32,numRecords:l.uint32,varSelectors:new l.LazyArray(S,"numRecords")}}),T=new l.Struct({platformID:l.uint16,encodingID:l.uint16,table:new l.Pointer(l.uint32,x,{type:"parent",lazy:!0})}),P=new l.Struct({version:l.uint16,numSubtables:l.uint16,tables:new l.Array(T,"numSubtables")}),N=new l.Struct({version:l.int32,revision:l.int32,checkSumAdjustment:l.uint32,magicNumber:l.uint32,flags:l.uint16,unitsPerEm:l.uint16,created:new l.Array(l.int32,2),modified:new l.Array(l.int32,2),xMin:l.int16,yMin:l.int16,xMax:l.int16,yMax:l.int16,macStyle:new l.Bitfield(l.uint16,["bold","italic","underline","outline","shadow","condensed","extended"]),lowestRecPPEM:l.uint16,fontDirectionHint:l.int16,indexToLocFormat:l.int16,glyphDataFormat:l.int16}),R=new l.Struct({version:l.int32,ascent:l.int16,descent:l.int16,lineGap:l.int16,advanceWidthMax:l.uint16,minLeftSideBearing:l.int16,minRightSideBearing:l.int16,xMaxExtent:l.int16,caretSlopeRise:l.int16,caretSlopeRun:l.int16,caretOffset:l.int16,reserved:new l.Reserved(l.int16,4),metricDataFormat:l.int16,numberOfMetrics:l.uint16}),G=new l.Struct({advance:l.uint16,bearing:l.int16}),H=new l.Struct({metrics:new l.LazyArray(G,(function(A){return A.parent.hhea.numberOfMetrics})),bearings:new l.LazyArray(l.int16,(function(A){return A.parent.maxp.numGlyphs-A.parent.hhea.numberOfMetrics}))}),k=new l.Struct({version:l.int32,numGlyphs:l.uint16,maxPoints:l.uint16,maxContours:l.uint16,maxComponentPoints:l.uint16,maxComponentContours:l.uint16,maxZones:l.uint16,maxTwilightPoints:l.uint16,maxStorage:l.uint16,maxFunctionDefs:l.uint16,maxInstructionDefs:l.uint16,maxStackElements:l.uint16,maxSizeOfInstructions:l.uint16,maxComponentElements:l.uint16,maxComponentDepth:l.uint16});function L(A,t,e){return void 0===e&&(e=0),1===A&&j[e]?j[e]:J[A][t]}var J=[["utf16be","utf16be","utf16be","utf16be","utf16be","utf16be"],["macroman","shift-jis","big5","euc-kr","iso-8859-6","iso-8859-8","macgreek","maccyrillic","symbol","Devanagari","Gurmukhi","Gujarati","Oriya","Bengali","Tamil","Telugu","Kannada","Malayalam","Sinhalese","Burmese","Khmer","macthai","Laotian","Georgian","Armenian","gb-2312-80","Tibetan","Mongolian","Geez","maccenteuro","Vietnamese","Sindhi"],["ascii"],["symbol","utf16be","shift-jis","gb18030","big5","wansung","johab",null,null,null,"utf16be"]],j={15:"maciceland",17:"macturkish",18:"maccroatian",24:"maccenteuro",25:"maccenteuro",26:"maccenteuro",27:"maccenteuro",28:"maccenteuro",30:"maciceland",37:"macromania",38:"maccenteuro",39:"maccenteuro",40:"maccenteuro",143:"macinuit",146:"macgaelic"},O=[[],{0:"en",30:"fo",60:"ks",90:"rw",1:"fr",31:"fa",61:"ku",91:"rn",2:"de",32:"ru",62:"sd",92:"ny",3:"it",33:"zh",63:"bo",93:"mg",4:"nl",34:"nl-BE",64:"ne",94:"eo",5:"sv",35:"ga",65:"sa",128:"cy",6:"es",36:"sq",66:"mr",129:"eu",7:"da",37:"ro",67:"bn",130:"ca",8:"pt",38:"cz",68:"as",131:"la",9:"no",39:"sk",69:"gu",132:"qu",10:"he",40:"si",70:"pa",133:"gn",11:"ja",41:"yi",71:"or",134:"ay",12:"ar",42:"sr",72:"ml",135:"tt",13:"fi",43:"mk",73:"kn",136:"ug",14:"el",44:"bg",74:"ta",137:"dz",15:"is",45:"uk",75:"te",138:"jv",16:"mt",46:"be",76:"si",139:"su",17:"tr",47:"uz",77:"my",140:"gl",18:"hr",48:"kk",78:"km",141:"af",19:"zh-Hant",49:"az-Cyrl",79:"lo",142:"br",20:"ur",50:"az-Arab",80:"vi",143:"iu",21:"hi",51:"hy",81:"id",144:"gd",22:"th",52:"ka",82:"tl",145:"gv",23:"ko",53:"mo",83:"ms",146:"ga",24:"lt",54:"ky",84:"ms-Arab",147:"to",25:"pl",55:"tg",85:"am",148:"el-polyton",26:"hu",56:"tk",86:"ti",149:"kl",27:"es",57:"mn-CN",87:"om",150:"az",28:"lv",58:"mn",88:"so",151:"nn",29:"se",59:"ps",89:"sw"},[],{1078:"af",16393:"en-IN",1159:"rw",1074:"tn",1052:"sq",6153:"en-IE",1089:"sw",1115:"si",1156:"gsw",8201:"en-JM",1111:"kok",1051:"sk",1118:"am",17417:"en-MY",1042:"ko",1060:"sl",5121:"ar-DZ",5129:"en-NZ",1088:"ky",11274:"es-AR",15361:"ar-BH",13321:"en-PH",1108:"lo",16394:"es-BO",3073:"ar",18441:"en-SG",1062:"lv",13322:"es-CL",2049:"ar-IQ",7177:"en-ZA",1063:"lt",9226:"es-CO",11265:"ar-JO",11273:"en-TT",2094:"dsb",5130:"es-CR",13313:"ar-KW",2057:"en-GB",1134:"lb",7178:"es-DO",12289:"ar-LB",1033:"en",1071:"mk",12298:"es-EC",4097:"ar-LY",12297:"en-ZW",2110:"ms-BN",17418:"es-SV",6145:"ary",1061:"et",1086:"ms",4106:"es-GT",8193:"ar-OM",1080:"fo",1100:"ml",18442:"es-HN",16385:"ar-QA",1124:"fil",1082:"mt",2058:"es-MX",1025:"ar-SA",1035:"fi",1153:"mi",19466:"es-NI",10241:"ar-SY",2060:"fr-BE",1146:"arn",6154:"es-PA",7169:"aeb",3084:"fr-CA",1102:"mr",15370:"es-PY",14337:"ar-AE",1036:"fr",1148:"moh",10250:"es-PE",9217:"ar-YE",5132:"fr-LU",1104:"mn",20490:"es-PR",1067:"hy",6156:"fr-MC",2128:"mn-CN",3082:"es",1101:"as",4108:"fr-CH",1121:"ne",1034:"es",2092:"az-Cyrl",1122:"fy",1044:"nb",21514:"es-US",1068:"az",1110:"gl",2068:"nn",14346:"es-UY",1133:"ba",1079:"ka",1154:"oc",8202:"es-VE",1069:"eu",3079:"de-AT",1096:"or",2077:"sv-FI",1059:"be",1031:"de",1123:"ps",1053:"sv",2117:"bn",5127:"de-LI",1045:"pl",1114:"syr",1093:"bn-IN",4103:"de-LU",1046:"pt",1064:"tg",8218:"bs-Cyrl",2055:"de-CH",2070:"pt-PT",2143:"tzm",5146:"bs",1032:"el",1094:"pa",1097:"ta",1150:"br",1135:"kl",1131:"qu-BO",1092:"tt",1026:"bg",1095:"gu",2155:"qu-EC",1098:"te",1027:"ca",1128:"ha",3179:"qu",1054:"th",3076:"zh-HK",1037:"he",1048:"ro",1105:"bo",5124:"zh-MO",1081:"hi",1047:"rm",1055:"tr",2052:"zh",1038:"hu",1049:"ru",1090:"tk",4100:"zh-SG",1039:"is",9275:"smn",1152:"ug",1028:"zh-TW",1136:"ig",4155:"smj-NO",1058:"uk",1155:"co",1057:"id",5179:"smj",1070:"hsb",1050:"hr",1117:"iu",3131:"se-FI",1056:"ur",4122:"hr-BA",2141:"iu-Latn",1083:"se",2115:"uz-Cyrl",1029:"cs",2108:"ga",2107:"se-SE",1091:"uz",1030:"da",1076:"xh",8251:"sms",1066:"vi",1164:"prs",1077:"zu",6203:"sma-NO",1106:"cy",1125:"dv",1040:"it",7227:"sms",1160:"wo",2067:"nl-BE",2064:"it-CH",1103:"sa",1157:"sah",1043:"nl",1041:"ja",7194:"sr-Cyrl-BA",1144:"ii",3081:"en-AU",1099:"kn",3098:"sr",1130:"yo",10249:"en-BZ",1087:"kk",6170:"sr-Latn-BA",4105:"en-CA",1107:"km",2074:"sr-Latn",9225:"en-029",1158:"quc",1132:"nso"}],W=new l.Struct({platformID:l.uint16,encodingID:l.uint16,languageID:l.uint16,nameID:l.uint16,length:l.uint16,string:new l.Pointer(l.uint16,new l.String("length",(function(A){return L(A.platformID,A.encodingID,A.languageID)})),{type:"parent",relativeTo:function(A){return A.parent.stringOffset},allowNull:!1})}),K=new l.Struct({length:l.uint16,tag:new l.Pointer(l.uint16,new l.String("length","utf16be"),{type:"parent",relativeTo:function(A){return A.stringOffset}})}),V=new l.VersionedStruct(l.uint16,{0:{count:l.uint16,stringOffset:l.uint16,records:new l.Array(W,"count")},1:{count:l.uint16,stringOffset:l.uint16,records:new l.Array(W,"count"),langTagCount:l.uint16,langTags:new l.Array(K,"langTagCount")}}),X=["copyright","fontFamily","fontSubfamily","uniqueSubfamily","fullName","version","postscriptName","trademark","manufacturer","designer","description","vendorURL","designerURL","license","licenseURL",null,"preferredFamily","preferredSubfamily","compatibleFull","sampleText","postscriptCIDFontName","wwsFamilyName","wwsSubfamilyName"];V.process=function(A){for(var t,e={},n=c(this.records);!(t=n()).done;){var r=t.value,i=O[r.platformID][r.languageID];null==i&&null!=this.langTags&&r.languageID>=32768&&(i=this.langTags[r.languageID-32768].tag),null==i&&(i=r.platformID+"-"+r.languageID);var o=r.nameID>=256?"fontFeatures":X[r.nameID]||r.nameID;null==e[o]&&(e[o]={});var s=e[o];r.nameID>=256&&(s=s[r.nameID]||(s[r.nameID]={})),"string"!=typeof r.string&&"string"==typeof s[i]||(s[i]=r.string)}this.records=e},V.preEncode=function(){if(!Array.isArray(this.records)){this.version=0;var A=[];for(var t in this.records){var e=this.records[t];"fontFeatures"!==t&&(A.push({platformID:3,encodingID:1,languageID:1033,nameID:X.indexOf(t),length:r.byteLength(e.en,"utf16le"),string:e.en}),"postscriptName"===t&&A.push({platformID:1,encodingID:0,languageID:0,nameID:X.indexOf(t),length:e.en.length,string:e.en}))}this.records=A,this.count=A.length,this.stringOffset=V.size(this,null,!1)}};var Z=new l.VersionedStruct(l.uint16,{header:{xAvgCharWidth:l.int16,usWeightClass:l.uint16,usWidthClass:l.uint16,fsType:new l.Bitfield(l.uint16,[null,"noEmbedding","viewOnly","editable",null,null,null,null,"noSubsetting","bitmapOnly"]),ySubscriptXSize:l.int16,ySubscriptYSize:l.int16,ySubscriptXOffset:l.int16,ySubscriptYOffset:l.int16,ySuperscriptXSize:l.int16,ySuperscriptYSize:l.int16,ySuperscriptXOffset:l.int16,ySuperscriptYOffset:l.int16,yStrikeoutSize:l.int16,yStrikeoutPosition:l.int16,sFamilyClass:l.int16,panose:new l.Array(l.uint8,10),ulCharRange:new l.Array(l.uint32,4),vendorID:new l.String(4),fsSelection:new l.Bitfield(l.uint16,["italic","underscore","negative","outlined","strikeout","bold","regular","useTypoMetrics","wws","oblique"]),usFirstCharIndex:l.uint16,usLastCharIndex:l.uint16},0:{},1:{typoAscender:l.int16,typoDescender:l.int16,typoLineGap:l.int16,winAscent:l.uint16,winDescent:l.uint16,codePageRange:new l.Array(l.uint32,2)},2:{typoAscender:l.int16,typoDescender:l.int16,typoLineGap:l.int16,winAscent:l.uint16,winDescent:l.uint16,codePageRange:new l.Array(l.uint32,2),xHeight:l.int16,capHeight:l.int16,defaultChar:l.uint16,breakChar:l.uint16,maxContent:l.uint16},5:{typoAscender:l.int16,typoDescender:l.int16,typoLineGap:l.int16,winAscent:l.uint16,winDescent:l.uint16,codePageRange:new l.Array(l.uint32,2),xHeight:l.int16,capHeight:l.int16,defaultChar:l.uint16,breakChar:l.uint16,maxContent:l.uint16,usLowerOpticalPointSize:l.uint16,usUpperOpticalPointSize:l.uint16}}),_=Z.versions;_[3]=_[4]=_[2];var q=new l.VersionedStruct(l.fixed32,{header:{italicAngle:l.fixed32,underlinePosition:l.int16,underlineThickness:l.int16,isFixedPitch:l.uint32,minMemType42:l.uint32,maxMemType42:l.uint32,minMemType1:l.uint32,maxMemType1:l.uint32},1:{},2:{numberOfGlyphs:l.uint16,glyphNameIndex:new l.Array(l.uint16,"numberOfGlyphs"),names:new l.Array(new l.String(l.uint8))},2.5:{numberOfGlyphs:l.uint16,offsets:new l.Array(l.uint8,"numberOfGlyphs")},3:{},4:{map:new l.Array(l.uint32,(function(A){return A.parent.maxp.numGlyphs}))}}),$=new l.Struct({controlValues:new l.Array(l.int16)}),AA=new l.Struct({instructions:new l.Array(l.uint8)}),tA=new l.VersionedStruct("head.indexToLocFormat",{0:{offsets:new l.Array(l.uint16)},1:{offsets:new l.Array(l.uint32)}});tA.process=function(){if(0===this.version)for(var A=0;A<this.offsets.length;A++)this.offsets[A]<<=1},tA.preEncode=function(){if(0===this.version)for(var A=0;A<this.offsets.length;A++)this.offsets[A]>>>=1};var eA=new l.Struct({controlValueProgram:new l.Array(l.uint8)}),nA=new l.Array(new l.Buffer),rA=function(){function A(A){this.type=A}var t=A.prototype;return t.getCFFVersion=function(A){for(;A&&!A.hdrSize;)A=A.parent;return A?A.version:-1},t.decode=function(A,t){var e=this.getCFFVersion(t)>=2?A.readUInt32BE():A.readUInt16BE();if(0===e)return[];var n,r=A.readUInt8();if(1===r)n=l.uint8;else if(2===r)n=l.uint16;else if(3===r)n=l.uint24;else{if(4!==r)throw new Error("Bad offset size in CFFIndex: ".concat(r," ").concat(A.pos));n=l.uint32}for(var i=[],o=A.pos+(e+1)*r-1,s=n.decode(A),a=0;a<e;a++){var c=n.decode(A);if(null!=this.type){var B=A.pos;A.pos=o+s,t.length=c-s,i.push(this.type.decode(A,t)),A.pos=B}else i.push({offset:o+s,length:c-s});s=c}return A.pos=o+s,i},t.size=function(A,t){var e=2;if(0===A.length)return e;for(var n,r=this.type||new l.Buffer,i=1,o=0;o<A.length;o++){var s=A[o];i+=r.size(s,t)}if(i<=255)n=l.uint8;else if(i<=65535)n=l.uint16;else if(i<=16777215)n=l.uint24;else{if(!(i<=4294967295))throw new Error("Bad offset in CFFIndex");n=l.uint32}return e+=1+n.size()*(A.length+1),e+=i-1,e},t.encode=function(A,t,e){if(A.writeUInt16BE(t.length),0!==t.length){for(var n,r,i=this.type||new l.Buffer,o=[],s=1,a=c(t);!(n=a()).done;){var B=n.value,g=i.size(B,e);o.push(g),s+=g}if(s<=255)r=l.uint8;else if(s<=65535)r=l.uint16;else if(s<=16777215)r=l.uint24;else{if(!(s<=4294967295))throw new Error("Bad offset in CFFIndex");r=l.uint32}A.writeUInt8(r.size()),s=1,r.encode(A,s);for(var u=0,w=o;u<w.length;u++)s+=w[u],r.encode(A,s);for(var h,E=c(t);!(h=E()).done;){var f=h.value;i.encode(A,f,e)}}},A}(),iA=["0","1","2","3","4","5","6","7","8","9",".","E","E-",null,"-"],oA={".":10,E:11,"E-":12,"-":14},sA=function(){function A(){}return A.decode=function(A,t){if(32<=t&&t<=246)return t-139;if(247<=t&&t<=250)return 256*(t-247)+A.readUInt8()+108;if(251<=t&&t<=254)return 256*-(t-251)-A.readUInt8()-108;if(28===t)return A.readInt16BE();if(29===t)return A.readInt32BE();if(30===t){for(var e="";;){var n=A.readUInt8(),r=n>>4;if(15===r)break;e+=iA[r];var i=15&n;if(15===i)break;e+=iA[i]}return parseFloat(e)}return null},A.size=function(A){if(A.forceLarge&&(A=32768),(0|A)!==A){var t=""+A;return 1+Math.ceil((t.length+1)/2)}return-107<=A&&A<=107?1:108<=A&&A<=1131||-1131<=A&&A<=-108?2:-32768<=A&&A<=32767?3:5},A.encode=function(A,t){var e=Number(t);if(t.forceLarge)return A.writeUInt8(29),A.writeInt32BE(e);if((0|e)===e)return-107<=e&&e<=107?A.writeUInt8(e+139):108<=e&&e<=1131?(e-=108,A.writeUInt8(247+(e>>8)),A.writeUInt8(255&e)):-1131<=e&&e<=-108?(e=-e-108,A.writeUInt8(251+(e>>8)),A.writeUInt8(255&e)):-32768<=e&&e<=32767?(A.writeUInt8(28),A.writeInt16BE(e)):(A.writeUInt8(29),A.writeInt32BE(e));A.writeUInt8(30);for(var n=""+e,r=0;r<n.length;r+=2){var i=n[r],o=oA[i]||+i;if(r===n.length-1)var s=15;else{var a=n[r+1];s=oA[a]||+a}A.writeUInt8(o<<4|15&s)}return 15!==s?A.writeUInt8(240):void 0},A}(),aA=function(){function A(A){void 0===A&&(A=[]),this.ops=A,this.fields={};for(var t,e=c(A);!(t=e()).done;){var n=t.value,r=Array.isArray(n[0])?n[0][0]<<8|n[0][1]:n[0];this.fields[r]=n}}var t=A.prototype;return t.decodeOperands=function(A,t,e,n){var r=this;if(Array.isArray(A))return n.map((function(n,i){return r.decodeOperands(A[i],t,e,[n])}));if(null!=A.decode)return A.decode(t,e,n);switch(A){case"number":case"offset":case"sid":return n[0];case"boolean":return!!n[0];default:return n}},t.encodeOperands=function(A,t,e,n){var r=this;return Array.isArray(A)?n.map((function(n,i){return r.encodeOperands(A[i],t,e,n)[0]})):null!=A.encode?A.encode(t,n,e):"number"==typeof n?[n]:"boolean"==typeof n?[+n]:Array.isArray(n)?n:[n]},t.decode=function(A,t){var e=A.pos+t.length,n={},r=[];for(var i in Object.defineProperties(n,{parent:{value:t},_startOffset:{value:A.pos}}),this.fields){var o=this.fields[i];n[o[1]]=o[3]}for(;A.pos<e;){var s=A.readUInt8();if(s<28){12===s&&(s=s<<8|A.readUInt8());var a=this.fields[s];if(!a)throw new Error("Unknown operator ".concat(s));var c=this.decodeOperands(a[2],A,n,r);null!=c&&(c instanceof u.PropertyDescriptor?Object.defineProperty(n,a[1],c):n[a[1]]=c),r=[]}else r.push(sA.decode(A,s))}return n},t.size=function(A,t,e){void 0===e&&(e=!0);var n={parent:t,val:A,pointerSize:0,startOffset:t.startOffset||0},r=0;for(var i in this.fields){var o=this.fields[i],s=A[o[1]];if(null!=s&&!w(s,o[3])){for(var a,B=c(this.encodeOperands(o[2],null,n,s));!(a=B()).done;){var g=a.value;r+=sA.size(g)}r+=(Array.isArray(o[0])?o[0]:[o[0]]).length}}return e&&(r+=n.pointerSize),r},t.encode=function(A,t,e){var n={pointers:[],startOffset:A.pos,parent:e,val:t,pointerSize:0};n.pointerOffset=A.pos+this.size(t,n,!1);for(var r,i=c(this.ops);!(r=i()).done;){var o=r.value,s=t[o[1]];if(null!=s&&!w(s,o[3])){for(var a,B=c(this.encodeOperands(o[2],A,n,s));!(a=B()).done;){var g=a.value;sA.encode(A,g)}for(var l,u=c(Array.isArray(o[0])?o[0]:[o[0]]);!(l=u()).done;){var h=l.value;A.writeUInt8(h)}}}for(var E=0;E<n.pointers.length;){var f=n.pointers[E++];f.type.encode(A,f.val,f.parent)}},A}(),cA=function(A){function t(t,e){return void 0===e&&(e={}),null==e.type&&(e.type="global"),A.call(this,null,t,e)||this}s(t,A);var e=t.prototype;return e.decode=function(t,e,n){return this.offsetType={decode:function(){return n[0]}},A.prototype.decode.call(this,t,e,n)},e.encode=function(t,e,n){if(!t)return this.offsetType={size:function(){return 0}},this.size(e,n),[new BA(0)];var r=null;return this.offsetType={encode:function(A,t){return r=t}},A.prototype.encode.call(this,t,e,n),[new BA(r)]},t}(l.Pointer),BA=function(){function A(A){this.val=A,this.forceLarge=!0}return A.prototype.valueOf=function(){return this.val},A}(),gA=new aA([[6,"BlueValues","delta",null],[7,"OtherBlues","delta",null],[8,"FamilyBlues","delta",null],[9,"FamilyOtherBlues","delta",null],[[12,9],"BlueScale","number",.039625],[[12,10],"BlueShift","number",7],[[12,11],"BlueFuzz","number",1],[10,"StdHW","number",null],[11,"StdVW","number",null],[[12,12],"StemSnapH","delta",null],[[12,13],"StemSnapV","delta",null],[[12,14],"ForceBold","boolean",!1],[[12,17],"LanguageGroup","number",0],[[12,18],"ExpansionFactor","number",.06],[[12,19],"initialRandomSeed","number",0],[20,"defaultWidthX","number",0],[21,"nominalWidthX","number",0],[22,"vsindex","number",0],[23,"blend",function(){function A(){}return A.decode=function(A,t,e){for(var n=e.pop();e.length>n;)e.pop()},A}(),null],[19,"Subrs",new cA(new rA,{type:"local"}),null]]),lA=[".notdef","space","exclam","quotedbl","numbersign","dollar","percent","ampersand","quoteright","parenleft","parenright","asterisk","plus","comma","hyphen","period","slash","zero","one","two","three","four","five","six","seven","eight","nine","colon","semicolon","less","equal","greater","question","at","A","B","C","D","E","F","G","H","I","J","K","L","M","N","O","P","Q","R","S","T","U","V","W","X","Y","Z","bracketleft","backslash","bracketright","asciicircum","underscore","quoteleft","a","b","c","d","e","f","g","h","i","j","k","l","m","n","o","p","q","r","s","t","u","v","w","x","y","z","braceleft","bar","braceright","asciitilde","exclamdown","cent","sterling","fraction","yen","florin","section","currency","quotesingle","quotedblleft","guillemotleft","guilsinglleft","guilsinglright","fi","fl","endash","dagger","daggerdbl","periodcentered","paragraph","bullet","quotesinglbase","quotedblbase","quotedblright","guillemotright","ellipsis","perthousand","questiondown","grave","acute","circumflex","tilde","macron","breve","dotaccent","dieresis","ring","cedilla","hungarumlaut","ogonek","caron","emdash","AE","ordfeminine","Lslash","Oslash","OE","ordmasculine","ae","dotlessi","lslash","oslash","oe","germandbls","onesuperior","logicalnot","mu","trademark","Eth","onehalf","plusminus","Thorn","onequarter","divide","brokenbar","degree","thorn","threequarters","twosuperior","registered","minus","eth","multiply","threesuperior","copyright","Aacute","Acircumflex","Adieresis","Agrave","Aring","Atilde","Ccedilla","Eacute","Ecircumflex","Edieresis","Egrave","Iacute","Icircumflex","Idieresis","Igrave","Ntilde","Oacute","Ocircumflex","Odieresis","Ograve","Otilde","Scaron","Uacute","Ucircumflex","Udieresis","Ugrave","Yacute","Ydieresis","Zcaron","aacute","acircumflex","adieresis","agrave","aring","atilde","ccedilla","eacute","ecircumflex","edieresis","egrave","iacute","icircumflex","idieresis","igrave","ntilde","oacute","ocircumflex","odieresis","ograve","otilde","scaron","uacute","ucircumflex","udieresis","ugrave","yacute","ydieresis","zcaron","exclamsmall","Hungarumlautsmall","dollaroldstyle","dollarsuperior","ampersandsmall","Acutesmall","parenleftsuperior","parenrightsuperior","twodotenleader","onedotenleader","zerooldstyle","oneoldstyle","twooldstyle","threeoldstyle","fouroldstyle","fiveoldstyle","sixoldstyle","sevenoldstyle","eightoldstyle","nineoldstyle","commasuperior","threequartersemdash","periodsuperior","questionsmall","asuperior","bsuperior","centsuperior","dsuperior","esuperior","isuperior","lsuperior","msuperior","nsuperior","osuperior","rsuperior","ssuperior","tsuperior","ff","ffi","ffl","parenleftinferior","parenrightinferior","Circumflexsmall","hyphensuperior","Gravesmall","Asmall","Bsmall","Csmall","Dsmall","Esmall","Fsmall","Gsmall","Hsmall","Ismall","Jsmall","Ksmall","Lsmall","Msmall","Nsmall","Osmall","Psmall","Qsmall","Rsmall","Ssmall","Tsmall","Usmall","Vsmall","Wsmall","Xsmall","Ysmall","Zsmall","colonmonetary","onefitted","rupiah","Tildesmall","exclamdownsmall","centoldstyle","Lslashsmall","Scaronsmall","Zcaronsmall","Dieresissmall","Brevesmall","Caronsmall","Dotaccentsmall","Macronsmall","figuredash","hypheninferior","Ogoneksmall","Ringsmall","Cedillasmall","questiondownsmall","oneeighth","threeeighths","fiveeighths","seveneighths","onethird","twothirds","zerosuperior","foursuperior","fivesuperior","sixsuperior","sevensuperior","eightsuperior","ninesuperior","zeroinferior","oneinferior","twoinferior","threeinferior","fourinferior","fiveinferior","sixinferior","seveninferior","eightinferior","nineinferior","centinferior","dollarinferior","periodinferior","commainferior","Agravesmall","Aacutesmall","Acircumflexsmall","Atildesmall","Adieresissmall","Aringsmall","AEsmall","Ccedillasmall","Egravesmall","Eacutesmall","Ecircumflexsmall","Edieresissmall","Igravesmall","Iacutesmall","Icircumflexsmall","Idieresissmall","Ethsmall","Ntildesmall","Ogravesmall","Oacutesmall","Ocircumflexsmall","Otildesmall","Odieresissmall","OEsmall","Oslashsmall","Ugravesmall","Uacutesmall","Ucircumflexsmall","Udieresissmall","Yacutesmall","Thornsmall","Ydieresissmall","001.000","001.001","001.002","001.003","Black","Bold","Book","Light","Medium","Regular","Roman","Semibold"],uA=["","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","space","exclam","quotedbl","numbersign","dollar","percent","ampersand","quoteright","parenleft","parenright","asterisk","plus","comma","hyphen","period","slash","zero","one","two","three","four","five","six","seven","eight","nine","colon","semicolon","less","equal","greater","question","at","A","B","C","D","E","F","G","H","I","J","K","L","M","N","O","P","Q","R","S","T","U","V","W","X","Y","Z","bracketleft","backslash","bracketright","asciicircum","underscore","quoteleft","a","b","c","d","e","f","g","h","i","j","k","l","m","n","o","p","q","r","s","t","u","v","w","x","y","z","braceleft","bar","braceright","asciitilde","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","exclamdown","cent","sterling","fraction","yen","florin","section","currency","quotesingle","quotedblleft","guillemotleft","guilsinglleft","guilsinglright","fi","fl","","endash","dagger","daggerdbl","periodcentered","","paragraph","bullet","quotesinglbase","quotedblbase","quotedblright","guillemotright","ellipsis","perthousand","","questiondown","","grave","acute","circumflex","tilde","macron","breve","dotaccent","dieresis","","ring","cedilla","","hungarumlaut","ogonek","caron","emdash","","","","","","","","","","","","","","","","","AE","","ordfeminine","","","","","Lslash","Oslash","OE","ordmasculine","","","","","","ae","","","","dotlessi","","","lslash","oslash","oe","germandbls"],wA=[".notdef","space","exclam","quotedbl","numbersign","dollar","percent","ampersand","quoteright","parenleft","parenright","asterisk","plus","comma","hyphen","period","slash","zero","one","two","three","four","five","six","seven","eight","nine","colon","semicolon","less","equal","greater","question","at","A","B","C","D","E","F","G","H","I","J","K","L","M","N","O","P","Q","R","S","T","U","V","W","X","Y","Z","bracketleft","backslash","bracketright","asciicircum","underscore","quoteleft","a","b","c","d","e","f","g","h","i","j","k","l","m","n","o","p","q","r","s","t","u","v","w","x","y","z","braceleft","bar","braceright","asciitilde","exclamdown","cent","sterling","fraction","yen","florin","section","currency","quotesingle","quotedblleft","guillemotleft","guilsinglleft","guilsinglright","fi","fl","endash","dagger","daggerdbl","periodcentered","paragraph","bullet","quotesinglbase","quotedblbase","quotedblright","guillemotright","ellipsis","perthousand","questiondown","grave","acute","circumflex","tilde","macron","breve","dotaccent","dieresis","ring","cedilla","hungarumlaut","ogonek","caron","emdash","AE","ordfeminine","Lslash","Oslash","OE","ordmasculine","ae","dotlessi","lslash","oslash","oe","germandbls","onesuperior","logicalnot","mu","trademark","Eth","onehalf","plusminus","Thorn","onequarter","divide","brokenbar","degree","thorn","threequarters","twosuperior","registered","minus","eth","multiply","threesuperior","copyright","Aacute","Acircumflex","Adieresis","Agrave","Aring","Atilde","Ccedilla","Eacute","Ecircumflex","Edieresis","Egrave","Iacute","Icircumflex","Idieresis","Igrave","Ntilde","Oacute","Ocircumflex","Odieresis","Ograve","Otilde","Scaron","Uacute","Ucircumflex","Udieresis","Ugrave","Yacute","Ydieresis","Zcaron","aacute","acircumflex","adieresis","agrave","aring","atilde","ccedilla","eacute","ecircumflex","edieresis","egrave","iacute","icircumflex","idieresis","igrave","ntilde","oacute","ocircumflex","odieresis","ograve","otilde","scaron","uacute","ucircumflex","udieresis","ugrave","yacute","ydieresis","zcaron"],hA=new l.Struct({reserved:new l.Reserved(l.uint16),reqFeatureIndex:l.uint16,featureCount:l.uint16,featureIndexes:new l.Array(l.uint16,"featureCount")}),EA=new l.Struct({tag:new l.String(4),langSys:new l.Pointer(l.uint16,hA,{type:"parent"})}),fA=new l.Struct({defaultLangSys:new l.Pointer(l.uint16,hA),count:l.uint16,langSysRecords:new l.Array(EA,"count")}),QA=new l.Struct({tag:new l.String(4),script:new l.Pointer(l.uint16,fA,{type:"parent"})}),dA=new l.Array(QA,l.uint16),CA=new l.Struct({featureParams:l.uint16,lookupCount:l.uint16,lookupListIndexes:new l.Array(l.uint16,"lookupCount")}),MA=new l.Struct({tag:new l.String(4),feature:new l.Pointer(l.uint16,CA,{type:"parent"})}),IA=new l.Array(MA,l.uint16),pA=new l.Struct({markAttachmentType:l.uint8,flags:new l.Bitfield(l.uint8,["rightToLeft","ignoreBaseGlyphs","ignoreLigatures","ignoreMarks","useMarkFilteringSet"])});function DA(A){var t=new l.Struct({lookupType:l.uint16,flags:pA,subTableCount:l.uint16,subTables:new l.Array(new l.Pointer(l.uint16,A),"subTableCount"),markFilteringSet:new l.Optional(l.uint16,(function(A){return A.flags.flags.useMarkFilteringSet}))});return new l.LazyArray(new l.Pointer(l.uint16,t),l.uint16)}var yA=new l.Struct({start:l.uint16,end:l.uint16,startCoverageIndex:l.uint16}),vA=new l.VersionedStruct(l.uint16,{1:{glyphCount:l.uint16,glyphs:new l.Array(l.uint16,"glyphCount")},2:{rangeCount:l.uint16,rangeRecords:new l.Array(yA,"rangeCount")}}),mA=new l.Struct({start:l.uint16,end:l.uint16,class:l.uint16}),FA=new l.VersionedStruct(l.uint16,{1:{startGlyph:l.uint16,glyphCount:l.uint16,classValueArray:new l.Array(l.uint16,"glyphCount")},2:{classRangeCount:l.uint16,classRangeRecord:new l.Array(mA,"classRangeCount")}}),YA=new l.Struct({a:l.uint16,b:l.uint16,deltaFormat:l.uint16}),bA=new l.Struct({sequenceIndex:l.uint16,lookupListIndex:l.uint16}),zA=new l.Struct({glyphCount:l.uint16,lookupCount:l.uint16,input:new l.Array(l.uint16,(function(A){return A.glyphCount-1})),lookupRecords:new l.Array(bA,"lookupCount")}),UA=new l.Array(new l.Pointer(l.uint16,zA),l.uint16),SA=new l.Struct({glyphCount:l.uint16,lookupCount:l.uint16,classes:new l.Array(l.uint16,(function(A){return A.glyphCount-1})),lookupRecords:new l.Array(bA,"lookupCount")}),xA=new l.Array(new l.Pointer(l.uint16,SA),l.uint16),TA=new l.VersionedStruct(l.uint16,{1:{coverage:new l.Pointer(l.uint16,vA),ruleSetCount:l.uint16,ruleSets:new l.Array(new l.Pointer(l.uint16,UA),"ruleSetCount")},2:{coverage:new l.Pointer(l.uint16,vA),classDef:new l.Pointer(l.uint16,FA),classSetCnt:l.uint16,classSet:new l.Array(new l.Pointer(l.uint16,xA),"classSetCnt")},3:{glyphCount:l.uint16,lookupCount:l.uint16,coverages:new l.Array(new l.Pointer(l.uint16,vA),"glyphCount"),lookupRecords:new l.Array(bA,"lookupCount")}}),PA=new l.Struct({backtrackGlyphCount:l.uint16,backtrack:new l.Array(l.uint16,"backtrackGlyphCount"),inputGlyphCount:l.uint16,input:new l.Array(l.uint16,(function(A){return A.inputGlyphCount-1})),lookaheadGlyphCount:l.uint16,lookahead:new l.Array(l.uint16,"lookaheadGlyphCount"),lookupCount:l.uint16,lookupRecords:new l.Array(bA,"lookupCount")}),NA=new l.Array(new l.Pointer(l.uint16,PA),l.uint16),RA=new l.VersionedStruct(l.uint16,{1:{coverage:new l.Pointer(l.uint16,vA),chainCount:l.uint16,chainRuleSets:new l.Array(new l.Pointer(l.uint16,NA),"chainCount")},2:{coverage:new l.Pointer(l.uint16,vA),backtrackClassDef:new l.Pointer(l.uint16,FA),inputClassDef:new l.Pointer(l.uint16,FA),lookaheadClassDef:new l.Pointer(l.uint16,FA),chainCount:l.uint16,chainClassSet:new l.Array(new l.Pointer(l.uint16,NA),"chainCount")},3:{backtrackGlyphCount:l.uint16,backtrackCoverage:new l.Array(new l.Pointer(l.uint16,vA),"backtrackGlyphCount"),inputGlyphCount:l.uint16,inputCoverage:new l.Array(new l.Pointer(l.uint16,vA),"inputGlyphCount"),lookaheadGlyphCount:l.uint16,lookaheadCoverage:new l.Array(new l.Pointer(l.uint16,vA),"lookaheadGlyphCount"),lookupCount:l.uint16,lookupRecords:new l.Array(bA,"lookupCount")}}),GA=new l.Fixed(16,"BE",14),HA=new l.Struct({startCoord:GA,peakCoord:GA,endCoord:GA}),kA=new l.Struct({axisCount:l.uint16,regionCount:l.uint16,variationRegions:new l.Array(new l.Array(HA,"axisCount"),"regionCount")}),LA=new l.Struct({shortDeltas:new l.Array(l.int16,(function(A){return A.parent.shortDeltaCount})),regionDeltas:new l.Array(l.int8,(function(A){return A.parent.regionIndexCount-A.parent.shortDeltaCount})),deltas:function(A){return A.shortDeltas.concat(A.regionDeltas)}}),JA=new l.Struct({itemCount:l.uint16,shortDeltaCount:l.uint16,regionIndexCount:l.uint16,regionIndexes:new l.Array(l.uint16,"regionIndexCount"),deltaSets:new l.Array(LA,"itemCount")}),jA=new l.Struct({format:l.uint16,variationRegionList:new l.Pointer(l.uint32,kA),variationDataCount:l.uint16,itemVariationData:new l.Array(new l.Pointer(l.uint32,JA),"variationDataCount")}),OA=new l.VersionedStruct(l.uint16,{1:(n={axisIndex:l.uint16},n.axisIndex=l.uint16,n.filterRangeMinValue=GA,n.filterRangeMaxValue=GA,n)}),WA=new l.Struct({conditionCount:l.uint16,conditionTable:new l.Array(new l.Pointer(l.uint32,OA),"conditionCount")}),KA=new l.Struct({featureIndex:l.uint16,alternateFeatureTable:new l.Pointer(l.uint32,CA,{type:"parent"})}),VA=new l.Struct({version:l.fixed32,substitutionCount:l.uint16,substitutions:new l.Array(KA,"substitutionCount")}),XA=new l.Struct({conditionSet:new l.Pointer(l.uint32,WA,{type:"parent"}),featureTableSubstitution:new l.Pointer(l.uint32,VA,{type:"parent"})}),ZA=new l.Struct({majorVersion:l.uint16,minorVersion:l.uint16,featureVariationRecordCount:l.uint32,featureVariationRecords:new l.Array(XA,"featureVariationRecordCount")}),_A=function(){function A(A,t){this.predefinedOps=A,this.type=t}var t=A.prototype;return t.decode=function(A,t,e){return this.predefinedOps[e[0]]?this.predefinedOps[e[0]]:this.type.decode(A,t,e)},t.size=function(A,t){return this.type.size(A,t)},t.encode=function(A,t,e){var n=this.predefinedOps.indexOf(t);return-1!==n?n:this.type.encode(A,t,e)},A}(),qA=function(A){function t(){return A.call(this,"UInt8")||this}return s(t,A),t.prototype.decode=function(A){return 127&l.uint8.decode(A)},t}(l.Number),$A=new l.Struct({first:l.uint16,nLeft:l.uint8}),At=new l.Struct({first:l.uint16,nLeft:l.uint16}),tt=new _A([uA,["","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","space","exclamsmall","Hungarumlautsmall","","dollaroldstyle","dollarsuperior","ampersandsmall","Acutesmall","parenleftsuperior","parenrightsuperior","twodotenleader","onedotenleader","comma","hyphen","period","fraction","zerooldstyle","oneoldstyle","twooldstyle","threeoldstyle","fouroldstyle","fiveoldstyle","sixoldstyle","sevenoldstyle","eightoldstyle","nineoldstyle","colon","semicolon","commasuperior","threequartersemdash","periodsuperior","questionsmall","","asuperior","bsuperior","centsuperior","dsuperior","esuperior","","","isuperior","","","lsuperior","msuperior","nsuperior","osuperior","","","rsuperior","ssuperior","tsuperior","","ff","fi","fl","ffi","ffl","parenleftinferior","","parenrightinferior","Circumflexsmall","hyphensuperior","Gravesmall","Asmall","Bsmall","Csmall","Dsmall","Esmall","Fsmall","Gsmall","Hsmall","Ismall","Jsmall","Ksmall","Lsmall","Msmall","Nsmall","Osmall","Psmall","Qsmall","Rsmall","Ssmall","Tsmall","Usmall","Vsmall","Wsmall","Xsmall","Ysmall","Zsmall","colonmonetary","onefitted","rupiah","Tildesmall","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","","exclamdownsmall","centoldstyle","Lslashsmall","","","Scaronsmall","Zcaronsmall","Dieresissmall","Brevesmall","Caronsmall","","Dotaccentsmall","","","Macronsmall","","","figuredash","hypheninferior","","","Ogoneksmall","Ringsmall","Cedillasmall","","","","onequarter","onehalf","threequarters","questiondownsmall","oneeighth","threeeighths","fiveeighths","seveneighths","onethird","twothirds","","","zerosuperior","onesuperior","twosuperior","threesuperior","foursuperior","fivesuperior","sixsuperior","sevensuperior","eightsuperior","ninesuperior","zeroinferior","oneinferior","twoinferior","threeinferior","fourinferior","fiveinferior","sixinferior","seveninferior","eightinferior","nineinferior","centinferior","dollarinferior","periodinferior","commainferior","Agravesmall","Aacutesmall","Acircumflexsmall","Atildesmall","Adieresissmall","Aringsmall","AEsmall","Ccedillasmall","Egravesmall","Eacutesmall","Ecircumflexsmall","Edieresissmall","Igravesmall","Iacutesmall","Icircumflexsmall","Idieresissmall","Ethsmall","Ntildesmall","Ogravesmall","Oacutesmall","Ocircumflexsmall","Otildesmall","Odieresissmall","OEsmall","Oslashsmall","Ugravesmall","Uacutesmall","Ucircumflexsmall","Udieresissmall","Yacutesmall","Thornsmall","Ydieresissmall"]],new cA(new l.VersionedStruct(new qA,{0:{nCodes:l.uint8,codes:new l.Array(l.uint8,"nCodes")},1:{nRanges:l.uint8,ranges:new l.Array($A,"nRanges")}}),{lazy:!0})),et=function(A){function t(){return A.apply(this,arguments)||this}return s(t,A),t.prototype.decode=function(A,t){for(var e=u.resolveLength(this.length,A,t),n=0,r=[];n<e;){var i=this.type.decode(A,t);i.offset=n,n+=i.nLeft+1,r.push(i)}return r},t}(l.Array),nt=new l.VersionedStruct(l.uint8,{0:{glyphs:new l.Array(l.uint16,(function(A){return A.parent.CharStrings.length-1}))},1:{ranges:new et($A,(function(A){return A.parent.CharStrings.length-1}))},2:{ranges:new et(At,(function(A){return A.parent.CharStrings.length-1}))}}),rt=new _A([wA,[".notdef","space","exclamsmall","Hungarumlautsmall","dollaroldstyle","dollarsuperior","ampersandsmall","Acutesmall","parenleftsuperior","parenrightsuperior","twodotenleader","onedotenleader","comma","hyphen","period","fraction","zerooldstyle","oneoldstyle","twooldstyle","threeoldstyle","fouroldstyle","fiveoldstyle","sixoldstyle","sevenoldstyle","eightoldstyle","nineoldstyle","colon","semicolon","commasuperior","threequartersemdash","periodsuperior","questionsmall","asuperior","bsuperior","centsuperior","dsuperior","esuperior","isuperior","lsuperior","msuperior","nsuperior","osuperior","rsuperior","ssuperior","tsuperior","ff","fi","fl","ffi","ffl","parenleftinferior","parenrightinferior","Circumflexsmall","hyphensuperior","Gravesmall","Asmall","Bsmall","Csmall","Dsmall","Esmall","Fsmall","Gsmall","Hsmall","Ismall","Jsmall","Ksmall","Lsmall","Msmall","Nsmall","Osmall","Psmall","Qsmall","Rsmall","Ssmall","Tsmall","Usmall","Vsmall","Wsmall","Xsmall","Ysmall","Zsmall","colonmonetary","onefitted","rupiah","Tildesmall","exclamdownsmall","centoldstyle","Lslashsmall","Scaronsmall","Zcaronsmall","Dieresissmall","Brevesmall","Caronsmall","Dotaccentsmall","Macronsmall","figuredash","hypheninferior","Ogoneksmall","Ringsmall","Cedillasmall","onequarter","onehalf","threequarters","questiondownsmall","oneeighth","threeeighths","fiveeighths","seveneighths","onethird","twothirds","zerosuperior","onesuperior","twosuperior","threesuperior","foursuperior","fivesuperior","sixsuperior","sevensuperior","eightsuperior","ninesuperior","zeroinferior","oneinferior","twoinferior","threeinferior","fourinferior","fiveinferior","sixinferior","seveninferior","eightinferior","nineinferior","centinferior","dollarinferior","periodinferior","commainferior","Agravesmall","Aacutesmall","Acircumflexsmall","Atildesmall","Adieresissmall","Aringsmall","AEsmall","Ccedillasmall","Egravesmall","Eacutesmall","Ecircumflexsmall","Edieresissmall","Igravesmall","Iacutesmall","Icircumflexsmall","Idieresissmall","Ethsmall","Ntildesmall","Ogravesmall","Oacutesmall","Ocircumflexsmall","Otildesmall","Odieresissmall","OEsmall","Oslashsmall","Ugravesmall","Uacutesmall","Ucircumflexsmall","Udieresissmall","Yacutesmall","Thornsmall","Ydieresissmall"],[".notdef","space","dollaroldstyle","dollarsuperior","parenleftsuperior","parenrightsuperior","twodotenleader","onedotenleader","comma","hyphen","period","fraction","zerooldstyle","oneoldstyle","twooldstyle","threeoldstyle","fouroldstyle","fiveoldstyle","sixoldstyle","sevenoldstyle","eightoldstyle","nineoldstyle","colon","semicolon","commasuperior","threequartersemdash","periodsuperior","asuperior","bsuperior","centsuperior","dsuperior","esuperior","isuperior","lsuperior","msuperior","nsuperior","osuperior","rsuperior","ssuperior","tsuperior","ff","fi","fl","ffi","ffl","parenleftinferior","parenrightinferior","hyphensuperior","colonmonetary","onefitted","rupiah","centoldstyle","figuredash","hypheninferior","onequarter","onehalf","threequarters","oneeighth","threeeighths","fiveeighths","seveneighths","onethird","twothirds","zerosuperior","onesuperior","twosuperior","threesuperior","foursuperior","fivesuperior","sixsuperior","sevensuperior","eightsuperior","ninesuperior","zeroinferior","oneinferior","twoinferior","threeinferior","fourinferior","fiveinferior","sixinferior","seveninferior","eightinferior","nineinferior","centinferior","dollarinferior","periodinferior","commainferior"]],new cA(nt,{lazy:!0})),it=new l.Struct({first:l.uint16,fd:l.uint8}),ot=new l.Struct({first:l.uint32,fd:l.uint16}),st=new l.VersionedStruct(l.uint8,{0:{fds:new l.Array(l.uint8,(function(A){return A.parent.CharStrings.length}))},3:{nRanges:l.uint16,ranges:new l.Array(it,"nRanges"),sentinel:l.uint16},4:{nRanges:l.uint32,ranges:new l.Array(ot,"nRanges"),sentinel:l.uint32}}),at=new cA(gA),ct=function(){function A(){}var t=A.prototype;return t.decode=function(A,t,e){return t.length=e[0],at.decode(A,t,[e[1]])},t.size=function(A,t){return[gA.size(A,t,!1),at.size(A,t)[0]]},t.encode=function(A,t,e){return[gA.size(t,e,!1),at.encode(A,t,e)[0]]},A}(),Bt=new aA([[18,"Private",new ct,null],[[12,38],"FontName","sid",null],[[12,7],"FontMatrix","array",[.001,0,0,.001,0,0]],[[12,5],"PaintType","number",0]]),gt=new aA([[[12,30],"ROS",["sid","sid","number"],null],[0,"version","sid",null],[1,"Notice","sid",null],[[12,0],"Copyright","sid",null],[2,"FullName","sid",null],[3,"FamilyName","sid",null],[4,"Weight","sid",null],[[12,1],"isFixedPitch","boolean",!1],[[12,2],"ItalicAngle","number",0],[[12,3],"UnderlinePosition","number",-100],[[12,4],"UnderlineThickness","number",50],[[12,5],"PaintType","number",0],[[12,6],"CharstringType","number",2],[[12,7],"FontMatrix","array",[.001,0,0,.001,0,0]],[13,"UniqueID","number",null],[5,"FontBBox","array",[0,0,0,0]],[[12,8],"StrokeWidth","number",0],[14,"XUID","array",null],[15,"charset",rt,wA],[16,"Encoding",tt,uA],[17,"CharStrings",new cA(new rA),null],[18,"Private",new ct,null],[[12,20],"SyntheticBase","number",null],[[12,21],"PostScript","sid",null],[[12,22],"BaseFontName","sid",null],[[12,23],"BaseFontBlend","delta",null],[[12,31],"CIDFontVersion","number",0],[[12,32],"CIDFontRevision","number",0],[[12,33],"CIDFontType","number",0],[[12,34],"CIDCount","number",8720],[[12,35],"UIDBase","number",null],[[12,37],"FDSelect",new cA(st),null],[[12,36],"FDArray",new cA(new rA(Bt)),null],[[12,38],"FontName","sid",null]]),lt=new l.Struct({length:l.uint16,itemVariationStore:jA}),ut=new aA([[[12,7],"FontMatrix","array",[.001,0,0,.001,0,0]],[17,"CharStrings",new cA(new rA),null],[[12,37],"FDSelect",new cA(st),null],[[12,36],"FDArray",new cA(new rA(Bt)),null],[24,"vstore",new cA(lt),null],[25,"maxstack","number",193]]),wt=new l.VersionedStruct(l.fixed16,{1:{hdrSize:l.uint8,offSize:l.uint8,nameIndex:new rA(new l.String("length")),topDictIndex:new rA(gt),stringIndex:new rA(new l.String("length")),globalSubrIndex:new rA},2:{hdrSize:l.uint8,length:l.uint16,topDict:ut,globalSubrIndex:new rA}}),ht=function(){function A(A){this.stream=A,this.decode()}A.decode=function(t){return new A(t)};var t=A.prototype;return t.decode=function(){this.stream.pos;var A=wt.decode(this.stream);for(var t in A){var e=A[t];this[t]=e}if(this.version<2){if(1!==this.topDictIndex.length)throw new Error("Only a single font is allowed in CFF");this.topDict=this.topDictIndex[0]}return this.isCIDFont=null!=this.topDict.ROS,this},t.string=function(A){return this.version>=2?null:A<lA.length?lA[A]:this.stringIndex[A-lA.length]},t.getCharString=function(A){return this.stream.pos=this.topDict.CharStrings[A].offset,this.stream.readBuffer(this.topDict.CharStrings[A].length)},t.getGlyphName=function(A){if(this.version>=2)return null;if(this.isCIDFont)return null;var t=this.topDict.charset;if(Array.isArray(t))return t[A];if(0===A)return".notdef";switch(A-=1,t.version){case 0:return this.string(t.glyphs[A]);case 1:case 2:for(var e=0;e<t.ranges.length;e++){var n=t.ranges[e];if(n.offset<=A&&A<=n.offset+n.nLeft)return this.string(n.first+(A-n.offset))}}return null},t.fdForGlyph=function(A){if(!this.topDict.FDSelect)return null;switch(this.topDict.FDSelect.version){case 0:return this.topDict.FDSelect.fds[A];case 3:case 4:for(var t=this.topDict.FDSelect.ranges,e=0,n=t.length-1;e<=n;){var r=e+n>>1;if(A<t[r].first)n=r-1;else{if(!(r<n&&A>=t[r+1].first))return t[r].fd;e=r+1}}default:throw new Error("Unknown FDSelect version: ".concat(this.topDict.FDSelect.version))}},t.privateDictForGlyph=function(A){if(this.topDict.FDSelect){var t=this.fdForGlyph(A);return this.topDict.FDArray[t]?this.topDict.FDArray[t].Private:null}return this.version<2?this.topDict.Private:this.topDict.FDArray[0].Private},o(A,[{key:"postscriptName",get:function(){return this.version<2?this.nameIndex[0]:null}},{key:"fullName",get:function(){return this.string(this.topDict.FullName)}},{key:"familyName",get:function(){return this.string(this.topDict.FamilyName)}}]),A}(),Et=new l.Struct({glyphIndex:l.uint16,vertOriginY:l.int16}),ft=new l.Struct({majorVersion:l.uint16,minorVersion:l.uint16,defaultVertOriginY:l.int16,numVertOriginYMetrics:l.uint16,metrics:new l.Array(Et,"numVertOriginYMetrics")}),Qt=new l.Struct({height:l.uint8,width:l.uint8,horiBearingX:l.int8,horiBearingY:l.int8,horiAdvance:l.uint8,vertBearingX:l.int8,vertBearingY:l.int8,vertAdvance:l.uint8}),dt=new l.Struct({height:l.uint8,width:l.uint8,bearingX:l.int8,bearingY:l.int8,advance:l.uint8}),Ct=new l.Struct({glyph:l.uint16,xOffset:l.int8,yOffset:l.int8}),Mt=function(){},It=function(){},pt=(new l.VersionedStruct("version",{1:{metrics:dt,data:Mt},2:{metrics:dt,data:It},5:{data:It},6:{metrics:Qt,data:Mt},7:{metrics:Qt,data:It},8:{metrics:dt,pad:new l.Reserved(l.uint8),numComponents:l.uint16,components:new l.Array(Ct,"numComponents")},9:{metrics:Qt,pad:new l.Reserved(l.uint8),numComponents:l.uint16,components:new l.Array(Ct,"numComponents")},17:{metrics:dt,dataLen:l.uint32,data:new l.Buffer("dataLen")},18:{metrics:Qt,dataLen:l.uint32,data:new l.Buffer("dataLen")},19:{dataLen:l.uint32,data:new l.Buffer("dataLen")}}),new l.Struct({ascender:l.int8,descender:l.int8,widthMax:l.uint8,caretSlopeNumerator:l.int8,caretSlopeDenominator:l.int8,caretOffset:l.int8,minOriginSB:l.int8,minAdvanceSB:l.int8,maxBeforeBL:l.int8,minAfterBL:l.int8,pad:new l.Reserved(l.int8,2)})),Dt=new l.Struct({glyphCode:l.uint16,offset:l.uint16}),yt=new l.VersionedStruct(l.uint16,{header:{imageFormat:l.uint16,imageDataOffset:l.uint32},1:{offsetArray:new l.Array(l.uint32,(function(A){return A.parent.lastGlyphIndex-A.parent.firstGlyphIndex+1}))},2:{imageSize:l.uint32,bigMetrics:Qt},3:{offsetArray:new l.Array(l.uint16,(function(A){return A.parent.lastGlyphIndex-A.parent.firstGlyphIndex+1}))},4:{numGlyphs:l.uint32,glyphArray:new l.Array(Dt,(function(A){return A.numGlyphs+1}))},5:{imageSize:l.uint32,bigMetrics:Qt,numGlyphs:l.uint32,glyphCodeArray:new l.Array(l.uint16,"numGlyphs")}}),vt=new l.Struct({firstGlyphIndex:l.uint16,lastGlyphIndex:l.uint16,subtable:new l.Pointer(l.uint32,yt)}),mt=new l.Struct({indexSubTableArray:new l.Pointer(l.uint32,new l.Array(vt,1),{type:"parent"}),indexTablesSize:l.uint32,numberOfIndexSubTables:l.uint32,colorRef:l.uint32,hori:pt,vert:pt,startGlyphIndex:l.uint16,endGlyphIndex:l.uint16,ppemX:l.uint8,ppemY:l.uint8,bitDepth:l.uint8,flags:new l.Bitfield(l.uint8,["horizontal","vertical"])}),Ft=new l.Struct({version:l.uint32,numSizes:l.uint32,sizes:new l.Array(mt,"numSizes")}),Yt=new l.Struct({ppem:l.uint16,resolution:l.uint16,imageOffsets:new l.Array(new l.Pointer(l.uint32,"void"),(function(A){return A.parent.parent.maxp.numGlyphs+1}))}),bt=new l.Struct({version:l.uint16,flags:new l.Bitfield(l.uint16,["renderOutlines"]),numImgTables:l.uint32,imageTables:new l.Array(new l.Pointer(l.uint32,Yt),"numImgTables")}),zt=new l.Struct({gid:l.uint16,paletteIndex:l.uint16}),Ut=new l.Struct({gid:l.uint16,firstLayerIndex:l.uint16,numLayers:l.uint16}),St=new l.Struct({version:l.uint16,numBaseGlyphRecords:l.uint16,baseGlyphRecord:new l.Pointer(l.uint32,new l.Array(Ut,"numBaseGlyphRecords")),layerRecords:new l.Pointer(l.uint32,new l.Array(zt,"numLayerRecords"),{lazy:!0}),numLayerRecords:l.uint16}),xt=new l.Struct({blue:l.uint8,green:l.uint8,red:l.uint8,alpha:l.uint8}),Tt=new l.VersionedStruct(l.uint16,{header:{numPaletteEntries:l.uint16,numPalettes:l.uint16,numColorRecords:l.uint16,colorRecords:new l.Pointer(l.uint32,new l.Array(xt,"numColorRecords")),colorRecordIndices:new l.Array(l.uint16,"numPalettes")},0:{},1:{offsetPaletteTypeArray:new l.Pointer(l.uint32,new l.Array(l.uint32,"numPalettes")),offsetPaletteLabelArray:new l.Pointer(l.uint32,new l.Array(l.uint16,"numPalettes")),offsetPaletteEntryLabelArray:new l.Pointer(l.uint32,new l.Array(l.uint16,"numPaletteEntries"))}}),Pt=new l.VersionedStruct(l.uint16,{1:{coordinate:l.int16},2:{coordinate:l.int16,referenceGlyph:l.uint16,baseCoordPoint:l.uint16},3:{coordinate:l.int16,deviceTable:new l.Pointer(l.uint16,YA)}}),Nt=new l.Struct({defaultIndex:l.uint16,baseCoordCount:l.uint16,baseCoords:new l.Array(new l.Pointer(l.uint16,Pt),"baseCoordCount")}),Rt=new l.Struct({tag:new l.String(4),minCoord:new l.Pointer(l.uint16,Pt,{type:"parent"}),maxCoord:new l.Pointer(l.uint16,Pt,{type:"parent"})}),Gt=new l.Struct({minCoord:new l.Pointer(l.uint16,Pt),maxCoord:new l.Pointer(l.uint16,Pt),featMinMaxCount:l.uint16,featMinMaxRecords:new l.Array(Rt,"featMinMaxCount")}),Ht=new l.Struct({tag:new l.String(4),minMax:new l.Pointer(l.uint16,Gt,{type:"parent"})}),kt=new l.Struct({baseValues:new l.Pointer(l.uint16,Nt),defaultMinMax:new l.Pointer(l.uint16,Gt),baseLangSysCount:l.uint16,baseLangSysRecords:new l.Array(Ht,"baseLangSysCount")}),Lt=new l.Struct({tag:new l.String(4),script:new l.Pointer(l.uint16,kt,{type:"parent"})}),Jt=new l.Array(Lt,l.uint16),jt=new l.Array(new l.String(4),l.uint16),Ot=new l.Struct({baseTagList:new l.Pointer(l.uint16,jt),baseScriptList:new l.Pointer(l.uint16,Jt)}),Wt=new l.VersionedStruct(l.uint32,{header:{horizAxis:new l.Pointer(l.uint16,Ot),vertAxis:new l.Pointer(l.uint16,Ot)},65536:{},65537:{itemVariationStore:new l.Pointer(l.uint32,jA)}}),Kt=new l.Array(l.uint16,l.uint16),Vt=new l.Struct({coverage:new l.Pointer(l.uint16,vA),glyphCount:l.uint16,attachPoints:new l.Array(new l.Pointer(l.uint16,Kt),"glyphCount")}),Xt=new l.VersionedStruct(l.uint16,{1:{coordinate:l.int16},2:{caretValuePoint:l.uint16},3:{coordinate:l.int16,deviceTable:new l.Pointer(l.uint16,YA)}}),Zt=new l.Array(new l.Pointer(l.uint16,Xt),l.uint16),_t=new l.Struct({coverage:new l.Pointer(l.uint16,vA),ligGlyphCount:l.uint16,ligGlyphs:new l.Array(new l.Pointer(l.uint16,Zt),"ligGlyphCount")}),qt=new l.Struct({markSetTableFormat:l.uint16,markSetCount:l.uint16,coverage:new l.Array(new l.Pointer(l.uint32,vA),"markSetCount")}),$t=new l.VersionedStruct(l.uint32,{header:{glyphClassDef:new l.Pointer(l.uint16,FA),attachList:new l.Pointer(l.uint16,Vt),ligCaretList:new l.Pointer(l.uint16,_t),markAttachClassDef:new l.Pointer(l.uint16,FA)},65536:{},65538:{markGlyphSetsDef:new l.Pointer(l.uint16,qt)},65539:{markGlyphSetsDef:new l.Pointer(l.uint16,qt),itemVariationStore:new l.Pointer(l.uint32,jA)}}),Ae=new l.Bitfield(l.uint16,["xPlacement","yPlacement","xAdvance","yAdvance","xPlaDevice","yPlaDevice","xAdvDevice","yAdvDevice"]),te={xPlacement:l.int16,yPlacement:l.int16,xAdvance:l.int16,yAdvance:l.int16,xPlaDevice:new l.Pointer(l.uint16,YA,{type:"global",relativeTo:function(A){return A.rel}}),yPlaDevice:new l.Pointer(l.uint16,YA,{type:"global",relativeTo:function(A){return A.rel}}),xAdvDevice:new l.Pointer(l.uint16,YA,{type:"global",relativeTo:function(A){return A.rel}}),yAdvDevice:new l.Pointer(l.uint16,YA,{type:"global",relativeTo:function(A){return A.rel}})},ee=function(){function A(A){void 0===A&&(A="valueFormat"),this.key=A}var t=A.prototype;return t.buildStruct=function(A){for(var t=A;!t[this.key]&&t.parent;)t=t.parent;if(t[this.key]){var e={rel:function(){return t._startOffset}},n=t[this.key];for(var r in n)n[r]&&(e[r]=te[r]);return new l.Struct(e)}},t.size=function(A,t){return this.buildStruct(t).size(A,t)},t.decode=function(A,t){var e=this.buildStruct(t).decode(A,t);return delete e.rel,e},A}(),ne=new l.Struct({secondGlyph:l.uint16,value1:new ee("valueFormat1"),value2:new ee("valueFormat2")}),re=new l.Array(ne,l.uint16),ie=new l.Struct({value1:new ee("valueFormat1"),value2:new ee("valueFormat2")}),oe=new l.VersionedStruct(l.uint16,{1:{xCoordinate:l.int16,yCoordinate:l.int16},2:{xCoordinate:l.int16,yCoordinate:l.int16,anchorPoint:l.uint16},3:{xCoordinate:l.int16,yCoordinate:l.int16,xDeviceTable:new l.Pointer(l.uint16,YA),yDeviceTable:new l.Pointer(l.uint16,YA)}}),se=new l.Struct({entryAnchor:new l.Pointer(l.uint16,oe,{type:"parent"}),exitAnchor:new l.Pointer(l.uint16,oe,{type:"parent"})}),ae=new l.Struct({class:l.uint16,markAnchor:new l.Pointer(l.uint16,oe,{type:"parent"})}),ce=new l.Array(ae,l.uint16),Be=new l.Array(new l.Pointer(l.uint16,oe),(function(A){return A.parent.classCount})),ge=new l.Array(Be,l.uint16),le=new l.Array(new l.Pointer(l.uint16,oe),(function(A){return A.parent.parent.classCount})),ue=new l.Array(le,l.uint16),we=new l.Array(new l.Pointer(l.uint16,ue),l.uint16),he=new l.VersionedStruct("lookupType",{1:new l.VersionedStruct(l.uint16,{1:{coverage:new l.Pointer(l.uint16,vA),valueFormat:Ae,value:new ee},2:{coverage:new l.Pointer(l.uint16,vA),valueFormat:Ae,valueCount:l.uint16,values:new l.LazyArray(new ee,"valueCount")}}),2:new l.VersionedStruct(l.uint16,{1:{coverage:new l.Pointer(l.uint16,vA),valueFormat1:Ae,valueFormat2:Ae,pairSetCount:l.uint16,pairSets:new l.LazyArray(new l.Pointer(l.uint16,re),"pairSetCount")},2:{coverage:new l.Pointer(l.uint16,vA),valueFormat1:Ae,valueFormat2:Ae,classDef1:new l.Pointer(l.uint16,FA),classDef2:new l.Pointer(l.uint16,FA),class1Count:l.uint16,class2Count:l.uint16,classRecords:new l.LazyArray(new l.LazyArray(ie,"class2Count"),"class1Count")}}),3:{format:l.uint16,coverage:new l.Pointer(l.uint16,vA),entryExitCount:l.uint16,entryExitRecords:new l.Array(se,"entryExitCount")},4:{format:l.uint16,markCoverage:new l.Pointer(l.uint16,vA),baseCoverage:new l.Pointer(l.uint16,vA),classCount:l.uint16,markArray:new l.Pointer(l.uint16,ce),baseArray:new l.Pointer(l.uint16,ge)},5:{format:l.uint16,markCoverage:new l.Pointer(l.uint16,vA),ligatureCoverage:new l.Pointer(l.uint16,vA),classCount:l.uint16,markArray:new l.Pointer(l.uint16,ce),ligatureArray:new l.Pointer(l.uint16,we)},6:{format:l.uint16,mark1Coverage:new l.Pointer(l.uint16,vA),mark2Coverage:new l.Pointer(l.uint16,vA),classCount:l.uint16,mark1Array:new l.Pointer(l.uint16,ce),mark2Array:new l.Pointer(l.uint16,ge)},7:TA,8:RA,9:{posFormat:l.uint16,lookupType:l.uint16,extension:new l.Pointer(l.uint32,he)}});he.versions[9].extension.type=he;var Ee=new l.VersionedStruct(l.uint32,{header:{scriptList:new l.Pointer(l.uint16,dA),featureList:new l.Pointer(l.uint16,IA),lookupList:new l.Pointer(l.uint16,new DA(he))},65536:{},65537:{featureVariations:new l.Pointer(l.uint32,ZA)}}),fe=new l.Array(l.uint16,l.uint16),Qe=fe,de=new l.Struct({glyph:l.uint16,compCount:l.uint16,components:new l.Array(l.uint16,(function(A){return A.compCount-1}))}),Ce=new l.Array(new l.Pointer(l.uint16,de),l.uint16),Me=new l.VersionedStruct("lookupType",{1:new l.VersionedStruct(l.uint16,{1:{coverage:new l.Pointer(l.uint16,vA),deltaGlyphID:l.int16},2:{coverage:new l.Pointer(l.uint16,vA),glyphCount:l.uint16,substitute:new l.LazyArray(l.uint16,"glyphCount")}}),2:{substFormat:l.uint16,coverage:new l.Pointer(l.uint16,vA),count:l.uint16,sequences:new l.LazyArray(new l.Pointer(l.uint16,fe),"count")},3:{substFormat:l.uint16,coverage:new l.Pointer(l.uint16,vA),count:l.uint16,alternateSet:new l.LazyArray(new l.Pointer(l.uint16,Qe),"count")},4:{substFormat:l.uint16,coverage:new l.Pointer(l.uint16,vA),count:l.uint16,ligatureSets:new l.LazyArray(new l.Pointer(l.uint16,Ce),"count")},5:TA,6:RA,7:{substFormat:l.uint16,lookupType:l.uint16,extension:new l.Pointer(l.uint32,Me)},8:{substFormat:l.uint16,coverage:new l.Pointer(l.uint16,vA),backtrackCoverage:new l.Array(new l.Pointer(l.uint16,vA),"backtrackGlyphCount"),lookaheadGlyphCount:l.uint16,lookaheadCoverage:new l.Array(new l.Pointer(l.uint16,vA),"lookaheadGlyphCount"),glyphCount:l.uint16,substitutes:new l.Array(l.uint16,"glyphCount")}});Me.versions[7].extension.type=Me;var Ie=new l.VersionedStruct(l.uint32,{header:{scriptList:new l.Pointer(l.uint16,dA),featureList:new l.Pointer(l.uint16,IA),lookupList:new l.Pointer(l.uint16,new DA(Me))},65536:{},65537:{featureVariations:new l.Pointer(l.uint32,ZA)}}),pe=new l.Array(l.uint16,l.uint16),De=new l.Struct({shrinkageEnableGSUB:new l.Pointer(l.uint16,pe),shrinkageDisableGSUB:new l.Pointer(l.uint16,pe),shrinkageEnableGPOS:new l.Pointer(l.uint16,pe),shrinkageDisableGPOS:new l.Pointer(l.uint16,pe),shrinkageJstfMax:new l.Pointer(l.uint16,new DA(he)),extensionEnableGSUB:new l.Pointer(l.uint16,pe),extensionDisableGSUB:new l.Pointer(l.uint16,pe),extensionEnableGPOS:new l.Pointer(l.uint16,pe),extensionDisableGPOS:new l.Pointer(l.uint16,pe),extensionJstfMax:new l.Pointer(l.uint16,new DA(he))}),ye=new l.Array(new l.Pointer(l.uint16,De),l.uint16),ve=new l.Struct({tag:new l.String(4),jstfLangSys:new l.Pointer(l.uint16,ye)}),me=new l.Struct({extenderGlyphs:new l.Pointer(l.uint16,new l.Array(l.uint16,l.uint16)),defaultLangSys:new l.Pointer(l.uint16,ye),langSysCount:l.uint16,langSysRecords:new l.Array(ve,"langSysCount")}),Fe=new l.Struct({tag:new l.String(4),script:new l.Pointer(l.uint16,me,{type:"parent"})}),Ye=new l.Struct({version:l.uint32,scriptCount:l.uint16,scriptList:new l.Array(Fe,"scriptCount")}),be=function(){function A(A){this._size=A}var t=A.prototype;return t.decode=function(A,t){switch(this.size(0,t)){case 1:return A.readUInt8();case 2:return A.readUInt16BE();case 3:return A.readUInt24BE();case 4:return A.readUInt32BE()}},t.size=function(A,t){return u.resolveLength(this._size,null,t)},A}(),ze=new l.Struct({entry:new be((function(A){return 1+((48&A.parent.entryFormat)>>4)})),outerIndex:function(A){return A.entry>>1+(15&A.parent.entryFormat)},innerIndex:function(A){return A.entry&(1<<1+(15&A.parent.entryFormat))-1}}),Ue=new l.Struct({entryFormat:l.uint16,mapCount:l.uint16,mapData:new l.Array(ze,"mapCount")}),Se=new l.Struct({majorVersion:l.uint16,minorVersion:l.uint16,itemVariationStore:new l.Pointer(l.uint32,jA),advanceWidthMapping:new l.Pointer(l.uint32,Ue),LSBMapping:new l.Pointer(l.uint32,Ue),RSBMapping:new l.Pointer(l.uint32,Ue)}),xe=new l.Struct({format:l.uint32,length:l.uint32,offset:l.uint32}),Te=new l.Struct({reserved:new l.Reserved(l.uint16,2),cbSignature:l.uint32,signature:new l.Buffer("cbSignature")}),Pe=new l.Struct({ulVersion:l.uint32,usNumSigs:l.uint16,usFlag:l.uint16,signatures:new l.Array(xe,"usNumSigs"),signatureBlocks:new l.Array(Te,"usNumSigs")}),Ne=new l.Struct({rangeMaxPPEM:l.uint16,rangeGaspBehavior:new l.Bitfield(l.uint16,["grayscale","gridfit","symmetricSmoothing","symmetricGridfit"])}),Re=new l.Struct({version:l.uint16,numRanges:l.uint16,gaspRanges:new l.Array(Ne,"numRanges")}),Ge=new l.Struct({pixelSize:l.uint8,maximumWidth:l.uint8,widths:new l.Array(l.uint8,(function(A){return A.parent.parent.maxp.numGlyphs}))}),He=new l.Struct({version:l.uint16,numRecords:l.int16,sizeDeviceRecord:l.int32,records:new l.Array(Ge,"numRecords")}),ke=new l.Struct({left:l.uint16,right:l.uint16,value:l.int16}),Le=new l.Struct({firstGlyph:l.uint16,nGlyphs:l.uint16,offsets:new l.Array(l.uint16,"nGlyphs"),max:function(A){return A.offsets.length&&Math.max.apply(Math,A.offsets)}}),Je=new l.Struct({off:function(A){return A._startOffset-A.parent.parent._startOffset},len:function(A){return((A.parent.leftTable.max-A.off)/A.parent.rowWidth+1)*(A.parent.rowWidth/2)},values:new l.LazyArray(l.int16,"len")}),je=new l.VersionedStruct("format",{0:{nPairs:l.uint16,searchRange:l.uint16,entrySelector:l.uint16,rangeShift:l.uint16,pairs:new l.Array(ke,"nPairs")},2:{rowWidth:l.uint16,leftTable:new l.Pointer(l.uint16,Le,{type:"parent"}),rightTable:new l.Pointer(l.uint16,Le,{type:"parent"}),array:new l.Pointer(l.uint16,Je,{type:"parent"})},3:{glyphCount:l.uint16,kernValueCount:l.uint8,leftClassCount:l.uint8,rightClassCount:l.uint8,flags:l.uint8,kernValue:new l.Array(l.int16,"kernValueCount"),leftClass:new l.Array(l.uint8,"glyphCount"),rightClass:new l.Array(l.uint8,"glyphCount"),kernIndex:new l.Array(l.uint8,(function(A){return A.leftClassCount*A.rightClassCount}))}}),Oe=new l.VersionedStruct("version",{0:{subVersion:l.uint16,length:l.uint16,format:l.uint8,coverage:new l.Bitfield(l.uint8,["horizontal","minimum","crossStream","override"]),subtable:je,padding:new l.Reserved(l.uint8,(function(A){return A.length-A._currentOffset}))},1:{length:l.uint32,coverage:new l.Bitfield(l.uint8,[null,null,null,null,null,"variation","crossStream","vertical"]),format:l.uint8,tupleIndex:l.uint16,subtable:je,padding:new l.Reserved(l.uint8,(function(A){return A.length-A._currentOffset}))}}),We=new l.VersionedStruct(l.uint16,{0:{nTables:l.uint16,tables:new l.Array(Oe,"nTables")},1:{reserved:new l.Reserved(l.uint16),nTables:l.uint32,tables:new l.Array(Oe,"nTables")}}),Ke=new l.Struct({version:l.uint16,numGlyphs:l.uint16,yPels:new l.Array(l.uint8,"numGlyphs")}),Ve=new l.Struct({version:l.uint16,fontNumber:l.uint32,pitch:l.uint16,xHeight:l.uint16,style:l.uint16,typeFamily:l.uint16,capHeight:l.uint16,symbolSet:l.uint16,typeface:new l.String(16),characterComplement:new l.String(8),fileName:new l.String(6),strokeWeight:new l.String(1),widthType:new l.String(1),serifStyle:l.uint8,reserved:new l.Reserved(l.uint8)}),Xe=new l.Struct({bCharSet:l.uint8,xRatio:l.uint8,yStartRatio:l.uint8,yEndRatio:l.uint8}),Ze=new l.Struct({yPelHeight:l.uint16,yMax:l.int16,yMin:l.int16}),_e=new l.Struct({recs:l.uint16,startsz:l.uint8,endsz:l.uint8,entries:new l.Array(Ze,"recs")}),qe=new l.Struct({version:l.uint16,numRecs:l.uint16,numRatios:l.uint16,ratioRanges:new l.Array(Xe,"numRatios"),offsets:new l.Array(l.uint16,"numRatios"),groups:new l.Array(_e,"numRecs")}),$e=new l.Struct({version:l.uint16,ascent:l.int16,descent:l.int16,lineGap:l.int16,advanceHeightMax:l.int16,minTopSideBearing:l.int16,minBottomSideBearing:l.int16,yMaxExtent:l.int16,caretSlopeRise:l.int16,caretSlopeRun:l.int16,caretOffset:l.int16,reserved:new l.Reserved(l.int16,4),metricDataFormat:l.int16,numberOfMetrics:l.uint16}),An=new l.Struct({advance:l.uint16,bearing:l.int16}),tn=new l.Struct({metrics:new l.LazyArray(An,(function(A){return A.parent.vhea.numberOfMetrics})),bearings:new l.LazyArray(l.int16,(function(A){return A.parent.maxp.numGlyphs-A.parent.vhea.numberOfMetrics}))}),en=new l.Fixed(16,"BE",14),nn=new l.Struct({fromCoord:en,toCoord:en}),rn=new l.Struct({pairCount:l.uint16,correspondence:new l.Array(nn,"pairCount")}),on=new l.Struct({version:l.fixed32,axisCount:l.uint32,segment:new l.Array(rn,"axisCount")}),sn=function(){function A(A,t,e){this.type=A,this.stream=t,this.parent=e,this.base=this.stream.pos,this._items=[]}var t=A.prototype;return t.getItem=function(A){if(null==this._items[A]){var t=this.stream.pos;this.stream.pos=this.base+this.type.size(null,this.parent)*A,this._items[A]=this.type.decode(this.stream,this.parent),this.stream.pos=t}return this._items[A]},t.inspect=function(){return"[UnboundedArray ".concat(this.type.constructor.name,"]")},A}(),an=function(A){function t(t){return A.call(this,t,0)||this}return s(t,A),t.prototype.decode=function(A,t){return new sn(this.type,A,t)},t}(l.Array),cn=function(A){void 0===A&&(A=l.uint16),A=new(function(){function A(A){this.type=A}var t=A.prototype;return t.decode=function(A,t){return t=t.parent.parent,this.type.decode(A,t)},t.size=function(A,t){return t=t.parent.parent,this.type.size(A,t)},t.encode=function(A,t,e){return e=e.parent.parent,this.type.encode(A,t,e)},A}())(A);var t=new l.Struct({unitSize:l.uint16,nUnits:l.uint16,searchRange:l.uint16,entrySelector:l.uint16,rangeShift:l.uint16}),e=new l.Struct({lastGlyph:l.uint16,firstGlyph:l.uint16,value:A}),n=new l.Struct({lastGlyph:l.uint16,firstGlyph:l.uint16,values:new l.Pointer(l.uint16,new l.Array(A,(function(A){return A.lastGlyph-A.firstGlyph+1})),{type:"parent"})}),r=new l.Struct({glyph:l.uint16,value:A});return new l.VersionedStruct(l.uint16,{0:{values:new an(A)},2:{binarySearchHeader:t,segments:new l.Array(e,(function(A){return A.binarySearchHeader.nUnits}))},4:{binarySearchHeader:t,segments:new l.Array(n,(function(A){return A.binarySearchHeader.nUnits}))},6:{binarySearchHeader:t,segments:new l.Array(r,(function(A){return A.binarySearchHeader.nUnits}))},8:{firstGlyph:l.uint16,count:l.uint16,values:new l.Array(A,"count")}})};function Bn(A,t){void 0===A&&(A={}),void 0===t&&(t=l.uint16);var e=Object.assign({newState:l.uint16,flags:l.uint16},A),n=new l.Struct(e),r=new an(new l.Array(l.uint16,(function(A){return A.nClasses})));return new l.Struct({nClasses:l.uint32,classTable:new l.Pointer(l.uint32,new cn(t)),stateArray:new l.Pointer(l.uint32,r),entryTable:new l.Pointer(l.uint32,new an(n))})}var gn=new l.VersionedStruct("format",{0:{deltas:new l.Array(l.int16,32)},1:{deltas:new l.Array(l.int16,32),mappingData:new cn(l.uint16)},2:{standardGlyph:l.uint16,controlPoints:new l.Array(l.uint16,32)},3:{standardGlyph:l.uint16,controlPoints:new l.Array(l.uint16,32),mappingData:new cn(l.uint16)}}),ln=new l.Struct({version:l.fixed32,format:l.uint16,defaultBaseline:l.uint16,subtable:gn}),un=new l.Struct({setting:l.uint16,nameIndex:l.int16,name:function(A){return A.parent.parent.parent.name.records.fontFeatures[A.nameIndex]}}),wn=new l.Struct({feature:l.uint16,nSettings:l.uint16,settingTable:new l.Pointer(l.uint32,new l.Array(un,"nSettings"),{type:"parent"}),featureFlags:new l.Bitfield(l.uint8,[null,null,null,null,null,null,"hasDefault","exclusive"]),defaultSetting:l.uint8,nameIndex:l.int16,name:function(A){return A.parent.parent.name.records.fontFeatures[A.nameIndex]}}),hn=new l.Struct({version:l.fixed32,featureNameCount:l.uint16,reserved1:new l.Reserved(l.uint16),reserved2:new l.Reserved(l.uint32),featureNames:new l.Array(wn,"featureNameCount")}),En=new l.Struct({axisTag:new l.String(4),minValue:l.fixed32,defaultValue:l.fixed32,maxValue:l.fixed32,flags:l.uint16,nameID:l.uint16,name:function(A){return A.parent.parent.name.records.fontFeatures[A.nameID]}}),fn=new l.Struct({nameID:l.uint16,name:function(A){return A.parent.parent.name.records.fontFeatures[A.nameID]},flags:l.uint16,coord:new l.Array(l.fixed32,(function(A){return A.parent.axisCount})),postscriptNameID:new l.Optional(l.uint16,(function(A){return A.parent.instanceSize-A._currentOffset>0}))}),Qn=new l.Struct({version:l.fixed32,offsetToData:l.uint16,countSizePairs:l.uint16,axisCount:l.uint16,axisSize:l.uint16,instanceCount:l.uint16,instanceSize:l.uint16,axis:new l.Array(En,"axisCount"),instance:new l.Array(fn,"instanceCount")}),dn=new l.Fixed(16,"BE",14),Cn=function(){function A(){}return A.decode=function(A,t){return t.flags?A.readUInt32BE():2*A.readUInt16BE()},A}(),Mn=new l.Struct({version:l.uint16,reserved:new l.Reserved(l.uint16),axisCount:l.uint16,globalCoordCount:l.uint16,globalCoords:new l.Pointer(l.uint32,new l.Array(new l.Array(dn,"axisCount"),"globalCoordCount")),glyphCount:l.uint16,flags:l.uint16,offsetToData:l.uint32,offsets:new l.Array(new l.Pointer(Cn,"void",{relativeTo:function(A){return A.offsetToData},allowNull:!1}),(function(A){return A.glyphCount+1}))}),In=new l.Struct({length:l.uint16,coverage:l.uint16,subFeatureFlags:l.uint32,stateTable:new function(A,t){void 0===A&&(A={}),void 0===t&&(t=l.uint16);var e=new l.Struct({version:function(){return 8},firstGlyph:l.uint16,values:new l.Array(l.uint8,l.uint16)}),n=Object.assign({newStateOffset:l.uint16,newState:function(A){return(A.newStateOffset-(A.parent.stateArray.base-A.parent._startOffset))/A.parent.nClasses},flags:l.uint16},A),r=new l.Struct(n),i=new an(new l.Array(l.uint8,(function(A){return A.nClasses})));return new l.Struct({nClasses:l.uint16,classTable:new l.Pointer(l.uint16,e),stateArray:new l.Pointer(l.uint16,i),entryTable:new l.Pointer(l.uint16,new an(r))})}}),pn=new l.Struct({justClass:l.uint32,beforeGrowLimit:l.fixed32,beforeShrinkLimit:l.fixed32,afterGrowLimit:l.fixed32,afterShrinkLimit:l.fixed32,growFlags:l.uint16,shrinkFlags:l.uint16}),Dn=new l.Array(pn,l.uint32),yn=new l.VersionedStruct("actionType",{0:{lowerLimit:l.fixed32,upperLimit:l.fixed32,order:l.uint16,glyphs:new l.Array(l.uint16,l.uint16)},1:{addGlyph:l.uint16},2:{substThreshold:l.fixed32,addGlyph:l.uint16,substGlyph:l.uint16},3:{},4:{variationAxis:l.uint32,minimumLimit:l.fixed32,noStretchValue:l.fixed32,maximumLimit:l.fixed32},5:{flags:l.uint16,glyph:l.uint16}}),vn=new l.Struct({actionClass:l.uint16,actionType:l.uint16,actionLength:l.uint32,actionData:yn,padding:new l.Reserved(l.uint8,(function(A){return A.actionLength-A._currentOffset}))}),mn=new l.Array(vn,l.uint32),Fn=new l.Struct({lookupTable:new cn(new l.Pointer(l.uint16,mn))}),Yn=new l.Struct({classTable:new l.Pointer(l.uint16,In,{type:"parent"}),wdcOffset:l.uint16,postCompensationTable:new l.Pointer(l.uint16,Fn,{type:"parent"}),widthDeltaClusters:new cn(new l.Pointer(l.uint16,Dn,{type:"parent",relativeTo:function(A){return A.wdcOffset}}))}),bn=new l.Struct({version:l.uint32,format:l.uint16,horizontal:new l.Pointer(l.uint16,Yn),vertical:new l.Pointer(l.uint16,Yn)}),zn={action:l.uint16},Un={markIndex:l.uint16,currentIndex:l.uint16},Sn={currentInsertIndex:l.uint16,markedInsertIndex:l.uint16},xn=new l.Struct({items:new an(new l.Pointer(l.uint32,new cn))}),Tn=new l.VersionedStruct("type",{0:{stateTable:new Bn},1:{stateTable:new Bn(Un),substitutionTable:new l.Pointer(l.uint32,xn)},2:{stateTable:new Bn(zn),ligatureActions:new l.Pointer(l.uint32,new an(l.uint32)),components:new l.Pointer(l.uint32,new an(l.uint16)),ligatureList:new l.Pointer(l.uint32,new an(l.uint16))},4:{lookupTable:new cn},5:{stateTable:new Bn(Sn),insertionActions:new l.Pointer(l.uint32,new an(l.uint16))}}),Pn=new l.Struct({length:l.uint32,coverage:l.uint24,type:l.uint8,subFeatureFlags:l.uint32,table:Tn,padding:new l.Reserved(l.uint8,(function(A){return A.length-A._currentOffset}))}),Nn=new l.Struct({featureType:l.uint16,featureSetting:l.uint16,enableFlags:l.uint32,disableFlags:l.uint32}),Rn=new l.Struct({defaultFlags:l.uint32,chainLength:l.uint32,nFeatureEntries:l.uint32,nSubtables:l.uint32,features:new l.Array(Nn,"nFeatureEntries"),subtables:new l.Array(Pn,"nSubtables")}),Gn=new l.Struct({version:l.uint16,unused:new l.Reserved(l.uint16),nChains:l.uint32,chains:new l.Array(Rn,"nChains")}),Hn=new l.Struct({left:l.int16,top:l.int16,right:l.int16,bottom:l.int16}),kn=new l.Struct({version:l.fixed32,format:l.uint16,lookupTable:new cn(Hn)}),Ln={};Ln.cmap=P,Ln.head=N,Ln.hhea=R,Ln.hmtx=H,Ln.maxp=k,Ln.name=V,Ln["OS/2"]=Z,Ln.post=q,Ln.fpgm=AA,Ln.loca=tA,Ln.prep=eA,Ln["cvt "]=$,Ln.glyf=nA,Ln["CFF "]=ht,Ln.CFF2=ht,Ln.VORG=ft,Ln.EBLC=Ft,Ln.CBLC=Ln.EBLC,Ln.sbix=bt,Ln.COLR=St,Ln.CPAL=Tt,Ln.BASE=Wt,Ln.GDEF=$t,Ln.GPOS=Ee,Ln.GSUB=Ie,Ln.JSTF=Ye,Ln.HVAR=Se,Ln.DSIG=Pe,Ln.gasp=Re,Ln.hdmx=He,Ln.kern=We,Ln.LTSH=Ke,Ln.PCLT=Ve,Ln.VDMX=qe,Ln.vhea=$e,Ln.vmtx=tn,Ln.avar=on,Ln.bsln=ln,Ln.feat=hn,Ln.fvar=Qn,Ln.gvar=Mn,Ln.just=bn,Ln.morx=Gn,Ln.opbd=kn;var Jn,jn=new l.Struct({tag:new l.String(4),checkSum:l.uint32,offset:new l.Pointer(l.uint32,"void",{type:"global"}),length:l.uint32}),On=new l.Struct({tag:new l.String(4),numTables:l.uint16,searchRange:l.uint16,entrySelector:l.uint16,rangeShift:l.uint16,tables:new l.Array(jn,"numTables")});function Wn(A,t){for(var e=0,n=A.length-1;e<=n;){var r=e+n>>1,i=t(A[r]);if(i<0)n=r-1;else{if(!(i>0))return r;e=r+1}}return-1}function Kn(A,t){for(var e=[];A<t;)e.push(A++);return e}On.process=function(){for(var A,t={},e=c(this.tables);!(A=e()).done;){var n=A.value;t[n.tag]=n}this.tables=t},On.preEncode=function(A){var t=[];for(var e in this.tables){var n=this.tables[e];n&&t.push({tag:e,checkSum:0,offset:new l.VoidPointer(Ln[e],n),length:Ln[e].size(n)})}this.tag="true",this.numTables=t.length,this.tables=t;var r=Math.floor(Math.log(this.numTables)/Math.LN2),i=Math.pow(2,r);this.searchRange=16*i,this.entrySelector=Math.log(i)/Math.LN2,this.rangeShift=16*this.numTables-this.searchRange};try{var Vn=e(4914)}catch(A){}var Xn=(Jn=function(){function A(A){if(this.encoding=null,this.cmap=this.findSubtable(A,[[3,10],[0,6],[0,4],[3,1],[0,3],[0,2],[0,1],[0,0]]),!this.cmap&&Vn)for(var t,e=c(A.tables);!(t=e()).done;){var n=t.value,r=L(n.platformID,n.encodingID,n.table.language-1);Vn.encodingExists(r)&&(this.cmap=n.table,this.encoding=r)}if(!this.cmap)throw new Error("Could not find a supported cmap table");this.uvs=this.findSubtable(A,[[0,5]]),this.uvs&&14!==this.uvs.version&&(this.uvs=null)}var t=A.prototype;return t.findSubtable=function(A,t){for(var e,n=c(t);!(e=n()).done;)for(var r,i=e.value,o=i[0],s=i[1],a=c(A.tables);!(r=a()).done;){var B=r.value;if(B.platformID===o&&B.encodingID===s)return B.table}return null},t.lookup=function(A,t){if(this.encoding){var e=Vn.encode(String.fromCodePoint(A),this.encoding);A=0;for(var n=0;n<e.length;n++)A=A<<8|e[n]}else if(t){var r=this.getVariationSelector(A,t);if(r)return r}var i=this.cmap;switch(i.version){case 0:return i.codeMap.get(A)||0;case 4:for(var o=0,s=i.segCount-1;o<=s;){var a=o+s>>1;if(A<i.startCode.get(a))s=a-1;else{if(!(A>i.endCode.get(a))){var c=i.idRangeOffset.get(a),B=void 0;if(0===c)B=A+i.idDelta.get(a);else{var g=c/2+(A-i.startCode.get(a))-(i.segCount-a);0!==(B=i.glyphIndexArray.get(g)||0)&&(B+=i.idDelta.get(a))}return 65535&B}o=a+1}}return 0;case 8:throw new Error("TODO: cmap format 8");case 6:case 10:return i.glyphIndices.get(A-i.firstCode)||0;case 12:case 13:for(var l=0,u=i.nGroups-1;l<=u;){var w=l+u>>1,h=i.groups.get(w);if(A<h.startCharCode)u=w-1;else{if(!(A>h.endCharCode))return 12===i.version?h.glyphID+(A-h.startCharCode):h.glyphID;l=w+1}}return 0;case 14:throw new Error("TODO: cmap format 14");default:throw new Error("Unknown cmap format ".concat(i.version))}},t.getVariationSelector=function(A,t){if(!this.uvs)return 0;var e=this.uvs.varSelectors.toArray(),n=Wn(e,(function(A){return t-A.varSelector})),r=e[n];return-1!==n&&r.defaultUVS&&(n=Wn(r.defaultUVS,(function(t){return A<t.startUnicodeValue?-1:A>t.startUnicodeValue+t.additionalCount?1:0}))),-1!==n&&r.nonDefaultUVS&&-1!==(n=Wn(r.nonDefaultUVS,(function(t){return A-t.unicodeValue})))?r.nonDefaultUVS[n].glyphID:0},t.getCharacterSet=function(){var A=this.cmap;switch(A.version){case 0:return Kn(0,A.codeMap.length);case 4:for(var t=[],e=A.endCode.toArray(),n=0;n<e.length;n++){var r=e[n]+1,i=A.startCode.get(n);t.push.apply(t,Kn(i,r))}return t;case 8:throw new Error("TODO: cmap format 8");case 6:case 10:return Kn(A.firstCode,A.firstCode+A.glyphIndices.length);case 12:case 13:for(var o,s=[],a=c(A.groups.toArray());!(o=a()).done;){var B=o.value;s.push.apply(s,Kn(B.startCharCode,B.endCharCode+1))}return s;case 14:throw new Error("TODO: cmap format 14");default:throw new Error("Unknown cmap format ".concat(A.version))}},t.codePointsForGlyph=function(A){var t=this.cmap;switch(t.version){case 0:for(var e=[],n=0;n<256;n++)t.codeMap.get(n)===A&&e.push(n);return e;case 4:for(var r=[],i=0;i<t.segCount;i++)for(var o=t.endCode.get(i),s=t.startCode.get(i),a=t.idRangeOffset.get(i),B=t.idDelta.get(i),g=s;g<=o;g++){var l=0;if(0===a)l=g+B;else{var u=a/2+(g-s)-(t.segCount-i);0!==(l=t.glyphIndexArray.get(u)||0)&&(l+=B)}l===A&&r.push(g)}return r;case 12:for(var w,h=[],E=c(t.groups.toArray());!(w=E()).done;){var f=w.value;A>=f.glyphID&&A<=f.glyphID+(f.endCharCode-f.startCharCode)&&h.push(f.startCharCode+(A-f.glyphID))}return h;case 13:for(var Q,d=[],C=c(t.groups.toArray());!(Q=C()).done;){var M=Q.value;A===M.glyphID&&d.push.apply(d,Kn(M.startCharCode,M.endCharCode+1))}return d;default:throw new Error("Unknown cmap format ".concat(t.version))}},A}(),y(Jn.prototype,"getCharacterSet",[v],Object.getOwnPropertyDescriptor(Jn.prototype,"getCharacterSet"),Jn.prototype),y(Jn.prototype,"codePointsForGlyph",[v],Object.getOwnPropertyDescriptor(Jn.prototype,"codePointsForGlyph"),Jn.prototype),Jn),Zn=function(){function A(A){this.kern=A.kern}var t=A.prototype;return t.process=function(A,t){for(var e=0;e<A.length-1;e++){var n=A[e].id,r=A[e+1].id;t[e].xAdvance+=this.getKerning(n,r)}},t.getKerning=function(A,t){for(var e,n=0,r=c(this.kern.tables);!(e=r()).done;){var i=e.value;if(!i.coverage.crossStream){switch(i.version){case 0:if(!i.coverage.horizontal)continue;break;case 1:if(i.coverage.vertical||i.coverage.variation)continue;break;default:throw new Error("Unsupported kerning table version ".concat(i.version))}var o=0,s=i.subtable;switch(i.format){case 0:var a=Wn(s.pairs,(function(e){return A-e.left||t-e.right}));a>=0&&(o=s.pairs[a].value);break;case 2:var B,g=0;B=A>=s.leftTable.firstGlyph&&A<s.leftTable.firstGlyph+s.leftTable.nGlyphs?s.leftTable.offsets[A-s.leftTable.firstGlyph]:s.array.off,t>=s.rightTable.firstGlyph&&t<s.rightTable.firstGlyph+s.rightTable.nGlyphs&&(g=s.rightTable.offsets[t-s.rightTable.firstGlyph]);var l=(B+g-s.array.off)/2;o=s.array.values.get(l);break;case 3:if(A>=s.glyphCount||t>=s.glyphCount)return 0;o=s.kernValue[s.kernIndex[s.leftClass[A]*s.rightClassCount+s.rightClass[t]]];break;default:throw new Error("Unsupported kerning sub-table format ".concat(i.format))}i.coverage.override?n=o:n+=o}}return n},A}(),_n=function(){function A(A){this.font=A}var t=A.prototype;return t.positionGlyphs=function(A,t){for(var e=0,n=0,r=0;r<A.length;r++)A[r].isMark?n=r:(e!==n&&this.positionCluster(A,t,e,n),e=n=r);return e!==n&&this.positionCluster(A,t,e,n),t},t.positionCluster=function(A,t,e,n){var r=A[e],i=r.cbox.copy();r.codePoints.length>1&&(i.minX+=(r.codePoints.length-1)*i.width/r.codePoints.length);for(var o=-t[e].xAdvance,s=0,a=this.font.unitsPerEm/16,c=e+1;c<=n;c++){var B=A[c],g=B.cbox,l=t[c],u=this.getCombiningClass(B.codePoints[0]);if("Not_Reordered"!==u){switch(l.xOffset=l.yOffset=0,u){case"Double_Above":case"Double_Below":l.xOffset+=i.minX-g.width/2-g.minX;break;case"Attached_Below_Left":case"Below_Left":case"Above_Left":l.xOffset+=i.minX-g.minX;break;case"Attached_Above_Right":case"Below_Right":case"Above_Right":l.xOffset+=i.maxX-g.width-g.minX;break;default:l.xOffset+=i.minX+(i.width-g.width)/2-g.minX}switch(u){case"Double_Below":case"Below_Left":case"Below":case"Below_Right":case"Attached_Below_Left":case"Attached_Below":"Attached_Below_Left"!==u&&"Attached_Below"!==u||(i.minY+=a),l.yOffset=-i.minY-g.maxY,i.minY+=g.height;break;case"Double_Above":case"Above_Left":case"Above":case"Above_Right":case"Attached_Above":case"Attached_Above_Right":"Attached_Above"!==u&&"Attached_Above_Right"!==u||(i.maxY+=a),l.yOffset=i.maxY-g.minY,i.maxY+=g.height}l.xAdvance=l.yAdvance=0,l.xOffset+=o,l.yOffset+=s}else o-=l.xAdvance,s-=l.yAdvance}},t.getCombiningClass=function(A){var t=h.getCombiningClass(A);if(3584==(-256&A))if("Not_Reordered"===t)switch(A){case 3633:case 3636:case 3637:case 3638:case 3639:case 3655:case 3660:case 3645:case 3662:return"Above_Right";case 3761:case 3764:case 3765:case 3766:case 3767:case 3771:case 3788:case 3789:return"Above";case 3772:return"Below"}else if(3642===A)return"Below_Right";switch(t){case"CCC10":case"CCC11":case"CCC12":case"CCC13":case"CCC14":case"CCC15":case"CCC16":case"CCC17":case"CCC18":case"CCC20":case"CCC22":case"CCC29":case"CCC32":case"CCC118":case"CCC129":case"CCC132":return"Below";case"CCC23":return"Attached_Above";case"CCC24":case"CCC107":return"Above_Right";case"CCC25":case"CCC19":return"Above_Left";case"CCC26":case"CCC27":case"CCC28":case"CCC30":case"CCC31":case"CCC33":case"CCC34":case"CCC35":case"CCC36":case"CCC122":case"CCC130":return"Above";case"CCC21":break;case"CCC103":return"Below_Right"}return t},A}(),qn=function(){function A(A,t,e,n){void 0===A&&(A=1/0),void 0===t&&(t=1/0),void 0===e&&(e=-1/0),void 0===n&&(n=-1/0),this.minX=A,this.minY=t,this.maxX=e,this.maxY=n}var t=A.prototype;return t.addPoint=function(A,t){Math.abs(A)!==1/0&&(A<this.minX&&(this.minX=A),A>this.maxX&&(this.maxX=A)),Math.abs(t)!==1/0&&(t<this.minY&&(this.minY=t),t>this.maxY&&(this.maxY=t))},t.copy=function(){return new A(this.minX,this.minY,this.maxX,this.maxY)},o(A,[{key:"width",get:function(){return this.maxX-this.minX}},{key:"height",get:function(){return this.maxY-this.minY}}]),A}(),$n={Caucasian_Albanian:"aghb",Arabic:"arab",Imperial_Aramaic:"armi",Armenian:"armn",Avestan:"avst",Balinese:"bali",Bamum:"bamu",Bassa_Vah:"bass",Batak:"batk",Bengali:["bng2","beng"],Bopomofo:"bopo",Brahmi:"brah",Braille:"brai",Buginese:"bugi",Buhid:"buhd",Chakma:"cakm",Canadian_Aboriginal:"cans",Carian:"cari",Cham:"cham",Cherokee:"cher",Coptic:"copt",Cypriot:"cprt",Cyrillic:"cyrl",Devanagari:["dev2","deva"],Deseret:"dsrt",Duployan:"dupl",Egyptian_Hieroglyphs:"egyp",Elbasan:"elba",Ethiopic:"ethi",Georgian:"geor",Glagolitic:"glag",Gothic:"goth",Grantha:"gran",Greek:"grek",Gujarati:["gjr2","gujr"],Gurmukhi:["gur2","guru"],Hangul:"hang",Han:"hani",Hanunoo:"hano",Hebrew:"hebr",Hiragana:"hira",Pahawh_Hmong:"hmng",Katakana_Or_Hiragana:"hrkt",Old_Italic:"ital",Javanese:"java",Kayah_Li:"kali",Katakana:"kana",Kharoshthi:"khar",Khmer:"khmr",Khojki:"khoj",Kannada:["knd2","knda"],Kaithi:"kthi",Tai_Tham:"lana",Lao:"lao ",Latin:"latn",Lepcha:"lepc",Limbu:"limb",Linear_A:"lina",Linear_B:"linb",Lisu:"lisu",Lycian:"lyci",Lydian:"lydi",Mahajani:"mahj",Mandaic:"mand",Manichaean:"mani",Mende_Kikakui:"mend",Meroitic_Cursive:"merc",Meroitic_Hieroglyphs:"mero",Malayalam:["mlm2","mlym"],Modi:"modi",Mongolian:"mong",Mro:"mroo",Meetei_Mayek:"mtei",Myanmar:["mym2","mymr"],Old_North_Arabian:"narb",Nabataean:"nbat",Nko:"nko ",Ogham:"ogam",Ol_Chiki:"olck",Old_Turkic:"orkh",Oriya:["ory2","orya"],Osmanya:"osma",Palmyrene:"palm",Pau_Cin_Hau:"pauc",Old_Permic:"perm",Phags_Pa:"phag",Inscriptional_Pahlavi:"phli",Psalter_Pahlavi:"phlp",Phoenician:"phnx",Miao:"plrd",Inscriptional_Parthian:"prti",Rejang:"rjng",Runic:"runr",Samaritan:"samr",Old_South_Arabian:"sarb",Saurashtra:"saur",Shavian:"shaw",Sharada:"shrd",Siddham:"sidd",Khudawadi:"sind",Sinhala:"sinh",Sora_Sompeng:"sora",Sundanese:"sund",Syloti_Nagri:"sylo",Syriac:"syrc",Tagbanwa:"tagb",Takri:"takr",Tai_Le:"tale",New_Tai_Lue:"talu",Tamil:["tml2","taml"],Tai_Viet:"tavt",Telugu:["tel2","telu"],Tifinagh:"tfng",Tagalog:"tglg",Thaana:"thaa",Thai:"thai",Tibetan:"tibt",Tirhuta:"tirh",Ugaritic:"ugar",Vai:"vai ",Warang_Citi:"wara",Old_Persian:"xpeo",Cuneiform:"xsux",Yi:"yi  ",Inherited:"zinh",Common:"zyyy",Unknown:"zzzz"},Ar={};for(var tr in $n){var er=$n[tr];if(Array.isArray(er))for(var nr,rr=c(er);!(nr=rr()).done;){var ir=nr.value;Ar[ir]=tr}else Ar[er]=tr}var or={arab:!0,hebr:!0,syrc:!0,thaa:!0,cprt:!0,khar:!0,phnx:!0,"nko ":!0,lydi:!0,avst:!0,armi:!0,phli:!0,prti:!0,sarb:!0,orkh:!0,samr:!0,mand:!0,merc:!0,mero:!0,mani:!0,mend:!0,nbat:!0,narb:!0,palm:!0,phlp:!0};function sr(A){return or[A]?"rtl":"ltr"}for(var ar=function(){function A(A,t,e,n,r){if(this.glyphs=A,this.positions=null,this.script=e,this.language=n||null,this.direction=r||sr(e),this.features={},Array.isArray(t))for(var i,o=c(t);!(i=o()).done;){var s=i.value;this.features[s]=!0}else"object"==typeof t&&(this.features=t)}return o(A,[{key:"advanceWidth",get:function(){for(var A,t=0,e=c(this.positions);!(A=e()).done;)t+=A.value.xAdvance;return t}},{key:"advanceHeight",get:function(){for(var A,t=0,e=c(this.positions);!(A=e()).done;)t+=A.value.yAdvance;return t}},{key:"bbox",get:function(){for(var A=new qn,t=0,e=0,n=0;n<this.glyphs.length;n++){var r=this.glyphs[n],i=this.positions[n],o=r.bbox;A.addPoint(o.minX+t+i.xOffset,o.minY+e+i.yOffset),A.addPoint(o.maxX+t+i.xOffset,o.maxY+e+i.yOffset),t+=i.xAdvance,e+=i.yAdvance}return A}}]),A}(),cr=function(A,t,e,n){void 0===A&&(A=0),void 0===t&&(t=0),void 0===e&&(e=0),void 0===n&&(n=0),this.xAdvance=A,this.yAdvance=t,this.xOffset=e,this.yOffset=n},Br={allTypographicFeatures:{code:0,exclusive:!1,allTypeFeatures:0},ligatures:{code:1,exclusive:!1,requiredLigatures:0,commonLigatures:2,rareLigatures:4,rebusPictures:8,diphthongLigatures:10,squaredLigatures:12,abbrevSquaredLigatures:14,symbolLigatures:16,contextualLigatures:18,historicalLigatures:20},cursiveConnection:{code:2,exclusive:!0,unconnected:0,partiallyConnected:1,cursive:2},letterCase:{code:3,exclusive:!0},verticalSubstitution:{code:4,exclusive:!1,substituteVerticalForms:0},linguisticRearrangement:{code:5,exclusive:!1,linguisticRearrangement:0},numberSpacing:{code:6,exclusive:!0,monospacedNumbers:0,proportionalNumbers:1,thirdWidthNumbers:2,quarterWidthNumbers:3},smartSwash:{code:8,exclusive:!1,wordInitialSwashes:0,wordFinalSwashes:2,nonFinalSwashes:8},diacritics:{code:9,exclusive:!0,showDiacritics:0,hideDiacritics:1,decomposeDiacritics:2},verticalPosition:{code:10,exclusive:!0,normalPosition:0,superiors:1,inferiors:2,ordinals:3,scientificInferiors:4},fractions:{code:11,exclusive:!0,noFractions:0,verticalFractions:1,diagonalFractions:2},overlappingCharacters:{code:13,exclusive:!1,preventOverlap:0},typographicExtras:{code:14,exclusive:!1,slashedZero:4},mathematicalExtras:{code:15,exclusive:!1,mathematicalGreek:10},ornamentSets:{code:16,exclusive:!0,noOrnaments:0,dingbats:1,piCharacters:2,fleurons:3,decorativeBorders:4,internationalSymbols:5,mathSymbols:6},characterAlternatives:{code:17,exclusive:!0,noAlternates:0},designComplexity:{code:18,exclusive:!0,designLevel1:0,designLevel2:1,designLevel3:2,designLevel4:3,designLevel5:4},styleOptions:{code:19,exclusive:!0,noStyleOptions:0,displayText:1,engravedText:2,illuminatedCaps:3,titlingCaps:4,tallCaps:5},characterShape:{code:20,exclusive:!0,traditionalCharacters:0,simplifiedCharacters:1,JIS1978Characters:2,JIS1983Characters:3,JIS1990Characters:4,traditionalAltOne:5,traditionalAltTwo:6,traditionalAltThree:7,traditionalAltFour:8,traditionalAltFive:9,expertCharacters:10,JIS2004Characters:11,hojoCharacters:12,NLCCharacters:13,traditionalNamesCharacters:14},numberCase:{code:21,exclusive:!0,lowerCaseNumbers:0,upperCaseNumbers:1},textSpacing:{code:22,exclusive:!0,proportionalText:0,monospacedText:1,halfWidthText:2,thirdWidthText:3,quarterWidthText:4,altProportionalText:5,altHalfWidthText:6},transliteration:{code:23,exclusive:!0,noTransliteration:0},annotation:{code:24,exclusive:!0,noAnnotation:0,boxAnnotation:1,roundedBoxAnnotation:2,circleAnnotation:3,invertedCircleAnnotation:4,parenthesisAnnotation:5,periodAnnotation:6,romanNumeralAnnotation:7,diamondAnnotation:8,invertedBoxAnnotation:9,invertedRoundedBoxAnnotation:10},kanaSpacing:{code:25,exclusive:!0,fullWidthKana:0,proportionalKana:1},ideographicSpacing:{code:26,exclusive:!0,fullWidthIdeographs:0,proportionalIdeographs:1,halfWidthIdeographs:2},unicodeDecomposition:{code:27,exclusive:!1,canonicalComposition:0,compatibilityComposition:2,transcodingComposition:4},rubyKana:{code:28,exclusive:!1,rubyKana:2},CJKSymbolAlternatives:{code:29,exclusive:!0,noCJKSymbolAlternatives:0,CJKSymbolAltOne:1,CJKSymbolAltTwo:2,CJKSymbolAltThree:3,CJKSymbolAltFour:4,CJKSymbolAltFive:5},ideographicAlternatives:{code:30,exclusive:!0,noIdeographicAlternatives:0,ideographicAltOne:1,ideographicAltTwo:2,ideographicAltThree:3,ideographicAltFour:4,ideographicAltFive:5},CJKVerticalRomanPlacement:{code:31,exclusive:!0,CJKVerticalRomanCentered:0,CJKVerticalRomanHBaseline:1},italicCJKRoman:{code:32,exclusive:!1,CJKItalicRoman:2},caseSensitiveLayout:{code:33,exclusive:!1,caseSensitiveLayout:0,caseSensitiveSpacing:2},alternateKana:{code:34,exclusive:!1,alternateHorizKana:0,alternateVertKana:2},stylisticAlternatives:{code:35,exclusive:!1,noStylisticAlternates:0,stylisticAltOne:2,stylisticAltTwo:4,stylisticAltThree:6,stylisticAltFour:8,stylisticAltFive:10,stylisticAltSix:12,stylisticAltSeven:14,stylisticAltEight:16,stylisticAltNine:18,stylisticAltTen:20,stylisticAltEleven:22,stylisticAltTwelve:24,stylisticAltThirteen:26,stylisticAltFourteen:28,stylisticAltFifteen:30,stylisticAltSixteen:32,stylisticAltSeventeen:34,stylisticAltEighteen:36,stylisticAltNineteen:38,stylisticAltTwenty:40},contextualAlternates:{code:36,exclusive:!1,contextualAlternates:0,swashAlternates:2,contextualSwashAlternates:4},lowerCase:{code:37,exclusive:!0,defaultLowerCase:0,lowerCaseSmallCaps:1,lowerCasePetiteCaps:2},upperCase:{code:38,exclusive:!0,defaultUpperCase:0,upperCaseSmallCaps:1,upperCasePetiteCaps:2},languageTag:{code:39,exclusive:!0},CJKRomanSpacing:{code:103,exclusive:!0,halfWidthCJKRoman:0,proportionalCJKRoman:1,defaultCJKRoman:2,fullWidthCJKRoman:3}},gr=function(A,t){return[Br[A].code,Br[A][t]]},lr={rlig:gr("ligatures","requiredLigatures"),clig:gr("ligatures","contextualLigatures"),dlig:gr("ligatures","rareLigatures"),hlig:gr("ligatures","historicalLigatures"),liga:gr("ligatures","commonLigatures"),hist:gr("ligatures","historicalLigatures"),smcp:gr("lowerCase","lowerCaseSmallCaps"),pcap:gr("lowerCase","lowerCasePetiteCaps"),frac:gr("fractions","diagonalFractions"),dnom:gr("fractions","diagonalFractions"),numr:gr("fractions","diagonalFractions"),afrc:gr("fractions","verticalFractions"),case:gr("caseSensitiveLayout","caseSensitiveLayout"),ccmp:gr("unicodeDecomposition","canonicalComposition"),cpct:gr("CJKVerticalRomanPlacement","CJKVerticalRomanCentered"),valt:gr("CJKVerticalRomanPlacement","CJKVerticalRomanCentered"),swsh:gr("contextualAlternates","swashAlternates"),cswh:gr("contextualAlternates","contextualSwashAlternates"),curs:gr("cursiveConnection","cursive"),c2pc:gr("upperCase","upperCasePetiteCaps"),c2sc:gr("upperCase","upperCaseSmallCaps"),init:gr("smartSwash","wordInitialSwashes"),fin2:gr("smartSwash","wordFinalSwashes"),medi:gr("smartSwash","nonFinalSwashes"),med2:gr("smartSwash","nonFinalSwashes"),fin3:gr("smartSwash","wordFinalSwashes"),fina:gr("smartSwash","wordFinalSwashes"),pkna:gr("kanaSpacing","proportionalKana"),half:gr("textSpacing","halfWidthText"),halt:gr("textSpacing","altHalfWidthText"),hkna:gr("alternateKana","alternateHorizKana"),vkna:gr("alternateKana","alternateVertKana"),ital:gr("italicCJKRoman","CJKItalicRoman"),lnum:gr("numberCase","upperCaseNumbers"),onum:gr("numberCase","lowerCaseNumbers"),mgrk:gr("mathematicalExtras","mathematicalGreek"),calt:gr("contextualAlternates","contextualAlternates"),vrt2:gr("verticalSubstitution","substituteVerticalForms"),vert:gr("verticalSubstitution","substituteVerticalForms"),tnum:gr("numberSpacing","monospacedNumbers"),pnum:gr("numberSpacing","proportionalNumbers"),sups:gr("verticalPosition","superiors"),subs:gr("verticalPosition","inferiors"),ordn:gr("verticalPosition","ordinals"),pwid:gr("textSpacing","proportionalText"),hwid:gr("textSpacing","halfWidthText"),qwid:gr("textSpacing","quarterWidthText"),twid:gr("textSpacing","thirdWidthText"),fwid:gr("textSpacing","proportionalText"),palt:gr("textSpacing","altProportionalText"),trad:gr("characterShape","traditionalCharacters"),smpl:gr("characterShape","simplifiedCharacters"),jp78:gr("characterShape","JIS1978Characters"),jp83:gr("characterShape","JIS1983Characters"),jp90:gr("characterShape","JIS1990Characters"),jp04:gr("characterShape","JIS2004Characters"),expt:gr("characterShape","expertCharacters"),hojo:gr("characterShape","hojoCharacters"),nlck:gr("characterShape","NLCCharacters"),tnam:gr("characterShape","traditionalNamesCharacters"),ruby:gr("rubyKana","rubyKana"),titl:gr("styleOptions","titlingCaps"),zero:gr("typographicExtras","slashedZero"),ss01:gr("stylisticAlternatives","stylisticAltOne"),ss02:gr("stylisticAlternatives","stylisticAltTwo"),ss03:gr("stylisticAlternatives","stylisticAltThree"),ss04:gr("stylisticAlternatives","stylisticAltFour"),ss05:gr("stylisticAlternatives","stylisticAltFive"),ss06:gr("stylisticAlternatives","stylisticAltSix"),ss07:gr("stylisticAlternatives","stylisticAltSeven"),ss08:gr("stylisticAlternatives","stylisticAltEight"),ss09:gr("stylisticAlternatives","stylisticAltNine"),ss10:gr("stylisticAlternatives","stylisticAltTen"),ss11:gr("stylisticAlternatives","stylisticAltEleven"),ss12:gr("stylisticAlternatives","stylisticAltTwelve"),ss13:gr("stylisticAlternatives","stylisticAltThirteen"),ss14:gr("stylisticAlternatives","stylisticAltFourteen"),ss15:gr("stylisticAlternatives","stylisticAltFifteen"),ss16:gr("stylisticAlternatives","stylisticAltSixteen"),ss17:gr("stylisticAlternatives","stylisticAltSeventeen"),ss18:gr("stylisticAlternatives","stylisticAltEighteen"),ss19:gr("stylisticAlternatives","stylisticAltNineteen"),ss20:gr("stylisticAlternatives","stylisticAltTwenty")},ur=1;ur<=99;ur++)lr["cv".concat("00".concat(ur).slice(-2))]=[Br.characterAlternatives.code,ur];var wr,hr={};for(var Er in lr){var fr=lr[Er];null==hr[fr[0]]&&(hr[fr[0]]={}),hr[fr[0]][fr[1]]=Er}function Qr(A){var t=A[0],e=A[1];if(isNaN(t))var n=Br[t]&&Br[t].code;else n=t;if(isNaN(e))var r=Br[t]&&Br[t][e];else r=e;return[n,r]}var dr,Cr=(wr=function(){function A(A){this.table=A}var t=A.prototype;return t.lookup=function(A){switch(this.table.version){case 0:return this.table.values.getItem(A);case 2:case 4:for(var t=0,e=this.table.binarySearchHeader.nUnits-1;t<=e;){var n=t+e>>1;if(65535===(o=this.table.segments[n]).firstGlyph)return null;if(A<o.firstGlyph)e=n-1;else{if(!(A>o.lastGlyph))return 2===this.table.version?o.value:o.values[A-o.firstGlyph];t=n+1}}return null;case 6:for(var r=0,i=this.table.binarySearchHeader.nUnits-1;r<=i;){var o;if(n=r+i>>1,65535===(o=this.table.segments[n]).glyph)return null;if(A<o.glyph)i=n-1;else{if(!(A>o.glyph))return o.value;r=n+1}}return null;case 8:return this.table.values[A-this.table.firstGlyph];default:throw new Error("Unknown lookup table format: ".concat(this.table.version))}},t.glyphsForValue=function(A){var t=[];switch(this.table.version){case 2:case 4:for(var e,n=c(this.table.segments);!(e=n()).done;){var r=e.value;if(2===this.table.version&&r.value===A)t.push.apply(t,Kn(r.firstGlyph,r.lastGlyph+1));else for(var i=0;i<r.values.length;i++)r.values[i]===A&&t.push(r.firstGlyph+i)}break;case 6:for(var o,s=c(this.table.segments);!(o=s()).done;){var a=o.value;a.value===A&&t.push(a.glyph)}break;case 8:for(var B=0;B<this.table.values.length;B++)this.table.values[B]===A&&t.push(this.table.firstGlyph+B);break;default:throw new Error("Unknown lookup table format: ".concat(this.table.version))}return t},A}(),y(wr.prototype,"glyphsForValue",[v],Object.getOwnPropertyDescriptor(wr.prototype,"glyphsForValue"),wr.prototype),wr),Mr=function(){function A(A){this.stateTable=A,this.lookupTable=new Cr(A.classTable)}var t=A.prototype;return t.process=function(A,t,e){for(var n=0,r=t?A.length-1:0,i=t?-1:1;1===i&&r<=A.length||-1===i&&r>=-1;){var o=null,s=1,a=!0;r===A.length||-1===r?s=0:65535===(o=A[r]).id?s=2:null==(s=this.lookupTable.lookup(o.id))&&(s=1);var c=this.stateTable.stateArray.getItem(n)[s],B=this.stateTable.entryTable.getItem(c);0!==s&&2!==s&&(e(o,B,r),a=!(16384&B.flags)),n=B.newState,a&&(r+=i)}return A},t.traverse=function(A,t,e){if(void 0===t&&(t=0),void 0===e&&(e=new Set),!e.has(t)){e.add(t);for(var n=this.stateTable,r=n.nClasses,i=n.stateArray,o=n.entryTable,s=i.getItem(t),a=4;a<r;a++)for(var B,g=s[a],l=o.getItem(g),u=c(this.lookupTable.glyphsForValue(a));!(B=u()).done;){var w=B.value;A.enter&&A.enter(w,l),0!==l.newState&&this.traverse(A,l.newState,e),A.exit&&A.exit(w,l)}}},A}(),Ir=4194304,pr=(dr=function(){function A(A){this.processIndicRearragement=this.processIndicRearragement.bind(this),this.processContextualSubstitution=this.processContextualSubstitution.bind(this),this.processLigature=this.processLigature.bind(this),this.processNoncontextualSubstitutions=this.processNoncontextualSubstitutions.bind(this),this.processGlyphInsertion=this.processGlyphInsertion.bind(this),this.font=A,this.morx=A.morx,this.inputCache=null}var t=A.prototype;return t.process=function(A,t){void 0===t&&(t={});for(var e,n=c(this.morx.chains);!(e=n()).done;){for(var r,i=e.value,o=i.defaultFlags,s=c(i.features);!(r=s()).done;){var a,B=r.value;(a=t[B.featureType])&&(a[B.featureSetting]?(o&=B.disableFlags,o|=B.enableFlags):!1===a[B.featureSetting]&&(o|=~B.disableFlags,o&=~B.enableFlags))}for(var g,l=c(i.subtables);!(g=l()).done;){var u=g.value;u.subFeatureFlags&o&&this.processSubtable(u,A)}}for(var w=A.length-1;w>=0;)65535===A[w].id&&A.splice(w,1),w--;return A},t.processSubtable=function(A,t){if(this.subtable=A,this.glyphs=t,4!==this.subtable.type){this.ligatureStack=[],this.markedGlyph=null,this.firstGlyph=null,this.lastGlyph=null,this.markedIndex=null;var e=this.getStateMachine(A),n=this.getProcessor(),r=!!(this.subtable.coverage&Ir);return e.process(this.glyphs,r,n)}this.processNoncontextualSubstitutions(this.subtable,this.glyphs)},t.getStateMachine=function(A){return new Mr(A.table.stateTable)},t.getProcessor=function(){switch(this.subtable.type){case 0:return this.processIndicRearragement;case 1:return this.processContextualSubstitution;case 2:return this.processLigature;case 4:return this.processNoncontextualSubstitutions;case 5:return this.processGlyphInsertion;default:throw new Error("Invalid morx subtable type: ".concat(this.subtable.type))}},t.processIndicRearragement=function(A,t,e){32768&t.flags&&(this.firstGlyph=e),8192&t.flags&&(this.lastGlyph=e),function(A,t,e,n){switch(t){case 0:return A;case 1:return Dr(A,[e,1],[n,0]);case 2:return Dr(A,[e,0],[n,1]);case 3:return Dr(A,[e,1],[n,1]);case 4:return Dr(A,[e,2],[n,0]);case 5:return Dr(A,[e,2],[n,0],!0,!1);case 6:return Dr(A,[e,0],[n,2]);case 7:return Dr(A,[e,0],[n,2],!1,!0);case 8:return Dr(A,[e,1],[n,2]);case 9:return Dr(A,[e,1],[n,2],!1,!0);case 10:return Dr(A,[e,2],[n,1]);case 11:return Dr(A,[e,2],[n,1],!0,!1);case 12:return Dr(A,[e,2],[n,2]);case 13:return Dr(A,[e,2],[n,2],!0,!1);case 14:return Dr(A,[e,2],[n,2],!1,!0);case 15:return Dr(A,[e,2],[n,2],!0,!0);default:throw new Error("Unknown verb: ".concat(t))}}(this.glyphs,15&t.flags,this.firstGlyph,this.lastGlyph)},t.processContextualSubstitution=function(A,t,e){var n=this.subtable.table.substitutionTable.items;if(65535!==t.markIndex){var r=n.getItem(t.markIndex),i=new Cr(r);A=this.glyphs[this.markedGlyph],(o=i.lookup(A.id))&&(this.glyphs[this.markedGlyph]=this.font.getGlyph(o,A.codePoints))}if(65535!==t.currentIndex){var o,s=n.getItem(t.currentIndex),a=new Cr(s);A=this.glyphs[e],(o=a.lookup(A.id))&&(this.glyphs[e]=this.font.getGlyph(o,A.codePoints))}32768&t.flags&&(this.markedGlyph=e)},t.processLigature=function(A,t,e){if(32768&t.flags&&this.ligatureStack.push(e),8192&t.flags){for(var n,r=this.subtable.table.ligatureActions,i=this.subtable.table.components,o=this.subtable.table.ligatureList,s=t.action,a=!1,c=0,B=[],g=[];!a;){var l,u=this.ligatureStack.pop();(l=B).unshift.apply(l,this.glyphs[u].codePoints);var w=r.getItem(s++);a=!!(2147483648&w);var h=!!(1073741824&w),E=(1073741823&w)<<2>>2;if(E+=this.glyphs[u].id,c+=i.getItem(E),a||h){var f=o.getItem(c);this.glyphs[u]=this.font.getGlyph(f,B),g.push(u),c=0,B=[]}else this.glyphs[u]=this.font.getGlyph(65535)}(n=this.ligatureStack).push.apply(n,g)}},t.processNoncontextualSubstitutions=function(A,t,e){var n=new Cr(A.table.lookupTable);for(e=0;e<t.length;e++){var r=t[e];if(65535!==r.id){var i=n.lookup(r.id);i&&(t[e]=this.font.getGlyph(i,r.codePoints))}}},t._insertGlyphs=function(A,t,e,n){for(var r,i=[];e--;){var o=this.subtable.table.insertionActions.getItem(t++);i.push(this.font.getGlyph(o))}n||A++,(r=this.glyphs).splice.apply(r,[A,0].concat(i))},t.processGlyphInsertion=function(A,t,e){if(32768&t.flags&&(this.markedIndex=e),65535!==t.markedInsertIndex){var n=(31&t.flags)>>>5,r=!!(1024&t.flags);this._insertGlyphs(this.markedIndex,t.markedInsertIndex,n,r)}if(65535!==t.currentInsertIndex){var i=(992&t.flags)>>>5,o=!!(2048&t.flags);this._insertGlyphs(e,t.currentInsertIndex,i,o)}},t.getSupportedFeatures=function(){for(var A,t=[],e=c(this.morx.chains);!(A=e()).done;)for(var n,r=c(A.value.features);!(n=r()).done;){var i=n.value;t.push([i.featureType,i.featureSetting])}return t},t.generateInputs=function(A){return this.inputCache||this.generateInputCache(),this.inputCache[A]||[]},t.generateInputCache=function(){this.inputCache={};for(var A,t=c(this.morx.chains);!(A=t()).done;)for(var e,n=A.value,r=n.defaultFlags,i=c(n.subtables);!(e=i()).done;){var o=e.value;o.subFeatureFlags&r&&this.generateInputsForSubtable(o)}},t.generateInputsForSubtable=function(A){var t=this;if(2===A.type){if(A.coverage&Ir)throw new Error("Reverse subtable, not supported.");this.subtable=A,this.ligatureStack=[];var e=this.getStateMachine(A),n=this.getProcessor(),r=[],i=[];this.glyphs=[],e.traverse({enter:function(A,e){var o=t.glyphs;i.push({glyphs:o.slice(),ligatureStack:t.ligatureStack.slice()});var s=t.font.getGlyph(A);r.push(s),o.push(r[r.length-1]),n(o[o.length-1],e,o.length-1);for(var a=0,c=0,B=0;B<o.length&&a<=1;B++)65535!==o[B].id&&(a++,c=o[B].id);if(1===a){var g=r.map((function(A){return A.id})),l=t.inputCache[c];l?l.push(g):t.inputCache[c]=[g]}},exit:function(){var A=i.pop();t.glyphs=A.glyphs,t.ligatureStack=A.ligatureStack,r.pop()}})}},A}(),y(dr.prototype,"getStateMachine",[v],Object.getOwnPropertyDescriptor(dr.prototype,"getStateMachine"),dr.prototype),dr);function Dr(A,t,e,n,r){void 0===n&&(n=!1),void 0===r&&(r=!1);var i=A.splice(e[0]-(e[1]-1),e[1]);r&&i.reverse();var o=A.splice.apply(A,[t[0],t[1]].concat(i));return n&&o.reverse(),A.splice.apply(A,[e[0]-(t[1]-1),0].concat(o)),A}var yr=function(){function A(A){this.font=A,this.morxProcessor=new pr(A),this.fallbackPosition=!1}var t=A.prototype;return t.substitute=function(A){"rtl"===A.direction&&A.glyphs.reverse(),this.morxProcessor.process(A.glyphs,function(A){var t={};for(var e in A){var n;(n=lr[e])&&(null==t[n[0]]&&(t[n[0]]={}),t[n[0]][n[1]]=A[e])}return t}(A.features))},t.getAvailableFeatures=function(A,t){return function(A){var t={};if(Array.isArray(A))for(var e=0;e<A.length;e++){var n,r=Qr(A[e]);(n=hr[r[0]]&&hr[r[0]][r[1]])&&(t[n]=!0)}else if("object"==typeof A)for(var i in A){var o=A[i];for(var s in o){var a=void 0,c=Qr([i,s]);o[s]&&(a=hr[c[0]]&&hr[c[0]][c[1]])&&(t[a]=!0)}}return Object.keys(t)}(this.morxProcessor.getSupportedFeatures())},t.stringsForGlyph=function(A){for(var t,e=this.morxProcessor.generateInputs(A),n=new Set,r=c(e);!(t=r()).done;){var i=t.value;this._addStrings(i,0,n,"")}return n},t._addStrings=function(A,t,e,n){for(var r,i=c(this.font._cmapProcessor.codePointsForGlyph(A[t]));!(r=i()).done;){var o=r.value,s=n+String.fromCodePoint(o);t<A.length-1?this._addStrings(A,t+1,e,s):e.add(s)}},A}(),vr=function(){function A(A,t,e){this.font=A,this.script=t,this.direction=e,this.stages=[],this.globalFeatures={},this.allFeatures={}}var t=A.prototype;return t._addFeatures=function(A,t){for(var e,n=this.stages.length-1,r=this.stages[n],i=c(A);!(e=i()).done;){var o=e.value;null==this.allFeatures[o]&&(r.push(o),this.allFeatures[o]=n,t&&(this.globalFeatures[o]=!0))}},t.add=function(A,t){if(void 0===t&&(t=!0),0===this.stages.length&&this.stages.push([]),"string"==typeof A&&(A=[A]),Array.isArray(A))this._addFeatures(A,t);else{if("object"!=typeof A)throw new Error("Unsupported argument to ShapingPlan#add");this._addFeatures(A.global||[],!0),this._addFeatures(A.local||[],!1)}},t.addStage=function(A,t){"function"==typeof A?this.stages.push(A,[]):(this.stages.push([]),this.add(A,t))},t.setFeatureOverrides=function(A){if(Array.isArray(A))this.add(A);else if("object"==typeof A)for(var t in A)if(A[t])this.add(t);else if(null!=this.allFeatures[t]){var e=this.stages[this.allFeatures[t]];e.splice(e.indexOf(t),1),delete this.allFeatures[t],delete this.globalFeatures[t]}},t.assignGlobalFeatures=function(A){for(var t,e=c(A);!(t=e()).done;){var n=t.value;for(var r in this.globalFeatures)n.features[r]=!0}},t.process=function(A,t,e){for(var n,r=c(this.stages);!(n=r()).done;){var i=n.value;"function"==typeof i?e||i(this.font,t,this):i.length>0&&A.applyFeatures(i,t,e)}},A}(),mr=["rvrn"],Fr=["ccmp","locl","rlig","mark","mkmk"],Yr=["frac","numr","dnom"],br=["calt","clig","liga","rclt","curs","kern"],zr={ltr:["ltra","ltrm"],rtl:["rtla","rtlm"]},Ur=function(){function A(){}return A.plan=function(A,t,e){this.planPreprocessing(A),this.planFeatures(A),this.planPostprocessing(A,e),A.assignGlobalFeatures(t),this.assignFeatures(A,t)},A.planPreprocessing=function(A){A.add({global:[].concat(mr,zr[A.direction]),local:Yr})},A.planFeatures=function(A){},A.planPostprocessing=function(A,t){A.add([].concat(Fr,br)),A.setFeatureOverrides(t)},A.assignFeatures=function(A,t){for(var e=0;e<t.length;e++){var n=t[e];if(8260===n.codePoints[0]){for(var r=e,i=e+1;r>0&&h.isDigit(t[r-1].codePoints[0]);)t[r-1].features.numr=!0,t[r-1].features.frac=!0,r--;for(;i<t.length&&h.isDigit(t[i].codePoints[0]);)t[i].features.dnom=!0,t[i].features.frac=!0,i++;n.features.frac=!0,e=i-1}}},A}();D(Ur,"zeroMarkWidths","AFTER_GPOS");var Sr=new E(r("APABAAAAAAAAOAAAAf0BAv7tmi1MxDAUx7vtvjhAgcDgkEgEAnmXEBIMCYaEcygEiqBQ4FAkCE4ikUgMiiBJSAgSiUQSDMn9L9eSl6bddddug9t7yS/trevre+3r27pcNxZiG+yCfdCVv/9LeQxOwRm4AJegD27ALbgD9+ABPJF+z+BN/h7yDj5k/VOWX6SdmU5+wLWknggxDxaS8u0qiiX4uiz9XamQ3wzDMAzDMAzDMAzDVI/h959V/v7BMAzDMAzDMLlyNTNiMSdewVxbiA44B4/guz1qW58VYlMI0WsJ0W+N6kXw0spvPtdwhtkwnGM6uLaV4Xyzg3v3PM9DPfQ/sOg4xPWjipy31P8LTqbU304c/cLCUmWJLNB2Uz2U1KTeRKNmKHVMfbJC+/0loTZRH/W5cvEvBJPMbREkWt3FD1NcqXZBSpuE2Ad0PBehPtNrPtIEdYP+hiRt/V1jIiE69X4NT/uVZI3PUHE9bm5M7ePGdZWy951v7Nn6j8v1WWKP3mt6ttnsigx6VN7Vc0VomSSGqW2mGNP1muZPl7LfjNUaKNFtDGVf2fvE9O7VlBS5j333c5p/eeoOqcs1R/hIqDWLJ7TTlksirVT1SI7l8k4Yp+g3jafGcrU1RM6l9th80XOpnlN97bDNY4i4s61B0Si/ipa0uHMl6zqEjlFfCZm/TM8KmzQDjmuTAQ==","base64")),xr=["isol","fina","fin2","fin3","medi","med2","init"],Tr="isol",Pr="fina",Nr="fin2",Rr="medi",Gr="med2",Hr="init",kr=null,Lr=[[[kr,kr,0],[kr,Tr,2],[kr,Tr,1],[kr,Tr,2],[kr,Tr,1],[kr,Tr,6]],[[kr,kr,0],[kr,Tr,2],[kr,Tr,1],[kr,Tr,2],[kr,Nr,5],[kr,Tr,6]],[[kr,kr,0],[kr,Tr,2],[Hr,Pr,1],[Hr,Pr,3],[Hr,Pr,4],[Hr,Pr,6]],[[kr,kr,0],[kr,Tr,2],[Rr,Pr,1],[Rr,Pr,3],[Rr,Pr,4],[Rr,Pr,6]],[[kr,kr,0],[kr,Tr,2],[Gr,Tr,1],[Gr,Tr,2],[Gr,Nr,5],[Gr,Tr,6]],[[kr,kr,0],[kr,Tr,2],[Tr,Tr,1],[Tr,Tr,2],[Tr,Nr,5],[Tr,Tr,6]],[[kr,kr,0],[kr,Tr,2],[kr,Tr,1],[kr,Tr,2],[kr,"fin3",5],[kr,Tr,6]]],Jr=function(A){function t(){return A.apply(this,arguments)||this}return s(t,A),t.planFeatures=function(A){A.add(["ccmp","locl"]);for(var t=0;t<xr.length;t++){var e=xr[t];A.addStage(e,!1)}A.addStage("mset")},t.assignFeatures=function(t,e){A.assignFeatures.call(this,t,e);for(var n=-1,r=0,i=[],o=0;o<e.length;o++){var s,a,c=jr((u=e[o]).codePoints[0]);if(6!==c){var B=Lr[r][c];a=B[0],s=B[1],r=B[2],a!==kr&&-1!==n&&(i[n]=a),i[o]=s,n=o}else i[o]=kr}for(var g=0;g<e.length;g++){var l,u=e[g];(l=i[g])&&(u.features[l]=!0)}},t}(Ur);function jr(A){var t=Sr.get(A);if(t)return t-1;var e=h.getCategory(A);return"Mn"===e||"Me"===e||"Cf"===e?6:0}var Or=function(){function A(A,t){this.glyphs=A,this.reset(t)}var t=A.prototype;return t.reset=function(A,t){void 0===A&&(A={}),void 0===t&&(t=0),this.options=A,this.flags=A.flags||{},this.markAttachmentType=A.markAttachmentType||0,this.index=t},t.shouldIgnore=function(A){return this.flags.ignoreMarks&&A.isMark||this.flags.ignoreBaseGlyphs&&A.isBase||this.flags.ignoreLigatures&&A.isLigature||this.markAttachmentType&&A.isMark&&A.markAttachmentType!==this.markAttachmentType},t.move=function(A){for(this.index+=A;0<=this.index&&this.index<this.glyphs.length&&this.shouldIgnore(this.glyphs[this.index]);)this.index+=A;return 0>this.index||this.index>=this.glyphs.length?null:this.glyphs[this.index]},t.next=function(){return this.move(1)},t.prev=function(){return this.move(-1)},t.peek=function(A){void 0===A&&(A=1);var t=this.index,e=this.increment(A);return this.index=t,e},t.peekIndex=function(A){void 0===A&&(A=1);var t=this.index;this.increment(A);var e=this.index;return this.index=t,e},t.increment=function(A){void 0===A&&(A=1);var t=A<0?-1:1;for(A=Math.abs(A);A--;)this.move(t);return this.glyphs[this.index]},o(A,[{key:"cur",get:function(){return this.glyphs[this.index]||null}}]),A}(),Wr=["DFLT","dflt","latn"],Kr=function(){function A(A,t){this.font=A,this.table=t,this.script=null,this.scriptTag=null,this.language=null,this.languageTag=null,this.features={},this.lookups={},this.variationsIndex=A._variationProcessor?this.findVariationsIndex(A._variationProcessor.normalizedCoords):-1,this.selectScript(),this.glyphs=[],this.positions=[],this.ligatureID=1,this.currentFeature=null}var t=A.prototype;return t.findScript=function(A){if(null==this.table.scriptList)return null;Array.isArray(A)||(A=[A]);for(var t,e=c(A);!(t=e()).done;)for(var n,r=t.value,i=c(this.table.scriptList);!(n=i()).done;){var o=n.value;if(o.tag===r)return o}return null},t.selectScript=function(A,t,e){var n,r=!1;if(!this.script||A!==this.scriptTag){if((n=this.findScript(A))||(n=this.findScript(Wr)),!n)return this.scriptTag;this.scriptTag=n.tag,this.script=n.script,this.language=null,this.languageTag=null,r=!0}if(e&&e===this.direction||(this.direction=e||sr(A)),t&&t.length<4&&(t+=" ".repeat(4-t.length)),!t||t!==this.languageTag){this.language=null;for(var i,o=c(this.script.langSysRecords);!(i=o()).done;){var s=i.value;if(s.tag===t){this.language=s.langSys,this.languageTag=s.tag;break}}this.language||(this.language=this.script.defaultLangSys,this.languageTag=null),r=!0}if(r&&(this.features={},this.language))for(var a,B=c(this.language.featureIndexes);!(a=B()).done;){var g=a.value,l=this.table.featureList[g],u=this.substituteFeatureForVariations(g);this.features[l.tag]=u||l.feature}return this.scriptTag},t.lookupsForFeatures=function(A,t){void 0===A&&(A=[]);for(var e,n=[],r=c(A);!(e=r()).done;){var i=e.value,o=this.features[i];if(o)for(var s,a=c(o.lookupListIndexes);!(s=a()).done;){var B=s.value;t&&-1!==t.indexOf(B)||n.push({feature:i,index:B,lookup:this.table.lookupList.get(B)})}}return n.sort((function(A,t){return A.index-t.index})),n},t.substituteFeatureForVariations=function(A){if(-1===this.variationsIndex)return null;for(var t,e=c(this.table.featureVariations.featureVariationRecords[this.variationsIndex].featureTableSubstitution.substitutions);!(t=e()).done;){var n=t.value;if(n.featureIndex===A)return n.alternateFeatureTable}return null},t.findVariationsIndex=function(A){var t=this.table.featureVariations;if(!t)return-1;for(var e=t.featureVariationRecords,n=0;n<e.length;n++){var r=e[n].conditionSet.conditionTable;if(this.variationConditionsMatch(r,A))return n}return-1},t.variationConditionsMatch=function(A,t){return A.every((function(A){var e=A.axisIndex<t.length?t[A.axisIndex]:0;return A.filterRangeMinValue<=e&&e<=A.filterRangeMaxValue}))},t.applyFeatures=function(A,t,e){var n=this.lookupsForFeatures(A);this.applyLookups(n,t,e)},t.applyLookups=function(A,t,e){this.glyphs=t,this.positions=e,this.glyphIterator=new Or(t);for(var n,r=c(A);!(n=r()).done;){var i=n.value,o=i.feature,s=i.lookup;for(this.currentFeature=o,this.glyphIterator.reset(s.flags);this.glyphIterator.index<t.length;)if(o in this.glyphIterator.cur.features){for(var a,B=c(s.subTables);!(a=B()).done;){var g=a.value;if(this.applyLookup(s.lookupType,g))break}this.glyphIterator.next()}else this.glyphIterator.next()}},t.applyLookup=function(A,t){throw new Error("applyLookup must be implemented by subclasses")},t.applyLookupList=function(A){for(var t,e=this.glyphIterator.options,n=this.glyphIterator.index,r=c(A);!(t=r()).done;){var i=t.value;this.glyphIterator.reset(e,n),this.glyphIterator.increment(i.sequenceIndex);var o=this.table.lookupList.get(i.lookupListIndex);this.glyphIterator.reset(o.flags,this.glyphIterator.index);for(var s,a=c(o.subTables);!(s=a()).done;){var B=s.value;if(this.applyLookup(o.lookupType,B))break}}return this.glyphIterator.reset(e,n),!0},t.coverageIndex=function(A,t){switch(null==t&&(t=this.glyphIterator.cur.id),A.version){case 1:return A.glyphs.indexOf(t);case 2:for(var e,n=c(A.rangeRecords);!(e=n()).done;){var r=e.value;if(r.start<=t&&t<=r.end)return r.startCoverageIndex+t-r.start}}return-1},t.match=function(A,t,e,n){for(var r=this.glyphIterator.index,i=this.glyphIterator.increment(A),o=0;o<t.length&&i&&e(t[o],i);)n&&n.push(this.glyphIterator.index),o++,i=this.glyphIterator.next();return this.glyphIterator.index=r,!(o<t.length)&&(n||!0)},t.sequenceMatches=function(A,t){return this.match(A,t,(function(A,t){return A===t.id}))},t.sequenceMatchIndices=function(A,t){var e=this;return this.match(A,t,(function(A,t){return e.currentFeature in t.features&&A===t.id}),[])},t.coverageSequenceMatches=function(A,t){var e=this;return this.match(A,t,(function(A,t){return e.coverageIndex(A,t.id)>=0}))},t.getClassID=function(A,t){switch(t.version){case 1:var e=A-t.startGlyph;if(e>=0&&e<t.classValueArray.length)return t.classValueArray[e];break;case 2:for(var n,r=c(t.classRangeRecord);!(n=r()).done;){var i=n.value;if(i.start<=A&&A<=i.end)return i.class}}return 0},t.classSequenceMatches=function(A,t,e){var n=this;return this.match(A,t,(function(A,t){return A===n.getClassID(t.id,e)}))},t.applyContext=function(A){switch(A.version){case 1:var t=this.coverageIndex(A.coverage);if(-1===t)return!1;for(var e,n=A.ruleSets[t],r=c(n);!(e=r()).done;){var i=e.value;if(this.sequenceMatches(1,i.input))return this.applyLookupList(i.lookupRecords)}break;case 2:if(-1===this.coverageIndex(A.coverage))return!1;if(-1===(t=this.getClassID(this.glyphIterator.cur.id,A.classDef)))return!1;for(var o,s=c(n=A.classSet[t]);!(o=s()).done;){var a=o.value;if(this.classSequenceMatches(1,a.classes,A.classDef))return this.applyLookupList(a.lookupRecords)}break;case 3:if(this.coverageSequenceMatches(0,A.coverages))return this.applyLookupList(A.lookupRecords)}return!1},t.applyChainingContext=function(A){switch(A.version){case 1:var t=this.coverageIndex(A.coverage);if(-1===t)return!1;for(var e,n=c(A.chainRuleSets[t]);!(e=n()).done;){var r=e.value;if(this.sequenceMatches(-r.backtrack.length,r.backtrack)&&this.sequenceMatches(1,r.input)&&this.sequenceMatches(1+r.input.length,r.lookahead))return this.applyLookupList(r.lookupRecords)}break;case 2:if(-1===this.coverageIndex(A.coverage))return!1;t=this.getClassID(this.glyphIterator.cur.id,A.inputClassDef);var i=A.chainClassSet[t];if(!i)return!1;for(var o,s=c(i);!(o=s()).done;){var a=o.value;if(this.classSequenceMatches(-a.backtrack.length,a.backtrack,A.backtrackClassDef)&&this.classSequenceMatches(1,a.input,A.inputClassDef)&&this.classSequenceMatches(1+a.input.length,a.lookahead,A.lookaheadClassDef))return this.applyLookupList(a.lookupRecords)}break;case 3:if(this.coverageSequenceMatches(-A.backtrackGlyphCount,A.backtrackCoverage)&&this.coverageSequenceMatches(0,A.inputCoverage)&&this.coverageSequenceMatches(A.inputGlyphCount,A.lookaheadCoverage))return this.applyLookupList(A.lookupRecords)}return!1},A}(),Vr=function(){function A(A,t,e,n){if(void 0===e&&(e=[]),this._font=A,this.codePoints=e,this.id=t,this.features={},Array.isArray(n))for(var r=0;r<n.length;r++){var i=n[r];this.features[i]=!0}else"object"==typeof n&&Object.assign(this.features,n);this.ligatureID=null,this.ligatureComponent=null,this.isLigated=!1,this.cursiveAttachment=null,this.markAttachment=null,this.shaperInfo=null,this.substituted=!1,this.isMultiplied=!1}return A.prototype.copy=function(){return new A(this._font,this.id,this.codePoints,this.features)},o(A,[{key:"id",get:function(){return this._id},set:function(A){this._id=A,this.substituted=!0;var t=this._font.GDEF;if(t&&t.glyphClassDef){var e=Kr.prototype.getClassID(A,t.glyphClassDef);this.isBase=1===e,this.isLigature=2===e,this.isMark=3===e,this.markAttachmentType=t.markAttachClassDef?Kr.prototype.getClassID(A,t.markAttachClassDef):0}else this.isMark=this.codePoints.length>0&&this.codePoints.every(h.isMark),this.isBase=!this.isMark,this.isLigature=this.codePoints.length>1,this.markAttachmentType=0}}]),A}(),Xr=function(A){function t(){return A.apply(this,arguments)||this}return s(t,A),t.planFeatures=function(A){A.add(["ljmo","vjmo","tjmo"],!1)},t.assignFeatures=function(A,t){for(var e=0,n=0;n<t.length;){var r,i=t[n].codePoints[0],o=Ai(i),s=ii[e][o];switch(r=s[0],e=s[1],r){case ti:A.font.hasGlyphForCodePoint(i)||(n=si(t,n,A.font));break;case ei:n=ai(t,n,A.font);break;case ni:ci(t,n,A.font);break;case ri:n=Bi(t,n,A.font)}n++}},t}(Ur);D(Xr,"zeroMarkWidths","NONE");var Zr=44032,_r=4352,qr=4449,$r=4519;function Ai(A){return function(A){return 4352<=A&&A<=4447||43360<=A&&A<=43388}(A)?1:function(A){return 4448<=A&&A<=4519||55216<=A&&A<=55238}(A)?2:function(A){return 4520<=A&&A<=4607||55243<=A&&A<=55291}(A)?3:function(A){return A-Zr<11173&&(A-Zr)%28==0}(A)?4:function(A){return Zr<=A&&A<=55204}(A)?5:function(A){return 12334<=A&&A<=12335}(A)?6:0}var ti=1,ei=2,ni=4,ri=5,ii=[[[0,0],[0,1],[0,0],[0,0],[ti,2],[ti,3],[ri,0]],[[0,0],[0,1],[ei,2],[0,0],[ti,2],[ti,3],[ri,0]],[[0,0],[0,1],[0,0],[ei,3],[ti,2],[ti,3],[ni,0]],[[0,0],[0,1],[0,0],[0,0],[ti,2],[ti,3],[ni,0]]];function oi(A,t,e){return new Vr(A,A.glyphForCodePoint(t).id,[t],e)}function si(A,t,e){var n=A[t],r=n.codePoints[0]-Zr,i=$r+r%28,o=_r+(r=r/28|0)/21|0,s=qr+r%21;if(!e.hasGlyphForCodePoint(o)||!e.hasGlyphForCodePoint(s)||i!==$r&&!e.hasGlyphForCodePoint(i))return t;var a=oi(e,o,n.features);a.features.ljmo=!0;var c=oi(e,s,n.features);c.features.vjmo=!0;var B=[a,c];if(i>$r){var g=oi(e,i,n.features);g.features.tjmo=!0,B.push(g)}return A.splice.apply(A,[t,1].concat(B)),t+B.length-1}function ai(A,t,e){var n,r,i,o,s=A[t],a=Ai(A[t].codePoints[0]),c=A[t-1].codePoints[0],B=Ai(c);if(4===B&&3===a)n=c,o=s;else{2===a?(r=A[t-1],i=s):(r=A[t-2],i=A[t-1],o=s);var g=r.codePoints[0],l=i.codePoints[0];(function(A){return _r<=A&&A<=4370})(g)&&function(A){return qr<=A&&A<=4469}(l)&&(n=Zr+28*(21*(g-_r)+(l-qr)))}var u=o&&o.codePoints[0]||$r;if(null!=n&&(u===$r||function(A){return 1<=A&&A<=4546}(u))){var w=n+(u-$r);if(e.hasGlyphForCodePoint(w)){var h=2===B?3:2;return A.splice(t-h+1,h,oi(e,w,s.features)),t-h+1}}return r&&(r.features.ljmo=!0),i&&(i.features.vjmo=!0),o&&(o.features.tjmo=!0),4===B?(si(A,t-1,e),t+1):t}function ci(A,t,e){var n=A[t],r=A[t].codePoints[0];if(0!==e.glyphForCodePoint(r).advanceWidth){var i=function(A){switch(Ai(A)){case 4:case 5:return 1;case 2:return 2;case 3:return 3}}(A[t-1].codePoints[0]);return A.splice(t,1),A.splice(t-i,0,n)}}function Bi(A,t,e){var n=A[t],r=A[t].codePoints[0];if(e.hasGlyphForCodePoint(9676)){var i=oi(e,9676,n.features),o=0===e.glyphForCodePoint(r).advanceWidth?t:t+1;A.splice(o,0,i),t++}return t}var gi={categories:["O","IND","S","GB","B","FM","CGJ","VMAbv","VMPst","VAbv","VPst","CMBlw","VPre","VBlw","H","VMBlw","CMAbv","MBlw","CS","R","SUB","MPst","MPre","FAbv","FPst","FBlw","null","SMAbv","SMBlw","VMPre","ZWNJ","ZWJ","WJ","M","VS","N","HN","MAbv"],decompositions:{2507:[2503,2494],2508:[2503,2519],2888:[2887,2902],2891:[2887,2878],2892:[2887,2903],3018:[3014,3006],3019:[3015,3006],3020:[3014,3031],3144:[3142,3158],3264:[3263,3285],3271:[3270,3285],3272:[3270,3286],3274:[3270,3266],3275:[3270,3266,3285],3402:[3398,3390],3403:[3399,3390],3404:[3398,3415],3546:[3545,3530],3548:[3545,3535],3549:[3545,3535,3530],3550:[3545,3551],3635:[3661,3634],3763:[3789,3762],3955:[3953,3954],3957:[3953,3956],3958:[4018,3968],3959:[4018,3953,3968],3960:[4019,3968],3961:[4019,3953,3968],3969:[3953,3968],6971:[6970,6965],6973:[6972,6965],6976:[6974,6965],6977:[6975,6965],6979:[6978,6965],69934:[69937,69927],69935:[69938,69927],70475:[70471,70462],70476:[70471,70487],70843:[70841,70842],70844:[70841,70832],70846:[70841,70845],71098:[71096,71087],71099:[71097,71087]},stateTable:[[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],[2,2,3,4,4,5,0,6,7,8,9,10,11,12,13,14,15,16,0,17,18,11,19,20,21,22,0,0,0,23,0,0,2,0,0,24,0,25],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,28,0,0,0,0,0,27,0,0,0],[0,0,0,0,0,29,0,30,31,32,33,34,35,36,37,38,39,40,0,0,41,35,42,43,44,45,0,0,0,46,0,0,0,0,39,0,0,47],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,5,0,6,7,0,0,0,0,0,0,14,0,0,0,0,0,0,0,20,21,22,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,5,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,21,22,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,5,0,6,7,8,9,0,0,12,0,14,0,0,0,0,0,0,0,20,21,22,0,0,0,23,0,0,0,0,0,0,0,0],[0,0,0,0,0,5,0,6,7,0,9,0,0,0,0,14,0,0,0,0,0,0,0,20,21,22,0,0,0,23,0,0,0,0,0,0,0,0],[0,0,0,0,0,5,0,6,7,8,9,10,11,12,13,14,0,16,0,0,18,11,19,20,21,22,0,0,0,23,0,0,0,0,0,0,0,25],[0,0,0,0,0,5,0,6,7,8,9,0,11,12,0,14,0,0,0,0,0,0,0,20,21,22,0,0,0,23,0,0,0,0,0,0,0,0],[0,0,0,0,0,5,0,6,7,0,9,0,0,12,0,14,0,0,0,0,0,0,0,20,21,22,0,0,0,23,0,0,0,0,0,0,0,0],[0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,5,0,0,7,0,0,0,0,0,0,14,0,0,0,0,0,0,0,20,21,22,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,5,0,6,7,8,9,10,11,12,13,14,15,16,0,0,18,11,19,20,21,22,0,0,0,23,0,0,0,0,0,0,0,25],[0,0,0,0,0,5,0,6,7,8,9,0,11,12,0,14,0,0,0,0,0,11,0,20,21,22,0,0,0,23,0,0,0,0,0,0,0,0],[0,0,0,4,4,5,0,6,7,8,9,10,11,12,13,14,15,16,0,0,18,11,19,20,21,22,0,0,0,23,0,0,0,0,0,0,0,25],[0,0,0,0,0,5,0,6,7,8,9,48,11,12,13,14,48,16,0,0,18,11,19,20,21,22,0,0,0,23,0,0,0,0,49,0,0,25],[0,0,0,0,0,5,0,6,7,8,9,0,11,12,0,14,0,16,0,0,0,11,0,20,21,22,0,0,0,23,0,0,0,0,0,0,0,25],[0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,21,22,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,22,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,5,0,6,7,0,0,0,0,0,0,14,0,0,0,0,0,0,0,20,21,22,0,0,0,23,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,51,0],[0,0,0,0,0,5,0,6,7,8,9,0,11,12,0,14,0,16,0,0,0,11,0,20,21,22,0,0,0,23,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,28,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,29,0,30,31,0,0,0,0,0,0,38,0,0,0,0,0,0,0,43,44,45,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,29,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,43,44,45,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,29,0,30,31,32,33,0,0,36,0,38,0,0,0,0,0,0,0,43,44,45,0,0,0,46,0,0,0,0,0,0,0,0],[0,0,0,0,0,29,0,30,31,0,33,0,0,0,0,38,0,0,0,0,0,0,0,43,44,45,0,0,0,46,0,0,0,0,0,0,0,0],[0,0,0,0,0,29,0,30,31,32,33,34,35,36,37,38,0,40,0,0,41,35,42,43,44,45,0,0,0,46,0,0,0,0,0,0,0,47],[0,0,0,0,0,29,0,30,31,32,33,0,35,36,0,38,0,0,0,0,0,0,0,43,44,45,0,0,0,46,0,0,0,0,0,0,0,0],[0,0,0,0,0,29,0,30,31,0,33,0,0,36,0,38,0,0,0,0,0,0,0,43,44,45,0,0,0,46,0,0,0,0,0,0,0,0],[0,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,29,0,0,31,0,0,0,0,0,0,38,0,0,0,0,0,0,0,43,44,45,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,29,0,30,31,32,33,34,35,36,37,38,39,40,0,0,41,35,42,43,44,45,0,0,0,46,0,0,0,0,0,0,0,47],[0,0,0,0,0,29,0,30,31,32,33,0,35,36,0,38,0,0,0,0,0,35,0,43,44,45,0,0,0,46,0,0,0,0,0,0,0,0],[0,0,0,0,0,29,0,30,31,32,33,52,35,36,37,38,52,40,0,0,41,35,42,43,44,45,0,0,0,46,0,0,0,0,53,0,0,47],[0,0,0,0,0,29,0,30,31,32,33,0,35,36,0,38,0,40,0,0,0,35,0,43,44,45,0,0,0,46,0,0,0,0,0,0,0,47],[0,0,0,0,0,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,43,44,45,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,0,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,45,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,29,0,30,31,0,0,0,0,0,0,38,0,0,0,0,0,0,0,43,44,45,0,0,0,46,0,0,0,0,0,0,0,0],[0,0,0,0,0,29,0,30,31,32,33,0,35,36,0,38,0,40,0,0,0,35,0,43,44,45,0,0,0,46,0,0,0,0,0,0,0,0],[0,0,0,0,0,5,0,6,7,8,9,48,11,12,13,14,0,16,0,0,18,11,19,20,21,22,0,0,0,23,0,0,0,0,0,0,0,25],[0,0,0,0,0,5,0,6,7,8,9,48,11,12,13,14,48,16,0,0,18,11,19,20,21,22,0,0,0,23,0,0,0,0,0,0,0,25],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,51,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,0,0],[0,0,0,0,0,29,0,30,31,32,33,52,35,36,37,38,0,40,0,0,41,35,42,43,44,45,0,0,0,46,0,0,0,0,0,0,0,47],[0,0,0,0,0,29,0,30,31,32,33,52,35,36,37,38,52,40,0,0,41,35,42,43,44,45,0,0,0,46,0,0,0,0,0,0,0,47],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,51,0]],accepting:[!1,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!1,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0],tags:[[],["broken_cluster"],["independent_cluster"],["symbol_cluster"],["standard_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],[],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["numeral_cluster"],["broken_cluster"],["independent_cluster"],["symbol_cluster"],["symbol_cluster"],["standard_cluster"],["standard_cluster"],["standard_cluster"],["standard_cluster"],["standard_cluster"],["standard_cluster"],["standard_cluster"],["standard_cluster"],["virama_terminated_cluster"],["standard_cluster"],["standard_cluster"],["standard_cluster"],["standard_cluster"],["standard_cluster"],["standard_cluster"],["standard_cluster"],["standard_cluster"],["standard_cluster"],["standard_cluster"],["broken_cluster"],["broken_cluster"],["numeral_cluster"],["number_joiner_terminated_cluster"],["standard_cluster"],["standard_cluster"],["numeral_cluster"]]},li=16,ui=128,wi=32768,hi=1<<17,Ei={Start:1,Ra_To_Become_Reph:2,Pre_M:4,Pre_C:8,Base_C:16,After_Main:32,Above_C:64,Before_Sub:128,Below_C:256,After_Sub:512,Before_Post:1024,Post_C:2048,After_Post:4096,Final_C:8192,SMVD:16384,End:32768},fi=202758,Qi=96,di=16400,Ci={Default:{hasOldSpec:!1,virama:0,basePos:"Last",rephPos:Ei.Before_Post,rephMode:"Implicit",blwfMode:"Pre_And_Post"},Devanagari:{hasOldSpec:!0,virama:2381,basePos:"Last",rephPos:Ei.Before_Post,rephMode:"Implicit",blwfMode:"Pre_And_Post"},Bengali:{hasOldSpec:!0,virama:2509,basePos:"Last",rephPos:Ei.After_Sub,rephMode:"Implicit",blwfMode:"Pre_And_Post"},Gurmukhi:{hasOldSpec:!0,virama:2637,basePos:"Last",rephPos:Ei.Before_Sub,rephMode:"Implicit",blwfMode:"Pre_And_Post"},Gujarati:{hasOldSpec:!0,virama:2765,basePos:"Last",rephPos:Ei.Before_Post,rephMode:"Implicit",blwfMode:"Pre_And_Post"},Oriya:{hasOldSpec:!0,virama:2893,basePos:"Last",rephPos:Ei.After_Main,rephMode:"Implicit",blwfMode:"Pre_And_Post"},Tamil:{hasOldSpec:!0,virama:3021,basePos:"Last",rephPos:Ei.After_Post,rephMode:"Implicit",blwfMode:"Pre_And_Post"},Telugu:{hasOldSpec:!0,virama:3149,basePos:"Last",rephPos:Ei.After_Post,rephMode:"Explicit",blwfMode:"Post_Only"},Kannada:{hasOldSpec:!0,virama:3277,basePos:"Last",rephPos:Ei.After_Post,rephMode:"Implicit",blwfMode:"Post_Only"},Malayalam:{hasOldSpec:!0,virama:3405,basePos:"Last",rephPos:Ei.After_Main,rephMode:"Log_Repha",blwfMode:"Pre_And_Post"},Khmer:{hasOldSpec:!1,virama:6098,basePos:"First",rephPos:Ei.Ra_To_Become_Reph,rephMode:"Vis_Repha",blwfMode:"Pre_And_Post"}},Mi={6078:[6081,6078],6079:[6081,6079],6080:[6081,6080],6084:[6081,6084],6085:[6081,6085]},Ii=gi.decompositions,pi=new E(r(" ","base64")),Di=new f({stateTable:[[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],[0,2,3,4,5,6,7,8,9,0,10,11,11,12,13,14,15,16,17],[0,0,0,18,19,20,21,22,23,0,24,0,0,25,26,0,0,27,0],[0,0,0,28,29,30,31,32,33,0,34,0,0,35,36,0,0,37,0],[0,0,0,38,5,7,7,8,9,0,10,0,0,0,13,0,0,16,0],[0,39,0,0,0,40,41,0,9,0,10,0,0,0,42,0,39,0,0],[0,0,0,0,43,44,44,8,9,0,0,0,0,12,43,0,0,0,0],[0,0,0,0,43,44,44,8,9,0,0,0,0,0,43,0,0,0,0],[0,0,0,45,46,47,48,49,9,0,10,0,0,0,42,0,0,0,0],[0,0,0,0,0,50,0,0,51,0,10,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,52,0,0,0,0,0,0,0,0],[0,0,0,53,54,55,56,57,58,0,59,0,0,60,61,0,0,62,0],[0,0,0,4,5,7,7,8,9,0,10,0,0,0,13,0,0,16,0],[0,63,64,0,0,40,41,0,9,0,10,0,0,0,42,0,63,0,0],[0,2,3,4,5,6,7,8,9,0,10,11,11,12,13,0,2,16,0],[0,0,0,18,65,20,21,22,23,0,24,0,0,25,26,0,0,27,0],[0,0,0,0,66,67,67,8,9,0,10,0,0,0,68,0,0,0,0],[0,0,0,69,0,70,70,0,71,0,72,0,0,0,0,0,0,0,0],[0,0,0,73,19,74,74,22,23,0,24,0,0,0,26,0,0,27,0],[0,75,0,0,0,76,77,0,23,0,24,0,0,0,78,0,75,0,0],[0,0,0,0,79,80,80,22,23,0,0,0,0,25,79,0,0,0,0],[0,0,0,18,19,20,74,22,23,0,24,0,0,25,26,0,0,27,0],[0,0,0,81,82,83,84,85,23,0,24,0,0,0,78,0,0,0,0],[0,0,0,0,0,86,0,0,87,0,24,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,88,0,0,0,0,0,0,0,0],[0,0,0,18,19,74,74,22,23,0,24,0,0,0,26,0,0,27,0],[0,89,90,0,0,76,77,0,23,0,24,0,0,0,78,0,89,0,0],[0,0,0,0,91,92,92,22,23,0,24,0,0,0,93,0,0,0,0],[0,0,0,94,29,95,31,32,33,0,34,0,0,0,36,0,0,37,0],[0,96,0,0,0,97,98,0,33,0,34,0,0,0,99,0,96,0,0],[0,0,0,0,100,101,101,32,33,0,0,0,0,35,100,0,0,0,0],[0,0,0,0,100,101,101,32,33,0,0,0,0,0,100,0,0,0,0],[0,0,0,102,103,104,105,106,33,0,34,0,0,0,99,0,0,0,0],[0,0,0,0,0,107,0,0,108,0,34,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,109,0,0,0,0,0,0,0,0],[0,0,0,28,29,95,31,32,33,0,34,0,0,0,36,0,0,37,0],[0,110,111,0,0,97,98,0,33,0,34,0,0,0,99,0,110,0,0],[0,0,0,0,112,113,113,32,33,0,34,0,0,0,114,0,0,0,0],[0,0,0,0,5,7,7,8,9,0,10,0,0,0,13,0,0,16,0],[0,0,0,115,116,117,118,8,9,0,10,0,0,119,120,0,0,16,0],[0,0,0,0,0,121,121,0,9,0,10,0,0,0,42,0,0,0,0],[0,39,0,122,0,123,123,8,9,0,10,0,0,0,42,0,39,0,0],[0,124,64,0,0,0,0,0,0,0,0,0,0,0,0,0,124,0,0],[0,39,0,0,0,121,125,0,9,0,10,0,0,0,42,0,39,0,0],[0,0,0,0,0,126,126,8,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,46,47,48,49,9,0,10,0,0,0,42,0,0,0,0],[0,0,0,0,0,47,47,49,9,0,10,0,0,0,42,0,0,0,0],[0,0,0,0,0,127,127,49,9,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,128,127,127,49,9,0,0,0,0,0,0,0,0,0,0],[0,0,0,129,130,131,132,133,9,0,10,0,0,0,42,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0],[0,0,0,0,0,50,0,0,0,0,10,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,134,0,0,0,0,0,0,0,0],[0,0,0,135,54,56,56,57,58,0,59,0,0,0,61,0,0,62,0],[0,136,0,0,0,137,138,0,58,0,59,0,0,0,139,0,136,0,0],[0,0,0,0,140,141,141,57,58,0,0,0,0,60,140,0,0,0,0],[0,0,0,0,140,141,141,57,58,0,0,0,0,0,140,0,0,0,0],[0,0,0,142,143,144,145,146,58,0,59,0,0,0,139,0,0,0,0],[0,0,0,0,0,147,0,0,148,0,59,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,149,0,0,0,0,0,0,0,0],[0,0,0,53,54,56,56,57,58,0,59,0,0,0,61,0,0,62,0],[0,150,151,0,0,137,138,0,58,0,59,0,0,0,139,0,150,0,0],[0,0,0,0,152,153,153,57,58,0,59,0,0,0,154,0,0,0,0],[0,0,0,155,116,156,157,8,9,0,10,0,0,158,120,0,0,16,0],[0,0,0,0,0,121,121,0,9,0,10,0,0,0,0,0,0,0,0],[0,75,3,4,5,159,160,8,161,0,162,0,11,12,163,0,75,16,0],[0,0,0,0,0,40,164,0,9,0,10,0,0,0,42,0,0,0,0],[0,0,0,0,165,44,44,8,9,0,0,0,0,0,165,0,0,0,0],[0,124,64,0,0,40,164,0,9,0,10,0,0,0,42,0,124,0,0],[0,0,0,0,0,70,70,0,71,0,72,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,71,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,166,0,0,167,0,72,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,168,0,0,0,0,0,0,0,0],[0,0,0,0,19,74,74,22,23,0,24,0,0,0,26,0,0,27,0],[0,0,0,0,79,80,80,22,23,0,0,0,0,0,79,0,0,0,0],[0,0,0,169,170,171,172,22,23,0,24,0,0,173,174,0,0,27,0],[0,0,0,0,0,175,175,0,23,0,24,0,0,0,78,0,0,0,0],[0,75,0,176,0,177,177,22,23,0,24,0,0,0,78,0,75,0,0],[0,178,90,0,0,0,0,0,0,0,0,0,0,0,0,0,178,0,0],[0,75,0,0,0,175,179,0,23,0,24,0,0,0,78,0,75,0,0],[0,0,0,0,0,180,180,22,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,82,83,84,85,23,0,24,0,0,0,78,0,0,0,0],[0,0,0,0,0,83,83,85,23,0,24,0,0,0,78,0,0,0,0],[0,0,0,0,0,181,181,85,23,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,182,181,181,85,23,0,0,0,0,0,0,0,0,0,0],[0,0,0,183,184,185,186,187,23,0,24,0,0,0,78,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0],[0,0,0,0,0,86,0,0,0,0,24,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,188,0,0,0,0,0,0,0,0],[0,0,0,189,170,190,191,22,23,0,24,0,0,192,174,0,0,27,0],[0,0,0,0,0,175,175,0,23,0,24,0,0,0,0,0,0,0,0],[0,0,0,0,0,76,193,0,23,0,24,0,0,0,78,0,0,0,0],[0,0,0,0,194,80,80,22,23,0,0,0,0,0,194,0,0,0,0],[0,178,90,0,0,76,193,0,23,0,24,0,0,0,78,0,178,0,0],[0,0,0,0,29,95,31,32,33,0,34,0,0,0,36,0,0,37,0],[0,0,0,0,100,101,101,32,33,0,0,0,0,0,100,0,0,0,0],[0,0,0,195,196,197,198,32,33,0,34,0,0,199,200,0,0,37,0],[0,0,0,0,0,201,201,0,33,0,34,0,0,0,99,0,0,0,0],[0,96,0,202,0,203,203,32,33,0,34,0,0,0,99,0,96,0,0],[0,204,111,0,0,0,0,0,0,0,0,0,0,0,0,0,204,0,0],[0,96,0,0,0,201,205,0,33,0,34,0,0,0,99,0,96,0,0],[0,0,0,0,0,206,206,32,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,103,104,105,106,33,0,34,0,0,0,99,0,0,0,0],[0,0,0,0,0,104,104,106,33,0,34,0,0,0,99,0,0,0,0],[0,0,0,0,0,207,207,106,33,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,208,207,207,106,33,0,0,0,0,0,0,0,0,0,0],[0,0,0,209,210,211,212,213,33,0,34,0,0,0,99,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,34,0,0,0,0,0,0,0,0],[0,0,0,0,0,107,0,0,0,0,34,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,214,0,0,0,0,0,0,0,0],[0,0,0,215,196,216,217,32,33,0,34,0,0,218,200,0,0,37,0],[0,0,0,0,0,201,201,0,33,0,34,0,0,0,0,0,0,0,0],[0,0,0,0,0,97,219,0,33,0,34,0,0,0,99,0,0,0,0],[0,0,0,0,220,101,101,32,33,0,0,0,0,0,220,0,0,0,0],[0,204,111,0,0,97,219,0,33,0,34,0,0,0,99,0,204,0,0],[0,0,0,221,116,222,222,8,9,0,10,0,0,0,120,0,0,16,0],[0,223,0,0,0,40,224,0,9,0,10,0,0,0,42,0,223,0,0],[0,0,0,0,225,44,44,8,9,0,0,0,0,119,225,0,0,0,0],[0,0,0,115,116,117,222,8,9,0,10,0,0,119,120,0,0,16,0],[0,0,0,115,116,222,222,8,9,0,10,0,0,0,120,0,0,16,0],[0,226,64,0,0,40,224,0,9,0,10,0,0,0,42,0,226,0,0],[0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0],[0,39,0,0,0,121,121,0,9,0,10,0,0,0,42,0,39,0,0],[0,0,0,0,0,44,44,8,9,0,0,0,0,0,0,0,0,0,0],[0,0,0,227,0,228,229,0,9,0,10,0,0,230,0,0,0,0,0],[0,39,0,122,0,121,121,0,9,0,10,0,0,0,42,0,39,0,0],[0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,231,231,49,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,232,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,130,131,132,133,9,0,10,0,0,0,42,0,0,0,0],[0,0,0,0,0,131,131,133,9,0,10,0,0,0,42,0,0,0,0],[0,0,0,0,0,233,233,133,9,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,234,233,233,133,9,0,0,0,0,0,0,0,0,0,0],[0,0,0,235,236,237,238,239,9,0,10,0,0,0,42,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,54,56,56,57,58,0,59,0,0,0,61,0,0,62,0],[0,0,0,240,241,242,243,57,58,0,59,0,0,244,245,0,0,62,0],[0,0,0,0,0,246,246,0,58,0,59,0,0,0,139,0,0,0,0],[0,136,0,247,0,248,248,57,58,0,59,0,0,0,139,0,136,0,0],[0,249,151,0,0,0,0,0,0,0,0,0,0,0,0,0,249,0,0],[0,136,0,0,0,246,250,0,58,0,59,0,0,0,139,0,136,0,0],[0,0,0,0,0,251,251,57,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,143,144,145,146,58,0,59,0,0,0,139,0,0,0,0],[0,0,0,0,0,144,144,146,58,0,59,0,0,0,139,0,0,0,0],[0,0,0,0,0,252,252,146,58,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,253,252,252,146,58,0,0,0,0,0,0,0,0,0,0],[0,0,0,254,255,256,257,258,58,0,59,0,0,0,139,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,59,0,0,0,0,0,0,0,0],[0,0,0,0,0,147,0,0,0,0,59,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,259,0,0,0,0,0,0,0,0],[0,0,0,260,241,261,262,57,58,0,59,0,0,263,245,0,0,62,0],[0,0,0,0,0,246,246,0,58,0,59,0,0,0,0,0,0,0,0],[0,0,0,0,0,137,264,0,58,0,59,0,0,0,139,0,0,0,0],[0,0,0,0,265,141,141,57,58,0,0,0,0,0,265,0,0,0,0],[0,249,151,0,0,137,264,0,58,0,59,0,0,0,139,0,249,0,0],[0,0,0,221,116,222,222,8,9,0,10,0,0,0,120,0,0,16,0],[0,0,0,0,225,44,44,8,9,0,0,0,0,158,225,0,0,0,0],[0,0,0,155,116,156,222,8,9,0,10,0,0,158,120,0,0,16,0],[0,0,0,155,116,222,222,8,9,0,10,0,0,0,120,0,0,16,0],[0,0,0,0,43,266,266,8,161,0,24,0,0,12,267,0,0,0,0],[0,75,0,176,43,268,268,269,161,0,24,0,0,0,267,0,75,0,0],[0,0,0,0,0,270,0,0,271,0,162,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,272,0,0,0,0,0,0,0,0],[0,273,274,0,0,40,41,0,9,0,10,0,0,0,42,0,273,0,0],[0,0,0,40,0,123,123,8,9,0,10,0,0,0,42,0,0,0,0],[0,0,0,0,0,121,275,0,9,0,10,0,0,0,42,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,72,0,0,0,0,0,0,0,0],[0,0,0,0,0,166,0,0,0,0,72,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,276,0,0,0,0,0,0,0,0],[0,0,0,277,170,278,278,22,23,0,24,0,0,0,174,0,0,27,0],[0,279,0,0,0,76,280,0,23,0,24,0,0,0,78,0,279,0,0],[0,0,0,0,281,80,80,22,23,0,0,0,0,173,281,0,0,0,0],[0,0,0,169,170,171,278,22,23,0,24,0,0,173,174,0,0,27,0],[0,0,0,169,170,278,278,22,23,0,24,0,0,0,174,0,0,27,0],[0,282,90,0,0,76,280,0,23,0,24,0,0,0,78,0,282,0,0],[0,0,0,0,0,0,0,0,23,0,0,0,0,0,0,0,0,0,0],[0,75,0,0,0,175,175,0,23,0,24,0,0,0,78,0,75,0,0],[0,0,0,0,0,80,80,22,23,0,0,0,0,0,0,0,0,0,0],[0,0,0,283,0,284,285,0,23,0,24,0,0,286,0,0,0,0,0],[0,75,0,176,0,175,175,0,23,0,24,0,0,0,78,0,75,0,0],[0,0,0,0,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,287,287,85,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,288,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,184,185,186,187,23,0,24,0,0,0,78,0,0,0,0],[0,0,0,0,0,185,185,187,23,0,24,0,0,0,78,0,0,0,0],[0,0,0,0,0,289,289,187,23,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,290,289,289,187,23,0,0,0,0,0,0,0,0,0,0],[0,0,0,291,292,293,294,295,23,0,24,0,0,0,78,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,277,170,278,278,22,23,0,24,0,0,0,174,0,0,27,0],[0,0,0,0,281,80,80,22,23,0,0,0,0,192,281,0,0,0,0],[0,0,0,189,170,190,278,22,23,0,24,0,0,192,174,0,0,27,0],[0,0,0,189,170,278,278,22,23,0,24,0,0,0,174,0,0,27,0],[0,0,0,76,0,177,177,22,23,0,24,0,0,0,78,0,0,0,0],[0,0,0,0,0,175,296,0,23,0,24,0,0,0,78,0,0,0,0],[0,0,0,297,196,298,298,32,33,0,34,0,0,0,200,0,0,37,0],[0,299,0,0,0,97,300,0,33,0,34,0,0,0,99,0,299,0,0],[0,0,0,0,301,101,101,32,33,0,0,0,0,199,301,0,0,0,0],[0,0,0,195,196,197,298,32,33,0,34,0,0,199,200,0,0,37,0],[0,0,0,195,196,298,298,32,33,0,34,0,0,0,200,0,0,37,0],[0,302,111,0,0,97,300,0,33,0,34,0,0,0,99,0,302,0,0],[0,0,0,0,0,0,0,0,33,0,0,0,0,0,0,0,0,0,0],[0,96,0,0,0,201,201,0,33,0,34,0,0,0,99,0,96,0,0],[0,0,0,0,0,101,101,32,33,0,0,0,0,0,0,0,0,0,0],[0,0,0,303,0,304,305,0,33,0,34,0,0,306,0,0,0,0,0],[0,96,0,202,0,201,201,0,33,0,34,0,0,0,99,0,96,0,0],[0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,307,307,106,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,308,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,210,211,212,213,33,0,34,0,0,0,99,0,0,0,0],[0,0,0,0,0,211,211,213,33,0,34,0,0,0,99,0,0,0,0],[0,0,0,0,0,309,309,213,33,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,310,309,309,213,33,0,0,0,0,0,0,0,0,0,0],[0,0,0,311,312,313,314,315,33,0,34,0,0,0,99,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,297,196,298,298,32,33,0,34,0,0,0,200,0,0,37,0],[0,0,0,0,301,101,101,32,33,0,0,0,0,218,301,0,0,0,0],[0,0,0,215,196,216,298,32,33,0,34,0,0,218,200,0,0,37,0],[0,0,0,215,196,298,298,32,33,0,34,0,0,0,200,0,0,37,0],[0,0,0,97,0,203,203,32,33,0,34,0,0,0,99,0,0,0,0],[0,0,0,0,0,201,316,0,33,0,34,0,0,0,99,0,0,0,0],[0,0,0,0,116,222,222,8,9,0,10,0,0,0,120,0,0,16,0],[0,0,0,0,225,44,44,8,9,0,0,0,0,0,225,0,0,0,0],[0,0,0,317,318,319,320,8,9,0,10,0,0,321,322,0,0,16,0],[0,223,0,323,0,123,123,8,9,0,10,0,0,0,42,0,223,0,0],[0,223,0,0,0,121,324,0,9,0,10,0,0,0,42,0,223,0,0],[0,0,0,325,318,326,327,8,9,0,10,0,0,328,322,0,0,16,0],[0,0,0,64,0,121,121,0,9,0,10,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,9,0,0,0,0,230,0,0,0,0,0],[0,0,0,227,0,228,121,0,9,0,10,0,0,230,0,0,0,0,0],[0,0,0,227,0,121,121,0,9,0,10,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,0,0],[0,0,0,0,0,329,329,133,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,330,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,236,237,238,239,9,0,10,0,0,0,42,0,0,0,0],[0,0,0,0,0,237,237,239,9,0,10,0,0,0,42,0,0,0,0],[0,0,0,0,0,331,331,239,9,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,332,331,331,239,9,0,0,0,0,0,0,0,0,0,0],[0,0,0,333,40,121,334,0,9,0,10,0,0,0,42,0,0,0,0],[0,0,0,335,241,336,336,57,58,0,59,0,0,0,245,0,0,62,0],[0,337,0,0,0,137,338,0,58,0,59,0,0,0,139,0,337,0,0],[0,0,0,0,339,141,141,57,58,0,0,0,0,244,339,0,0,0,0],[0,0,0,240,241,242,336,57,58,0,59,0,0,244,245,0,0,62,0],[0,0,0,240,241,336,336,57,58,0,59,0,0,0,245,0,0,62,0],[0,340,151,0,0,137,338,0,58,0,59,0,0,0,139,0,340,0,0],[0,0,0,0,0,0,0,0,58,0,0,0,0,0,0,0,0,0,0],[0,136,0,0,0,246,246,0,58,0,59,0,0,0,139,0,136,0,0],[0,0,0,0,0,141,141,57,58,0,0,0,0,0,0,0,0,0,0],[0,0,0,341,0,342,343,0,58,0,59,0,0,344,0,0,0,0,0],[0,136,0,247,0,246,246,0,58,0,59,0,0,0,139,0,136,0,0],[0,0,0,0,0,0,0,57,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,345,345,146,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,346,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,255,256,257,258,58,0,59,0,0,0,139,0,0,0,0],[0,0,0,0,0,256,256,258,58,0,59,0,0,0,139,0,0,0,0],[0,0,0,0,0,347,347,258,58,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,348,347,347,258,58,0,0,0,0,0,0,0,0,0,0],[0,0,0,349,350,351,352,353,58,0,59,0,0,0,139,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,335,241,336,336,57,58,0,59,0,0,0,245,0,0,62,0],[0,0,0,0,339,141,141,57,58,0,0,0,0,263,339,0,0,0,0],[0,0,0,260,241,261,336,57,58,0,59,0,0,263,245,0,0,62,0],[0,0,0,260,241,336,336,57,58,0,59,0,0,0,245,0,0,62,0],[0,0,0,137,0,248,248,57,58,0,59,0,0,0,139,0,0,0,0],[0,0,0,0,0,246,354,0,58,0,59,0,0,0,139,0,0,0,0],[0,0,0,0,0,126,126,8,23,0,0,0,0,0,0,0,0,0,0],[0,355,90,0,0,121,125,0,9,0,10,0,0,0,42,0,355,0,0],[0,0,0,0,0,356,356,269,23,0,0,0,0,0,0,0,0,0,0],[0,0,0,357,358,359,360,361,161,0,162,0,0,0,362,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,162,0,0,0,0,0,0,0,0],[0,0,0,0,0,270,0,0,0,0,162,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,363,0,0,0,0,0,0,0,0],[0,0,0,364,116,365,366,8,161,0,162,0,0,367,120,0,0,16,0],[0,0,0,0,0,368,368,0,161,0,162,0,0,0,0,0,0,0,0],[0,0,0,40,0,121,121,0,9,0,10,0,0,0,42,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,170,278,278,22,23,0,24,0,0,0,174,0,0,27,0],[0,0,0,0,281,80,80,22,23,0,0,0,0,0,281,0,0,0,0],[0,0,0,369,370,371,372,22,23,0,24,0,0,373,374,0,0,27,0],[0,279,0,375,0,177,177,22,23,0,24,0,0,0,78,0,279,0,0],[0,279,0,0,0,175,376,0,23,0,24,0,0,0,78,0,279,0,0],[0,0,0,377,370,378,379,22,23,0,24,0,0,380,374,0,0,27,0],[0,0,0,90,0,175,175,0,23,0,24,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,23,0,0,0,0,286,0,0,0,0,0],[0,0,0,283,0,284,175,0,23,0,24,0,0,286,0,0,0,0,0],[0,0,0,283,0,175,175,0,23,0,24,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,85,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,0,0],[0,0,0,0,0,381,381,187,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,382,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,292,293,294,295,23,0,24,0,0,0,78,0,0,0,0],[0,0,0,0,0,293,293,295,23,0,24,0,0,0,78,0,0,0,0],[0,0,0,0,0,383,383,295,23,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,384,383,383,295,23,0,0,0,0,0,0,0,0,0,0],[0,0,0,385,76,175,386,0,23,0,24,0,0,0,78,0,0,0,0],[0,0,0,76,0,175,175,0,23,0,24,0,0,0,78,0,0,0,0],[0,0,0,0,196,298,298,32,33,0,34,0,0,0,200,0,0,37,0],[0,0,0,0,301,101,101,32,33,0,0,0,0,0,301,0,0,0,0],[0,0,0,387,388,389,390,32,33,0,34,0,0,391,392,0,0,37,0],[0,299,0,393,0,203,203,32,33,0,34,0,0,0,99,0,299,0,0],[0,299,0,0,0,201,394,0,33,0,34,0,0,0,99,0,299,0,0],[0,0,0,395,388,396,397,32,33,0,34,0,0,398,392,0,0,37,0],[0,0,0,111,0,201,201,0,33,0,34,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,33,0,0,0,0,306,0,0,0,0,0],[0,0,0,303,0,304,201,0,33,0,34,0,0,306,0,0,0,0,0],[0,0,0,303,0,201,201,0,33,0,34,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,103,0,0],[0,0,0,0,0,399,399,213,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,400,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,312,313,314,315,33,0,34,0,0,0,99,0,0,0,0],[0,0,0,0,0,313,313,315,33,0,34,0,0,0,99,0,0,0,0],[0,0,0,0,0,401,401,315,33,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,402,401,401,315,33,0,0,0,0,0,0,0,0,0,0],[0,0,0,403,97,201,404,0,33,0,34,0,0,0,99,0,0,0,0],[0,0,0,97,0,201,201,0,33,0,34,0,0,0,99,0,0,0,0],[0,0,0,405,318,406,406,8,9,0,10,0,0,0,322,0,0,16,0],[0,407,0,0,0,40,408,0,9,0,10,0,0,0,42,0,407,0,0],[0,0,0,0,409,44,44,8,9,0,0,0,0,321,409,0,0,0,0],[0,0,0,317,318,319,406,8,9,0,10,0,0,321,322,0,0,16,0],[0,0,0,317,318,406,406,8,9,0,10,0,0,0,322,0,0,16,0],[0,410,64,0,0,40,408,0,9,0,10,0,0,0,42,0,410,0,0],[0,223,0,0,0,121,121,0,9,0,10,0,0,0,42,0,223,0,0],[0,223,0,323,0,121,121,0,9,0,10,0,0,0,42,0,223,0,0],[0,0,0,405,318,406,406,8,9,0,10,0,0,0,322,0,0,16,0],[0,0,0,0,409,44,44,8,9,0,0,0,0,328,409,0,0,0,0],[0,0,0,325,318,326,406,8,9,0,10,0,0,328,322,0,0,16,0],[0,0,0,325,318,406,406,8,9,0,10,0,0,0,322,0,0,16,0],[0,0,0,0,0,0,0,133,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,130,0,0],[0,0,0,0,0,411,411,239,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,412,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,40,121,334,0,9,0,10,0,0,0,42,0,0,0,0],[0,0,0,0,413,0,0,0,9,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,241,336,336,57,58,0,59,0,0,0,245,0,0,62,0],[0,0,0,0,339,141,141,57,58,0,0,0,0,0,339,0,0,0,0],[0,0,0,414,415,416,417,57,58,0,59,0,0,418,419,0,0,62,0],[0,337,0,420,0,248,248,57,58,0,59,0,0,0,139,0,337,0,0],[0,337,0,0,0,246,421,0,58,0,59,0,0,0,139,0,337,0,0],[0,0,0,422,415,423,424,57,58,0,59,0,0,425,419,0,0,62,0],[0,0,0,151,0,246,246,0,58,0,59,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,58,0,0,0,0,344,0,0,0,0,0],[0,0,0,341,0,342,246,0,58,0,59,0,0,344,0,0,0,0,0],[0,0,0,341,0,246,246,0,58,0,59,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,146,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,143,0,0],[0,0,0,0,0,426,426,258,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,427,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,350,351,352,353,58,0,59,0,0,0,139,0,0,0,0],[0,0,0,0,0,351,351,353,58,0,59,0,0,0,139,0,0,0,0],[0,0,0,0,0,428,428,353,58,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,429,428,428,353,58,0,0,0,0,0,0,0,0,0,0],[0,0,0,430,137,246,431,0,58,0,59,0,0,0,139,0,0,0,0],[0,0,0,137,0,246,246,0,58,0,59,0,0,0,139,0,0,0,0],[0,0,0,432,116,433,434,8,161,0,162,0,0,435,120,0,0,16,0],[0,0,0,0,0,180,180,269,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,358,359,360,361,161,0,162,0,0,0,362,0,0,0,0],[0,0,0,0,0,359,359,361,161,0,162,0,0,0,362,0,0,0,0],[0,0,0,0,0,436,436,361,161,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,437,436,436,361,161,0,0,0,0,0,0,0,0,0,0],[0,0,0,438,439,440,441,442,161,0,162,0,0,0,362,0,0,0,0],[0,443,274,0,0,0,0,0,0,0,0,0,0,0,0,0,443,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,444,116,445,445,8,161,0,162,0,0,0,120,0,0,16,0],[0,0,0,0,225,44,44,8,161,0,0,0,0,367,225,0,0,0,0],[0,0,0,364,116,365,445,8,161,0,162,0,0,367,120,0,0,16,0],[0,0,0,364,116,445,445,8,161,0,162,0,0,0,120,0,0,16,0],[0,0,0,0,0,0,0,0,161,0,0,0,0,0,0,0,0,0,0],[0,0,0,446,370,447,447,22,23,0,24,0,0,0,374,0,0,27,0],[0,448,0,0,0,76,449,0,23,0,24,0,0,0,78,0,448,0,0],[0,0,0,0,450,80,80,22,23,0,0,0,0,373,450,0,0,0,0],[0,0,0,369,370,371,447,22,23,0,24,0,0,373,374,0,0,27,0],[0,0,0,369,370,447,447,22,23,0,24,0,0,0,374,0,0,27,0],[0,451,90,0,0,76,449,0,23,0,24,0,0,0,78,0,451,0,0],[0,279,0,0,0,175,175,0,23,0,24,0,0,0,78,0,279,0,0],[0,279,0,375,0,175,175,0,23,0,24,0,0,0,78,0,279,0,0],[0,0,0,446,370,447,447,22,23,0,24,0,0,0,374,0,0,27,0],[0,0,0,0,450,80,80,22,23,0,0,0,0,380,450,0,0,0,0],[0,0,0,377,370,378,447,22,23,0,24,0,0,380,374,0,0,27,0],[0,0,0,377,370,447,447,22,23,0,24,0,0,0,374,0,0,27,0],[0,0,0,0,0,0,0,187,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,0,0],[0,0,0,0,0,452,452,295,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,453,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,76,175,386,0,23,0,24,0,0,0,78,0,0,0,0],[0,0,0,0,454,0,0,0,23,0,0,0,0,0,0,0,0,0,0],[0,0,0,455,388,456,456,32,33,0,34,0,0,0,392,0,0,37,0],[0,457,0,0,0,97,458,0,33,0,34,0,0,0,99,0,457,0,0],[0,0,0,0,459,101,101,32,33,0,0,0,0,391,459,0,0,0,0],[0,0,0,387,388,389,456,32,33,0,34,0,0,391,392,0,0,37,0],[0,0,0,387,388,456,456,32,33,0,34,0,0,0,392,0,0,37,0],[0,460,111,0,0,97,458,0,33,0,34,0,0,0,99,0,460,0,0],[0,299,0,0,0,201,201,0,33,0,34,0,0,0,99,0,299,0,0],[0,299,0,393,0,201,201,0,33,0,34,0,0,0,99,0,299,0,0],[0,0,0,455,388,456,456,32,33,0,34,0,0,0,392,0,0,37,0],[0,0,0,0,459,101,101,32,33,0,0,0,0,398,459,0,0,0,0],[0,0,0,395,388,396,456,32,33,0,34,0,0,398,392,0,0,37,0],[0,0,0,395,388,456,456,32,33,0,34,0,0,0,392,0,0,37,0],[0,0,0,0,0,0,0,213,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,210,0,0],[0,0,0,0,0,461,461,315,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,462,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,97,201,404,0,33,0,34,0,0,0,99,0,0,0,0],[0,0,0,0,463,0,0,0,33,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,318,406,406,8,9,0,10,0,0,0,322,0,0,16,0],[0,0,0,0,409,44,44,8,9,0,0,0,0,0,409,0,0,0,0],[0,0,0,464,465,466,467,8,9,0,10,0,0,468,469,0,0,16,0],[0,407,0,470,0,123,123,8,9,0,10,0,0,0,42,0,407,0,0],[0,407,0,0,0,121,471,0,9,0,10,0,0,0,42,0,407,0,0],[0,0,0,472,465,473,474,8,9,0,10,0,0,475,469,0,0,16,0],[0,0,0,0,0,0,0,239,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,236,0,0],[0,0,0,0,0,0,476,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,477,415,478,478,57,58,0,59,0,0,0,419,0,0,62,0],[0,479,0,0,0,137,480,0,58,0,59,0,0,0,139,0,479,0,0],[0,0,0,0,481,141,141,57,58,0,0,0,0,418,481,0,0,0,0],[0,0,0,414,415,416,478,57,58,0,59,0,0,418,419,0,0,62,0],[0,0,0,414,415,478,478,57,58,0,59,0,0,0,419,0,0,62,0],[0,482,151,0,0,137,480,0,58,0,59,0,0,0,139,0,482,0,0],[0,337,0,0,0,246,246,0,58,0,59,0,0,0,139,0,337,0,0],[0,337,0,420,0,246,246,0,58,0,59,0,0,0,139,0,337,0,0],[0,0,0,477,415,478,478,57,58,0,59,0,0,0,419,0,0,62,0],[0,0,0,0,481,141,141,57,58,0,0,0,0,425,481,0,0,0,0],[0,0,0,422,415,423,478,57,58,0,59,0,0,425,419,0,0,62,0],[0,0,0,422,415,478,478,57,58,0,59,0,0,0,419,0,0,62,0],[0,0,0,0,0,0,0,258,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0],[0,0,0,0,0,483,483,353,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,484,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,137,246,431,0,58,0,59,0,0,0,139,0,0,0,0],[0,0,0,0,485,0,0,0,58,0,0,0,0,0,0,0,0,0,0],[0,0,0,444,116,445,445,8,161,0,162,0,0,0,120,0,0,16,0],[0,0,0,0,225,44,44,8,161,0,0,0,0,435,225,0,0,0,0],[0,0,0,432,116,433,445,8,161,0,162,0,0,435,120,0,0,16,0],[0,0,0,432,116,445,445,8,161,0,162,0,0,0,120,0,0,16,0],[0,0,0,0,0,486,486,361,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,487,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,439,440,441,442,161,0,162,0,0,0,362,0,0,0,0],[0,0,0,0,0,440,440,442,161,0,162,0,0,0,362,0,0,0,0],[0,0,0,0,0,488,488,442,161,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,489,488,488,442,161,0,0,0,0,0,0,0,0,0,0],[0,0,0,490,491,492,493,494,161,0,162,0,0,0,362,0,0,0,0],[0,0,0,495,0,496,497,0,161,0,162,0,0,498,0,0,0,0,0],[0,0,0,0,116,445,445,8,161,0,162,0,0,0,120,0,0,16,0],[0,0,0,0,225,44,44,8,161,0,0,0,0,0,225,0,0,0,0],[0,0,0,0,370,447,447,22,23,0,24,0,0,0,374,0,0,27,0],[0,0,0,0,450,80,80,22,23,0,0,0,0,0,450,0,0,0,0],[0,0,0,499,500,501,502,22,23,0,24,0,0,503,504,0,0,27,0],[0,448,0,505,0,177,177,22,23,0,24,0,0,0,78,0,448,0,0],[0,448,0,0,0,175,506,0,23,0,24,0,0,0,78,0,448,0,0],[0,0,0,507,500,508,509,22,23,0,24,0,0,510,504,0,0,27,0],[0,0,0,0,0,0,0,295,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,292,0,0],[0,0,0,0,0,0,511,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,388,456,456,32,33,0,34,0,0,0,392,0,0,37,0],[0,0,0,0,459,101,101,32,33,0,0,0,0,0,459,0,0,0,0],[0,0,0,512,513,514,515,32,33,0,34,0,0,516,517,0,0,37,0],[0,457,0,518,0,203,203,32,33,0,34,0,0,0,99,0,457,0,0],[0,457,0,0,0,201,519,0,33,0,34,0,0,0,99,0,457,0,0],[0,0,0,520,513,521,522,32,33,0,34,0,0,523,517,0,0,37,0],[0,0,0,0,0,0,0,315,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,312,0,0],[0,0,0,0,0,0,524,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,525,465,526,526,8,9,0,10,0,0,0,469,0,0,16,0],[0,527,0,0,0,40,528,0,9,0,10,0,0,0,42,0,527,0,0],[0,0,0,0,529,44,44,8,9,0,0,0,0,468,529,0,0,0,0],[0,0,0,464,465,466,526,8,9,0,10,0,0,468,469,0,0,16,0],[0,0,0,464,465,526,526,8,9,0,10,0,0,0,469,0,0,16,0],[0,530,64,0,0,40,528,0,9,0,10,0,0,0,42,0,530,0,0],[0,407,0,0,0,121,121,0,9,0,10,0,0,0,42,0,407,0,0],[0,407,0,470,0,121,121,0,9,0,10,0,0,0,42,0,407,0,0],[0,0,0,525,465,526,526,8,9,0,10,0,0,0,469,0,0,16,0],[0,0,0,0,529,44,44,8,9,0,0,0,0,475,529,0,0,0,0],[0,0,0,472,465,473,526,8,9,0,10,0,0,475,469,0,0,16,0],[0,0,0,472,465,526,526,8,9,0,10,0,0,0,469,0,0,16,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,0],[0,0,0,0,415,478,478,57,58,0,59,0,0,0,419,0,0,62,0],[0,0,0,0,481,141,141,57,58,0,0,0,0,0,481,0,0,0,0],[0,0,0,531,532,533,534,57,58,0,59,0,0,535,536,0,0,62,0],[0,479,0,537,0,248,248,57,58,0,59,0,0,0,139,0,479,0,0],[0,479,0,0,0,246,538,0,58,0,59,0,0,0,139,0,479,0,0],[0,0,0,539,532,540,541,57,58,0,59,0,0,542,536,0,0,62,0],[0,0,0,0,0,0,0,353,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,350,0,0],[0,0,0,0,0,0,543,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,361,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,358,0,0],[0,0,0,0,0,544,544,442,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,545,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,491,492,493,494,161,0,162,0,0,0,362,0,0,0,0],[0,0,0,0,0,492,492,494,161,0,162,0,0,0,362,0,0,0,0],[0,0,0,0,0,546,546,494,161,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,547,546,546,494,161,0,0,0,0,0,0,0,0,0,0],[0,0,0,548,549,368,550,0,161,0,162,0,0,0,362,0,0,0,0],[0,0,0,274,0,368,368,0,161,0,162,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,161,0,0,0,0,498,0,0,0,0,0],[0,0,0,495,0,496,368,0,161,0,162,0,0,498,0,0,0,0,0],[0,0,0,495,0,368,368,0,161,0,162,0,0,0,0,0,0,0,0],[0,0,0,551,500,552,552,22,23,0,24,0,0,0,504,0,0,27,0],[0,553,0,0,0,76,554,0,23,0,24,0,0,0,78,0,553,0,0],[0,0,0,0,555,80,80,22,23,0,0,0,0,503,555,0,0,0,0],[0,0,0,499,500,501,552,22,23,0,24,0,0,503,504,0,0,27,0],[0,0,0,499,500,552,552,22,23,0,24,0,0,0,504,0,0,27,0],[0,556,90,0,0,76,554,0,23,0,24,0,0,0,78,0,556,0,0],[0,448,0,0,0,175,175,0,23,0,24,0,0,0,78,0,448,0,0],[0,448,0,505,0,175,175,0,23,0,24,0,0,0,78,0,448,0,0],[0,0,0,551,500,552,552,22,23,0,24,0,0,0,504,0,0,27,0],[0,0,0,0,555,80,80,22,23,0,0,0,0,510,555,0,0,0,0],[0,0,0,507,500,508,552,22,23,0,24,0,0,510,504,0,0,27,0],[0,0,0,507,500,552,552,22,23,0,24,0,0,0,504,0,0,27,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,0,0],[0,0,0,557,513,558,558,32,33,0,34,0,0,0,517,0,0,37,0],[0,559,0,0,0,97,560,0,33,0,34,0,0,0,99,0,559,0,0],[0,0,0,0,561,101,101,32,33,0,0,0,0,516,561,0,0,0,0],[0,0,0,512,513,514,558,32,33,0,34,0,0,516,517,0,0,37,0],[0,0,0,512,513,558,558,32,33,0,34,0,0,0,517,0,0,37,0],[0,562,111,0,0,97,560,0,33,0,34,0,0,0,99,0,562,0,0],[0,457,0,0,0,201,201,0,33,0,34,0,0,0,99,0,457,0,0],[0,457,0,518,0,201,201,0,33,0,34,0,0,0,99,0,457,0,0],[0,0,0,557,513,558,558,32,33,0,34,0,0,0,517,0,0,37,0],[0,0,0,0,561,101,101,32,33,0,0,0,0,523,561,0,0,0,0],[0,0,0,520,513,521,558,32,33,0,34,0,0,523,517,0,0,37,0],[0,0,0,520,513,558,558,32,33,0,34,0,0,0,517,0,0,37,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,97,0,0],[0,0,0,0,465,526,526,8,9,0,10,0,0,0,469,0,0,16,0],[0,0,0,0,529,44,44,8,9,0,0,0,0,0,529,0,0,0,0],[0,0,0,563,66,564,565,8,9,0,10,0,0,566,68,0,0,16,0],[0,527,0,567,0,123,123,8,9,0,10,0,0,0,42,0,527,0,0],[0,527,0,0,0,121,568,0,9,0,10,0,0,0,42,0,527,0,0],[0,0,0,569,66,570,571,8,9,0,10,0,0,572,68,0,0,16,0],[0,0,0,573,532,574,574,57,58,0,59,0,0,0,536,0,0,62,0],[0,575,0,0,0,137,576,0,58,0,59,0,0,0,139,0,575,0,0],[0,0,0,0,577,141,141,57,58,0,0,0,0,535,577,0,0,0,0],[0,0,0,531,532,533,574,57,58,0,59,0,0,535,536,0,0,62,0],[0,0,0,531,532,574,574,57,58,0,59,0,0,0,536,0,0,62,0],[0,578,151,0,0,137,576,0,58,0,59,0,0,0,139,0,578,0,0],[0,479,0,0,0,246,246,0,58,0,59,0,0,0,139,0,479,0,0],[0,479,0,537,0,246,246,0,58,0,59,0,0,0,139,0,479,0,0],[0,0,0,573,532,574,574,57,58,0,59,0,0,0,536,0,0,62,0],[0,0,0,0,577,141,141,57,58,0,0,0,0,542,577,0,0,0,0],[0,0,0,539,532,540,574,57,58,0,59,0,0,542,536,0,0,62,0],[0,0,0,539,532,574,574,57,58,0,59,0,0,0,536,0,0,62,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,137,0,0],[0,0,0,0,0,0,0,442,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,439,0,0],[0,0,0,0,0,579,579,494,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,580,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,549,368,550,0,161,0,162,0,0,0,362,0,0,0,0],[0,0,0,0,0,368,368,0,161,0,162,0,0,0,362,0,0,0,0],[0,0,0,0,581,0,0,0,161,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,500,552,552,22,23,0,24,0,0,0,504,0,0,27,0],[0,0,0,0,555,80,80,22,23,0,0,0,0,0,555,0,0,0,0],[0,0,0,582,91,583,584,22,23,0,24,0,0,585,93,0,0,27,0],[0,553,0,586,0,177,177,22,23,0,24,0,0,0,78,0,553,0,0],[0,553,0,0,0,175,587,0,23,0,24,0,0,0,78,0,553,0,0],[0,0,0,588,91,589,590,22,23,0,24,0,0,591,93,0,0,27,0],[0,0,0,0,513,558,558,32,33,0,34,0,0,0,517,0,0,37,0],[0,0,0,0,561,101,101,32,33,0,0,0,0,0,561,0,0,0,0],[0,0,0,592,112,593,594,32,33,0,34,0,0,595,114,0,0,37,0],[0,559,0,596,0,203,203,32,33,0,34,0,0,0,99,0,559,0,0],[0,559,0,0,0,201,597,0,33,0,34,0,0,0,99,0,559,0,0],[0,0,0,598,112,599,600,32,33,0,34,0,0,601,114,0,0,37,0],[0,0,0,602,66,67,67,8,9,0,10,0,0,0,68,0,0,16,0],[0,0,0,0,165,44,44,8,9,0,0,0,0,566,165,0,0,0,0],[0,0,0,563,66,564,67,8,9,0,10,0,0,566,68,0,0,16,0],[0,0,0,563,66,67,67,8,9,0,10,0,0,0,68,0,0,16,0],[0,527,0,0,0,121,121,0,9,0,10,0,0,0,42,0,527,0,0],[0,527,0,567,0,121,121,0,9,0,10,0,0,0,42,0,527,0,0],[0,0,0,602,66,67,67,8,9,0,10,0,0,0,68,0,0,16,0],[0,0,0,0,165,44,44,8,9,0,0,0,0,572,165,0,0,0,0],[0,0,0,569,66,570,67,8,9,0,10,0,0,572,68,0,0,16,0],[0,0,0,569,66,67,67,8,9,0,10,0,0,0,68,0,0,16,0],[0,0,0,0,532,574,574,57,58,0,59,0,0,0,536,0,0,62,0],[0,0,0,0,577,141,141,57,58,0,0,0,0,0,577,0,0,0,0],[0,0,0,603,152,604,605,57,58,0,59,0,0,606,154,0,0,62,0],[0,575,0,607,0,248,248,57,58,0,59,0,0,0,139,0,575,0,0],[0,575,0,0,0,246,608,0,58,0,59,0,0,0,139,0,575,0,0],[0,0,0,609,152,610,611,57,58,0,59,0,0,612,154,0,0,62,0],[0,0,0,0,0,0,0,494,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,491,0,0],[0,0,0,0,0,0,613,0,0,0,0,0,0,0,0,0,0,0,0],[0,0,0,614,91,92,92,22,23,0,24,0,0,0,93,0,0,27,0],[0,0,0,0,194,80,80,22,23,0,0,0,0,585,194,0,0,0,0],[0,0,0,582,91,583,92,22,23,0,24,0,0,585,93,0,0,27,0],[0,0,0,582,91,92,92,22,23,0,24,0,0,0,93,0,0,27,0],[0,553,0,0,0,175,175,0,23,0,24,0,0,0,78,0,553,0,0],[0,553,0,586,0,175,175,0,23,0,24,0,0,0,78,0,553,0,0],[0,0,0,614,91,92,92,22,23,0,24,0,0,0,93,0,0,27,0],[0,0,0,0,194,80,80,22,23,0,0,0,0,591,194,0,0,0,0],[0,0,0,588,91,589,92,22,23,0,24,0,0,591,93,0,0,27,0],[0,0,0,588,91,92,92,22,23,0,24,0,0,0,93,0,0,27,0],[0,0,0,615,112,113,113,32,33,0,34,0,0,0,114,0,0,37,0],[0,0,0,0,220,101,101,32,33,0,0,0,0,595,220,0,0,0,0],[0,0,0,592,112,593,113,32,33,0,34,0,0,595,114,0,0,37,0],[0,0,0,592,112,113,113,32,33,0,34,0,0,0,114,0,0,37,0],[0,559,0,0,0,201,201,0,33,0,34,0,0,0,99,0,559,0,0],[0,559,0,596,0,201,201,0,33,0,34,0,0,0,99,0,559,0,0],[0,0,0,615,112,113,113,32,33,0,34,0,0,0,114,0,0,37,0],[0,0,0,0,220,101,101,32,33,0,0,0,0,601,220,0,0,0,0],[0,0,0,598,112,599,113,32,33,0,34,0,0,601,114,0,0,37,0],[0,0,0,598,112,113,113,32,33,0,34,0,0,0,114,0,0,37,0],[0,0,0,0,66,67,67,8,9,0,10,0,0,0,68,0,0,16,0],[0,0,0,616,152,153,153,57,58,0,59,0,0,0,154,0,0,62,0],[0,0,0,0,265,141,141,57,58,0,0,0,0,606,265,0,0,0,0],[0,0,0,603,152,604,153,57,58,0,59,0,0,606,154,0,0,62,0],[0,0,0,603,152,153,153,57,58,0,59,0,0,0,154,0,0,62,0],[0,575,0,0,0,246,246,0,58,0,59,0,0,0,139,0,575,0,0],[0,575,0,607,0,246,246,0,58,0,59,0,0,0,139,0,575,0,0],[0,0,0,616,152,153,153,57,58,0,59,0,0,0,154,0,0,62,0],[0,0,0,0,265,141,141,57,58,0,0,0,0,612,265,0,0,0,0],[0,0,0,609,152,610,153,57,58,0,59,0,0,612,154,0,0,62,0],[0,0,0,609,152,153,153,57,58,0,59,0,0,0,154,0,0,62,0],[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,549,0,0],[0,0,0,0,91,92,92,22,23,0,24,0,0,0,93,0,0,27,0],[0,0,0,0,112,113,113,32,33,0,34,0,0,0,114,0,0,37,0],[0,0,0,0,152,153,153,57,58,0,59,0,0,0,154,0,0,62,0]],accepting:[!1,!0,!0,!0,!0,!0,!1,!1,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!1,!0,!0,!0,!0,!0,!0,!0,!0,!0,!1,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!1,!0,!1,!0,!0,!1,!1,!0,!0,!0,!0,!0,!0,!1,!1,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!1,!0,!0,!1,!0,!0,!0,!1,!0,!0,!0,!1,!0,!1,!0,!0,!1,!1,!0,!0,!0,!0,!0,!0,!0,!1,!0,!0,!1,!0,!0,!0,!1,!0,!1,!0,!0,!1,!1,!0,!0,!0,!0,!0,!0,!0,!1,!0,!0,!0,!1,!0,!0,!0,!1,!0,!1,!0,!0,!1,!1,!1,!0,!0,!1,!1,!0,!0,!0,!0,!0,!0,!1,!0,!1,!0,!0,!1,!1,!0,!0,!0,!0,!0,!0,!0,!1,!0,!0,!1,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!0,!1,!0,!0,!0,!1,!0,!1,!0,!0,!1,!1,!1,!0,!0,!1,!1,!0,!0,!0,!1,!0,!0,!0,!0,!0,!0,!1,!0,!0,!0,!1,!0,!1,!0,!0,!1,!1,!1,!0,!0,!1,!1,!0,!0,!0,!1,!0,!0,!0,!0,!0,!1,!0,!0,!0,!0,!0,!1,!0,!0,!1,!1,!1,!1,!0,!0,!1,!1,!0,!0,!0,!1,!0,!0,!0,!1,!0,!1,!0,!0,!1,!1,!1,!0,!0,!1,!1,!0,!0,!0,!1,!0,!0,!0,!0,!1,!0,!1,!0,!0,!0,!0,!0,!0,!0,!0,!0,!1,!0,!0,!0,!0,!0,!1,!0,!0,!1,!1,!1,!1,!0,!0,!1,!1,!0,!0,!0,!1,!0,!0,!0,!0,!0,!1,!0,!0,!1,!1,!1,!1,!0,!0,!1,!1,!0,!0,!0,!0,!1,!0,!0,!0,!0,!0,!0,!1,!0,!0,!1,!1,!1,!1,!0,!1,!0,!1,!0,!0,!0,!0,!0,!1,!0,!0,!1,!1,!1,!1,!0,!0,!1,!1,!0,!0,!0,!1,!0,!0,!1,!1,!0,!1,!0,!0,!1,!0,!0,!1,!0,!0,!1,!0,!0,!0,!0,!0,!0,!1,!0,!0,!1,!1,!1,!1,!0,!1,!0,!0,!1,!0,!0,!0,!0,!0,!0,!1,!0,!0,!1,!1,!1,!1,!0,!1,!0,!1,!0,!0,!0,!0,!1,!1,!1,!0,!0,!1,!0,!0,!0,!0,!0,!0,!1,!0,!0,!1,!1,!1,!1,!0,!1,!0,!1,!0,!0,!1,!1,!0,!0,!1,!1,!0,!0,!0,!1,!0,!1,!0,!0,!0,!0,!1,!1,!1,!0,!1,!0,!0,!0,!0,!1,!1,!1,!0,!0,!1,!0,!0,!0,!0,!0,!0,!1,!0,!0,!1,!0,!1,!0,!0,!0,!0,!1,!1,!1,!1,!1,!1,!1,!0,!0,!1,!1,!0,!0,!1,!0,!0,!0,!0,!1,!0,!0,!0,!0,!0,!0,!1,!0,!0,!1,!0,!0,!1,!0,!0,!0,!0,!0,!0,!1,!0,!0,!1,!0,!1,!0,!0,!0,!0,!0,!0,!1,!0,!0,!0,!0,!0,!0,!1,!0,!0,!1,!1,!1,!1,!1,!0,!0,!1,!0,!1,!0,!0,!0,!0,!0,!1,!0,!0,!0,!0,!0,!1,!0,!0,!0,!0,!0,!1,!0,!0,!0,!1,!0,!0,!0,!0,!1,!1,!1,!0,!1,!0,!0,!0,!0,!0,!1,!0,!0,!0,!1,!0,!0,!0,!0,!0,!1,!0,!0,!0,!0,!1,!0,!0,!0,!0,!0,!1,!0,!0,!1,!0,!0,!0],tags:[[],["broken_cluster"],["consonant_syllable"],["vowel_syllable"],["broken_cluster"],["broken_cluster"],[],[],["broken_cluster"],["broken_cluster"],["broken_cluster"],["standalone_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["consonant_syllable"],["broken_cluster"],["symbol_cluster"],["consonant_syllable"],["consonant_syllable"],[],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["vowel_syllable"],["vowel_syllable"],[],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],[],["broken_cluster"],[],["broken_cluster"],["broken_cluster"],[],[],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["standalone_cluster"],["standalone_cluster"],[],[],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["broken_cluster"],["broken_cluster"],["consonant_syllable","broken_cluster"],["broken_cluster"],[],["broken_cluster"],["symbol_cluster"],[],["symbol_cluster"],["symbol_cluster"],["consonant_syllable"],[],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],[],["consonant_syllable"],[],["consonant_syllable"],["consonant_syllable"],[],[],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],[],["consonant_syllable"],["vowel_syllable"],[],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],[],["vowel_syllable"],[],["vowel_syllable"],["vowel_syllable"],[],[],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],[],["vowel_syllable"],["broken_cluster"],["broken_cluster"],[],["broken_cluster"],["broken_cluster"],["broken_cluster"],[],["broken_cluster"],[],["broken_cluster"],["broken_cluster"],[],[],[],["broken_cluster"],["broken_cluster"],[],[],["broken_cluster"],["broken_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],[],["standalone_cluster"],[],["standalone_cluster"],["standalone_cluster"],[],[],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],[],["standalone_cluster"],["broken_cluster"],[],["broken_cluster"],["broken_cluster"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable","broken_cluster"],["consonant_syllable","broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["symbol_cluster"],["symbol_cluster"],["symbol_cluster"],["consonant_syllable"],["consonant_syllable"],[],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],[],["consonant_syllable"],[],["consonant_syllable"],["consonant_syllable"],[],[],[],["consonant_syllable"],["consonant_syllable"],[],[],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],[],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["vowel_syllable"],["vowel_syllable"],[],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],[],["vowel_syllable"],[],["vowel_syllable"],["vowel_syllable"],[],[],[],["vowel_syllable"],["vowel_syllable"],[],[],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],[],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["broken_cluster"],[],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],[],["broken_cluster"],["broken_cluster"],[],[],[],[],["broken_cluster"],["broken_cluster"],[],[],["broken_cluster"],["standalone_cluster"],["standalone_cluster"],[],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],[],["standalone_cluster"],[],["standalone_cluster"],["standalone_cluster"],[],[],[],["standalone_cluster"],["standalone_cluster"],[],[],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],[],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],[],["broken_cluster"],[],["consonant_syllable","broken_cluster"],["consonant_syllable","broken_cluster"],["consonant_syllable","broken_cluster"],["consonant_syllable","broken_cluster"],["consonant_syllable","broken_cluster"],["consonant_syllable","broken_cluster"],["broken_cluster"],["symbol_cluster"],["consonant_syllable"],[],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],[],["consonant_syllable"],["consonant_syllable"],[],[],[],[],["consonant_syllable"],["consonant_syllable"],[],[],["consonant_syllable"],["consonant_syllable"],["vowel_syllable"],[],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],[],["vowel_syllable"],["vowel_syllable"],[],[],[],[],["vowel_syllable"],["vowel_syllable"],[],[],["vowel_syllable"],["vowel_syllable"],["broken_cluster"],["broken_cluster"],[],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],[],["broken_cluster"],["broken_cluster"],[],[],[],[],["broken_cluster"],[],["standalone_cluster"],[],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],[],["standalone_cluster"],["standalone_cluster"],[],[],[],[],["standalone_cluster"],["standalone_cluster"],[],[],["standalone_cluster"],["standalone_cluster"],["consonant_syllable","broken_cluster"],[],["consonant_syllable","broken_cluster"],["consonant_syllable","broken_cluster"],[],[],["consonant_syllable","broken_cluster"],[],["consonant_syllable","broken_cluster"],["consonant_syllable","broken_cluster"],[],["consonant_syllable","broken_cluster"],["consonant_syllable","broken_cluster"],[],["consonant_syllable"],["consonant_syllable"],[],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],[],["consonant_syllable"],["consonant_syllable"],[],[],[],[],["consonant_syllable"],[],["vowel_syllable"],["vowel_syllable"],[],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],[],["vowel_syllable"],["vowel_syllable"],[],[],[],[],["vowel_syllable"],[],["broken_cluster"],[],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],[],[],[],["standalone_cluster"],["standalone_cluster"],[],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],[],["standalone_cluster"],["standalone_cluster"],[],[],[],[],["standalone_cluster"],[],["consonant_syllable","broken_cluster"],[],["consonant_syllable","broken_cluster"],["consonant_syllable","broken_cluster"],[],[],["consonant_syllable","broken_cluster"],["consonant_syllable","broken_cluster"],[],[],["consonant_syllable","broken_cluster"],["consonant_syllable","broken_cluster"],["consonant_syllable","broken_cluster"],[],["consonant_syllable"],[],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],[],[],[],["vowel_syllable"],[],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],[],[],[],["broken_cluster"],["broken_cluster"],[],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],[],["broken_cluster"],["broken_cluster"],[],["standalone_cluster"],[],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],[],[],[],[],[],[],[],["consonant_syllable","broken_cluster"],["consonant_syllable","broken_cluster"],[],[],["consonant_syllable","broken_cluster"],["consonant_syllable","broken_cluster"],[],["consonant_syllable","broken_cluster"],["consonant_syllable","broken_cluster"],["consonant_syllable"],["consonant_syllable"],[],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],[],["consonant_syllable"],["consonant_syllable"],[],["vowel_syllable"],["vowel_syllable"],[],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],[],["vowel_syllable"],["vowel_syllable"],[],["broken_cluster"],[],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["standalone_cluster"],["standalone_cluster"],[],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],[],["standalone_cluster"],["standalone_cluster"],[],[],[],[],[],["consonant_syllable","broken_cluster"],["consonant_syllable","broken_cluster"],[],["consonant_syllable"],[],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["vowel_syllable"],[],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["broken_cluster"],[],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],["broken_cluster"],[],["broken_cluster"],["broken_cluster"],["standalone_cluster"],[],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],[],[],[],["consonant_syllable"],[],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],["consonant_syllable"],[],["consonant_syllable"],["consonant_syllable"],["vowel_syllable"],[],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],["vowel_syllable"],[],["vowel_syllable"],["vowel_syllable"],["broken_cluster"],["standalone_cluster"],[],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],["standalone_cluster"],[],["standalone_cluster"],["standalone_cluster"],[],["consonant_syllable"],["vowel_syllable"],["standalone_cluster"]]}),yi=function(A){function t(){return A.apply(this,arguments)||this}return s(t,A),t.planFeatures=function(A){A.addStage(Yi),A.addStage(["locl","ccmp"]),A.addStage(Ti),A.addStage("nukt"),A.addStage("akhn"),A.addStage("rphf",!1),A.addStage("rkrf"),A.addStage("pref",!1),A.addStage("blwf",!1),A.addStage("abvf",!1),A.addStage("half",!1),A.addStage("pstf",!1),A.addStage("vatu"),A.addStage("cjct"),A.addStage("cfar",!1),A.addStage(Pi),A.addStage({local:["init"],global:["pres","abvs","blws","psts","haln","dist","abvm","blwm","calt","clig"]}),A.unicodeScript=function(A){return Ar[A]}(A.script),A.indicConfig=Ci[A.unicodeScript]||Ci.Default,A.isOldSpec=A.indicConfig.hasOldSpec&&"2"!==A.script[A.script.length-1]},t.assignFeatures=function(A,t){for(var e=function(e){var n=t[e].codePoints[0],r=Mi[n]||Ii[n];if(r){var i=r.map((function(n){var r=A.font.glyphForCodePoint(n);return new Vr(A.font,r.id,[n],t[e].features)}));t.splice.apply(t,[e,1].concat(i))}},n=t.length-1;n>=0;n--)e(n)},t}(Ur);function vi(A){return pi.get(A.codePoints[0])>>8}function mi(A){return 1<<(255&pi.get(A.codePoints[0]))}D(yi,"zeroMarkWidths","NONE");var Fi=function(A,t,e,n){this.category=A,this.position=t,this.syllableType=e,this.syllable=n};function Yi(A,t){for(var e,n=0,r=0,i=c(Di.match(t.map(vi)));!(e=i()).done;){var o=e.value,s=o[0],a=o[1],B=o[2];if(s>r){++n;for(var g=r;g<s;g++)t[g].shaperInfo=new Fi(1,Ei.End,"non_indic_cluster",n)}++n;for(var l=s;l<=a;l++)t[l].shaperInfo=new Fi(1<<vi(t[l]),mi(t[l]),B[0],n);r=a+1}if(r<t.length){++n;for(var u=r;u<t.length;u++)t[u].shaperInfo=new Fi(1,Ei.End,"non_indic_cluster",n)}}function bi(A){return A.shaperInfo.category&fi}function zi(A){return A.shaperInfo.category&Qi}function Ui(A){return A.shaperInfo.category&di}function Si(A,t){for(var e,n=c(A);!(e=n()).done;){var r;e.value.features=((r={})[t]=!0,r)}return A[0]._font._layoutEngine.engine.GSUBProcessor.applyFeatures([t],A),1===A.length}function xi(A,t,e){var n=[e,t,e];return Si(n.slice(0,2),"blwf")||Si(n.slice(1,3),"blwf")?Ei.Below_C:Si(n.slice(0,2),"pstf")||Si(n.slice(1,3),"pstf")||Si(n.slice(0,2),"pref")||Si(n.slice(1,3),"pref")?Ei.Post_C:Ei.Base_C}function Ti(A,t,e){var n=e.indicConfig,r=A._layoutEngine.engine.GSUBProcessor.features,i=A.glyphForCodePoint(9676).id,o=A.glyphForCodePoint(n.virama).id;if(o)for(var s=new Vr(A,o,[n.virama]),a=0;a<t.length;a++)t[a].shaperInfo.position===Ei.Base_C&&(t[a].shaperInfo.position=xi(0,t[a].copy(),s));for(var c=0,B=Ni(t,0);c<t.length;B=Ni(t,c=B)){var g=t[c].shaperInfo,l=(g.category,g.syllableType);if("symbol_cluster"!==l&&"non_indic_cluster"!==l){if("broken_cluster"===l&&i){var u=new Vr(A,i,[9676]);u.shaperInfo=new Fi(1<<vi(u),mi(u),t[c].shaperInfo.syllableType,t[c].shaperInfo.syllable);for(var w=c;w<B&&t[w].shaperInfo.category===wi;)w++;t.splice(w++,0,u),B++}var h=B,E=c,f=!1;if(n.rephPos!==Ei.Ra_To_Become_Reph&&r.rphf&&c+3<=B&&("Implicit"===n.rephMode&&!zi(t[c+2])||"Explicit"===n.rephMode&&64===t[c+2].shaperInfo.category)){var Q=[t[c].copy(),t[c+1].copy(),t[c+2].copy()];if(Si(Q.slice(0,2),"rphf")||"Explicit"===n.rephMode&&Si(Q,"rphf")){for(E+=2;E<B&&zi(t[E]);)E++;h=c,f=!0}}else if("Log_Repha"===n.rephMode&&t[c].shaperInfo.category===wi){for(E++;E<B&&zi(t[E]);)E++;h=c,f=!0}switch(n.basePos){case"Last":var d=B,C=!1;do{var M=t[--d].shaperInfo;if(bi(t[d])){if(M.position!==Ei.Below_C&&(M.position!==Ei.Post_C||C)){h=d;break}M.position===Ei.Below_C&&(C=!0),h=d}else if(c<d&&64===M.category&&t[d-1].shaperInfo.category===li)break}while(d>E);break;case"First":for(var I=(h=c)+1;I<B;I++)bi(t[I])&&(t[I].shaperInfo.position=Ei.Below_C)}f&&h===c&&E-h<=2&&(f=!1);for(var p=c;p<h;p++){var D=t[p].shaperInfo;D.position=Math.min(Ei.Pre_C,D.position)}h<B&&(t[h].shaperInfo.position=Ei.Base_C);for(var y=h+1;y<B;y++)if(t[y].shaperInfo.category===ui){for(var v=y+1;v<B;v++)if(bi(t[v])){t[v].shaperInfo.position=Ei.Final_C;break}break}if(f&&(t[c].shaperInfo.position=Ei.Ra_To_Become_Reph),e.isOldSpec)for(var m="Malayalam"!==e.unicodeScript,F=h+1;F<B;F++)if(t[F].shaperInfo.category===li){var Y=void 0;for(Y=B-1;Y>F&&!(bi(t[Y])||m&&t[Y].shaperInfo.category===li);Y--);if(t[Y].shaperInfo.category!==li&&Y>F){var b=t[F];t.splice.apply(t,[F,0].concat(t.splice(F+1,Y-F))),t[Y]=b}break}for(var z=Ei.Start,U=c;U<B;U++){var S=t[U].shaperInfo;if(S.category&(8200|Qi|hi|di&S.category)){if(S.position=z,S.category===li&&S.position===Ei.Pre_M)for(var x=U;x>c;x--)if(t[x-1].shaperInfo.position!==Ei.Pre_M){S.position=t[x-1].shaperInfo.position;break}}else S.position!==Ei.SMVD&&(z=S.position)}for(var T=h,P=h+1;P<B;P++)if(bi(t[P])){for(var N=T+1;N<P;N++)t[N].shaperInfo.position<Ei.SMVD&&(t[N].shaperInfo.position=t[P].shaperInfo.position);T=P}else t[P].shaperInfo.category===ui&&(T=P);var R=t.slice(c,B);R.sort((function(A,t){return A.shaperInfo.position-t.shaperInfo.position})),t.splice.apply(t,[c,R.length].concat(R));for(var G=c;G<B;G++)if(t[G].shaperInfo.position===Ei.Base_C){h=G;break}for(var H=c;H<B&&t[H].shaperInfo.position===Ei.Ra_To_Become_Reph;H++)t[H].features.rphf=!0;for(var k=!e.isOldSpec&&"Pre_And_Post"===n.blwfMode,L=c;L<h;L++)t[L].features.half=!0,k&&(t[L].features.blwf=!0);for(var J=h+1;J<B;J++)t[J].features.abvf=!0,t[J].features.pstf=!0,t[J].features.blwf=!0;if(e.isOldSpec&&"Devanagari"===e.unicodeScript)for(var j=c;j+1<h;j++)65536!==t[j].shaperInfo.category||t[j+1].shaperInfo.category!==li||j+1!==h&&64!==t[j+2].shaperInfo.category||(t[j].features.blwf=!0,t[j+1].features.blwf=!0);if(r.pref&&h+2<B)for(var O=h+1;O+2-1<B;O++)if(Si([t[O].copy(),t[O+1].copy()],"pref")){for(var W=0;W<2;W++)t[O++].features.pref=!0;if(r.cfar)for(;O<B;O++)t[O].features.cfar=!0;break}for(var K=c+1;K<B;K++)if(zi(t[K])){var V=32===t[K].shaperInfo.category,X=K;do{X--,V&&delete t[X].features.half}while(X>c&&!bi(t[X]))}}}}function Pi(A,t,e){for(var n=e.indicConfig,r=A._layoutEngine.engine.GSUBProcessor.features,i=0,o=Ni(t,0);i<t.length;o=Ni(t,i=o)){for(var s=!!r.pref,a=i;a<o;a++)if(t[a].shaperInfo.position>=Ei.Base_C){if(s&&a+1<o)for(var c=a+1;c<o;c++)if(t[c].features.pref){if(!t[c].substituted||!t[c].isLigated||t[c].isMultiplied){for(a=c;a<o&&Ui(t[a]);)a++;t[a].shaperInfo.position=Ei.BASE_C,s=!1}break}if("Malayalam"===e.unicodeScript)for(var B=a+1;B<o;B++){for(;B<o&&zi(t[B]);)B++;if(B===o||!Ui(t[B]))break;for(B++;B<o&&zi(t[B]);)B++;B<o&&bi(t[B])&&t[B].shaperInfo.position===Ei.Below_C&&(t[a=B].shaperInfo.position=Ei.Base_C)}i<a&&t[a].shaperInfo.position>Ei.Base_C&&a--;break}if(a===o&&i<a&&64===t[a-1].shaperInfo.category&&a--,a<o)for(;i<a&&t[a].shaperInfo.category&(8|di);)a--;if(i+1<o&&i<a){var g=a===o?a-2:a-1;if("Malayalam"!==e.unicodeScript&&"Tamil"!==e.unicodeScript){for(;g>i&&!(t[g].shaperInfo.category&(ui|di));)g--;Ui(t[g])&&t[g].shaperInfo.position!==Ei.Pre_M?g+1<o&&zi(t[g+1])&&g++:g=i}if(i<g&&t[g].shaperInfo.position!==Ei.Pre_M)for(var l=g;l>i;l--)if(t[l-1].shaperInfo.position===Ei.Pre_M){var u=l-1;u<a&&a<=g&&a--;var w=t[u];t.splice.apply(t,[u,0].concat(t.splice(u+1,g-u))),t[g]=w,g--}}if(i+1<o&&t[i].shaperInfo.position===Ei.Ra_To_Become_Reph&&t[i].shaperInfo.category===wi!==(t[i].isLigated&&!t[i].isMultiplied)){var E=void 0,f=n.rephPos,Q=!1;if(f!==Ei.After_Post){for(E=i+1;E<a&&!Ui(t[E]);)E++;if(E<a&&Ui(t[E])&&(E+1<a&&zi(t[E+1])&&E++,Q=!0),!Q&&f===Ei.After_Main){for(E=a;E+1<o&&t[E+1].shaperInfo.position<=Ei.After_Main;)E++;Q=E<o}if(!Q&&f===Ei.After_Sub){for(E=a;E+1<o&&!(t[E+1].shaperInfo.position&(Ei.Post_C|Ei.After_Post|Ei.SMVD));)E++;Q=E<o}}if(!Q){for(E=i+1;E<a&&!Ui(t[E]);)E++;E<a&&Ui(t[E])&&(E+1<a&&zi(t[E+1])&&E++,Q=!0)}if(!Q){for(E=o-1;E>i&&t[E].shaperInfo.position===Ei.SMVD;)E--;if(Ui(t[E]))for(var d=a+1;d<E;d++)t[d].shaperInfo.category===ui&&E--}var C=t[i];t.splice.apply(t,[i,0].concat(t.splice(i+1,E-i))),t[E]=C,i<a&&a<=E&&a--}if(s&&a+1<o)for(var M=a+1;M<o;M++)if(t[M].features.pref){if(t[M].isLigated&&!t[M].isMultiplied){var I=a;if("Malayalam"!==e.unicodeScript&&"Tamil"!==e.unicodeScript){for(;I>i&&!(t[I-1].shaperInfo.category&(ui|di));)I--;if(I>i&&t[I-1].shaperInfo.category===ui)for(var p=M,D=a+1;D<p;D++)if(t[D].shaperInfo.category===ui){I--;break}}I>i&&Ui(t[I-1])&&I<o&&zi(t[I])&&I++;var y=M,v=t[y];t.splice.apply(t,[I+1,0].concat(t.splice(I,y-I))),t[I]=v,I<=a&&a<y&&a++}break}t[i].shaperInfo.position!==Ei.Pre_M||i&&/Cf|Mn/.test(h.getCategory(t[i-1].codePoints[0]))||(t[i].features.init=!0)}}function Ni(A,t){if(t>=A.length)return t;for(var e=A[t].shaperInfo.syllable;++t<A.length&&A[t].shaperInfo.syllable===e;);return t}var Ri=gi.categories,Gi=gi.decompositions,Hi=new E(r(" ","base64")),ki=new f(gi),Li=function(A){function t(){return A.apply(this,arguments)||this}return s(t,A),t.planFeatures=function(A){A.addStage(Oi),A.addStage(["locl","ccmp","nukt","akhn"]),A.addStage(Wi),A.addStage(["rphf"],!1),A.addStage(Ki),A.addStage(Wi),A.addStage(["pref"]),A.addStage(Vi),A.addStage(["rkrf","abvf","blwf","half","pstf","vatu","cjct"]),A.addStage(Xi),A.addStage(["abvs","blws","pres","psts","dist","abvm","blwm"])},t.assignFeatures=function(A,t){for(var e=function(e){var n=t[e].codePoints[0];if(Gi[n]){var r=Gi[n].map((function(n){var r=A.font.glyphForCodePoint(n);return new Vr(A.font,r.id,[n],t[e].features)}));t.splice.apply(t,[e,1].concat(r))}},n=t.length-1;n>=0;n--)e(n)},t}(Ur);function Ji(A){return Hi.get(A.codePoints[0])}D(Li,"zeroMarkWidths","BEFORE_GPOS");var ji=function(A,t,e){this.category=A,this.syllableType=t,this.syllable=e};function Oi(A,t){for(var e,n=0,r=c(ki.match(t.map(Ji)));!(e=r()).done;){var i=e.value,o=i[0],s=i[1],a=i[2];++n;for(var B=o;B<=s;B++)t[B].shaperInfo=new ji(Ri[Ji(t[B])],a[0],n);for(var g="R"===t[o].shaperInfo.category?1:Math.min(3,s-o),l=o;l<o+g;l++)t[l].features.rphf=!0}}function Wi(A,t){for(var e,n=c(t);!(e=n()).done;)e.value.substituted=!1}function Ki(A,t){for(var e,n=c(t);!(e=n()).done;){var r=e.value;r.substituted&&r.features.rphf&&(r.shaperInfo.category="R")}}function Vi(A,t){for(var e,n=c(t);!(e=n()).done;){var r=e.value;r.substituted&&(r.shaperInfo.category="VPre")}}function Xi(A,t){for(var e=A.glyphForCodePoint(9676).id,n=0,r=Zi(t,0);n<t.length;r=Zi(t,n=r)){var i=void 0,o=void 0,s=t[n].shaperInfo,a=s.syllableType;if("virama_terminated_cluster"===a||"standard_cluster"===a||"broken_cluster"===a){if("broken_cluster"===a&&e){var c=new Vr(A,e,[9676]);for(c.shaperInfo=s,i=n;i<r&&"R"===t[i].shaperInfo.category;i++);t.splice(++i,0,c),r++}if("R"===s.category&&r-n>1)for(i=n+1;i<r;i++)if(qi(s=t[i].shaperInfo)||_i(t[i])){_i(t[i])&&i--,t.splice.apply(t,[n,0].concat(t.splice(n+1,i-n),[t[i]]));break}for(i=n,o=r;i<r;i++)qi(s=t[i].shaperInfo)||_i(t[i])?o=_i(t[i])?i+1:i:("VPre"===s.category||"VMPre"===s.category)&&o<i&&t.splice.apply(t,[o,1,t[i]].concat(t.splice(o,i-o)))}}}function Zi(A,t){if(t>=A.length)return t;for(var e=A[t].shaperInfo.syllable;++t<A.length&&A[t].shaperInfo.syllable===e;);return t}function _i(A){return"H"===A.shaperInfo.category&&!A.isLigated}function qi(A){return"B"===A.category||"GB"===A.category}for(var $i={arab:Jr,mong:Jr,syrc:Jr,"nko ":Jr,phag:Jr,mand:Jr,mani:Jr,phlp:Jr,hang:Xr,bng2:yi,beng:yi,dev2:yi,deva:yi,gjr2:yi,gujr:yi,guru:yi,gur2:yi,knda:yi,knd2:yi,mlm2:yi,mlym:yi,ory2:yi,orya:yi,taml:yi,tml2:yi,telu:yi,tel2:yi,khmr:yi,bali:Li,batk:Li,brah:Li,bugi:Li,buhd:Li,cakm:Li,cham:Li,dupl:Li,egyp:Li,gran:Li,hano:Li,java:Li,kthi:Li,kali:Li,khar:Li,khoj:Li,sind:Li,lepc:Li,limb:Li,mahj:Li,mtei:Li,modi:Li,hmng:Li,rjng:Li,saur:Li,shrd:Li,sidd:Li,sinh:Li,sund:Li,sylo:Li,tglg:Li,tagb:Li,tale:Li,lana:Li,tavt:Li,takr:Li,tibt:Li,tfng:Li,tirh:Li,latn:Ur,DFLT:Ur},Ao=function(A){function t(){return A.apply(this,arguments)||this}return s(t,A),t.prototype.applyLookup=function(A,t){var e=this;switch(A){case 1:var n=this.coverageIndex(t.coverage);if(-1===n)return!1;var r=this.glyphIterator.cur;switch(t.version){case 1:r.id=r.id+t.deltaGlyphID&65535;break;case 2:r.id=t.substitute.get(n)}return!0;case 2:var i=this.coverageIndex(t.coverage);if(-1!==i){var o,s=t.sequences.get(i);if(0===s.length)return this.glyphs.splice(this.glyphIterator.index,1),!0;this.glyphIterator.cur.id=s[0],this.glyphIterator.cur.ligatureComponent=0;var a=this.glyphIterator.cur.features,B=this.glyphIterator.cur,g=s.slice(1).map((function(A,t){var n=new Vr(e.font,A,void 0,a);return n.shaperInfo=B.shaperInfo,n.isLigated=B.isLigated,n.ligatureComponent=t+1,n.substituted=!0,n.isMultiplied=!0,n}));return(o=this.glyphs).splice.apply(o,[this.glyphIterator.index+1,0].concat(g)),!0}return!1;case 3:var l=this.coverageIndex(t.coverage);return-1!==l&&(this.glyphIterator.cur.id=t.alternateSet.get(l)[0],!0);case 4:var u=this.coverageIndex(t.coverage);if(-1===u)return!1;for(var w,h=c(t.ligatureSets.get(u));!(w=h()).done;){var E=w.value,f=this.sequenceMatchIndices(1,E.components);if(f){for(var Q,d=this.glyphIterator.cur,C=d.codePoints.slice(),M=c(f);!(Q=M()).done;){var I,p=Q.value;(I=C).push.apply(I,this.glyphs[p].codePoints)}var D=new Vr(this.font,E.glyph,C,d.features);D.shaperInfo=d.shaperInfo,D.isLigated=!0,D.substituted=!0;for(var y=d.isMark,v=0;v<f.length&&y;v++)y=this.glyphs[f[v]].isMark;D.ligatureID=y?null:this.ligatureID++;for(var m,F=d.ligatureID,Y=d.codePoints.length,b=Y,z=this.glyphIterator.index+1,U=c(f);!(m=U()).done;){var S=m.value;if(y)z=S;else for(;z<S;){var x=b-Y+Math.min(this.glyphs[z].ligatureComponent||1,Y);this.glyphs[z].ligatureID=D.ligatureID,this.glyphs[z].ligatureComponent=x,z++}F=this.glyphs[z].ligatureID,b+=Y=this.glyphs[z].codePoints.length,z++}if(F&&!y)for(var T=z;T<this.glyphs.length&&this.glyphs[T].ligatureID===F;T++)x=b-Y+Math.min(this.glyphs[T].ligatureComponent||1,Y),this.glyphs[T].ligatureComponent=x;for(var P=f.length-1;P>=0;P--)this.glyphs.splice(f[P],1);return this.glyphs[this.glyphIterator.index]=D,!0}}return!1;case 5:return this.applyContext(t);case 6:return this.applyChainingContext(t);case 7:return this.applyLookup(t.lookupType,t.extension);default:throw new Error("GSUB lookupType ".concat(A," is not supported"))}},t}(Kr),to=function(A){function t(){return A.apply(this,arguments)||this}s(t,A);var e=t.prototype;return e.applyPositionValue=function(A,t){var e=this.positions[this.glyphIterator.peekIndex(A)];null!=t.xAdvance&&(e.xAdvance+=t.xAdvance),null!=t.yAdvance&&(e.yAdvance+=t.yAdvance),null!=t.xPlacement&&(e.xOffset+=t.xPlacement),null!=t.yPlacement&&(e.yOffset+=t.yPlacement);var n=this.font._variationProcessor,r=this.font.GDEF&&this.font.GDEF.itemVariationStore;n&&r&&(t.xPlaDevice&&(e.xOffset+=n.getDelta(r,t.xPlaDevice.a,t.xPlaDevice.b)),t.yPlaDevice&&(e.yOffset+=n.getDelta(r,t.yPlaDevice.a,t.yPlaDevice.b)),t.xAdvDevice&&(e.xAdvance+=n.getDelta(r,t.xAdvDevice.a,t.xAdvDevice.b)),t.yAdvDevice&&(e.yAdvance+=n.getDelta(r,t.yAdvDevice.a,t.yAdvDevice.b)))},e.applyLookup=function(A,t){switch(A){case 1:var e=this.coverageIndex(t.coverage);if(-1===e)return!1;switch(t.version){case 1:this.applyPositionValue(0,t.value);break;case 2:this.applyPositionValue(0,t.values.get(e))}return!0;case 2:var n=this.glyphIterator.peek();if(!n)return!1;var r=this.coverageIndex(t.coverage);if(-1===r)return!1;switch(t.version){case 1:for(var i,o=c(t.pairSets.get(r));!(i=o()).done;){var s=i.value;if(s.secondGlyph===n.id)return this.applyPositionValue(0,s.value1),this.applyPositionValue(1,s.value2),!0}return!1;case 2:var a=this.getClassID(this.glyphIterator.cur.id,t.classDef1),B=this.getClassID(n.id,t.classDef2);if(-1===a||-1===B)return!1;var g=t.classRecords.get(a).get(B);return this.applyPositionValue(0,g.value1),this.applyPositionValue(1,g.value2),!0}case 3:var l=this.glyphIterator.peekIndex(),u=this.glyphs[l];if(!u)return!1;var w=t.entryExitRecords[this.coverageIndex(t.coverage)];if(!w||!w.exitAnchor)return!1;var h=t.entryExitRecords[this.coverageIndex(t.coverage,u.id)];if(!h||!h.entryAnchor)return!1;var E=this.getAnchor(h.entryAnchor),f=this.getAnchor(w.exitAnchor),Q=this.positions[this.glyphIterator.index],d=this.positions[l];switch(this.direction){case"ltr":Q.xAdvance=f.x+Q.xOffset;var C=E.x+d.xOffset;d.xAdvance-=C,d.xOffset-=C;break;case"rtl":C=f.x+Q.xOffset,Q.xAdvance-=C,Q.xOffset-=C,d.xAdvance=E.x+d.xOffset}return this.glyphIterator.flags.rightToLeft?(this.glyphIterator.cur.cursiveAttachment=l,Q.yOffset=E.y-f.y):(u.cursiveAttachment=this.glyphIterator.index,Q.yOffset=f.y-E.y),!0;case 4:var M=this.coverageIndex(t.markCoverage);if(-1===M)return!1;for(var I=this.glyphIterator.index;--I>=0&&(this.glyphs[I].isMark||this.glyphs[I].ligatureComponent>0););if(I<0)return!1;var p=this.coverageIndex(t.baseCoverage,this.glyphs[I].id);if(-1===p)return!1;var D=t.markArray[M],y=t.baseArray[p][D.class];return this.applyAnchor(D,y,I),!0;case 5:var v=this.coverageIndex(t.markCoverage);if(-1===v)return!1;for(var m=this.glyphIterator.index;--m>=0&&this.glyphs[m].isMark;);if(m<0)return!1;var F=this.coverageIndex(t.ligatureCoverage,this.glyphs[m].id);if(-1===F)return!1;var Y=t.ligatureArray[F],b=this.glyphIterator.cur,z=this.glyphs[m],U=z.ligatureID&&z.ligatureID===b.ligatureID&&b.ligatureComponent>0?Math.min(b.ligatureComponent,z.codePoints.length)-1:z.codePoints.length-1,S=t.markArray[v],x=Y[U][S.class];return this.applyAnchor(S,x,m),!0;case 6:var T=this.coverageIndex(t.mark1Coverage);if(-1===T)return!1;var P=this.glyphIterator.peekIndex(-1),N=this.glyphs[P];if(!N||!N.isMark)return!1;var R=this.glyphIterator.cur,G=!1;if(R.ligatureID===N.ligatureID?R.ligatureID?R.ligatureComponent===N.ligatureComponent&&(G=!0):G=!0:(R.ligatureID&&!R.ligatureComponent||N.ligatureID&&!N.ligatureComponent)&&(G=!0),!G)return!1;var H=this.coverageIndex(t.mark2Coverage,N.id);if(-1===H)return!1;var k=t.mark1Array[T],L=t.mark2Array[H][k.class];return this.applyAnchor(k,L,P),!0;case 7:return this.applyContext(t);case 8:return this.applyChainingContext(t);case 9:return this.applyLookup(t.lookupType,t.extension);default:throw new Error("Unsupported GPOS table: ".concat(A))}},e.applyAnchor=function(A,t,e){var n=this.getAnchor(t),r=this.getAnchor(A.markAnchor),i=(this.positions[e],this.positions[this.glyphIterator.index]);i.xOffset=n.x-r.x,i.yOffset=n.y-r.y,this.glyphIterator.cur.markAttachment=e},e.getAnchor=function(A){var t=A.xCoordinate,e=A.yCoordinate,n=this.font._variationProcessor,r=this.font.GDEF&&this.font.GDEF.itemVariationStore;return n&&r&&(A.xDeviceTable&&(t+=n.getDelta(r,A.xDeviceTable.a,A.xDeviceTable.b)),A.yDeviceTable&&(e+=n.getDelta(r,A.yDeviceTable.a,A.yDeviceTable.b))),{x:t,y:e}},e.applyFeatures=function(t,e,n){A.prototype.applyFeatures.call(this,t,e,n);for(var r=0;r<this.glyphs.length;r++)this.fixCursiveAttachment(r);this.fixMarkAttachment()},e.fixCursiveAttachment=function(A){var t=this.glyphs[A];if(null!=t.cursiveAttachment){var e=t.cursiveAttachment;t.cursiveAttachment=null,this.fixCursiveAttachment(e),this.positions[A].yOffset+=this.positions[e].yOffset}},e.fixMarkAttachment=function(){for(var A=0;A<this.glyphs.length;A++){var t=this.glyphs[A];if(null!=t.markAttachment){var e=t.markAttachment;if(this.positions[A].xOffset+=this.positions[e].xOffset,this.positions[A].yOffset+=this.positions[e].yOffset,"ltr"===this.direction)for(var n=e;n<A;n++)this.positions[A].xOffset-=this.positions[n].xAdvance,this.positions[A].yOffset-=this.positions[n].yAdvance;else for(var r=e+1;r<A+1;r++)this.positions[A].xOffset+=this.positions[r].xAdvance,this.positions[A].yOffset+=this.positions[r].yAdvance}}},t}(Kr),eo=function(){function A(A){this.font=A,this.glyphInfos=null,this.plan=null,this.GSUBProcessor=null,this.GPOSProcessor=null,this.fallbackPosition=!0,A.GSUB&&(this.GSUBProcessor=new Ao(A,A.GSUB)),A.GPOS&&(this.GPOSProcessor=new to(A,A.GPOS))}var t=A.prototype;return t.setup=function(A){var t=this;this.glyphInfos=A.glyphs.map((function(A){return new Vr(t.font,A.id,[].concat(A.codePoints))}));var e=null;for(var n in this.GPOSProcessor&&(e=this.GPOSProcessor.selectScript(A.script,A.language,A.direction)),this.GSUBProcessor&&(e=this.GSUBProcessor.selectScript(A.script,A.language,A.direction)),this.shaper=function(A){Array.isArray(A)||(A=[A]);for(var t,e=c(A);!(t=e()).done;){var n=t.value,r=$i[n];if(r)return r}return Ur}(e),this.plan=new vr(this.font,e,A.direction),this.shaper.plan(this.plan,this.glyphInfos,A.features),this.plan.allFeatures)A.features[n]=!0},t.substitute=function(A){var t=this;this.GSUBProcessor&&(this.plan.process(this.GSUBProcessor,this.glyphInfos),A.glyphs=this.glyphInfos.map((function(A){return t.font.getGlyph(A.id,A.codePoints)})))},t.position=function(A){return"BEFORE_GPOS"===this.shaper.zeroMarkWidths&&this.zeroMarkAdvances(A.positions),this.GPOSProcessor&&this.plan.process(this.GPOSProcessor,this.glyphInfos,A.positions),"AFTER_GPOS"===this.shaper.zeroMarkWidths&&this.zeroMarkAdvances(A.positions),"rtl"===A.direction&&(A.glyphs.reverse(),A.positions.reverse()),this.GPOSProcessor&&this.GPOSProcessor.features},t.zeroMarkAdvances=function(A){for(var t=0;t<this.glyphInfos.length;t++)this.glyphInfos[t].isMark&&(A[t].xAdvance=0,A[t].yAdvance=0)},t.cleanup=function(){this.glyphInfos=null,this.plan=null,this.shaper=null},t.getAvailableFeatures=function(A,t){var e=[];return this.GSUBProcessor&&(this.GSUBProcessor.selectScript(A,t),e.push.apply(e,Object.keys(this.GSUBProcessor.features))),this.GPOSProcessor&&(this.GPOSProcessor.selectScript(A,t),e.push.apply(e,Object.keys(this.GPOSProcessor.features))),e},A}(),no=function(){function A(A){this.font=A,this.unicodeLayoutEngine=null,this.kernProcessor=null,this.font.morx?this.engine=new yr(this.font):(this.font.GSUB||this.font.GPOS)&&(this.engine=new eo(this.font))}var t=A.prototype;return t.layout=function(A,t,e,n,r){if("string"==typeof t&&(r=n,n=e,e=t,t=[]),"string"==typeof A){null==e&&(e=function(A){for(var t=A.length,e=0;e<t;){var n=A.charCodeAt(e++);if(55296<=n&&n<=56319&&e<t){var r=A.charCodeAt(e);56320<=r&&r<=57343&&(e++,n=((1023&n)<<10)+(1023&r)+65536)}var i=h.getScript(n);if("Common"!==i&&"Inherited"!==i&&"Unknown"!==i)return $n[i]}return $n.Unknown}(A));var i=this.font.glyphsForString(A)}else{if(null==e){for(var o,s=[],a=c(A);!(o=a()).done;){var B=o.value;s.push.apply(s,B.codePoints)}e=function(A){for(var t=0;t<A.length;t++){var e=A[t],n=h.getScript(e);if("Common"!==n&&"Inherited"!==n&&"Unknown"!==n)return $n[n]}return $n.Unknown}(s)}i=A}var g=new ar(i,t,e,n,r);return 0===i.length?(g.positions=[],g):(this.engine&&this.engine.setup&&this.engine.setup(g),this.substitute(g),this.position(g),this.hideDefaultIgnorables(g.glyphs,g.positions),this.engine&&this.engine.cleanup&&this.engine.cleanup(),g)},t.substitute=function(A){this.engine&&this.engine.substitute&&this.engine.substitute(A)},t.position=function(A){A.positions=A.glyphs.map((function(A){return new cr(A.advanceWidth)}));var t=null;this.engine&&this.engine.position&&(t=this.engine.position(A)),t||this.engine&&!this.engine.fallbackPosition||(this.unicodeLayoutEngine||(this.unicodeLayoutEngine=new _n(this.font)),this.unicodeLayoutEngine.positionGlyphs(A.glyphs,A.positions)),t&&t.kern||!1===A.features.kern||!this.font.kern||(this.kernProcessor||(this.kernProcessor=new Zn(this.font)),this.kernProcessor.process(A.glyphs,A.positions),A.features.kern=!0)},t.hideDefaultIgnorables=function(A,t){for(var e=this.font.glyphForCodePoint(32),n=0;n<A.length;n++)this.isDefaultIgnorable(A[n].codePoints[0])&&(A[n]=e,t[n].xAdvance=0,t[n].yAdvance=0)},t.isDefaultIgnorable=function(A){var t=A>>16;if(0===t)switch(A>>8){case 0:return 173===A;case 3:return 847===A;case 6:return 1564===A;case 23:return 6068<=A&&A<=6069;case 24:return 6155<=A&&A<=6158;case 32:return 8203<=A&&A<=8207||8234<=A&&A<=8238||8288<=A&&A<=8303;case 254:return 65024<=A&&A<=65039||65279===A;case 255:return 65520<=A&&A<=65528;default:return!1}else switch(t){case 1:return 113824<=A&&A<=113827||119155<=A&&A<=119162;case 14:return 917504<=A&&A<=921599;default:return!1}},t.getAvailableFeatures=function(A,t){var e=[];return this.engine&&e.push.apply(e,this.engine.getAvailableFeatures(A,t)),this.font.kern&&-1===e.indexOf("kern")&&e.push("kern"),e},t.stringsForGlyph=function(A){for(var t,e=new Set,n=c(this.font._cmapProcessor.codePointsForGlyph(A));!(t=n()).done;){var r=t.value;e.add(String.fromCodePoint(r))}if(this.engine&&this.engine.stringsForGlyph)for(var i,o=c(this.engine.stringsForGlyph(A));!(i=o()).done;){var s=i.value;e.add(s)}return Array.from(e)},A}(),ro={moveTo:"M",lineTo:"L",quadraticCurveTo:"Q",bezierCurveTo:"C",closePath:"Z"},io=function(){function A(){this.commands=[],this._bbox=null,this._cbox=null}var t=A.prototype;return t.toFunction=function(){var A=this;return function(t){A.commands.forEach((function(A){return t[A.command].apply(t,A.args)}))}},t.toSVG=function(){return this.commands.map((function(A){var t=A.args.map((function(A){return Math.round(100*A)/100}));return"".concat(ro[A.command]).concat(t.join(" "))})).join("")},t.mapPoints=function(t){for(var e,n=new A,r=c(this.commands);!(e=r()).done;){for(var i=e.value,o=[],s=0;s<i.args.length;s+=2){var a=t(i.args[s],i.args[s+1]),B=a[0],g=a[1];o.push(B,g)}n[i.command].apply(n,o)}return n},t.transform=function(A,t,e,n,r,i){return this.mapPoints((function(o,s){return[o=A*o+e*s+r,s=t*o+n*s+i]}))},t.translate=function(A,t){return this.transform(1,0,0,1,A,t)},t.rotate=function(A){var t=Math.cos(A),e=Math.sin(A);return this.transform(t,e,-e,t,0,0)},t.scale=function(A,t){return void 0===t&&(t=A),this.transform(A,0,0,t,0,0)},o(A,[{key:"cbox",get:function(){if(!this._cbox){for(var A,t=new qn,e=c(this.commands);!(A=e()).done;)for(var n=A.value,r=0;r<n.args.length;r+=2)t.addPoint(n.args[r],n.args[r+1]);this._cbox=Object.freeze(t)}return this._cbox}},{key:"bbox",get:function(){if(this._bbox)return this._bbox;for(var A,t=new qn,e=0,n=0,r=function(A){return Math.pow(1-A,3)*M[y]+3*Math.pow(1-A,2)*A*I[y]+3*(1-A)*Math.pow(A,2)*p[y]+Math.pow(A,3)*D[y]},i=c(this.commands);!(A=i()).done;){var o=A.value;switch(o.command){case"moveTo":case"lineTo":var s=o.args,a=s[0],B=s[1];t.addPoint(a,B),e=a,n=B;break;case"quadraticCurveTo":case"bezierCurveTo":if("quadraticCurveTo"===o.command)var g=o.args,l=g[0],u=g[1],w=e+2/3*(l-e),h=n+2/3*(u-n),E=(d=g[2])+2/3*(l-d),f=(C=g[3])+2/3*(u-C);else var Q=o.args,d=(w=Q[0],h=Q[1],E=Q[2],f=Q[3],Q[4]),C=Q[5];t.addPoint(d,C);for(var M=[e,n],I=[w,h],p=[E,f],D=[d,C],y=0;y<=1;y++){var v=6*M[y]-12*I[y]+6*p[y],m=-3*M[y]+9*I[y]-9*p[y]+3*D[y];if(o=3*I[y]-3*M[y],0!==m){var F=Math.pow(v,2)-4*o*m;if(!(F<0)){var Y=(-v+Math.sqrt(F))/(2*m);0<Y&&Y<1&&(0===y?t.addPoint(r(Y),t.maxY):1===y&&t.addPoint(t.maxX,r(Y)));var b=(-v-Math.sqrt(F))/(2*m);0<b&&b<1&&(0===y?t.addPoint(r(b),t.maxY):1===y&&t.addPoint(t.maxX,r(b)))}}else{if(0===v)continue;var z=-o/v;0<z&&z<1&&(0===y?t.addPoint(r(z),t.maxY):1===y&&t.addPoint(t.maxX,r(z)))}}e=d,n=C}}return this._bbox=Object.freeze(t)}}]),A}(),oo=function(A){io.prototype[A]=function(){this._bbox=this._cbox=null;for(var t=arguments.length,e=new Array(t),n=0;n<t;n++)e[n]=arguments[n];return this.commands.push({command:A,args:e}),this}},so=0,ao=["moveTo","lineTo","quadraticCurveTo","bezierCurveTo","closePath"];so<ao.length;so++)oo(ao[so]);var co,Bo,go=[".notdef",".null","nonmarkingreturn","space","exclam","quotedbl","numbersign","dollar","percent","ampersand","quotesingle","parenleft","parenright","asterisk","plus","comma","hyphen","period","slash","zero","one","two","three","four","five","six","seven","eight","nine","colon","semicolon","less","equal","greater","question","at","A","B","C","D","E","F","G","H","I","J","K","L","M","N","O","P","Q","R","S","T","U","V","W","X","Y","Z","bracketleft","backslash","bracketright","asciicircum","underscore","grave","a","b","c","d","e","f","g","h","i","j","k","l","m","n","o","p","q","r","s","t","u","v","w","x","y","z","braceleft","bar","braceright","asciitilde","Adieresis","Aring","Ccedilla","Eacute","Ntilde","Odieresis","Udieresis","aacute","agrave","acircumflex","adieresis","atilde","aring","ccedilla","eacute","egrave","ecircumflex","edieresis","iacute","igrave","icircumflex","idieresis","ntilde","oacute","ograve","ocircumflex","odieresis","otilde","uacute","ugrave","ucircumflex","udieresis","dagger","degree","cent","sterling","section","bullet","paragraph","germandbls","registered","copyright","trademark","acute","dieresis","notequal","AE","Oslash","infinity","plusminus","lessequal","greaterequal","yen","mu","partialdiff","summation","product","pi","integral","ordfeminine","ordmasculine","Omega","ae","oslash","questiondown","exclamdown","logicalnot","radical","florin","approxequal","Delta","guillemotleft","guillemotright","ellipsis","nonbreakingspace","Agrave","Atilde","Otilde","OE","oe","endash","emdash","quotedblleft","quotedblright","quoteleft","quoteright","divide","lozenge","ydieresis","Ydieresis","fraction","currency","guilsinglleft","guilsinglright","fi","fl","daggerdbl","periodcentered","quotesinglbase","quotedblbase","perthousand","Acircumflex","Ecircumflex","Aacute","Edieresis","Egrave","Iacute","Icircumflex","Idieresis","Igrave","Oacute","Ocircumflex","apple","Ograve","Uacute","Ucircumflex","Ugrave","dotlessi","circumflex","tilde","macron","breve","dotaccent","ring","cedilla","hungarumlaut","ogonek","caron","Lslash","lslash","Scaron","scaron","Zcaron","zcaron","brokenbar","Eth","eth","Yacute","yacute","Thorn","thorn","minus","multiply","onesuperior","twosuperior","threesuperior","onehalf","onequarter","threequarters","franc","Gbreve","gbreve","Idotaccent","Scedilla","scedilla","Cacute","cacute","Ccaron","ccaron","dcroat"],lo=(co=function(){function A(A,t,e){this.id=A,this.codePoints=t,this._font=e,this.isMark=this.codePoints.length>0&&this.codePoints.every(h.isMark),this.isLigature=this.codePoints.length>1}var t=A.prototype;return t._getPath=function(){return new io},t._getCBox=function(){return this.path.cbox},t._getBBox=function(){return this.path.bbox},t._getTableMetrics=function(A){if(this.id<A.metrics.length)return A.metrics.get(this.id);var t=A.metrics.get(A.metrics.length-1);return{advance:t?t.advance:0,bearing:A.bearings.get(this.id-A.metrics.length)||0}},t._getMetrics=function(A){if(this._metrics)return this._metrics;var t,e=this._getTableMetrics(this._font.hmtx),n=e.advance,r=e.bearing;if(this._font.vmtx)var i=this._getTableMetrics(this._font.vmtx),o=i.advance,s=i.bearing;else if(null==A&&(A=this.cbox),(t=this._font["OS/2"])&&t.version>0)o=Math.abs(t.typoAscender-t.typoDescender),s=t.typoAscender-A.maxY;else{var a=this._font.hhea;o=Math.abs(a.ascent-a.descent),s=a.ascent-A.maxY}return this._font._variationProcessor&&this._font.HVAR&&(n+=this._font._variationProcessor.getAdvanceAdjustment(this.id,this._font.HVAR)),this._metrics={advanceWidth:n,advanceHeight:o,leftBearing:r,topBearing:s}},t.getScaledPath=function(A){var t=1/this._font.unitsPerEm*A;return this.path.scale(t)},t._getName=function(){var A=this._font.post;if(!A)return null;switch(A.version){case 1:return go[this.id];case 2:var t=A.glyphNameIndex[this.id];return t<go.length?go[t]:A.names[t-go.length];case 2.5:return go[this.id+A.offsets[this.id]];case 4:return String.fromCharCode(A.map[this.id])}},t.render=function(A,t){A.save();var e=1/this._font.head.unitsPerEm*t;A.scale(e,e),this.path.toFunction()(A),A.fill(),A.restore()},o(A,[{key:"cbox",get:function(){return this._getCBox()}},{key:"bbox",get:function(){return this._getBBox()}},{key:"path",get:function(){return this._getPath()}},{key:"advanceWidth",get:function(){return this._getMetrics().advanceWidth}},{key:"advanceHeight",get:function(){return this._getMetrics().advanceHeight}},{key:"ligatureCaretPositions",get:function(){}},{key:"name",get:function(){return this._getName()}}]),A}(),y(co.prototype,"cbox",[v],Object.getOwnPropertyDescriptor(co.prototype,"cbox"),co.prototype),y(co.prototype,"bbox",[v],Object.getOwnPropertyDescriptor(co.prototype,"bbox"),co.prototype),y(co.prototype,"path",[v],Object.getOwnPropertyDescriptor(co.prototype,"path"),co.prototype),y(co.prototype,"advanceWidth",[v],Object.getOwnPropertyDescriptor(co.prototype,"advanceWidth"),co.prototype),y(co.prototype,"advanceHeight",[v],Object.getOwnPropertyDescriptor(co.prototype,"advanceHeight"),co.prototype),y(co.prototype,"name",[v],Object.getOwnPropertyDescriptor(co.prototype,"name"),co.prototype),co),uo=new l.Struct({numberOfContours:l.int16,xMin:l.int16,yMin:l.int16,xMax:l.int16,yMax:l.int16}),wo=function(){function A(A,t,e,n){void 0===e&&(e=0),void 0===n&&(n=0),this.onCurve=A,this.endContour=t,this.x=e,this.y=n}return A.prototype.copy=function(){return new A(this.onCurve,this.endContour,this.x,this.y)},A}(),ho=function(A,t,e){this.glyphID=A,this.dx=t,this.dy=e,this.pos=0,this.scaleX=this.scaleY=1,this.scale01=this.scale10=0},Eo=function(A){function t(){return A.apply(this,arguments)||this}s(t,A);var e=t.prototype;return e._getCBox=function(A){if(this._font._variationProcessor&&!A)return this.path.cbox;var t=this._font._getTableStream("glyf");t.pos+=this._font.loca.offsets[this.id];var e=uo.decode(t),n=new qn(e.xMin,e.yMin,e.xMax,e.yMax);return Object.freeze(n)},e._parseGlyphCoord=function(A,t,e,n){if(e){var r=A.readUInt8();n||(r=-r),r+=t}else r=n?t:t+A.readInt16BE();return r},e._decode=function(){var A=this._font.loca.offsets[this.id];if(A===this._font.loca.offsets[this.id+1])return null;var t=this._font._getTableStream("glyf");t.pos+=A;var e=t.pos,n=uo.decode(t);return n.numberOfContours>0?this._decodeSimple(n,t):n.numberOfContours<0&&this._decodeComposite(n,t,e),n},e._decodeSimple=function(A,t){A.points=[];var e=new l.Array(l.uint16,A.numberOfContours).decode(t);A.instructions=new l.Array(l.uint8,l.uint16).decode(t);for(var n=[],r=e[e.length-1]+1;n.length<r;){var i=t.readUInt8();if(n.push(i),8&i)for(var o=t.readUInt8(),s=0;s<o;s++)n.push(i)}for(var a=0;a<n.length;a++){i=n[a];var c=new wo(!!(1&i),e.indexOf(a)>=0,0,0);A.points.push(c)}var B=0;for(a=0;a<n.length;a++)i=n[a],A.points[a].x=B=this._parseGlyphCoord(t,B,2&i,16&i);var g=0;for(a=0;a<n.length;a++)i=n[a],A.points[a].y=g=this._parseGlyphCoord(t,g,4&i,32&i);if(this._font._variationProcessor){var u=A.points.slice();u.push.apply(u,this._getPhantomPoints(A)),this._font._variationProcessor.transformPoints(this.id,u),A.phantomPoints=u.slice(-4)}},e._decodeComposite=function(A,t,e){void 0===e&&(e=0),A.components=[];for(var n=!1,r=32;32&r;){r=t.readUInt16BE();var i=t.pos-e,o=t.readUInt16BE();if(n||(n=0!=(256&r)),1&r)var s=t.readInt16BE(),a=t.readInt16BE();else s=t.readInt8(),a=t.readInt8();(g=new ho(o,s,a)).pos=i,8&r?g.scaleX=g.scaleY=(t.readUInt8()<<24|t.readUInt8()<<16)/1073741824:64&r?(g.scaleX=(t.readUInt8()<<24|t.readUInt8()<<16)/1073741824,g.scaleY=(t.readUInt8()<<24|t.readUInt8()<<16)/1073741824):128&r&&(g.scaleX=(t.readUInt8()<<24|t.readUInt8()<<16)/1073741824,g.scale01=(t.readUInt8()<<24|t.readUInt8()<<16)/1073741824,g.scale10=(t.readUInt8()<<24|t.readUInt8()<<16)/1073741824,g.scaleY=(t.readUInt8()<<24|t.readUInt8()<<16)/1073741824),A.components.push(g)}if(this._font._variationProcessor){for(var c=[],B=0;B<A.components.length;B++){var g=A.components[B];c.push(new wo(!0,!0,g.dx,g.dy))}c.push.apply(c,this._getPhantomPoints(A)),this._font._variationProcessor.transformPoints(this.id,c),A.phantomPoints=c.splice(-4,4);for(var l=0;l<c.length;l++){var u=c[l];A.components[l].dx=u.x,A.components[l].dy=u.y}}return n},e._getPhantomPoints=function(A){var t=this._getCBox(!0);null==this._metrics&&(this._metrics=lo.prototype._getMetrics.call(this,t));var e=this._metrics,n=e.advanceWidth,r=e.advanceHeight,i=e.leftBearing,o=e.topBearing;return[new wo(!1,!0,A.xMin-i,0),new wo(!1,!0,A.xMin-i+n,0),new wo(!1,!0,0,A.yMax+o),new wo(!1,!0,0,A.yMax+o+r)]},e._getContours=function(){var A=this._decode();if(!A)return[];var t=[];if(A.numberOfContours<0)for(var e,n=c(A.components);!(e=n()).done;)for(var r=e.value,i=this._font.getGlyph(r.glyphID)._getContours(),o=0;o<i.length;o++)for(var s=i[o],a=0;a<s.length;a++){var B=s[a],g=B.x*r.scaleX+B.y*r.scale01+r.dx,l=B.y*r.scaleY+B.x*r.scale10+r.dy;t.push(new wo(B.onCurve,B.endContour,g,l))}else t=A.points||[];A.phantomPoints&&!this._font.directory.tables.HVAR&&(this._metrics.advanceWidth=A.phantomPoints[1].x-A.phantomPoints[0].x,this._metrics.advanceHeight=A.phantomPoints[3].y-A.phantomPoints[2].y,this._metrics.leftBearing=A.xMin-A.phantomPoints[0].x,this._metrics.topBearing=A.phantomPoints[2].y-A.yMax);for(var u=[],w=[],h=0;h<t.length;h++){var E=t[h];w.push(E),E.endContour&&(u.push(w),w=[])}return u},e._getMetrics=function(){if(this._metrics)return this._metrics;var t=this._getCBox(!0);return A.prototype._getMetrics.call(this,t),this._font._variationProcessor&&!this._font.HVAR&&this.path,this._metrics},e._getPath=function(){for(var A=this._getContours(),t=new io,e=0;e<A.length;e++){var n=A[e],r=n[0],i=n[n.length-1],o=0;if(r.onCurve){var s=null;o=1}else s=r=i.onCurve?i:new wo(!1,!1,(r.x+i.x)/2,(r.y+i.y)/2);t.moveTo(r.x,r.y);for(var a=o;a<n.length;a++){var c=n[a],B=0===a?r:n[a-1];if(B.onCurve&&c.onCurve)t.lineTo(c.x,c.y);else if(B.onCurve&&!c.onCurve)s=c;else if(B.onCurve||c.onCurve){if(B.onCurve||!c.onCurve)throw new Error("Unknown TTF path state");t.quadraticCurveTo(s.x,s.y,c.x,c.y),s=null}else{var g=(B.x+c.x)/2,l=(B.y+c.y)/2;t.quadraticCurveTo(B.x,B.y,g,l);s=c}}s&&t.quadraticCurveTo(s.x,s.y,r.x,r.y),t.closePath()}return t},t}(lo),fo=function(A){function t(){return A.apply(this,arguments)||this}s(t,A);var e=t.prototype;return e._getName=function(){return this._font.CFF2?A.prototype._getName.call(this):this._font["CFF "].getGlyphName(this.id)},e.bias=function(A){return A.length<1240?107:A.length<33900?1131:32768},e._getPath=function(){var A=this._font.CFF2||this._font["CFF "],t=A.stream,e=A.topDict.CharStrings[this.id],n=e.offset+e.length;t.pos=e.offset;var r,i,o=new io,s=[],a=[],c=null,B=0,g=0,l=0,u=!1;this._usedGsubrs=r={},this._usedSubrs=i={};var w=A.globalSubrIndex||[],h=this.bias(w),E=A.privateDictForGlyph(this.id)||{},f=E.Subrs||[],Q=this.bias(f),d=A.topDict.vstore&&A.topDict.vstore.itemVariationStore,C=E.vsindex,M=this._font._variationProcessor;function I(){null==c&&(c=s.shift()+E.nominalWidthX)}function p(){return s.length%2!=0&&I(),B+=s.length>>1,s.length=0}function D(A,t){u&&o.closePath(),o.moveTo(A,t),u=!0}return function e(){for(;t.pos<n;){var c=t.readUInt8();if(c<32)switch(c){case 1:case 3:case 18:case 23:p();break;case 4:s.length>1&&I(),l+=s.shift(),D(g,l);break;case 5:for(;s.length>=2;)g+=s.shift(),l+=s.shift(),o.lineTo(g,l);break;case 6:case 7:for(var E=6===c;s.length>=1;)E?g+=s.shift():l+=s.shift(),o.lineTo(g,l),E=!E;break;case 8:for(;s.length>0;){var y=g+s.shift(),v=l+s.shift(),m=y+s.shift(),F=v+s.shift();g=m+s.shift(),l=F+s.shift(),o.bezierCurveTo(y,v,m,F,g,l)}break;case 10:var Y=s.pop()+Q,b=f[Y];if(b){i[Y]=!0;var z=t.pos,U=n;t.pos=b.offset,n=b.offset+b.length,e(),t.pos=z,n=U}break;case 11:if(A.version>=2)break;return;case 14:if(A.version>=2)break;s.length>0&&I(),u&&(o.closePath(),u=!1);break;case 15:if(A.version<2)throw new Error("vsindex operator not supported in CFF v1");C=s.pop();break;case 16:if(A.version<2)throw new Error("blend operator not supported in CFF v1");if(!M)throw new Error("blend operator in non-variation font");for(var S=M.getBlendVector(d,C),x=s.pop(),T=x*S.length,P=s.length-T,N=P-x,R=0;R<x;R++){for(var G=s[N+R],H=0;H<S.length;H++)G+=S[H]*s[P++];s[N+R]=G}for(;T--;)s.pop();break;case 19:case 20:p(),t.pos+=B+7>>3;break;case 21:s.length>2&&I(),g+=s.shift(),l+=s.shift(),D(g,l);break;case 22:s.length>1&&I(),D(g+=s.shift(),l);break;case 24:for(;s.length>=8;)y=g+s.shift(),v=l+s.shift(),m=y+s.shift(),F=v+s.shift(),g=m+s.shift(),l=F+s.shift(),o.bezierCurveTo(y,v,m,F,g,l);g+=s.shift(),l+=s.shift(),o.lineTo(g,l);break;case 25:for(;s.length>=8;)g+=s.shift(),l+=s.shift(),o.lineTo(g,l);y=g+s.shift(),v=l+s.shift(),m=y+s.shift(),F=v+s.shift(),g=m+s.shift(),l=F+s.shift(),o.bezierCurveTo(y,v,m,F,g,l);break;case 26:for(s.length%2&&(g+=s.shift());s.length>=4;)y=g,v=l+s.shift(),m=y+s.shift(),F=v+s.shift(),g=m,l=F+s.shift(),o.bezierCurveTo(y,v,m,F,g,l);break;case 27:for(s.length%2&&(l+=s.shift());s.length>=4;)y=g+s.shift(),v=l,m=y+s.shift(),F=v+s.shift(),g=m+s.shift(),l=F,o.bezierCurveTo(y,v,m,F,g,l);break;case 28:s.push(t.readInt16BE());break;case 29:Y=s.pop()+h,(b=w[Y])&&(r[Y]=!0,z=t.pos,U=n,t.pos=b.offset,n=b.offset+b.length,e(),t.pos=z,n=U);break;case 30:case 31:for(E=31===c;s.length>=4;)E?(y=g+s.shift(),v=l,m=y+s.shift(),F=v+s.shift(),l=F+s.shift(),g=m+(1===s.length?s.shift():0)):(y=g,v=l+s.shift(),m=y+s.shift(),F=v+s.shift(),g=m+s.shift(),l=F+(1===s.length?s.shift():0)),o.bezierCurveTo(y,v,m,F,g,l),E=!E;break;case 12:switch(c=t.readUInt8()){case 3:var k=s.pop(),L=s.pop();s.push(k&&L?1:0);break;case 4:k=s.pop(),L=s.pop(),s.push(k||L?1:0);break;case 5:k=s.pop(),s.push(k?0:1);break;case 9:k=s.pop(),s.push(Math.abs(k));break;case 10:k=s.pop(),L=s.pop(),s.push(k+L);break;case 11:k=s.pop(),L=s.pop(),s.push(k-L);break;case 12:k=s.pop(),L=s.pop(),s.push(k/L);break;case 14:k=s.pop(),s.push(-k);break;case 15:k=s.pop(),L=s.pop(),s.push(k===L?1:0);break;case 18:s.pop();break;case 20:var J=s.pop(),j=s.pop();a[j]=J;break;case 21:j=s.pop(),s.push(a[j]||0);break;case 22:var O=s.pop(),W=s.pop(),K=s.pop(),V=s.pop();s.push(K<=V?O:W);break;case 23:s.push(Math.random());break;case 24:k=s.pop(),L=s.pop(),s.push(k*L);break;case 26:k=s.pop(),s.push(Math.sqrt(k));break;case 27:k=s.pop(),s.push(k,k);break;case 28:k=s.pop(),L=s.pop(),s.push(L,k);break;case 29:(j=s.pop())<0?j=0:j>s.length-1&&(j=s.length-1),s.push(s[j]);break;case 30:var X=s.pop(),Z=s.pop();if(Z>=0)for(;Z>0;){for(var _=s[X-1],q=X-2;q>=0;q--)s[q+1]=s[q];s[0]=_,Z--}else for(;Z<0;){_=s[0];for(var $=0;$<=X;$++)s[$]=s[$+1];s[X-1]=_,Z++}break;case 34:y=g+s.shift(),v=l,m=y+s.shift(),F=v+s.shift();var AA=m+s.shift(),tA=F,eA=AA+s.shift(),nA=tA,rA=eA+s.shift(),iA=nA,oA=rA+s.shift(),sA=iA;g=oA,l=sA,o.bezierCurveTo(y,v,m,F,AA,tA),o.bezierCurveTo(eA,nA,rA,iA,oA,sA);break;case 35:for(var aA=[],cA=0;cA<=5;cA++)g+=s.shift(),l+=s.shift(),aA.push(g,l);o.bezierCurveTo.apply(o,aA.slice(0,6)),o.bezierCurveTo.apply(o,aA.slice(6)),s.shift();break;case 36:y=g+s.shift(),v=l+s.shift(),m=y+s.shift(),nA=tA=F=v+s.shift(),rA=(eA=(AA=m+s.shift())+s.shift())+s.shift(),iA=nA+s.shift(),oA=rA+s.shift(),g=oA,l=sA=iA,o.bezierCurveTo(y,v,m,F,AA,tA),o.bezierCurveTo(eA,nA,rA,iA,oA,sA);break;case 37:var BA=g,gA=l;aA=[];for(var lA=0;lA<=4;lA++)g+=s.shift(),l+=s.shift(),aA.push(g,l);Math.abs(g-BA)>Math.abs(l-gA)?(g+=s.shift(),l=gA):(g=BA,l+=s.shift()),aA.push(g,l),o.bezierCurveTo.apply(o,aA.slice(0,6)),o.bezierCurveTo.apply(o,aA.slice(6));break;default:throw new Error("Unknown op: 12 ".concat(c))}break;default:throw new Error("Unknown op: ".concat(c))}else if(c<247)s.push(c-139);else if(c<251){var uA=t.readUInt8();s.push(256*(c-247)+uA+108)}else c<255?(uA=t.readUInt8(),s.push(256*-(c-251)-uA-108)):s.push(t.readInt32BE()/65536)}}(),u&&o.closePath(),o},t}(lo),Qo=new l.Struct({originX:l.uint16,originY:l.uint16,type:new l.String(4),data:new l.Buffer((function(A){return A.parent.buflen-A._currentOffset}))}),Co=function(A){function t(){return A.apply(this,arguments)||this}s(t,A);var e=t.prototype;return e.getImageForSize=function(A){for(var t=0;t<this._font.sbix.imageTables.length;t++){var e=this._font.sbix.imageTables[t];if(e.ppem>=A)break}var n=e.imageOffsets,r=n[this.id],i=n[this.id+1];return r===i?null:(this._font.stream.pos=r,Qo.decode(this._font.stream,{buflen:i-r}))},e.render=function(t,e){var n=this.getImageForSize(e);if(null!=n){var r=e/this._font.unitsPerEm;t.image(n.data,{height:e,x:n.originX,y:(this.bbox.minY-n.originY)*r})}this._font.sbix.flags.renderOutlines&&A.prototype.render.call(this,t,e)},t}(Eo),Mo=function(A,t){this.glyph=A,this.color=t},Io=function(A){function t(){return A.apply(this,arguments)||this}s(t,A);var e=t.prototype;return e._getBBox=function(){for(var A=new qn,t=0;t<this.layers.length;t++){var e=this.layers[t].glyph.bbox;A.addPoint(e.minX,e.minY),A.addPoint(e.maxX,e.maxY)}return A},e.render=function(A,t){for(var e,n=c(this.layers);!(e=n()).done;){var r=e.value,i=r.glyph,o=r.color;A.fillColor([o.red,o.green,o.blue],o.alpha/255*100),i.render(A,t)}},o(t,[{key:"layers",get:function(){for(var A=this._font.CPAL,t=this._font.COLR,e=0,n=t.baseGlyphRecord.length-1;e<=n;){var r=e+n>>1,i=t.baseGlyphRecord[r];if(this.id<i.gid)n=r-1;else{if(!(this.id>i.gid)){var o=i;break}e=r+1}}if(null==o){var s=this._font._getBaseGlyph(this.id);return[new Mo(s,B={red:0,green:0,blue:0,alpha:255})]}for(var a=[],c=o.firstLayerIndex;c<o.firstLayerIndex+o.numLayers;c++){i=t.layerRecords[c];var B=A.colorRecords[i.paletteIndex];s=this._font._getBaseGlyph(i.gid),a.push(new Mo(s,B))}return a}}]),t}(lo),po=function(){function A(A,t){this.font=A,this.normalizedCoords=this.normalizeCoords(t),this.blendVectors=new Map}var t=A.prototype;return t.normalizeCoords=function(A){for(var t=[],e=0;e<this.font.fvar.axis.length;e++){var n=this.font.fvar.axis[e];A[e]<n.defaultValue?t.push((A[e]-n.defaultValue+Number.EPSILON)/(n.defaultValue-n.minValue+Number.EPSILON)):t.push((A[e]-n.defaultValue+Number.EPSILON)/(n.maxValue-n.defaultValue+Number.EPSILON))}if(this.font.avar)for(e=0;e<this.font.avar.segment.length;e++)for(var r=this.font.avar.segment[e],i=0;i<r.correspondence.length;i++){var o=r.correspondence[i];if(i>=1&&t[e]<o.fromCoord){var s=r.correspondence[i-1];t[e]=((t[e]-s.fromCoord)*(o.toCoord-s.toCoord)+Number.EPSILON)/(o.fromCoord-s.fromCoord+Number.EPSILON)+s.toCoord;break}}return t},t.transformPoints=function(A,t){if(this.font.fvar&&this.font.gvar){var e=this.font.gvar;if(!(A>=e.glyphCount)){var n=e.offsets[A];if(n!==e.offsets[A+1]){var r=this.font.stream;if(r.pos=n,!(r.pos>=r.length)){var i=r.readUInt16BE(),o=n+r.readUInt16BE();if(32768&i){var s=r.pos;r.pos=o;var a=this.decodePoints();o=r.pos,r.pos=s}var c=t.map((function(A){return A.copy()}));i&=4095;for(var B=0;B<i;B++){var g=r.readUInt16BE(),l=r.readUInt16BE();if(32768&l)for(var u=[],w=0;w<e.axisCount;w++)u.push(r.readInt16BE()/16384);else{if((4095&l)>=e.globalCoordCount)throw new Error("Invalid gvar table");u=e.globalCoords[4095&l]}if(16384&l){for(var h=[],E=0;E<e.axisCount;E++)h.push(r.readInt16BE()/16384);for(var f=[],Q=0;Q<e.axisCount;Q++)f.push(r.readInt16BE()/16384)}var d=this.tupleFactor(l,u,h,f);if(0!==d){if(s=r.pos,r.pos=o,8192&l)var C=this.decodePoints();else C=a;var M=0===C.length?t.length:C.length,I=this.decodeDeltas(M),p=this.decodeDeltas(M);if(0===C.length)for(var D=0;D<t.length;D++){var y=t[D];y.x+=Math.round(I[D]*d),y.y+=Math.round(p[D]*d)}else{for(var v=c.map((function(A){return A.copy()})),m=t.map((function(){return!1})),F=0;F<C.length;F++){var Y=C[F];if(Y<t.length){var b=v[Y];m[Y]=!0,b.x+=Math.round(I[F]*d),b.y+=Math.round(p[F]*d)}}this.interpolateMissingDeltas(v,c,m);for(var z=0;z<t.length;z++){var U=v[z].x-c[z].x,S=v[z].y-c[z].y;t[z].x+=U,t[z].y+=S}}o+=g,r.pos=s}else o+=g}}}}}},t.decodePoints=function(){var A=this.font.stream,t=A.readUInt8();128&t&&(t=(127&t)<<8|A.readUInt8());for(var e=new Uint16Array(t),n=0,r=0;n<t;)for(var i=A.readUInt8(),o=1+(127&i),s=128&i?A.readUInt16:A.readUInt8,a=0;a<o&&n<t;a++)r+=s.call(A),e[n++]=r;return e},t.decodeDeltas=function(A){for(var t=this.font.stream,e=0,n=new Int16Array(A);e<A;){var r=t.readUInt8(),i=1+(63&r);if(128&r)e+=i;else for(var o=64&r?t.readInt16BE:t.readInt8,s=0;s<i&&e<A;s++)n[e++]=o.call(t)}return n},t.tupleFactor=function(A,t,e,n){for(var r=this.normalizedCoords,i=this.font.gvar,o=1,s=0;s<i.axisCount;s++)if(0!==t[s]){if(0===r[s])return 0;if(0==(16384&A)){if(r[s]<Math.min(0,t[s])||r[s]>Math.max(0,t[s]))return 0;o=(o*r[s]+Number.EPSILON)/(t[s]+Number.EPSILON)}else{if(r[s]<e[s]||r[s]>n[s])return 0;o=r[s]<t[s]?o*(r[s]-e[s]+Number.EPSILON)/(t[s]-e[s]+Number.EPSILON):o*(n[s]-r[s]+Number.EPSILON)/(n[s]-t[s]+Number.EPSILON)}}return o},t.interpolateMissingDeltas=function(A,t,e){if(0!==A.length)for(var n=0;n<A.length;){for(var r=n,i=n,o=A[i];!o.endContour;)o=A[++i];for(;n<=i&&!e[n];)n++;if(!(n>i)){var s=n,a=n;for(n++;n<=i;)e[n]&&(this.deltaInterpolate(a+1,n-1,a,n,t,A),a=n),n++;a===s?this.deltaShift(r,i,a,t,A):(this.deltaInterpolate(a+1,i,a,s,t,A),s>0&&this.deltaInterpolate(r,s-1,a,s,t,A)),n=i+1}}},t.deltaInterpolate=function(A,t,e,n,r,i){if(!(A>t))for(var o=["x","y"],s=0;s<o.length;s++){var a=o[s];if(r[e][a]>r[n][a]){var c=e;e=n,n=c}var B=r[e][a],g=r[n][a],l=i[e][a],u=i[n][a];if(B!==g||l===u)for(var w=B===g?0:(u-l)/(g-B),h=A;h<=t;h++){var E=r[h][a];E<=B?E+=l-B:E>=g?E+=u-g:E=l+(E-B)*w,i[h][a]=E}}},t.deltaShift=function(A,t,e,n,r){var i=r[e].x-n[e].x,o=r[e].y-n[e].y;if(0!==i||0!==o)for(var s=A;s<=t;s++)s!==e&&(r[s].x+=i,r[s].y+=o)},t.getAdvanceAdjustment=function(A,t){var e,n;if(t.advanceWidthMapping){var r=A;r>=t.advanceWidthMapping.mapCount&&(r=t.advanceWidthMapping.mapCount-1),t.advanceWidthMapping.entryFormat;var i=t.advanceWidthMapping.mapData[r];e=i.outerIndex,n=i.innerIndex}else e=0,n=A;return this.getDelta(t.itemVariationStore,e,n)},t.getDelta=function(A,t,e){if(t>=A.itemVariationData.length)return 0;var n=A.itemVariationData[t];if(e>=n.deltaSets.length)return 0;for(var r=n.deltaSets[e],i=this.getBlendVector(A,t),o=0,s=0;s<n.regionIndexCount;s++)o+=r.deltas[s]*i[s];return o},t.getBlendVector=function(A,t){var e=A.itemVariationData[t];if(this.blendVectors.has(e))return this.blendVectors.get(e);for(var n=this.normalizedCoords,r=[],i=0;i<e.regionIndexCount;i++){for(var o=1,s=e.regionIndexes[i],a=A.variationRegionList.variationRegions[s],c=0;c<a.length;c++){var B=a[c];o*=B.startCoord>B.peakCoord||B.peakCoord>B.endCoord||B.startCoord<0&&B.endCoord>0&&0!==B.peakCoord||0===B.peakCoord?1:n[c]<B.startCoord||n[c]>B.endCoord?0:n[c]===B.peakCoord?1:n[c]<B.peakCoord?(n[c]-B.startCoord+Number.EPSILON)/(B.peakCoord-B.startCoord+Number.EPSILON):(B.endCoord-n[c]+Number.EPSILON)/(B.endCoord-B.peakCoord+Number.EPSILON)}r[i]=o}return this.blendVectors.set(e,r),r},A}(),Do=Promise.resolve(),yo=function(){function A(A){this.font=A,this.glyphs=[],this.mapping={},this.includeGlyph(0)}var t=A.prototype;return t.includeGlyph=function(A){return"object"==typeof A&&(A=A.id),null==this.mapping[A]&&(this.glyphs.push(A),this.mapping[A]=this.glyphs.length-1),this.mapping[A]},t.encodeStream=function(){var A=this,t=new l.EncodeStream;return Do.then((function(){return A.encode(t),t.end()})),t},A}(),vo=function(){function A(){}return A.size=function(A){return A>=0&&A<=255?1:2},A.encode=function(A,t){t>=0&&t<=255?A.writeUInt8(t):A.writeInt16BE(t)},A}(),mo=new l.Struct({numberOfContours:l.int16,xMin:l.int16,yMin:l.int16,xMax:l.int16,yMax:l.int16,endPtsOfContours:new l.Array(l.uint16,"numberOfContours"),instructions:new l.Array(l.uint8,l.uint16),flags:new l.Array(l.uint8,0),xPoints:new l.Array(vo,0),yPoints:new l.Array(vo,0)}),Fo=function(){function A(){}var t=A.prototype;return t.encodeSimple=function(A,t){void 0===t&&(t=[]);for(var e=[],n=[],r=[],i=[],o=0,s=0,a=0,c=0,B=0,g=0;g<A.commands.length;g++){for(var u=A.commands[g],w=0;w<u.args.length;w+=2){var h=u.args[w],E=u.args[w+1],f=0;if("quadraticCurveTo"===u.command&&2===w){var Q=A.commands[g+1];if(Q&&"quadraticCurveTo"===Q.command){var d=(s+Q.args[0])/2,C=(a+Q.args[1])/2;if(h===d&&E===C)continue}}"quadraticCurveTo"===u.command&&0===w||(f|=1),f=this._encodePoint(h,s,n,f,2,16),(f=this._encodePoint(E,a,r,f,4,32))===c&&o<255?(i[i.length-1]|=8,o++):(o>0&&(i.push(o),o=0),i.push(f),c=f),s=h,a=E,B++}"closePath"===u.command&&e.push(B-1)}A.commands.length>1&&"closePath"!==A.commands[A.commands.length-1].command&&e.push(B-1);var M=A.bbox,I={numberOfContours:e.length,xMin:M.minX,yMin:M.minY,xMax:M.maxX,yMax:M.maxY,endPtsOfContours:e,instructions:t,flags:i,xPoints:n,yPoints:r},p=mo.size(I),D=4-p%4,y=new l.EncodeStream(p+D);return mo.encode(y,I),0!==D&&y.fill(0,D),y.buffer},t._encodePoint=function(A,t,e,n,r,i){var o=A-t;return A===t?n|=i:(-255<=o&&o<=255&&(n|=r,o<0?o=-o:n|=i),e.push(o)),n},A}(),Yo=function(A){function t(t){var e;return(e=A.call(this,t)||this).glyphEncoder=new Fo,e}s(t,A);var e=t.prototype;return e._addGlyph=function(A){var t=this.font.getGlyph(A),e=t._decode(),n=this.font.loca.offsets[A],i=this.font.loca.offsets[A+1],o=this.font._getTableStream("glyf");o.pos+=n;var s=o.readBuffer(i-n);if(e&&e.numberOfContours<0){s=r.from(s);for(var a,B=c(e.components);!(a=B()).done;){var g=a.value;A=this.includeGlyph(g.glyphID),s.writeUInt16BE(A,g.pos)}}else e&&this.font._variationProcessor&&(s=this.glyphEncoder.encodeSimple(t.path,e.instructions));return this.glyf.push(s),this.loca.offsets.push(this.offset),this.hmtx.metrics.push({advance:t.advanceWidth,bearing:t._getMetrics().leftBearing}),this.offset+=s.length,this.glyf.length-1},e.encode=function(A){this.glyf=[],this.offset=0,this.loca={offsets:[],version:this.font.loca.version},this.hmtx={metrics:[],bearings:[]};for(var t=0;t<this.glyphs.length;)this._addGlyph(this.glyphs[t++]);var e=Q(this.font.maxp);e.numGlyphs=this.glyf.length,this.loca.offsets.push(this.offset);var n=Q(this.font.head);n.indexToLocFormat=this.loca.version;var r=Q(this.font.hhea);r.numberOfMetrics=this.hmtx.metrics.length,On.encode(A,{tables:{head:n,hhea:r,loca:this.loca,maxp:e,"cvt ":this.font["cvt "],prep:this.font.prep,glyf:this.glyf,hmtx:this.hmtx,fpgm:this.font.fpgm}})},t}(yo),bo=function(A){function t(t){var e;if((e=A.call(this,t)||this).cff=e.font["CFF "],!e.cff)throw new Error("Not a CFF Font");return e}s(t,A);var e=t.prototype;return e.subsetCharstrings=function(){this.charstrings=[];for(var A,t={},e=c(this.glyphs);!(A=e()).done;){var n=A.value;this.charstrings.push(this.cff.getCharString(n));var r=this.font.getGlyph(n);for(var i in r.path,r._usedGsubrs)t[i]=!0}this.gsubrs=this.subsetSubrs(this.cff.globalSubrIndex,t)},e.subsetSubrs=function(A,t){for(var e=[],n=0;n<A.length;n++){var i=A[n];t[n]?(this.cff.stream.pos=i.offset,e.push(this.cff.stream.readBuffer(i.length))):e.push(r.from([11]))}return e},e.subsetFontdict=function(A){A.FDArray=[],A.FDSelect={version:0,fds:[]};for(var t,e={},n=[],r={},i=c(this.glyphs);!(t=i()).done;){var o=t.value,s=this.cff.fdForGlyph(o);if(null!=s){e[s]||(A.FDArray.push(Object.assign({},this.cff.topDict.FDArray[s])),n.push({}),r[s]=A.FDArray.length-1),e[s]=!0,A.FDSelect.fds.push(r[s]);var a=this.font.getGlyph(o);for(var B in a.path,a._usedSubrs)n[r[s]][B]=!0}}for(var g=0;g<A.FDArray.length;g++){var l=A.FDArray[g];delete l.FontName,l.Private&&l.Private.Subrs&&(l.Private=Object.assign({},l.Private),l.Private.Subrs=this.subsetSubrs(l.Private.Subrs,n[g]))}},e.createCIDFontdict=function(A){for(var t,e={},n=c(this.glyphs);!(t=n()).done;){var r=t.value,i=this.font.getGlyph(r);for(var o in i.path,i._usedSubrs)e[o]=!0}var s=Object.assign({},this.cff.topDict.Private);return this.cff.topDict.Private&&this.cff.topDict.Private.Subrs&&(s.Subrs=this.subsetSubrs(this.cff.topDict.Private.Subrs,e)),A.FDArray=[{Private:s}],A.FDSelect={version:3,nRanges:1,ranges:[{first:0,fd:0}],sentinel:this.charstrings.length}},e.addString=function(A){return A?(this.strings||(this.strings=[]),this.strings.push(A),lA.length+this.strings.length-1):null},e.encode=function(A){this.subsetCharstrings();var t={version:this.charstrings.length>255?2:1,ranges:[{first:1,nLeft:this.charstrings.length-2}]},e=Object.assign({},this.cff.topDict);e.Private=null,e.charset=t,e.Encoding=null,e.CharStrings=this.charstrings;for(var n=0,r=["version","Notice","Copyright","FullName","FamilyName","Weight","PostScript","BaseFontName","FontName"];n<r.length;n++){var i=r[n];e[i]=this.addString(this.cff.string(e[i]))}e.ROS=[this.addString("Adobe"),this.addString("Identity"),0],e.CIDCount=this.charstrings.length,this.cff.isCIDFont?this.subsetFontdict(e):this.createCIDFontdict(e);var o={version:1,hdrSize:this.cff.hdrSize,offSize:4,header:this.cff.header,nameIndex:[this.cff.postscriptName],topDictIndex:[e],stringIndex:this.strings,globalSubrIndex:this.gsubrs};wt.encode(A,o)},t}(yo),zo=(Bo=function(){function A(A,t){for(var e in void 0===t&&(t=null),this.defaultLanguage=null,this.stream=A,this.variationCoords=t,this._directoryPos=this.stream.pos,this._tables={},this._glyphs={},this._decodeDirectory(),this.directory.tables){var n=this.directory.tables[e];Ln[e]&&n.length>0&&Object.defineProperty(this,e,{get:this._getTable.bind(this,n)})}}A.probe=function(A){var t=A.toString("ascii",0,4);return"true"===t||"OTTO"===t||t===String.fromCharCode(0,1,0,0)};var t=A.prototype;return t.setDefaultLanguage=function(A){void 0===A&&(A=null),this.defaultLanguage=A},t._getTable=function(A){if(!(A.tag in this._tables))try{this._tables[A.tag]=this._decodeTable(A)}catch(A){I.logErrors}return this._tables[A.tag]},t._getTableStream=function(A){var t=this.directory.tables[A];return t?(this.stream.pos=t.offset,this.stream):null},t._decodeDirectory=function(){return this.directory=On.decode(this.stream,{_startOffset:0})},t._decodeTable=function(A){var t=this.stream.pos,e=this._getTableStream(A.tag),n=Ln[A.tag].decode(e,this,A.length);return this.stream.pos=t,n},t.getName=function(A,t){void 0===t&&(t=this.defaultLanguage||I.defaultLanguage);var e=this.name&&this.name.records[A];return e&&(e[t]||e[this.defaultLanguage]||e[I.defaultLanguage]||e.en||e[Object.keys(e)[0]])||null},t.hasGlyphForCodePoint=function(A){return!!this._cmapProcessor.lookup(A)},t.glyphForCodePoint=function(A){return this.getGlyph(this._cmapProcessor.lookup(A),[A])},t.glyphsForString=function(A){for(var t=[],e=A.length,n=0,r=-1,i=-1;n<=e;){var o=0,s=0;if(n<e){if(55296<=(o=A.charCodeAt(n++))&&o<=56319&&n<e){var a=A.charCodeAt(n);56320<=a&&a<=57343&&(n++,o=((1023&o)<<10)+(1023&a)+65536)}s=65024<=o&&o<=65039||917760<=o&&o<=917999?1:0}else n++;0===i&&1===s?t.push(this.getGlyph(this._cmapProcessor.lookup(r,o),[r,o])):0===i&&0===s&&t.push(this.glyphForCodePoint(r)),r=o,i=s}return t},t.layout=function(A,t,e,n,r){return this._layoutEngine.layout(A,t,e,n,r)},t.stringsForGlyph=function(A){return this._layoutEngine.stringsForGlyph(A)},t.getAvailableFeatures=function(A,t){return this._layoutEngine.getAvailableFeatures(A,t)},t._getBaseGlyph=function(A,t){return void 0===t&&(t=[]),this._glyphs[A]||(this.directory.tables.glyf?this._glyphs[A]=new Eo(A,t,this):(this.directory.tables["CFF "]||this.directory.tables.CFF2)&&(this._glyphs[A]=new fo(A,t,this))),this._glyphs[A]||null},t.getGlyph=function(A,t){return void 0===t&&(t=[]),this._glyphs[A]||(this.directory.tables.sbix?this._glyphs[A]=new Co(A,t,this):this.directory.tables.COLR&&this.directory.tables.CPAL?this._glyphs[A]=new Io(A,t,this):this._getBaseGlyph(A,t)),this._glyphs[A]||null},t.createSubset=function(){return this.directory.tables["CFF "]?new bo(this):new Yo(this)},t.getVariation=function(t){if(!this.directory.tables.fvar||!(this.directory.tables.gvar&&this.directory.tables.glyf||this.directory.tables.CFF2))throw new Error("Variations require a font with the fvar, gvar and glyf, or CFF2 tables.");if("string"==typeof t&&(t=this.namedVariations[t]),"object"!=typeof t)throw new Error("Variation settings must be either a variation name or settings object.");var e=this.fvar.axis.map((function(A,e){var n=A.axisTag.trim();return n in t?Math.max(A.minValue,Math.min(A.maxValue,t[n])):A.defaultValue})),n=new l.DecodeStream(this.stream.buffer);n.pos=this._directoryPos;var r=new A(n,e);return r._tables=this._tables,r},t.getFont=function(A){return this.getVariation(A)},o(A,[{key:"postscriptName",get:function(){return this.getName("postscriptName")}},{key:"fullName",get:function(){return this.getName("fullName")}},{key:"familyName",get:function(){return this.getName("fontFamily")}},{key:"subfamilyName",get:function(){return this.getName("fontSubfamily")}},{key:"copyright",get:function(){return this.getName("copyright")}},{key:"version",get:function(){return this.getName("version")}},{key:"ascent",get:function(){return this.hhea.ascent}},{key:"descent",get:function(){return this.hhea.descent}},{key:"lineGap",get:function(){return this.hhea.lineGap}},{key:"underlinePosition",get:function(){return this.post.underlinePosition}},{key:"underlineThickness",get:function(){return this.post.underlineThickness}},{key:"italicAngle",get:function(){return this.post.italicAngle}},{key:"capHeight",get:function(){var A=this["OS/2"];return A?A.capHeight:this.ascent}},{key:"xHeight",get:function(){var A=this["OS/2"];return A?A.xHeight:0}},{key:"numGlyphs",get:function(){return this.maxp.numGlyphs}},{key:"unitsPerEm",get:function(){return this.head.unitsPerEm}},{key:"bbox",get:function(){return Object.freeze(new qn(this.head.xMin,this.head.yMin,this.head.xMax,this.head.yMax))}},{key:"_cmapProcessor",get:function(){return new Xn(this.cmap)}},{key:"characterSet",get:function(){return this._cmapProcessor.getCharacterSet()}},{key:"_layoutEngine",get:function(){return new no(this)}},{key:"availableFeatures",get:function(){return this._layoutEngine.getAvailableFeatures()}},{key:"variationAxes",get:function(){var A={};if(!this.fvar)return A;for(var t,e=c(this.fvar.axis);!(t=e()).done;){var n=t.value;A[n.axisTag.trim()]={name:n.name.en,min:n.minValue,default:n.defaultValue,max:n.maxValue}}return A}},{key:"namedVariations",get:function(){var A={};if(!this.fvar)return A;for(var t,e=c(this.fvar.instance);!(t=e()).done;){for(var n=t.value,r={},i=0;i<this.fvar.axis.length;i++)r[this.fvar.axis[i].axisTag.trim()]=n.coord[i];A[n.name.en]=r}return A}},{key:"_variationProcessor",get:function(){if(!this.fvar)return null;var A=this.variationCoords;return A||this.CFF2?(A||(A=this.fvar.axis.map((function(A){return A.defaultValue}))),new po(this,A)):null}}]),A}(),y(Bo.prototype,"bbox",[v],Object.getOwnPropertyDescriptor(Bo.prototype,"bbox"),Bo.prototype),y(Bo.prototype,"_cmapProcessor",[v],Object.getOwnPropertyDescriptor(Bo.prototype,"_cmapProcessor"),Bo.prototype),y(Bo.prototype,"characterSet",[v],Object.getOwnPropertyDescriptor(Bo.prototype,"characterSet"),Bo.prototype),y(Bo.prototype,"_layoutEngine",[v],Object.getOwnPropertyDescriptor(Bo.prototype,"_layoutEngine"),Bo.prototype),y(Bo.prototype,"variationAxes",[v],Object.getOwnPropertyDescriptor(Bo.prototype,"variationAxes"),Bo.prototype),y(Bo.prototype,"namedVariations",[v],Object.getOwnPropertyDescriptor(Bo.prototype,"namedVariations"),Bo.prototype),y(Bo.prototype,"_variationProcessor",[v],Object.getOwnPropertyDescriptor(Bo.prototype,"_variationProcessor"),Bo.prototype),Bo),Uo=new l.Struct({tag:new l.String(4),offset:new l.Pointer(l.uint32,"void",{type:"global"}),compLength:l.uint32,length:l.uint32,origChecksum:l.uint32}),So=new l.Struct({tag:new l.String(4),flavor:l.uint32,length:l.uint32,numTables:l.uint16,reserved:new l.Reserved(l.uint16),totalSfntSize:l.uint32,majorVersion:l.uint16,minorVersion:l.uint16,metaOffset:l.uint32,metaLength:l.uint32,metaOrigLength:l.uint32,privOffset:l.uint32,privLength:l.uint32,tables:new l.Array(Uo,"numTables")});So.process=function(){for(var A,t={},e=c(this.tables);!(A=e()).done;){var n=A.value;t[n.tag]=n}this.tables=t};var xo=function(A){function t(){return A.apply(this,arguments)||this}s(t,A),t.probe=function(A){return"wOFF"===A.toString("ascii",0,4)};var e=t.prototype;return e._decodeDirectory=function(){this.directory=So.decode(this.stream,{_startOffset:0})},e._getTableStream=function(A){var t=this.directory.tables[A];if(t){if(this.stream.pos=t.offset,t.compLength<t.length){this.stream.pos+=2;var e=r.alloc(t.length),n=d(this.stream.readBuffer(t.compLength-2),e);return new l.DecodeStream(n)}return this.stream}return null},t}(zo),To=function(A){function t(){return A.apply(this,arguments)||this}s(t,A);var e=t.prototype;return e._decode=function(){return this._font._transformedGlyphs[this.id]},e._getCBox=function(){return this.path.bbox},t}(Eo),Po={decode:function(A){for(var t=0,e=[0,1,2,3,4],n=0;n<e.length;n++){var r=A.readUInt8();if(3758096384&t)throw new Error("Overflow");if(t=t<<7|127&r,0==(128&r))return t}throw new Error("Bad base 128 number")}},No=["cmap","head","hhea","hmtx","maxp","name","OS/2","post","cvt ","fpgm","glyf","loca","prep","CFF ","VORG","EBDT","EBLC","gasp","hdmx","kern","LTSH","PCLT","VDMX","vhea","vmtx","BASE","GDEF","GPOS","GSUB","EBSC","JSTF","MATH","CBDT","CBLC","COLR","CPAL","SVG ","sbix","acnt","avar","bdat","bloc","bsln","cvar","fdsc","feat","fmtx","fvar","gvar","hsty","just","lcar","mort","morx","opbd","prop","trak","Zapf","Silf","Glat","Gloc","Feat","Sill"],Ro=new l.Struct({flags:l.uint8,customTag:new l.Optional(new l.String(4),(function(A){return 63==(63&A.flags)})),tag:function(A){return A.customTag||No[63&A.flags]},length:Po,transformVersion:function(A){return A.flags>>>6&3},transformed:function(A){return"glyf"===A.tag||"loca"===A.tag?0===A.transformVersion:0!==A.transformVersion},transformLength:new l.Optional(Po,(function(A){return A.transformed}))}),Go=new l.Struct({tag:new l.String(4),flavor:l.uint32,length:l.uint32,numTables:l.uint16,reserved:new l.Reserved(l.uint16),totalSfntSize:l.uint32,totalCompressedSize:l.uint32,majorVersion:l.uint16,minorVersion:l.uint16,metaOffset:l.uint32,metaLength:l.uint32,metaOrigLength:l.uint32,privOffset:l.uint32,privLength:l.uint32,tables:new l.Array(Ro,"numTables")});Go.process=function(){for(var A={},t=0;t<this.tables.length;t++){var e=this.tables[t];A[e.tag]=e}return this.tables=A};var Ho=function(A){function t(){return A.apply(this,arguments)||this}s(t,A),t.probe=function(A){return"wOF2"===A.toString("ascii",0,4)};var e=t.prototype;return e._decodeDirectory=function(){this.directory=Go.decode(this.stream),this._dataPos=this.stream.pos},e._decompress=function(){if(!this._decompressed){this.stream.pos=this._dataPos;var A=this.stream.readBuffer(this.directory.totalCompressedSize),t=0;for(var e in this.directory.tables){var n=this.directory.tables[e];n.offset=t,t+=null!=n.transformLength?n.transformLength:n.length}var i=C(A,t);if(!i)throw new Error("Error decoding compressed data in WOFF2");this.stream=new l.DecodeStream(r.from(i)),this._decompressed=!0}},e._decodeTable=function(t){return this._decompress(),A.prototype._decodeTable.call(this,t)},e._getBaseGlyph=function(t,e){if(void 0===e&&(e=[]),!this._glyphs[t])return this.directory.tables.glyf&&this.directory.tables.glyf.transformed?(this._transformedGlyphs||this._transformGlyfTable(),this._glyphs[t]=new To(t,e,this)):A.prototype._getBaseGlyph.call(this,t,e)},e._transformGlyfTable=function(){this._decompress(),this.stream.pos=this.directory.tables.glyf.offset;for(var A=Lo.decode(this.stream),t=[],e=0;e<A.numGlyphs;e++){var n={},r=A.nContours.readInt16BE();if(n.numberOfContours=r,r>0){for(var i=[],o=0,s=0;s<r;s++)o+=Jo(A.nPoints),i.push(o);n.points=Oo(A.flags,A.glyphs,o);for(var a=0;a<r;a++)n.points[i[a]-1].endContour=!0;Jo(A.glyphs)}else r<0&&Eo.prototype._decodeComposite.call({_font:this},n,A.composites)&&Jo(A.glyphs);t.push(n)}this._transformedGlyphs=t},t}(zo),ko=function(){function A(A){this.length=A,this._buf=new l.Buffer(A)}return A.prototype.decode=function(A,t){return new l.DecodeStream(this._buf.decode(A,t))},A}(),Lo=new l.Struct({version:l.uint32,numGlyphs:l.uint16,indexFormat:l.uint16,nContourStreamSize:l.uint32,nPointsStreamSize:l.uint32,flagStreamSize:l.uint32,glyphStreamSize:l.uint32,compositeStreamSize:l.uint32,bboxStreamSize:l.uint32,instructionStreamSize:l.uint32,nContours:new ko("nContourStreamSize"),nPoints:new ko("nPointsStreamSize"),flags:new ko("flagStreamSize"),glyphs:new ko("glyphStreamSize"),composites:new ko("compositeStreamSize"),bboxes:new ko("bboxStreamSize"),instructions:new ko("instructionStreamSize")});function Jo(A){var t=A.readUInt8();return 253===t?A.readUInt16BE():255===t?A.readUInt8()+253:254===t?A.readUInt8()+506:t}function jo(A,t){return 1&A?t:-t}function Oo(A,t,e){for(var n,r=n=0,i=[],o=0;o<e;o++){var s=0,a=0,c=A.readUInt8(),B=!(c>>7);if((c&=127)<10)s=0,a=jo(c,((14&c)<<7)+t.readUInt8());else if(c<20)s=jo(c,((c-10&14)<<7)+t.readUInt8()),a=0;else if(c<84)s=jo(c,1+(48&(g=c-20))+((l=t.readUInt8())>>4)),a=jo(c>>1,1+((12&g)<<2)+(15&l));else if(c<120){var g;s=jo(c,1+((g=c-84)/12<<8)+t.readUInt8()),a=jo(c>>1,1+(g%12>>2<<8)+t.readUInt8())}else if(c<124){var l=t.readUInt8(),u=t.readUInt8();s=jo(c,(l<<4)+(u>>4)),a=jo(c>>1,((15&u)<<8)+t.readUInt8())}else s=jo(c,t.readUInt16BE()),a=jo(c>>1,t.readUInt16BE());r+=s,n+=a,i.push(new wo(B,!1,r,n))}return i}var Wo=new l.VersionedStruct(l.uint32,{65536:{numFonts:l.uint32,offsets:new l.Array(l.uint32,"numFonts")},131072:{numFonts:l.uint32,offsets:new l.Array(l.uint32,"numFonts"),dsigTag:l.uint32,dsigLength:l.uint32,dsigOffset:l.uint32}}),Ko=function(){function A(A){if(this.stream=A,"ttcf"!==A.readString(4))throw new Error("Not a TrueType collection");this.header=Wo.decode(A)}return A.probe=function(A){return"ttcf"===A.toString("ascii",0,4)},A.prototype.getFont=function(A){for(var t,e=c(this.header.offsets);!(t=e()).done;){var n=t.value,r=new l.DecodeStream(this.stream.buffer);r.pos=n;var i=new zo(r);if(i.postscriptName===A)return i}return null},o(A,[{key:"fonts",get:function(){for(var A,t=[],e=c(this.header.offsets);!(A=e()).done;){var n=A.value,r=new l.DecodeStream(this.stream.buffer);r.pos=n,t.push(new zo(r))}return t}}]),A}(),Vo=new l.String(l.uint8),Xo=(new l.Struct({len:l.uint32,buf:new l.Buffer("len")}),new l.Struct({id:l.uint16,nameOffset:l.int16,attr:l.uint8,dataOffset:l.uint24,handle:l.uint32})),Zo=new l.Struct({name:new l.String(4),maxTypeIndex:l.uint16,refList:new l.Pointer(l.uint16,new l.Array(Xo,(function(A){return A.maxTypeIndex+1})),{type:"parent"})}),_o=new l.Struct({length:l.uint16,types:new l.Array(Zo,(function(A){return A.length+1}))}),qo=new l.Struct({reserved:new l.Reserved(l.uint8,24),typeList:new l.Pointer(l.uint16,_o),nameListOffset:new l.Pointer(l.uint16,"void")}),$o=new l.Struct({dataOffset:l.uint32,map:new l.Pointer(l.uint32,qo),dataLength:l.uint32,mapLength:l.uint32}),As=function(){function A(A){this.stream=A,this.header=$o.decode(this.stream);for(var t,e=c(this.header.map.typeList.types);!(t=e()).done;){for(var n,r=t.value,i=c(r.refList);!(n=i()).done;){var o=n.value;o.nameOffset>=0?(this.stream.pos=o.nameOffset+this.header.map.nameListOffset,o.name=Vo.decode(this.stream)):o.name=null}"sfnt"===r.name&&(this.sfnt=r)}}return A.probe=function(A){var t=new l.DecodeStream(A);try{var e=$o.decode(t)}catch(A){return!1}for(var n,r=c(e.map.typeList.types);!(n=r()).done;)if("sfnt"===n.value.name)return!0;return!1},A.prototype.getFont=function(A){if(!this.sfnt)return null;for(var t,e=c(this.sfnt.refList);!(t=e()).done;){var n=t.value,r=this.header.dataOffset+n.dataOffset+4,i=new l.DecodeStream(this.stream.buffer.slice(r)),o=new zo(i);if(o.postscriptName===A)return o}return null},o(A,[{key:"fonts",get:function(){for(var A,t=[],e=c(this.sfnt.refList);!(A=e()).done;){var n=A.value,r=this.header.dataOffset+n.dataOffset+4,i=new l.DecodeStream(this.stream.buffer.slice(r));t.push(new zo(i))}return t}}]),A}();I.registerFormat(zo),I.registerFormat(xo),I.registerFormat(Ho),I.registerFormat(Ko),I.registerFormat(As),A.exports=I},7337:function(A,t,e){"use strict";var n=e(4781),r=e(9742),i=e(2055),o=i.BK,s=i.CR,a=i.LF,c=i.NL,B=i.SG,g=i.WJ,l=i.SP,u=i.ZWJ,w=i.BA,h=i.HY,E=i.NS,f=i.AI,Q=i.AL,d=i.CJ,C=i.HL,M=i.RI,I=i.SA,p=i.XX,D=e(8383),y=D.DI_BRK,v=D.IN_BRK,m=D.CI_BRK,F=D.CP_BRK,Y=(D.PR_BRK,D.pairTable),b=new n(r.toByteArray(" ")),z=function(A){switch(A){case f:case I:case B:case p:return Q;case d:return E;default:return A}},U=function(A){switch(A){case a:case c:return o;case l:return g;default:return A}},S=function(A,t){void 0===t&&(t=!1),this.position=A,this.required=t},x=function(){function A(A){this.string=A,this.pos=0,this.lastPos=0,this.curClass=null,this.nextClass=null,this.LB8a=!1,this.LB21a=!1,this.LB30a=0}var t=A.prototype;return t.nextCodePoint=function(){var A=this.string.charCodeAt(this.pos++),t=this.string.charCodeAt(this.pos);return 55296<=A&&A<=56319&&56320<=t&&t<=57343?(this.pos++,1024*(A-55296)+(t-56320)+65536):A},t.nextCharClass=function(){return z(b.get(this.nextCodePoint()))},t.getSimpleBreak=function(){switch(this.nextClass){case l:return!1;case o:case a:case c:return this.curClass=o,!1;case s:return this.curClass=s,!1}return null},t.getPairTableBreak=function(A){var t=!1;switch(Y[this.curClass][this.nextClass]){case y:t=!0;break;case v:t=A===l;break;case m:if(!(t=A===l))return!1;break;case F:if(A!==l)return t}return this.LB8a&&(t=!1),!this.LB21a||this.curClass!==h&&this.curClass!==w?this.LB21a=this.curClass===C:(t=!1,this.LB21a=!1),this.curClass===M?(this.LB30a++,2==this.LB30a&&this.nextClass===M&&(t=!0,this.LB30a=0)):this.LB30a=0,this.curClass=this.nextClass,t},t.nextBreak=function(){if(null==this.curClass){var A=this.nextCharClass();this.curClass=U(A),this.nextClass=A,this.LB8a=A===u,this.LB30a=0}for(;this.pos<this.string.length;){this.lastPos=this.pos;var t=this.nextClass;if(this.nextClass=this.nextCharClass(),this.curClass===o||this.curClass===s&&this.nextClass!==a)return this.curClass=U(z(this.nextClass)),new S(this.lastPos,!0);var e=this.getSimpleBreak();if(null===e&&(e=this.getPairTableBreak(t)),this.LB8a=this.nextClass===u,e)return new S(this.lastPos)}return this.lastPos<this.string.length?(this.lastPos=this.string.length,new S(this.string.length)):null},A}();A.exports=x},4927:function(A,t,e){function n(A){try{if(!e.g.localStorage)return!1}catch(A){return!1}var t=e.g.localStorage[A];return null!=t&&"true"===String(t).toLowerCase()}A.exports=function(A,t){if(n("noDeprecation"))return A;var e=!1;return function(){if(!e){if(n("throwDeprecation"))throw new Error(t);n("traceDeprecation"),e=!0}return A.apply(this,arguments)}}},384:function(A){A.exports=function(A){return A&&"object"==typeof A&&"function"==typeof A.copy&&"function"==typeof A.fill&&"function"==typeof A.readUInt8}},5955:function(A,t,e){"use strict";var n=e(2584),r=e(8662),i=e(6430),o=e(5692);function s(A){return A.call.bind(A)}var a="undefined"!=typeof BigInt,c="undefined"!=typeof Symbol,B=s(Object.prototype.toString),g=s(Number.prototype.valueOf),l=s(String.prototype.valueOf),u=s(Boolean.prototype.valueOf);if(a)var w=s(BigInt.prototype.valueOf);if(c)var h=s(Symbol.prototype.valueOf);function E(A,t){if("object"!=typeof A)return!1;try{return t(A),!0}catch(A){return!1}}function f(A){return"[object Map]"===B(A)}function Q(A){return"[object Set]"===B(A)}function d(A){return"[object WeakMap]"===B(A)}function C(A){return"[object WeakSet]"===B(A)}function M(A){return"[object ArrayBuffer]"===B(A)}function I(A){return"undefined"!=typeof ArrayBuffer&&(M.working?M(A):A instanceof ArrayBuffer)}function p(A){return"[object DataView]"===B(A)}function D(A){return"undefined"!=typeof DataView&&(p.working?p(A):A instanceof DataView)}t.isArgumentsObject=n,t.isGeneratorFunction=r,t.isTypedArray=o,t.isPromise=function(A){return"undefined"!=typeof Promise&&A instanceof Promise||null!==A&&"object"==typeof A&&"function"==typeof A.then&&"function"==typeof A.catch},t.isArrayBufferView=function(A){return"undefined"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer.isView(A):o(A)||D(A)},t.isUint8Array=function(A){return"Uint8Array"===i(A)},t.isUint8ClampedArray=function(A){return"Uint8ClampedArray"===i(A)},t.isUint16Array=function(A){return"Uint16Array"===i(A)},t.isUint32Array=function(A){return"Uint32Array"===i(A)},t.isInt8Array=function(A){return"Int8Array"===i(A)},t.isInt16Array=function(A){return"Int16Array"===i(A)},t.isInt32Array=function(A){return"Int32Array"===i(A)},t.isFloat32Array=function(A){return"Float32Array"===i(A)},t.isFloat64Array=function(A){return"Float64Array"===i(A)},t.isBigInt64Array=function(A){return"BigInt64Array"===i(A)},t.isBigUint64Array=function(A){return"BigUint64Array"===i(A)},f.working="undefined"!=typeof Map&&f(new Map),t.isMap=function(A){return"undefined"!=typeof Map&&(f.working?f(A):A instanceof Map)},Q.working="undefined"!=typeof Set&&Q(new Set),t.isSet=function(A){return"undefined"!=typeof Set&&(Q.working?Q(A):A instanceof Set)},d.working="undefined"!=typeof WeakMap&&d(new WeakMap),t.isWeakMap=function(A){return"undefined"!=typeof WeakMap&&(d.working?d(A):A instanceof WeakMap)},C.working="undefined"!=typeof WeakSet&&C(new WeakSet),t.isWeakSet=function(A){return C(A)},M.working="undefined"!=typeof ArrayBuffer&&M(new ArrayBuffer),t.isArrayBuffer=I,p.working="undefined"!=typeof ArrayBuffer&&"undefined"!=typeof DataView&&p(new DataView(new ArrayBuffer(1),0,1)),t.isDataView=D;var y="undefined"!=typeof SharedArrayBuffer?SharedArrayBuffer:void 0;function v(A){return"[object SharedArrayBuffer]"===B(A)}function m(A){return void 0!==y&&(void 0===v.working&&(v.working=v(new y)),v.working?v(A):A instanceof y)}function F(A){return E(A,g)}function Y(A){return E(A,l)}function b(A){return E(A,u)}function z(A){return a&&E(A,w)}function U(A){return c&&E(A,h)}t.isSharedArrayBuffer=m,t.isAsyncFunction=function(A){return"[object AsyncFunction]"===B(A)},t.isMapIterator=function(A){return"[object Map Iterator]"===B(A)},t.isSetIterator=function(A){return"[object Set Iterator]"===B(A)},t.isGeneratorObject=function(A){return"[object Generator]"===B(A)},t.isWebAssemblyCompiledModule=function(A){return"[object WebAssembly.Module]"===B(A)},t.isNumberObject=F,t.isStringObject=Y,t.isBooleanObject=b,t.isBigIntObject=z,t.isSymbolObject=U,t.isBoxedPrimitive=function(A){return F(A)||Y(A)||b(A)||z(A)||U(A)},t.isAnyArrayBuffer=function(A){return"undefined"!=typeof Uint8Array&&(I(A)||m(A))},["isProxy","isExternal","isModuleNamespaceObject"].forEach((function(A){Object.defineProperty(t,A,{enumerable:!1,value:function(){throw new Error(A+" is not supported in userland")}})}))},9539:function(A,t,e){var n=e(4155),r=Object.getOwnPropertyDescriptors||function(A){for(var t=Object.keys(A),e={},n=0;n<t.length;n++)e[t[n]]=Object.getOwnPropertyDescriptor(A,t[n]);return e},i=/%[sdj%]/g;t.format=function(A){if(!d(A)){for(var t=[],e=0;e<arguments.length;e++)t.push(c(arguments[e]));return t.join(" ")}e=1;for(var n=arguments,r=n.length,o=String(A).replace(i,(function(A){if("%%"===A)return"%";if(e>=r)return A;switch(A){case"%s":return String(n[e++]);case"%d":return Number(n[e++]);case"%j":try{return JSON.stringify(n[e++])}catch(A){return"[Circular]"}default:return A}})),s=n[e];e<r;s=n[++e])f(s)||!I(s)?o+=" "+s:o+=" "+c(s);return o},t.deprecate=function(A,e){if(void 0!==n&&!0===n.noDeprecation)return A;if(void 0===n)return function(){return t.deprecate(A,e).apply(this,arguments)};var r=!1;return function(){if(!r){if(n.throwDeprecation)throw new Error(e);n.traceDeprecation,r=!0}return A.apply(this,arguments)}};var o={},s=/^$/;if(n.env.NODE_DEBUG){var a=n.env.NODE_DEBUG;a=a.replace(/[|\\{}()[\]^$+?.]/g,"\\$&").replace(/\*/g,".*").replace(/,/g,"$|^").toUpperCase(),s=new RegExp("^"+a+"$","i")}function c(A,e){var n={seen:[],stylize:g};return arguments.length>=3&&(n.depth=arguments[2]),arguments.length>=4&&(n.colors=arguments[3]),E(e)?n.showHidden=e:e&&t._extend(n,e),C(n.showHidden)&&(n.showHidden=!1),C(n.depth)&&(n.depth=2),C(n.colors)&&(n.colors=!1),C(n.customInspect)&&(n.customInspect=!0),n.colors&&(n.stylize=B),l(n,A,n.depth)}function B(A,t){var e=c.styles[t];return e?"["+c.colors[e][0]+"m"+A+"["+c.colors[e][1]+"m":A}function g(A,t){return A}function l(A,e,n){if(A.customInspect&&e&&y(e.inspect)&&e.inspect!==t.inspect&&(!e.constructor||e.constructor.prototype!==e)){var r=e.inspect(n,A);return d(r)||(r=l(A,r,n)),r}var i=function(A,t){if(C(t))return A.stylize("undefined","undefined");if(d(t)){var e="'"+JSON.stringify(t).replace(/^"|"$/g,"").replace(/'/g,"\\'").replace(/\\"/g,'"')+"'";return A.stylize(e,"string")}return Q(t)?A.stylize(""+t,"number"):E(t)?A.stylize(""+t,"boolean"):f(t)?A.stylize("null","null"):void 0}(A,e);if(i)return i;var o=Object.keys(e),s=function(A){var t={};return A.forEach((function(A,e){t[A]=!0})),t}(o);if(A.showHidden&&(o=Object.getOwnPropertyNames(e)),D(e)&&(o.indexOf("message")>=0||o.indexOf("description")>=0))return u(e);if(0===o.length){if(y(e)){var a=e.name?": "+e.name:"";return A.stylize("[Function"+a+"]","special")}if(M(e))return A.stylize(RegExp.prototype.toString.call(e),"regexp");if(p(e))return A.stylize(Date.prototype.toString.call(e),"date");if(D(e))return u(e)}var c,B="",g=!1,I=["{","}"];return h(e)&&(g=!0,I=["[","]"]),y(e)&&(B=" [Function"+(e.name?": "+e.name:"")+"]"),M(e)&&(B=" "+RegExp.prototype.toString.call(e)),p(e)&&(B=" "+Date.prototype.toUTCString.call(e)),D(e)&&(B=" "+u(e)),0!==o.length||g&&0!=e.length?n<0?M(e)?A.stylize(RegExp.prototype.toString.call(e),"regexp"):A.stylize("[Object]","special"):(A.seen.push(e),c=g?function(A,t,e,n,r){for(var i=[],o=0,s=t.length;o<s;++o)m(t,String(o))?i.push(w(A,t,e,n,String(o),!0)):i.push("");return r.forEach((function(r){r.match(/^\d+$/)||i.push(w(A,t,e,n,r,!0))})),i}(A,e,n,s,o):o.map((function(t){return w(A,e,n,s,t,g)})),A.seen.pop(),function(A,t,e){var n=A.reduce((function(A,t){return t.indexOf("\n"),A+t.replace(/\u001b\[\d\d?m/g,"").length+1}),0);return n>60?e[0]+(""===t?"":t+"\n ")+" "+A.join(",\n  ")+" "+e[1]:e[0]+t+" "+A.join(", ")+" "+e[1]}(c,B,I)):I[0]+B+I[1]}function u(A){return"["+Error.prototype.toString.call(A)+"]"}function w(A,t,e,n,r,i){var o,s,a;if((a=Object.getOwnPropertyDescriptor(t,r)||{value:t[r]}).get?s=a.set?A.stylize("[Getter/Setter]","special"):A.stylize("[Getter]","special"):a.set&&(s=A.stylize("[Setter]","special")),m(n,r)||(o="["+r+"]"),s||(A.seen.indexOf(a.value)<0?(s=f(e)?l(A,a.value,null):l(A,a.value,e-1)).indexOf("\n")>-1&&(s=i?s.split("\n").map((function(A){return"  "+A})).join("\n").slice(2):"\n"+s.split("\n").map((function(A){return"   "+A})).join("\n")):s=A.stylize("[Circular]","special")),C(o)){if(i&&r.match(/^\d+$/))return s;(o=JSON.stringify(""+r)).match(/^"([a-zA-Z_][a-zA-Z_0-9]*)"$/)?(o=o.slice(1,-1),o=A.stylize(o,"name")):(o=o.replace(/'/g,"\\'").replace(/\\"/g,'"').replace(/(^"|"$)/g,"'"),o=A.stylize(o,"string"))}return o+": "+s}function h(A){return Array.isArray(A)}function E(A){return"boolean"==typeof A}function f(A){return null===A}function Q(A){return"number"==typeof A}function d(A){return"string"==typeof A}function C(A){return void 0===A}function M(A){return I(A)&&"[object RegExp]"===v(A)}function I(A){return"object"==typeof A&&null!==A}function p(A){return I(A)&&"[object Date]"===v(A)}function D(A){return I(A)&&("[object Error]"===v(A)||A instanceof Error)}function y(A){return"function"==typeof A}function v(A){return Object.prototype.toString.call(A)}function m(A,t){return Object.prototype.hasOwnProperty.call(A,t)}t.debuglog=function(A){return A=A.toUpperCase(),o[A]||(s.test(A)?(n.pid,o[A]=function(){t.format.apply(t,arguments)}):o[A]=function(){}),o[A]},t.inspect=c,c.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},c.styles={special:"cyan",number:"yellow",boolean:"yellow",undefined:"grey",null:"bold",string:"green",date:"magenta",regexp:"red"},t.types=e(5955),t.isArray=h,t.isBoolean=E,t.isNull=f,t.isNullOrUndefined=function(A){return null==A},t.isNumber=Q,t.isString=d,t.isSymbol=function(A){return"symbol"==typeof A},t.isUndefined=C,t.isRegExp=M,t.types.isRegExp=M,t.isObject=I,t.isDate=p,t.types.isDate=p,t.isError=D,t.types.isNativeError=D,t.isFunction=y,t.isPrimitive=function(A){return null===A||"boolean"==typeof A||"number"==typeof A||"string"==typeof A||"symbol"==typeof A||void 0===A},t.isBuffer=e(384),t.log=function(){},t.inherits=e(5717),t._extend=function(A,t){if(!t||!I(t))return A;for(var e=Object.keys(t),n=e.length;n--;)A[e[n]]=t[e[n]];return A};var F="undefined"!=typeof Symbol?Symbol("util.promisify.custom"):void 0;function Y(A,t){if(!A){var e=new Error("Promise was rejected with a falsy value");e.reason=A,A=e}return t(A)}t.promisify=function(A){if("function"!=typeof A)throw new TypeError('The "original" argument must be of type Function');if(F&&A[F]){var t;if("function"!=typeof(t=A[F]))throw new TypeError('The "util.promisify.custom" argument must be of type Function');return Object.defineProperty(t,F,{value:t,enumerable:!1,writable:!1,configurable:!0}),t}function t(){for(var t,e,n=new Promise((function(A,n){t=A,e=n})),r=[],i=0;i<arguments.length;i++)r.push(arguments[i]);r.push((function(A,n){A?e(A):t(n)}));try{A.apply(this,r)}catch(A){e(A)}return n}return Object.setPrototypeOf(t,Object.getPrototypeOf(A)),F&&Object.defineProperty(t,F,{value:t,enumerable:!1,writable:!1,configurable:!0}),Object.defineProperties(t,r(A))},t.promisify.custom=F,t.callbackify=function(A){if("function"!=typeof A)throw new TypeError('The "original" argument must be of type Function');function t(){for(var t=[],e=0;e<arguments.length;e++)t.push(arguments[e]);var r=t.pop();if("function"!=typeof r)throw new TypeError("The last argument must be of type Function");var i=this,o=function(){return r.apply(i,arguments)};A.apply(this,t).then((function(A){n.nextTick(o.bind(null,null,A))}),(function(A){n.nextTick(Y.bind(null,A,o))}))}return Object.setPrototypeOf(t,Object.getPrototypeOf(A)),Object.defineProperties(t,r(A)),t}},6430:function(A,t,e){"use strict";var n=e(4029),r=e(3083),i=e(1924),o=e(7296),s=i("Object.prototype.toString"),a=e(6410)(),c="undefined"==typeof globalThis?e.g:globalThis,B=r(),g=i("String.prototype.slice"),l={},u=Object.getPrototypeOf;a&&o&&u&&n(B,(function(A){if("function"==typeof c[A]){var t=new c[A];if(Symbol.toStringTag in t){var e=u(t),n=o(e,Symbol.toStringTag);if(!n){var r=u(e);n=o(r,Symbol.toStringTag)}l[A]=n.get}}}));var w=e(5692);A.exports=function(A){return!!w(A)&&(a&&Symbol.toStringTag in A?function(A){var t=!1;return n(l,(function(e,n){if(!t)try{var r=e.call(A);r===n&&(t=r)}catch(A){}})),t}(A):g(s(A),8,-1))}},6513:function(A,t,e){A.exports=e(5011)},5011:function(A,t,e){!function(){var t;if(A.exports&&!e.g.xmldocAssumeBrowser)t=e(6099);else if(!(t=this.sax))throw new Error("Expected sax to be defined. Make sure you're including sax.js before this file.");function n(A){var t=a[a.length-1].parser;this.name=A.name,this.attr=A.attributes,this.val="",this.children=[],this.firstChild=null,this.lastChild=null,this.line=t.line,this.column=t.column,this.position=t.position,this.startTagPosition=t.startTagPosition}function r(A){this.text=A}function i(A){this.cdata=A}function o(A){this.comment=A}function s(A){if(A&&(A=A.toString().trim()),!A)throw new Error("No XML to parse!");this.doctype="",this.parser=t.parser(!0),function(A){A.onopentag=c,A.onclosetag=B,A.ontext=g,A.oncdata=l,A.oncomment=u,A.ondoctype=w,A.onerror=h}(this.parser),a=[this],this.parser.write(A),delete this.parser}n.prototype._addChild=function(A){this.children.push(A),this.firstChild||(this.firstChild=A),this.lastChild=A},n.prototype._opentag=function(A){var t=new n(A);this._addChild(t),a.unshift(t)},n.prototype._closetag=function(){a.shift()},n.prototype._text=function(A){void 0!==this.children&&(this.val+=A,this._addChild(new r(A)))},n.prototype._cdata=function(A){this.val+=A,this._addChild(new i(A))},n.prototype._comment=function(A){void 0!==this.children&&this._addChild(new o(A))},n.prototype._error=function(A){throw A},n.prototype.eachChild=function(A,t){for(var e=0,n=this.children.length;e<n;e++)if("element"===this.children[e].type&&!1===A.call(t,this.children[e],e,this.children))return},n.prototype.childNamed=function(A){for(var t=0,e=this.children.length;t<e;t++){var n=this.children[t];if(n.name===A)return n}},n.prototype.childrenNamed=function(A){for(var t=[],e=0,n=this.children.length;e<n;e++)this.children[e].name===A&&t.push(this.children[e]);return t},n.prototype.childWithAttribute=function(A,t){for(var e=0,n=this.children.length;e<n;e++){var r=this.children[e];if("element"===r.type&&(t&&r.attr[A]===t||!t&&r.attr[A]))return r}},n.prototype.descendantsNamed=function(A){for(var t=[],e=0,n=this.children.length;e<n;e++){var r=this.children[e];"element"===r.type&&(r.name===A&&t.push(r),t=t.concat(r.descendantsNamed(A)))}return t},n.prototype.descendantWithPath=function(A){for(var t=this,e=A.split("."),n=0,r=e.length;n<r;n++){if(!t||"element"!==t.type)return;t=t.childNamed(e[n])}return t},n.prototype.valueWithPath=function(A){var t=A.split("@"),e=this.descendantWithPath(t[0]);return e?t.length>1?e.attr[t[1]]:e.val:void 0},n.prototype.toString=function(A){return this.toStringWithIndent("",A)},n.prototype.toStringWithIndent=function(A,t){var e=A+"<"+this.name,n=t&&t.compressed?"":"\n";for(var r in t&&t.preserveWhitespace,this.attr)Object.prototype.hasOwnProperty.call(this.attr,r)&&(e+=" "+r+'="'+E(this.attr[r])+'"');if(1===this.children.length&&"element"!==this.children[0].type)e+=">"+this.children[0].toString(t)+"</"+this.name+">";else if(this.children.length){e+=">"+n;for(var i=A+(t&&t.compressed?"":"  "),o=0,s=this.children.length;o<s;o++)e+=this.children[o].toStringWithIndent(i,t)+n;e+=A+"</"+this.name+">"}else t&&t.html?-1!==["area","base","br","col","embed","frame","hr","img","input","keygen","link","menuitem","meta","param","source","track","wbr"].indexOf(this.name)?e+="/>":e+="></"+this.name+">":e+="/>";return e},r.prototype.toString=function(A){return f(E(this.text),A)},r.prototype.toStringWithIndent=function(A,t){return A+this.toString(t)},i.prototype.toString=function(A){return"<![CDATA["+f(this.cdata,A)+"]]>"},i.prototype.toStringWithIndent=function(A,t){return A+this.toString(t)},o.prototype.toString=function(A){return"\x3c!--"+f(E(this.comment),A)+"--\x3e"},o.prototype.toStringWithIndent=function(A,t){return A+this.toString(t)},n.prototype.type="element",r.prototype.type="text",i.prototype.type="cdata",o.prototype.type="comment",function(A,t){for(var e in t)t.hasOwnProperty(e)&&(A[e]=t[e])}(s.prototype,n.prototype),s.prototype._opentag=function(A){void 0===this.children?n.call(this,A):n.prototype._opentag.apply(this,arguments)},s.prototype._doctype=function(A){this.doctype+=A};var a=null;function c(){a[0]&&a[0]._opentag.apply(a[0],arguments)}function B(){a[0]&&a[0]._closetag.apply(a[0],arguments)}function g(){a[0]&&a[0]._text.apply(a[0],arguments)}function l(){a[0]&&a[0]._cdata.apply(a[0],arguments)}function u(){a[0]&&a[0]._comment.apply(a[0],arguments)}function w(){a[0]&&a[0]._doctype.apply(a[0],arguments)}function h(){a[0]&&a[0]._error.apply(a[0],arguments)}function E(A){return A.toString().replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;").replace(/'/g,"&apos;").replace(/"/g,"&quot;")}function f(A,t){var e=A;return t&&t.trimmed&&A.length>25&&(e=e.substring(0,25).trim()+"…"),t&&t.preserveWhitespace||(e=e.trim()),e}A.exports&&!e.g.xmldocAssumeBrowser?(A.exports.XmlDocument=s,A.exports.XmlElement=n,A.exports.XmlTextNode=r,A.exports.XmlCDataNode=i,A.exports.XmlCommentNode=o):(this.XmlDocument=s,this.XmlElement=n,this.XmlTextNode=r,this.XmlCDataNode=i,this.XmlCommentNode=o)}()},6255:function(A,t,e){"use strict";function n(A){this.fs=A,this.resolving={}}"undefined"==typeof window||window.Promise||e(3867),e(4667),n.prototype.resolve=function(A,t){if(!this.resolving[A]){var e=this;this.resolving[A]=new Promise((function(n,r){0===A.toLowerCase().indexOf("https://")||0===A.toLowerCase().indexOf("http://")?e.fs.existsSync(A)?n():function(A,t){return new Promise((function(e,n){var r=new XMLHttpRequest;for(var i in r.open("GET",A,!0),t)r.setRequestHeader(i,t[i]);r.responseType="arraybuffer",r.onreadystatechange=function(){4===r.readyState&&(r.status>=200&&r.status<300||setTimeout((function(){n(new TypeError('Failed to fetch (url: "'+A+'")'))}),0))},r.onload=function(){r.status>=200&&r.status<300&&e(r.response)},r.onerror=function(){setTimeout((function(){n(new TypeError('Network request failed (url: "'+A+'")'))}),0)},r.ontimeout=function(){setTimeout((function(){n(new TypeError('Network request failed (url: "'+A+'")'))}),0)},r.send()}))}(A,t).then((function(t){e.fs.writeFileSync(A,t),n()}),(function(A){r(A)})):n()}))}return this.resolving[A]},n.prototype.resolved=function(){var A=this;return new Promise((function(t,e){Promise.all(Object.values(A.resolving)).then((function(){t()}),(function(A){e(A)}))}))},A.exports=n},4275:function(A,t,e){"use strict";var n=e(8823).Buffer,r=e(6225).isFunction,i=e(6225).isUndefined,o=(e(6225).isNull,e(2984).saveAs),s={Roboto:{normal:"Roboto-Regular.ttf",bold:"Roboto-Medium.ttf",italics:"Roboto-Italic.ttf",bolditalics:"Roboto-MediumItalic.ttf"}};function a(A,t,e,n){this.docDefinition=A,this.tableLayouts=t||null,this.fonts=e||s,this.vfs=n}a.prototype._createDoc=function(A,t){var n=function(A){return"object"==typeof A?{url:A.url,headers:A.headers}:{url:A,headers:{}}};A=A||{},this.tableLayouts&&(A.tableLayouts=this.tableLayouts);var i=new(e(8617))(this.fonts);if(e(3857).bindFS(this.vfs),!r(t))return i.createPdfKitDocument(this.docDefinition,A);var o=new(e(6255))(e(3857));for(var s in this.fonts)if(this.fonts.hasOwnProperty(s)){if(this.fonts[s].normal)if(Array.isArray(this.fonts[s].normal)){var a=n(this.fonts[s].normal[0]);o.resolve(a.url,a.headers),this.fonts[s].normal[0]=a.url}else a=n(this.fonts[s].normal),o.resolve(a.url,a.headers),this.fonts[s].normal=a.url;this.fonts[s].bold&&(Array.isArray(this.fonts[s].bold)?(a=n(this.fonts[s].bold[0]),o.resolve(a.url,a.headers),this.fonts[s].bold[0]=a.url):(a=n(this.fonts[s].bold),o.resolve(a.url,a.headers),this.fonts[s].bold=a.url)),this.fonts[s].italics&&(Array.isArray(this.fonts[s].italics)?(a=n(this.fonts[s].italics[0]),o.resolve(a.url,a.headers),this.fonts[s].italics[0]=a.url):(a=n(this.fonts[s].italics),o.resolve(a.url,a.headers),this.fonts[s].italics=a.url)),this.fonts[s].bolditalics&&(Array.isArray(this.fonts[s].bolditalics)?(a=n(this.fonts[s].bolditalics[0]),o.resolve(a.url,a.headers),this.fonts[s].bolditalics[0]=a.url):(a=n(this.fonts[s].bolditalics),o.resolve(a.url,a.headers),this.fonts[s].bolditalics=a.url))}if(this.docDefinition.images)for(var c in this.docDefinition.images)this.docDefinition.images.hasOwnProperty(c)&&(a=n(this.docDefinition.images[c]),o.resolve(a.url,a.headers),this.docDefinition.images[c]=a.url);var B=this;o.resolved().then((function(){var e=i.createPdfKitDocument(B.docDefinition,A);t(e)}),(function(A){throw A}))},a.prototype._flushDoc=function(A,t){var e,r=[];A.on("readable",(function(){for(var t;null!==(t=A.read(9007199254740991));)r.push(t)})),A.on("end",(function(){e=n.concat(r),t(e,A._pdfMakePages)})),A.end()},a.prototype._getPages=function(A,t){if(!t)throw"_getPages is an async method and needs a callback argument";var e=this;this._createDoc(A,(function(A){e._flushDoc(A,(function(A,e){t(e)}))}))},a.prototype._bufferToBlob=function(A){var t;try{t=new Blob([A],{type:"application/pdf"})}catch(n){if("InvalidStateError"===n.name){var e=new Uint8Array(A);t=new Blob([e.buffer],{type:"application/pdf"})}}if(!t)throw"Could not generate blob";return t},a.prototype._openWindow=function(){var A=window.open("","_blank");if(null===A)throw"Open PDF in new window blocked by browser";return A},a.prototype._openPdf=function(A,t){t||(t=this._openWindow());try{this.getBlob((function(A){var e=(window.URL||window.webkitURL).createObjectURL(A);t.location.href=e}),A)}catch(A){throw t.close(),A}},a.prototype.open=function(A,t){(A=A||{}).autoPrint=!1,t=t||null,this._openPdf(A,t)},a.prototype.print=function(A,t){(A=A||{}).autoPrint=!0,t=t||null,this._openPdf(A,t)},a.prototype.download=function(A,t,e){r(A)&&(i(t)||(e=t),t=A,A=null),A=A||"file.pdf",this.getBlob((function(e){o(e,A),r(t)&&t()}),e)},a.prototype.getBase64=function(A,t){if(!A)throw"getBase64 is an async method and needs a callback argument";this.getBuffer((function(t){A(t.toString("base64"))}),t)},a.prototype.getDataUrl=function(A,t){if(!A)throw"getDataUrl is an async method and needs a callback argument";this.getBuffer((function(t){A("data:application/pdf;base64,"+t.toString("base64"))}),t)},a.prototype.getBlob=function(A,t){if(!A)throw"getBlob is an async method and needs a callback argument";var e=this;this.getBuffer((function(t){var n=e._bufferToBlob(t);A(n)}),t)},a.prototype.getBuffer=function(A,t){if(!A)throw"getBuffer is an async method and needs a callback argument";var e=this;this._createDoc(t,(function(t){e._flushDoc(t,(function(t){A(t)}))}))},a.prototype.getStream=function(A,t){if(!r(t))return this._createDoc(A);this._createDoc(A,(function(A){t(A)}))},A.exports={createPdf:function(A,t,n,r){if(!function(){try{var A=new Uint8Array(1),t={foo:function(){return 42}};return Object.setPrototypeOf(t,Uint8Array.prototype),Object.setPrototypeOf(A,t),42===A.foo()}catch(A){return!1}}())throw"Your browser does not provide the level of support needed";return new a(A,t||e.g.pdfMake.tableLayouts,n||e.g.pdfMake.fonts,r||e.g.pdfMake.vfs)}}},3857:function(A,t,e){"use strict";var n=e(8823).Buffer;function r(){this.fileSystem={},this.dataSystem={}}function i(A){return 0===A.indexOf("/")&&(A=A.substring(1)),0===A.indexOf("/")&&(A=A.substring(1)),A}r.prototype.existsSync=function(A){return A=i(A),void 0!==this.fileSystem[A]||void 0!==this.dataSystem[A]},r.prototype.readFileSync=function(A,t){A=i(A);var e=this.dataSystem[A];if("string"==typeof e&&"utf8"===t)return e;if(e)return new n(e,"string"==typeof e?"base64":void 0);var r=this.fileSystem[A];if(r)return r;throw"File '"+A+"' not found in virtual file system"},r.prototype.writeFileSync=function(A,t){this.fileSystem[i(A)]=t},r.prototype.bindFS=function(A){this.dataSystem=A||{}},A.exports=new r},4498:function(A,t,e){"use strict";var n=e(6225).isString;function r(A){return"auto"===A.width}function i(A){return null===A.width||void 0===A.width||"*"===A.width||"star"===A.width}A.exports={buildColumnWidths:function(A,t){var e=[],o=0,s=0,a=[],c=0,B=0,g=[],l=t;A.forEach((function(A){r(A)?(e.push(A),o+=A._minWidth,s+=A._maxWidth):i(A)?(a.push(A),c=Math.max(c,A._minWidth),B=Math.max(B,A._maxWidth)):g.push(A)})),g.forEach((function(A){n(A.width)&&/\d+%/.test(A.width)&&(A.width=parseFloat(A.width)*l/100),A.width<A._minWidth&&A.elasticWidth?A._calcWidth=A._minWidth:A._calcWidth=A.width,t-=A._calcWidth}));var u=o+c*a.length,w=s+B*a.length;if(u>=t)e.forEach((function(A){A._calcWidth=A._minWidth})),a.forEach((function(A){A._calcWidth=c}));else{if(w<t)e.forEach((function(A){A._calcWidth=A._maxWidth,t-=A._calcWidth}));else{var h=t-u,E=w-u;e.forEach((function(A){var e=A._maxWidth-A._minWidth;A._calcWidth=A._minWidth+e*h/E,t-=A._calcWidth}))}if(a.length>0){var f=t/a.length;a.forEach((function(A){A._calcWidth=f}))}}},measureMinMax:function(A){for(var t={min:0,max:0},e={min:0,max:0},n=0,o=0,s=A.length;o<s;o++){var a=A[o];i(a)?(e.min=Math.max(e.min,a._minWidth),e.max=Math.max(e.max,a._maxWidth),n++):r(a)?(t.min+=a._minWidth,t.max+=a._maxWidth):(t.min+=void 0!==a.width&&a.width||a._minWidth,t.max+=void 0!==a.width&&a.width||a._maxWidth)}return n&&(t.min+=n*e.min,t.max+=n*e.max),t},isAutoColumn:r,isStarColumn:i}},1728:function(A,t,e){"use strict";var n=e(1350),r=e(7597),i=e(4498),o=e(6225).isString,s=e(6225).isNumber,a=e(6225).isObject,c=e(6225).isArray,B=e(6225).fontStringify,g=e(6225).getNodeId,l=e(6225).pack,u=e(145);function w(A,t,e,i,o,s,a){this.textTools=new n(A),this.styleStack=new r(t,e),this.imageMeasure=i,this.svgMeasure=o,this.tableLayouts=s,this.images=a,this.autoImageIndex=1}w.prototype.measureDocument=function(A){return this.measureNode(A)},w.prototype.measureNode=function(A){var t=this;return this.styleStack.auto(A,(function(){if(A._margin=function(){function e(A,t){return A.marginLeft||A.marginTop||A.marginRight||A.marginBottom?[A.marginLeft||t[0]||0,A.marginTop||t[1]||0,A.marginRight||t[2]||0,A.marginBottom||t[3]||0]:t}function n(A){return s(A)?A=[A,A,A,A]:c(A)&&2===A.length&&(A=[A[0],A[1],A[0],A[1]]),A}var r=[void 0,void 0,void 0,void 0];if(A.style){var i=function(A){for(var e={},n=A.length-1;n>=0;n--){var r=A[n],i=t.styleStack.styleDictionary[r];for(var o in i)i.hasOwnProperty(o)&&(e[o]=i[o])}return e}(c(A.style)?A.style:[A.style]);i&&(r=e(i,r)),i.margin&&(r=n(i.margin))}return r=e(A,r),A.margin&&(r=n(A.margin)),void 0===r[0]&&void 0===r[1]&&void 0===r[2]&&void 0===r[3]?null:r}(),A.columns)return e(t.measureColumns(A));if(A.stack)return e(t.measureVerticalContainer(A));if(A.ul)return e(t.measureUnorderedList(A));if(A.ol)return e(t.measureOrderedList(A));if(A.table)return e(t.measureTable(A));if(void 0!==A.text)return e(t.measureLeaf(A));if(A.toc)return e(t.measureToc(A));if(A.image)return e(t.measureImage(A));if(A.svg)return e(t.measureSVG(A));if(A.canvas)return e(t.measureCanvas(A));if(A.qr)return e(t.measureQr(A));throw"Unrecognized document structure: "+JSON.stringify(A,B)}));function e(A){var t=A._margin;return t&&(A._minWidth+=t[0]+t[2],A._maxWidth+=t[0]+t[2]),A}},w.prototype.convertIfBase64Image=function(A){if(/^data:image\/(jpeg|jpg|png);base64,/.test(A.image)){var t="$$pdfmake$$"+this.autoImageIndex++;this.images[t]=A.image,A.image=t}},w.prototype.measureImageWithDimensions=function(A,t){if(A.fit){var e=t.width/t.height>A.fit[0]/A.fit[1]?A.fit[0]/t.width:A.fit[1]/t.height;A._width=A._minWidth=A._maxWidth=t.width*e,A._height=t.height*e}else A._width=A._minWidth=A._maxWidth=A.width||t.width,A._height=A.height||t.height*A._width/t.width,s(A.maxWidth)&&A.maxWidth<A._width&&(A._width=A._minWidth=A._maxWidth=A.maxWidth,A._height=A._width*t.height/t.width),s(A.maxHeight)&&A.maxHeight<A._height&&(A._height=A.maxHeight,A._width=A._minWidth=A._maxWidth=A._height*t.width/t.height),s(A.minWidth)&&A.minWidth>A._width&&(A._width=A._minWidth=A._maxWidth=A.minWidth,A._height=A._width*t.height/t.width),s(A.minHeight)&&A.minHeight>A._height&&(A._height=A.minHeight,A._width=A._minWidth=A._maxWidth=A._height*t.width/t.height);A._alignment=this.styleStack.getProperty("alignment")},w.prototype.measureImage=function(A){this.images&&this.convertIfBase64Image(A);var t=this.imageMeasure.measureImage(A.image);return this.measureImageWithDimensions(A,t),A},w.prototype.measureSVG=function(A){var t=this.svgMeasure.measureSVG(A.svg);return this.measureImageWithDimensions(A,t),A.font=this.styleStack.getProperty("font"),A.svg=this.svgMeasure.writeDimensions(A.svg,{width:A._width,height:A._height}),A},w.prototype.measureLeaf=function(A){A._textRef&&A._textRef._textNodeRef.text&&(A.text=A._textRef._textNodeRef.text);var t=this.styleStack.clone();t.push(A);var e=this.textTools.buildInlines(A.text,t);return A._inlines=e.items,A._minWidth=e.minWidth,A._maxWidth=e.maxWidth,A},w.prototype.measureToc=function(A){if(A.toc.title&&(A.toc.title=this.measureNode(A.toc.title)),A.toc._items.length>0){for(var t=[],e=A.toc.textStyle||{},n=A.toc.numberStyle||e,r=A.toc.textMargin||[0,0,0,0],i=0,o=A.toc._items.length;i<o;i++){var s=A.toc._items[i],a=s._textNodeRef.tocStyle||e,c=s._textNodeRef.tocMargin||r,B=s._textNodeRef.tocNumberStyle||n,l=g(s._nodeRef);t.push([{text:s._textNodeRef.text,linkToDestination:l,alignment:"left",style:a,margin:c},{text:"00000",linkToDestination:l,alignment:"right",_tocItemRef:s._nodeRef,style:B,margin:[0,c[1],0,c[3]]}])}A.toc._table={table:{dontBreakRows:!0,widths:["*","auto"],body:t},layout:"noBorders"},A.toc._table=this.measureNode(A.toc._table)}return A},w.prototype.measureVerticalContainer=function(A){var t=A.stack;A._minWidth=0,A._maxWidth=0;for(var e=0,n=t.length;e<n;e++)t[e]=this.measureNode(t[e]),A._minWidth=Math.max(A._minWidth,t[e]._minWidth),A._maxWidth=Math.max(A._maxWidth,t[e]._maxWidth);return A},w.prototype.gapSizeForList=function(){return this.textTools.sizeOfString("9. ",this.styleStack)},w.prototype.buildUnorderedMarker=function(A,t,e){var n,r=A.getProperty("markerColor")||A.getProperty("color")||"black";switch(e){case"circle":n=function(A,t){var e=A.fontSize/6;return{canvas:[{x:e,y:A.height/A.lineHeight+A.descender-A.fontSize/3,r1:e,r2:e,type:"ellipse",lineColor:t}]}}(t,r);break;case"square":n=function(A,t){var e=A.fontSize/3;return{canvas:[{x:0,y:A.height/A.lineHeight+A.descender-A.fontSize/3-e/2,h:e,w:e,type:"rect",color:t}]}}(t,r);break;case"none":n={};break;default:n=function(A,t){var e=A.fontSize/6;return{canvas:[{x:e,y:A.height/A.lineHeight+A.descender-A.fontSize/3,r1:e,r2:e,type:"ellipse",color:t}]}}(t,r)}return n._minWidth=n._maxWidth=t.width,n._minHeight=n._maxHeight=t.height,n},w.prototype.buildOrderedMarker=function(A,t,e,n){function r(A){return A<1?A.toString():function A(t){return(t>=26?A((t/26>>0)-1):"")+"abcdefghijklmnopqrstuvwxyz"[t%26>>0]}(A-1)}function i(A){if(A<1||A>4999)return A.toString();var t,e=A,n={M:1e3,CM:900,D:500,CD:400,C:100,XC:90,L:50,XL:40,X:10,IX:9,V:5,IV:4,I:1},r="";for(t in n)for(;e>=n[t];)r+=t,e-=n[t];return r}var o;switch(e){case"none":o=null;break;case"upper-alpha":o=r(A).toUpperCase();break;case"lower-alpha":o=r(A);break;case"upper-roman":o=i(A);break;case"lower-roman":o=i(A).toLowerCase();break;default:o=function(A){return A.toString()}(A)}if(null===o)return{};n&&(c(n)?(n[0]&&(o=n[0]+o),n[1]&&(o+=n[1]),o+=" "):o+=n+" ");var s={text:o},a=t.getProperty("markerColor");return a&&(s.color=a),{_inlines:this.textTools.buildInlines(s,t).items}},w.prototype.measureUnorderedList=function(A){var t=this.styleStack.clone(),e=A.ul;A.type=A.type||"disc",A._gapSize=this.gapSizeForList(),A._minWidth=0,A._maxWidth=0;for(var n=0,r=e.length;n<r;n++){var i=e[n]=this.measureNode(e[n]);i.ol||i.ul||(i.listMarker=this.buildUnorderedMarker(t,A._gapSize,i.listType||A.type)),A._minWidth=Math.max(A._minWidth,e[n]._minWidth+A._gapSize.width),A._maxWidth=Math.max(A._maxWidth,e[n]._maxWidth+A._gapSize.width)}return A},w.prototype.measureOrderedList=function(A){var t=this.styleStack.clone(),e=A.ol;A.type=A.type||"decimal",A.separator=A.separator||".",A.reversed=A.reversed||!1,s(A.start)||(A.start=A.reversed?e.length:1),A._gapSize=this.gapSizeForList(),A._minWidth=0,A._maxWidth=0;for(var n=A.start,r=0,i=e.length;r<i;r++){if(!(a=e[r]=this.measureNode(e[r])).ol&&!a.ul){var o=s(a.counter)?a.counter:n;a.listMarker=this.buildOrderedMarker(o,t,a.listType||A.type,A.separator),a.listMarker._inlines&&(A._gapSize.width=Math.max(A._gapSize.width,a.listMarker._inlines[0].width))}A._minWidth=Math.max(A._minWidth,e[r]._minWidth),A._maxWidth=Math.max(A._maxWidth,e[r]._maxWidth),A.reversed?n--:n++}for(A._minWidth+=A._gapSize.width,A._maxWidth+=A._gapSize.width,r=0,i=e.length;r<i;r++){var a;(a=e[r]).ol||a.ul||(a.listMarker._minWidth=a.listMarker._maxWidth=A._gapSize.width)}return A},w.prototype.measureColumns=function(A){var t=A.columns;A._gap=this.styleStack.getProperty("columnGap")||0;for(var e=0,n=t.length;e<n;e++)t[e]=this.measureNode(t[e]);var r=i.measureMinMax(t),o=t.length>0?t.length-1:0;return A._minWidth=r.min+A._gap*o,A._maxWidth=r.max+A._gap*o,A},w.prototype.measureTable=function(A){!function(A){if(A.table.widths||(A.table.widths="auto"),o(A.table.widths))for(A.table.widths=[A.table.widths];A.table.widths.length<A.table.body[0].length;)A.table.widths.push(A.table.widths[A.table.widths.length-1]);for(var t=0,e=A.table.widths.length;t<e;t++){var n=A.table.widths[t];(s(n)||o(n))&&(A.table.widths[t]={width:n})}}(A),A._layout=function(t){var e=A.layout;return o(e)&&(e=t[e]),l({hLineWidth:function(A,t){return 1},vLineWidth:function(A,t){return 1},hLineColor:function(A,t){return"black"},vLineColor:function(A,t){return"black"},hLineStyle:function(A,t){return null},vLineStyle:function(A,t){return null},paddingLeft:function(A,t){return 4},paddingRight:function(A,t){return 4},paddingTop:function(A,t){return 2},paddingBottom:function(A,t){return 2},fillColor:function(A,t){return null},fillOpacity:function(A,t){return 1},defaultBorder:!0},e)}(this.tableLayouts),A._offsets=function(t){for(var e=[],n=0,r=0,i=0,o=A.table.widths.length;i<o;i++){var s=r+t.vLineWidth(i,A)+t.paddingLeft(i,A);e.push(s),n+=s,r=t.paddingRight(i,A)}return{total:n+=r+t.vLineWidth(A.table.widths.length,A),offsets:e}}(A._layout);var t,e,n,r,c=[];for(t=0,n=A.table.body[0].length;t<n;t++){var B=A.table.widths[t];for(B._minWidth=0,B._maxWidth=0,e=0,r=A.table.body.length;e<r;e++){var g=A.table.body[e],u=g[t];if(void 0===u)throw"Malformed table row, a cell is undefined.";null===u&&(u=""),u._span||((u=g[t]=this.styleStack.auto(u,h(this,u))).colSpan&&u.colSpan>1?(f(g,t,u.colSpan),c.push({col:t,span:u.colSpan,minWidth:u._minWidth,maxWidth:u._maxWidth})):(B._minWidth=Math.max(B._minWidth,u._minWidth),B._maxWidth=Math.max(B._maxWidth,u._maxWidth))),u.rowSpan&&u.rowSpan>1&&Q(A.table,e,t,u.rowSpan)}}!function(){for(var t,e,n=0,r=c.length;n<r;n++){var i=c[n],o=E(i.col,i.span,A._offsets),s=i.minWidth-o.minWidth,a=i.maxWidth-o.maxWidth;if(s>0)for(t=s/i.span,e=0;e<i.span;e++)A.table.widths[i.col+e]._minWidth+=t;if(a>0)for(t=a/i.span,e=0;e<i.span;e++)A.table.widths[i.col+e]._maxWidth+=t}}();var w=i.measureMinMax(A.table.widths);return A._minWidth=w.min+A._offsets.total,A._maxWidth=w.max+A._offsets.total,A;function h(A,t){return function(){return a(t)&&(t.fillColor=A.styleStack.getProperty("fillColor"),t.fillOpacity=A.styleStack.getProperty("fillOpacity")),A.measureNode(t)}}function E(t,e,n){for(var r={minWidth:0,maxWidth:0},i=0;i<e;i++)r.minWidth+=A.table.widths[t+i]._minWidth+(i?n.offsets[t+i]:0),r.maxWidth+=A.table.widths[t+i]._maxWidth+(i?n.offsets[t+i]:0);return r}function f(A,t,e){for(var n=1;n<e;n++)A[t+n]={_span:!0,_minWidth:0,_maxWidth:0,rowSpan:A[t].rowSpan}}function Q(A,t,e,n){for(var r=1;r<n;r++)A.body[t+r][e]={_span:!0,_minWidth:0,_maxWidth:0,fillColor:A.body[t][e].fillColor,fillOpacity:A.body[t][e].fillOpacity}}},w.prototype.measureCanvas=function(A){for(var t=0,e=0,n=0,r=A.canvas.length;n<r;n++){var i=A.canvas[n];switch(i.type){case"ellipse":t=Math.max(t,i.x+i.r1),e=Math.max(e,i.y+i.r2);break;case"rect":t=Math.max(t,i.x+i.w),e=Math.max(e,i.y+i.h);break;case"line":t=Math.max(t,i.x1,i.x2),e=Math.max(e,i.y1,i.y2);break;case"polyline":for(var o=0,s=i.points.length;o<s;o++)t=Math.max(t,i.points[o].x),e=Math.max(e,i.points[o].y)}}return A._minWidth=A._maxWidth=t,A._minHeight=A._maxHeight=e,A._alignment=this.styleStack.getProperty("alignment"),A},w.prototype.measureQr=function(A){return(A=u.measure(A))._alignment=this.styleStack.getProperty("alignment"),A},A.exports=w},4889:function(A,t,e){"use strict";var n=e(8823).Buffer,r=e(6225).isString,i=e(6225).isNumber,o=e(6225).isBoolean,s=e(6225).isArray,a=e(6225).isUndefined,c=e(6225).fontStringify;function B(){}B.prototype.preprocessDocument=function(A){return this.parentNode=null,this.tocs=[],this.nodeReferences=[],this.preprocessNode(A)},B.prototype.preprocessNode=function(A){if(s(A)?A={stack:A}:r(A)?A={text:A}:i(A)||o(A)?A={text:A.toString()}:null==A||0===Object.keys(A).length?A={text:""}:!("text"in A)||void 0!==A.text&&null!==A.text||(A.text=""),A.columns)return this.preprocessColumns(A);if(A.stack)return this.preprocessVerticalContainer(A);if(A.ul)return this.preprocessList(A);if(A.ol)return this.preprocessList(A);if(A.table)return this.preprocessTable(A);if(void 0!==A.text)return this.preprocessText(A);if(A.toc)return this.preprocessToc(A);if(A.image)return this.preprocessImage(A);if(A.svg)return this.preprocessSVG(A);if(A.canvas)return this.preprocessCanvas(A);if(A.qr)return this.preprocessQr(A);if(A.pageReference||A.textReference)return this.preprocessText(A);throw"Unrecognized document structure: "+JSON.stringify(A,c)},B.prototype.preprocessColumns=function(A){for(var t=A.columns,e=0,n=t.length;e<n;e++)t[e]=this.preprocessNode(t[e]);return A},B.prototype.preprocessVerticalContainer=function(A){for(var t=A.stack,e=0,n=t.length;e<n;e++)t[e]=this.preprocessNode(t[e]);return A},B.prototype.preprocessList=function(A){for(var t=A.ul||A.ol,e=0,n=t.length;e<n;e++)t[e]=this.preprocessNode(t[e]);return A},B.prototype.preprocessTable=function(A){var t,e,n,r;for(t=0,n=A.table.body[0].length;t<n;t++)for(e=0,r=A.table.body.length;e<r;e++){var i=A.table.body[e],o=i[t];void 0!==o&&(null===o&&(o=""),o._span||(i[t]=this.preprocessNode(o)))}return A},B.prototype.preprocessText=function(A){if(A.tocItem){s(A.tocItem)||(A.tocItem=[A.tocItem]);for(var t=0,e=A.tocItem.length;t<e;t++){r(A.tocItem[t])||(A.tocItem[t]="_default_");var n=A.tocItem[t];this.tocs[n]||(this.tocs[n]={toc:{_items:[],_pseudo:!0}}),A.id||(A.id="toc-"+n+"-"+this.tocs[n].toc._items.length);var i={_nodeRef:this._getNodeForNodeRef(A),_textNodeRef:A};this.tocs[n].toc._items.push(i)}}if(A.id)if(this.nodeReferences[A.id]){if(!this.nodeReferences[A.id]._pseudo)throw"Node id '"+A.id+"' already exists";this.nodeReferences[A.id]._nodeRef=this._getNodeForNodeRef(A),this.nodeReferences[A.id]._textNodeRef=A,this.nodeReferences[A.id]._pseudo=!1}else this.nodeReferences[A.id]={_nodeRef:this._getNodeForNodeRef(A),_textNodeRef:A};if(A.pageReference&&(this.nodeReferences[A.pageReference]||(this.nodeReferences[A.pageReference]={_nodeRef:{},_textNodeRef:{},_pseudo:!0}),A.text="00000",A.linkToDestination=A.pageReference,A._pageRef=this.nodeReferences[A.pageReference]),A.textReference&&(this.nodeReferences[A.textReference]||(this.nodeReferences[A.textReference]={_nodeRef:{},_pseudo:!0}),A.text="",A.linkToDestination=A.textReference,A._textRef=this.nodeReferences[A.textReference]),A.text&&A.text.text)A.text=[this.preprocessNode(A.text)];else if(s(A.text)){var o=!1;for(null===this.parentNode&&(this.parentNode=A,o=!0),t=0,e=A.text.length;t<e;t++)A.text[t]=this.preprocessNode(A.text[t]);o&&(this.parentNode=null)}return A},B.prototype.preprocessToc=function(A){if(A.toc.id||(A.toc.id="_default_"),A.toc.title=A.toc.title?this.preprocessNode(A.toc.title):null,A.toc._items=[],this.tocs[A.toc.id]){if(!this.tocs[A.toc.id].toc._pseudo)throw"TOC '"+A.toc.id+"' already exists";A.toc._items=this.tocs[A.toc.id].toc._items}return this.tocs[A.toc.id]=A,A},B.prototype.preprocessImage=function(A){return a(A.image.type)||a(A.image.data)||"Buffer"!==A.image.type||!s(A.image.data)||(A.image=n.from(A.image.data)),A},B.prototype.preprocessSVG=function(A){return A},B.prototype.preprocessCanvas=function(A){return A},B.prototype.preprocessQr=function(A){return A},B.prototype._getNodeForNodeRef=function(A){return this.parentNode?this.parentNode:A},A.exports=B},3858:function(A,t,e){"use strict";var n=e(8537),r=e(6225).isString;function i(A,t){this.pages=[],this.pageMargins=t,this.x=t.left,this.availableWidth=A.width-t.left-t.right,this.availableHeight=0,this.page=-1,this.snapshots=[],this.endingCell=null,this.tracker=new n,this.backgroundLength=[],this.addPage(A)}i.prototype.beginColumnGroup=function(){this.snapshots.push({x:this.x,y:this.y,availableHeight:this.availableHeight,availableWidth:this.availableWidth,page:this.page,bottomMost:{x:this.x,y:this.y,availableHeight:this.availableHeight,availableWidth:this.availableWidth,page:this.page},endingCell:this.endingCell,lastColumnWidth:this.lastColumnWidth}),this.lastColumnWidth=0},i.prototype.beginColumn=function(A,t,e){var n=this.snapshots[this.snapshots.length-1];this.calculateBottomMost(n),this.endingCell=e,this.page=n.page,this.x=this.x+this.lastColumnWidth+(t||0),this.y=n.y,this.availableWidth=A,this.availableHeight=n.availableHeight,this.lastColumnWidth=A},i.prototype.calculateBottomMost=function(A){this.endingCell?(this.saveContextInEndingCell(this.endingCell),this.endingCell=null):A.bottomMost=function(A,t){var e;return{page:(e=A.page>t.page?A:t.page>A.page?t:A.y>t.y?A:t).page,x:e.x,y:e.y,availableHeight:e.availableHeight,availableWidth:e.availableWidth}}(this,A.bottomMost)},i.prototype.markEnding=function(A){this.page=A._columnEndingContext.page,this.x=A._columnEndingContext.x,this.y=A._columnEndingContext.y,this.availableWidth=A._columnEndingContext.availableWidth,this.availableHeight=A._columnEndingContext.availableHeight,this.lastColumnWidth=A._columnEndingContext.lastColumnWidth},i.prototype.saveContextInEndingCell=function(A){A._columnEndingContext={page:this.page,x:this.x,y:this.y,availableHeight:this.availableHeight,availableWidth:this.availableWidth,lastColumnWidth:this.lastColumnWidth}},i.prototype.completeColumnGroup=function(A){var t=this.snapshots.pop();this.calculateBottomMost(t),this.endingCell=null,this.x=t.x;var e=t.bottomMost.y;A&&(t.page===t.bottomMost.page?t.y+A>e&&(e=t.y+A):e+=A),this.y=e,this.page=t.bottomMost.page,this.availableWidth=t.availableWidth,this.availableHeight=t.bottomMost.availableHeight,A&&(this.availableHeight-=e-t.bottomMost.y),this.lastColumnWidth=t.lastColumnWidth},i.prototype.addMargin=function(A,t){this.x+=A,this.availableWidth-=A+(t||0)},i.prototype.moveDown=function(A){return this.y+=A,this.availableHeight-=A,this.availableHeight>0},i.prototype.initializePage=function(){this.y=this.pageMargins.top,this.availableHeight=this.getCurrentPage().pageSize.height-this.pageMargins.top-this.pageMargins.bottom,this.pageSnapshot().availableWidth=this.getCurrentPage().pageSize.width-this.pageMargins.left-this.pageMargins.right},i.prototype.pageSnapshot=function(){return this.snapshots[0]?this.snapshots[0]:this},i.prototype.moveTo=function(A,t){null!=A&&(this.x=A,this.availableWidth=this.getCurrentPage().pageSize.width-this.x-this.pageMargins.right),null!=t&&(this.y=t,this.availableHeight=this.getCurrentPage().pageSize.height-this.y-this.pageMargins.bottom)},i.prototype.moveToRelative=function(A,t){null!=A&&(this.x=this.x+A),null!=t&&(this.y=this.y+t)},i.prototype.beginDetachedBlock=function(){this.snapshots.push({x:this.x,y:this.y,availableHeight:this.availableHeight,availableWidth:this.availableWidth,page:this.page,endingCell:this.endingCell,lastColumnWidth:this.lastColumnWidth})},i.prototype.endDetachedBlock=function(){var A=this.snapshots.pop();this.x=A.x,this.y=A.y,this.availableWidth=A.availableWidth,this.availableHeight=A.availableHeight,this.page=A.page,this.endingCell=A.endingCell,this.lastColumnWidth=A.lastColumnWidth};var o=function(A,t){return(t=function(A,t){return void 0===A?t:r(A)&&"landscape"===A.toLowerCase()?"landscape":"portrait"}(t,A.pageSize.orientation))!==A.pageSize.orientation?{orientation:t,width:A.pageSize.height,height:A.pageSize.width}:{orientation:A.pageSize.orientation,width:A.pageSize.width,height:A.pageSize.height}};i.prototype.moveToNextPage=function(A){var t=this.page+1,e=this.page,n=this.y,r=t>=this.pages.length;if(r){var i=this.availableWidth,s=this.getCurrentPage().pageSize.orientation,a=o(this.getCurrentPage(),A);this.addPage(a),s===a.orientation&&(this.availableWidth=i)}else this.page=t,this.initializePage();return{newPageCreated:r,prevPage:e,prevY:n,y:this.y}},i.prototype.addPage=function(A){var t={items:[],pageSize:A};return this.pages.push(t),this.backgroundLength.push(0),this.page=this.pages.length-1,this.initializePage(),this.tracker.emit("pageAdded"),t},i.prototype.getCurrentPage=function(){return this.page<0||this.page>=this.pages.length?null:this.pages[this.page]},i.prototype.getCurrentPosition=function(){var A=this.getCurrentPage().pageSize,t=A.height-this.pageMargins.top-this.pageMargins.bottom,e=A.width-this.pageMargins.left-this.pageMargins.right;return{pageNumber:this.page+1,pageOrientation:A.orientation,pageInnerHeight:t,pageInnerWidth:e,left:this.x,top:this.y,verticalRatio:(this.y-this.pageMargins.top)/t,horizontalRatio:(this.x-this.pageMargins.left)/e}},A.exports=i},1196:function(A,t,e){"use strict";var n=e(4775),r=e(6225).isNumber,i=e(6225).pack,o=e(6225).offsetVector,s=e(3858);function a(A,t){this.context=A,this.contextStack=[],this.tracker=t}function c(A,t,e){null==e||e<0||e>A.items.length?A.items.push(t):A.items.splice(e,0,t)}a.prototype.addLine=function(A,t,e){var n=A.getHeight(),r=this.context,i=r.getCurrentPage(),o=this.getCurrentPositionOnPage();return!(r.availableHeight<n||!i)&&(A.x=r.x+(A.x||0),A.y=r.y+(A.y||0),this.alignLine(A),c(i,{type:"line",item:A},e),this.tracker.emit("lineAdded",A),t||r.moveDown(n),o)},a.prototype.alignLine=function(A){var t=this.context.availableWidth,e=A.getWidth(),n=A.inlines&&A.inlines.length>0&&A.inlines[0].alignment,r=0;switch(n){case"right":r=t-e;break;case"center":r=(t-e)/2}if(r&&(A.x=(A.x||0)+r),"justify"===n&&!A.newLineForced&&!A.lastLineInParagraph&&A.inlines.length>1)for(var i=(t-e)/(A.inlines.length-1),o=1,s=A.inlines.length;o<s;o++)r=o*i,A.inlines[o].x+=r,A.inlines[o].justifyShift=i},a.prototype.addImage=function(A,t,e){var n=this.context,r=n.getCurrentPage(),i=this.getCurrentPositionOnPage();return!(!r||void 0===A.absolutePosition&&n.availableHeight<A._height&&r.items.length>0)&&(void 0===A._x&&(A._x=A.x||0),A.x=n.x+A._x,A.y=n.y,this.alignImage(A),c(r,{type:e||"image",item:A},t),n.moveDown(A._height),i)},a.prototype.addSVG=function(A,t){return this.addImage(A,t,"svg")},a.prototype.addQr=function(A,t){var e=this.context,n=e.getCurrentPage(),r=this.getCurrentPositionOnPage();if(!n||void 0===A.absolutePosition&&e.availableHeight<A._height)return!1;void 0===A._x&&(A._x=A.x||0),A.x=e.x+A._x,A.y=e.y,this.alignImage(A);for(var i=0,o=A._canvas.length;i<o;i++){var s=A._canvas[i];s.x+=A.x,s.y+=A.y,this.addVector(s,!0,!0,t)}return e.moveDown(A._height),r},a.prototype.alignImage=function(A){var t=this.context.availableWidth,e=A._minWidth,n=0;switch(A._alignment){case"right":n=t-e;break;case"center":n=(t-e)/2}n&&(A.x=(A.x||0)+n)},a.prototype.alignCanvas=function(A){var t=this.context.availableWidth,e=A._minWidth,n=0;switch(A._alignment){case"right":n=t-e;break;case"center":n=(t-e)/2}n&&A.canvas.forEach((function(A){o(A,n,0)}))},a.prototype.addVector=function(A,t,e,n){var r=this.context,i=r.getCurrentPage(),s=this.getCurrentPositionOnPage();if(i)return o(A,t?0:r.x,e?0:r.y),c(i,{type:"vector",item:A},n),s},a.prototype.beginClip=function(A,t){var e=this.context;return e.getCurrentPage().items.push({type:"beginClip",item:{x:e.x,y:e.y,width:A,height:t}}),!0},a.prototype.endClip=function(){return this.context.getCurrentPage().items.push({type:"endClip"}),!0},a.prototype.addFragment=function(A,t,e,r){var s=this.context,a=s.getCurrentPage();return!(!t&&A.height>s.availableHeight||(A.items.forEach((function(r){switch(r.type){case"line":var c=function(A){var t=new n(A.maxWidth);for(var e in A)A.hasOwnProperty(e)&&(t[e]=A[e]);return t}(r.item);c._node&&(c._node.positions[0].pageNumber=s.page+1),c.x=(c.x||0)+(t?A.xOffset||0:s.x),c.y=(c.y||0)+(e?A.yOffset||0:s.y),a.items.push({type:"line",item:c});break;case"vector":var B=i(r.item);o(B,t?A.xOffset||0:s.x,e?A.yOffset||0:s.y),a.items.push({type:"vector",item:B});break;case"image":case"svg":var g=i(r.item);g.x=(g.x||0)+(t?A.xOffset||0:s.x),g.y=(g.y||0)+(e?A.yOffset||0:s.y),a.items.push({type:r.type,item:g})}})),r||s.moveDown(A.height),0))},a.prototype.pushContext=function(A,t){void 0===A&&(t=this.context.getCurrentPage().height-this.context.pageMargins.top-this.context.pageMargins.bottom,A=this.context.availableWidth),r(A)&&(A=new s({width:A,height:t},{left:0,right:0,top:0,bottom:0})),this.contextStack.push(this.context),this.context=A},a.prototype.popContext=function(){this.context=this.contextStack.pop()},a.prototype.getCurrentPositionOnPage=function(){return(this.contextStack[0]||this.context).getCurrentPosition()},A.exports=a},2249:function(A,t,e){"use strict";var n=e(6225).isArray;function r(A,t){for(var e in this.fonts={},this.pdfKitDoc=t,this.fontCache={},A)if(A.hasOwnProperty(e)){var n=A[e];this.fonts[e]={normal:n.normal,bold:n.bold,italics:n.italics,bolditalics:n.bolditalics}}}r.prototype.getFontType=function(A,t){return function(A,t){var e="normal";return A&&t?e="bolditalics":A?e="bold":t&&(e="italics"),e}(A,t)},r.prototype.getFontFile=function(A,t,e){var n=this.getFontType(t,e);return this.fonts[A]&&this.fonts[A][n]?this.fonts[A][n]:null},r.prototype.provideFont=function(A,t,e){var r=this.getFontType(t,e);if(null===this.getFontFile(A,t,e))throw new Error("Font '"+A+"' in style '"+r+"' is not defined in the font section of the document definition.");if(this.fontCache[A]=this.fontCache[A]||{},!this.fontCache[A][r]){var i=this.fonts[A][r];n(i)||(i=[i]),this.fontCache[A][r]=this.pdfKitDoc.font.apply(this.pdfKitDoc,i)._font}return this.fontCache[A][r]},A.exports=r},6225:function(A){"use strict";function t(A){return Array.isArray(A)}A.exports={isString:function(A){return"string"==typeof A||A instanceof String},isNumber:function(A){return"number"==typeof A||A instanceof Number},isBoolean:function(A){return"boolean"==typeof A},isArray:t,isFunction:function(A){return"function"==typeof A},isObject:function(A){return null!==A&&"object"==typeof A},isNull:function(A){return null===A},isUndefined:function(A){return void 0===A},pack:function(){for(var A={},t=0,e=arguments.length;t<e;t++){var n=arguments[t];if(n)for(var r in n)n.hasOwnProperty(r)&&(A[r]=n[r])}return A},fontStringify:function(A,t){return"font"===A?"font":t},offsetVector:function(A,t,e){switch(A.type){case"ellipse":case"rect":A.x+=t,A.y+=e;break;case"line":A.x1+=t,A.x2+=t,A.y1+=e,A.y2+=e;break;case"polyline":for(var n=0,r=A.points.length;n<r;n++)A.points[n].x+=t,A.points[n].y+=e}},getNodeId:function A(e){if(e.id)return e.id;if(t(e.text))for(var n=0,r=e.text.length;n<r;n++){var i=A(e.text[n]);if(i)return i}return null},isPattern:function(A){return t(A)&&2===A.length},getPattern:function(A,t){return[t[A[0]],A[1]]}}},3090:function(A,t,e){"use strict";var n=e(8823).Buffer,r=e(3857);function i(A,t){this.pdfKitDoc=A,this.imageDictionary=t||{}}i.prototype.measureImage=function(A){var t,e=this;if(this.pdfKitDoc._imageRegistry[A])t=this.pdfKitDoc._imageRegistry[A];else{try{if(t=this.pdfKitDoc.openImage(function(A){var t=e.imageDictionary[A];if(!t)return A;if(r.existsSync(t))return r.readFileSync(t);var i=t.indexOf("base64,");return i<0?e.imageDictionary[A]:n.from(t.substring(i+7),"base64")}(A)),!t)throw"No image"}catch(A){throw"Invalid image: "+A.toString()+"\nImages dictionary should contain dataURL entries (or local file paths in node.js)"}t.embed(this.pdfKitDoc),this.pdfKitDoc._imageRegistry[A]=t}return{width:t.width,height:t.height}},A.exports=i},2678:function(A,t,e){"use strict";var n=e(8537),r=e(4889),i=e(1728),o=e(3858),s=e(2912),a=e(4498),c=e(9342),B=e(4775),g=e(6225).isString,l=e(6225).isArray,u=e(6225).isUndefined,w=e(6225).isNull,h=e(6225).pack,E=e(6225).offsetVector,f=e(6225).fontStringify,Q=e(6225).getNodeId,d=e(6225).isFunction,C=e(1350),M=e(7597),I=e(6225).isNumber;function p(A,t){t.forEach((function(t){A.push(t)}))}function D(A,t,e,r){this.pageSize=A,this.pageMargins=t,this.tracker=new n,this.imageMeasure=e,this.svgMeasure=r,this.tableLayouts={}}D.prototype.registerTableLayouts=function(A){this.tableLayouts=h(this.tableLayouts,A)},D.prototype.layoutDocument=function(A,t,e,n,o,s,a,c,B,g){function u(A,t){if(!d(g))return!1;(A=A.filter((function(A){return A.positions.length>0}))).forEach((function(A){var e={};["id","text","ul","ol","table","image","qr","canvas","svg","columns","headlineLevel","style","pageBreak","pageOrientation","width","height"].forEach((function(t){void 0!==A[t]&&(e[t]=A[t])})),e.startPosition=A.positions[0],e.pageNumbers=Array.from(new Set(A.positions.map((function(A){return A.pageNumber})))),e.pages=t.length,e.stack=l(A.stack),A.nodeInfo=e}));for(var e=0;e<A.length;e++){var n=A[e];if("before"!==n.pageBreak&&!n.pageBreakCalculated){n.pageBreakCalculated=!0;var r=n.nodeInfo.pageNumbers[0],i=[],o=[],s=[];if(g.length>1)for(var a=e+1,c=A.length;a<c;a++)A[a].nodeInfo.pageNumbers.indexOf(r)>-1&&i.push(A[a].nodeInfo),g.length>2&&A[a].nodeInfo.pageNumbers.indexOf(r+1)>-1&&o.push(A[a].nodeInfo);if(g.length>3)for(a=0;a<e;a++)A[a].nodeInfo.pageNumbers.indexOf(r)>-1&&s.push(A[a].nodeInfo);if(g(n.nodeInfo,i,o,s))return n.pageBreak="before",!0}}return!1}function w(A){A.linearNodeList.forEach((function(A){A.resetXY()}))}this.docPreprocessor=new r,this.docMeasure=new i(t,e,n,this.imageMeasure,this.svgMeasure,this.tableLayouts,c);for(var h=this.tryLayoutDocument(A,t,e,n,o,s,a,c,B);u(h.linearNodeList,h.pages);)w(h),h=this.tryLayoutDocument(A,t,e,n,o,s,a,c,B);return h.pages},D.prototype.tryLayoutDocument=function(A,t,e,n,r,i,a,c,B,g){this.linearNodeList=[],A=this.docPreprocessor.preprocessDocument(A),A=this.docMeasure.measureDocument(A),this.writer=new s(new o(this.pageSize,this.pageMargins),this.tracker);var l=this;return this.writer.context().tracker.startTracking("pageAdded",(function(){l.addBackground(r)})),this.addBackground(r),this.processNode(A),this.addHeadersAndFooters(i,a),null!=B&&this.addWatermark(B,t,n),{pages:this.writer.context().pages,linearNodeList:this.linearNodeList}},D.prototype.addBackground=function(A){var t=d(A)?A:function(){return A},e=this.writer.context(),n=e.getCurrentPage().pageSize,r=t(e.page+1,n);r&&(this.writer.beginUnbreakableBlock(n.width,n.height),r=this.docPreprocessor.preprocessDocument(r),this.processNode(this.docMeasure.measureDocument(r)),this.writer.commitUnbreakableBlock(0,0),e.backgroundLength[e.page]+=r.positions.length)},D.prototype.addStaticRepeatable=function(A,t){this.addDynamicRepeatable((function(){return JSON.parse(JSON.stringify(A))}),t)},D.prototype.addDynamicRepeatable=function(A,t){for(var e=0,n=this.writer.context().pages.length;e<n;e++){this.writer.context().page=e;var r=A(e+1,n,this.writer.context().pages[e].pageSize);if(r){var i=t(this.writer.context().getCurrentPage().pageSize,this.pageMargins);this.writer.beginUnbreakableBlock(i.width,i.height),r=this.docPreprocessor.preprocessDocument(r),this.processNode(this.docMeasure.measureDocument(r)),this.writer.commitUnbreakableBlock(i.x,i.y)}}},D.prototype.addHeadersAndFooters=function(A,t){var e=function(A,t){return{x:0,y:0,width:A.width,height:t.top}},n=function(A,t){return{x:0,y:A.height-t.bottom,width:A.width,height:t.bottom}};d(A)?this.addDynamicRepeatable(A,e):A&&this.addStaticRepeatable(A,e),d(t)?this.addDynamicRepeatable(t,n):t&&this.addStaticRepeatable(t,n)},D.prototype.addWatermark=function(A,t,e){if(g(A)&&(A={text:A}),A.text){A.font=A.font||e.font||"Roboto",A.fontSize=A.fontSize||"auto",A.color=A.color||"black",A.opacity=I(A.opacity)?A.opacity:.6,A.bold=A.bold||!1,A.italics=A.italics||!1,A.angle=u(A.angle)||w(A.angle)?null:A.angle,null===A.angle&&(A.angle=-180*Math.atan2(this.pageSize.height,this.pageSize.width)/Math.PI),"auto"===A.fontSize&&(A.fontSize=function(A,t,e){for(var n,r=new C(e),i=new M(null,{font:t.font,bold:t.bold,italics:t.italics}),o=0,s=1e3,a=(o+s)/2;Math.abs(o-s)>1;)i.push({fontSize:a}),(n=r.sizeOfRotatedText(t.text,t.angle,i)).width>A.width?a=(o+(s=a))/2:n.width<A.width&&(a=n.height>A.height?(o+(s=a))/2:((o=a)+s)/2),i.pop();return a}(this.pageSize,A,t));var n={text:A.text,font:t.provideFont(A.font,A.bold,A.italics),fontSize:A.fontSize,color:A.color,opacity:A.opacity,angle:A.angle};n._size=function(A,t){var e=new C(t),n=new M(null,{font:A.font,bold:A.bold,italics:A.italics});return n.push({fontSize:A.fontSize}),{size:e.sizeOfString(A.text,n),rotatedSize:e.sizeOfRotatedText(A.text,A.angle,n)}}(A,t);for(var r=this.writer.context().pages,i=0,o=r.length;i<o;i++)r[i].watermark=n}},D.prototype.processNode=function(A){var t=this;this.linearNodeList.push(A),function(A){var t=A.x,e=A.y;A.positions=[],l(A.canvas)&&A.canvas.forEach((function(A){var t=A.x,e=A.y,n=A.x1,r=A.y1,i=A.x2,o=A.y2;A.resetXY=function(){A.x=t,A.y=e,A.x1=n,A.y1=r,A.x2=i,A.y2=o}})),A.resetXY=function(){A.x=t,A.y=e,l(A.canvas)&&A.canvas.forEach((function(A){A.resetXY()}))}}(A),function(e){var n=A._margin;"before"===A.pageBreak?t.writer.moveToNextPage(A.pageOrientation):"beforeOdd"===A.pageBreak?(t.writer.moveToNextPage(A.pageOrientation),(t.writer.context().page+1)%2==1&&t.writer.moveToNextPage(A.pageOrientation)):"beforeEven"===A.pageBreak&&(t.writer.moveToNextPage(A.pageOrientation),(t.writer.context().page+1)%2==0&&t.writer.moveToNextPage(A.pageOrientation)),n&&(t.writer.context().moveDown(n[1]),t.writer.context().addMargin(n[0],n[2])),e(),n&&(t.writer.context().addMargin(-n[0],-n[2]),t.writer.context().moveDown(n[3])),"after"===A.pageBreak?t.writer.moveToNextPage(A.pageOrientation):"afterOdd"===A.pageBreak?(t.writer.moveToNextPage(A.pageOrientation),(t.writer.context().page+1)%2==1&&t.writer.moveToNextPage(A.pageOrientation)):"afterEven"===A.pageBreak&&(t.writer.moveToNextPage(A.pageOrientation),(t.writer.context().page+1)%2==0&&t.writer.moveToNextPage(A.pageOrientation))}((function(){var e=A.unbreakable;e&&t.writer.beginUnbreakableBlock();var n=A.absolutePosition;n&&(t.writer.context().beginDetachedBlock(),t.writer.context().moveTo(n.x||0,n.y||0));var r=A.relativePosition;if(r&&(t.writer.context().beginDetachedBlock(),t.writer.context().moveToRelative(r.x||0,r.y||0)),A.stack)t.processVerticalContainer(A);else if(A.columns)t.processColumns(A);else if(A.ul)t.processList(!1,A);else if(A.ol)t.processList(!0,A);else if(A.table)t.processTable(A);else if(void 0!==A.text)t.processLeaf(A);else if(A.toc)t.processToc(A);else if(A.image)t.processImage(A);else if(A.svg)t.processSVG(A);else if(A.canvas)t.processCanvas(A);else if(A.qr)t.processQr(A);else if(!A._span)throw"Unrecognized document structure: "+JSON.stringify(A,f);(n||r)&&t.writer.context().endDetachedBlock(),e&&t.writer.commitUnbreakableBlock()}))},D.prototype.processVerticalContainer=function(A){var t=this;A.stack.forEach((function(e){t.processNode(e),p(A.positions,e.positions)}))},D.prototype.processColumns=function(A){var t=A.columns,e=this.writer.context().availableWidth,n=function(A){if(!A)return null;var e=[];e.push(0);for(var n=t.length-1;n>0;n--)e.push(A);return e}(A._gap);n&&(e-=(n.length-1)*A._gap),a.buildColumnWidths(t,e);var r=this.processRow(t,t,n);p(A.positions,r.positions)},D.prototype.processRow=function(A,t,e,n,r,i){var o=this,s=[],a=[];return this.tracker.auto("pageChanged",(function(A){for(var t,e=0,n=s.length;e<n;e++){var r=s[e];if(r.prevPage===A.prevPage){t=r;break}}t||(t=A,s.push(t)),t.prevY=Math.max(t.prevY,A.prevY),t.y=Math.min(t.y,A.y)}),(function(){t=t||A,o.writer.context().beginColumnGroup();for(var n=0,r=A.length;n<r;n++){var s=A[n],g=t[n]._calcWidth,l=c(n);if(s.colSpan&&s.colSpan>1)for(var u=1;u<s.colSpan;u++)g+=t[++n]._calcWidth+e[n];o.writer.context().beginColumn(g,l,B(s,n)),s._span?s._columnEndingContext&&o.writer.context().markEnding(s):(o.processNode(s),p(a,s.positions))}o.writer.context().completeColumnGroup(i)})),{pageBreaks:s,positions:a};function c(A){return e&&e.length>A?e[A]:0}function B(A,t){if(A.rowSpan&&A.rowSpan>1){var e=r+A.rowSpan-1;if(e>=n.length)throw"Row span for column "+t+" (with indexes starting from 0) exceeded row count";return n[e][t]}return null}},D.prototype.processList=function(A,t){var e,n=this,r=A?t.ol:t.ul,i=t._gapSize;this.writer.context().addMargin(i.width),this.tracker.auto("lineAdded",(function(A){if(e){var t=e;if(e=null,t.canvas){var r=t.canvas[0];E(r,-t._minWidth,0),n.writer.addVector(r)}else if(t._inlines){var i=new B(n.pageSize.width);i.addInline(t._inlines[0]),i.x=-t._minWidth,i.y=A.getAscenderHeight()-i.getAscenderHeight(),n.writer.addLine(i,!0)}}}),(function(){r.forEach((function(A){e=A.listMarker,n.processNode(A),p(t.positions,A.positions)}))})),this.writer.context().addMargin(-i.width)},D.prototype.processTable=function(A){var t=new c(A);t.beginTable(this.writer);for(var e=A.table.heights,n=0,r=A.table.body.length;n<r;n++){var i;t.beginRow(n,this.writer),"auto"===(i=d(e)?e(n):l(e)?e[n]:e)&&(i=void 0);var o=this.processRow(A.table.body[n],A.table.widths,A._offsets.offsets,A.table.body,n,i);p(A.positions,o.positions),t.endRow(n,this.writer,o.pageBreaks)}t.endTable(this.writer)},D.prototype.processLeaf=function(A){var t=this.buildNextLine(A);t&&(A.tocItem||A.id)&&(t._node=A);var e=t?t.getHeight():0,n=A.maxHeight||-1;if(t){var r=Q(A);r&&(t.id=r)}if(A._tocItemRef&&(t._pageNodeRef=A._tocItemRef),A._pageRef&&(t._pageNodeRef=A._pageRef._nodeRef),t&&t.inlines&&l(t.inlines))for(var i=0,o=t.inlines.length;i<o;i++)t.inlines[i]._tocItemRef&&(t.inlines[i]._pageNodeRef=t.inlines[i]._tocItemRef),t.inlines[i]._pageRef&&(t.inlines[i]._pageNodeRef=t.inlines[i]._pageRef._nodeRef);for(;t&&(-1===n||e<n);){var s=this.writer.addLine(t);A.positions.push(s),(t=this.buildNextLine(A))&&(e+=t.getHeight())}},D.prototype.processToc=function(A){A.toc.title&&this.processNode(A.toc.title),A.toc._table&&this.processNode(A.toc._table)},D.prototype.buildNextLine=function(A){function t(A){var t=A.constructor();for(var e in A)t[e]=A[e];return t}if(!A._inlines||0===A._inlines.length)return null;for(var e=new B(this.writer.context().availableWidth),n=new C(null),r=!1;A._inlines&&A._inlines.length>0&&(e.hasEnoughSpaceForInline(A._inlines[0],A._inlines.slice(1))||r);){var i=!1,o=A._inlines.shift();if(r=!1,!o.noWrap&&o.text.length>1&&o.width>e.getAvailableWidth()){var s=o.width/o.text.length,a=Math.floor(e.getAvailableWidth()/s);if(a<1&&(a=1),a<o.text.length){var c=t(o);c.text=o.text.substr(a),o.text=o.text.substr(0,a),c.width=n.widthOfString(c.text,c.font,c.fontSize,c.characterSpacing,c.fontFeatures),o.width=n.widthOfString(o.text,o.font,o.fontSize,o.characterSpacing,o.fontFeatures),A._inlines.unshift(c),i=!0}}e.addInline(o),r=o.noNewLine&&!i}return e.lastLineInParagraph=0===A._inlines.length,e},D.prototype.processImage=function(A){var t=this.writer.addImage(A);A.positions.push(t)},D.prototype.processSVG=function(A){var t=this.writer.addSVG(A);A.positions.push(t)},D.prototype.processCanvas=function(A){var t=A._minHeight;void 0===A.absolutePosition&&this.writer.context().availableHeight<t&&this.writer.moveToNextPage(),this.writer.alignCanvas(A),A.canvas.forEach((function(t){var e=this.writer.addVector(t);A.positions.push(e)}),this),this.writer.context().moveDown(t)},D.prototype.processQr=function(A){var t=this.writer.addQr(A);A.positions.push(t)},A.exports=D},4775:function(A){"use strict";function t(A){this.maxWidth=A,this.leadingCut=0,this.trailingCut=0,this.inlineWidths=0,this.inlines=[]}t.prototype.getAscenderHeight=function(){var A=0;return this.inlines.forEach((function(t){A=Math.max(A,t.font.ascender/1e3*t.fontSize)})),A},t.prototype.hasEnoughSpaceForInline=function(A,t){if(t=t||[],0===this.inlines.length)return!0;if(this.newLineForced)return!1;var e=A.width,n=A.trailingCut||0;if(A.noNewLine)for(var r=0,i=t.length;r<i;r++){var o=t[r];if(e+=o.width,n+=o.trailingCut||0,!o.noNewLine)break}return this.inlineWidths+e-this.leadingCut-n<=this.maxWidth},t.prototype.addInline=function(A){0===this.inlines.length&&(this.leadingCut=A.leadingCut||0),this.trailingCut=A.trailingCut||0,A.x=this.inlineWidths-this.leadingCut,this.inlines.push(A),this.inlineWidths+=A.width,A.lineEnd&&(this.newLineForced=!0)},t.prototype.getWidth=function(){return this.inlineWidths-this.leadingCut-this.trailingCut},t.prototype.getAvailableWidth=function(){return this.maxWidth-this.getWidth()},t.prototype.getHeight=function(){var A=0;return this.inlines.forEach((function(t){A=Math.max(A,t.height||0)})),A},A.exports=t},2912:function(A,t,e){"use strict";var n=e(6225).isUndefined,r=e(1196);function i(A,t){this.transactionLevel=0,this.repeatables=[],this.tracker=t,this.writer=new r(A,t)}function o(A,t){var e=t(A);return e||(A.moveToNextPage(),e=t(A)),e}i.prototype.addLine=function(A,t,e){return o(this,(function(n){return n.writer.addLine(A,t,e)}))},i.prototype.addImage=function(A,t){return o(this,(function(e){return e.writer.addImage(A,t)}))},i.prototype.addSVG=function(A,t){return o(this,(function(e){return e.writer.addSVG(A,t)}))},i.prototype.addQr=function(A,t){return o(this,(function(e){return e.writer.addQr(A,t)}))},i.prototype.addVector=function(A,t,e,n){return this.writer.addVector(A,t,e,n)},i.prototype.beginClip=function(A,t){return this.writer.beginClip(A,t)},i.prototype.endClip=function(){return this.writer.endClip()},i.prototype.alignCanvas=function(A){this.writer.alignCanvas(A)},i.prototype.addFragment=function(A,t,e,n){this.writer.addFragment(A,t,e,n)||(this.moveToNextPage(),this.writer.addFragment(A,t,e,n))},i.prototype.moveToNextPage=function(A){var t=this.writer.context.moveToNextPage(A);this.repeatables.forEach((function(A){n(A.insertedOnPages[this.writer.context.page])?(A.insertedOnPages[this.writer.context.page]=!0,this.writer.addFragment(A,!0)):this.writer.context.moveDown(A.height)}),this),this.writer.tracker.emit("pageChanged",{prevPage:t.prevPage,prevY:t.prevY,y:this.writer.context.y})},i.prototype.beginUnbreakableBlock=function(A,t){0==this.transactionLevel++&&(this.originalX=this.writer.context.x,this.writer.pushContext(A,t))},i.prototype.commitUnbreakableBlock=function(A,t){if(0==--this.transactionLevel){var e=this.writer.context;this.writer.popContext();var n=e.pages.length;if(n>0){var r=e.pages[0];if(r.xOffset=A,r.yOffset=t,n>1)if(void 0!==A||void 0!==t)r.height=e.getCurrentPage().pageSize.height-e.pageMargins.top-e.pageMargins.bottom;else{r.height=this.writer.context.getCurrentPage().pageSize.height-this.writer.context.pageMargins.top-this.writer.context.pageMargins.bottom;for(var i=0,o=this.repeatables.length;i<o;i++)r.height-=this.repeatables[i].height}else r.height=e.y;void 0!==A||void 0!==t?this.writer.addFragment(r,!0,!0,!0):this.addFragment(r)}}},i.prototype.currentBlockToRepeatable=function(){var A=this.writer.context,t={items:[]};return A.pages[0].items.forEach((function(A){t.items.push(A)})),t.xOffset=this.originalX,t.height=A.y,t.insertedOnPages=[],t},i.prototype.pushToRepeatables=function(A){this.repeatables.push(A)},i.prototype.popFromRepeatables=function(){this.repeatables.pop()},i.prototype.context=function(){return this.writer.context},A.exports=i},6079:function(A,t,e){"use strict";var n=function(A){return A&&"object"==typeof A&&"default"in A?A.default:A}(e(5219));A.exports={getEngineInstance:function(){return n},createPdfDocument:function(A){return new n(A=A||{})}}},8617:function(A,t,e){"use strict";var n=e(6079),r=e(2249),i=e(2678),o=e(4762),s=e(3090),a=e(7601),c=e(3497),B=e(1350),g=e(6225).isFunction,l=e(6225).isString,u=e(6225).isNumber,w=e(6225).isBoolean,h=e(6225).isArray,E=e(6225).isUndefined,f=e(6225).isPattern,Q=e(6225).getPattern,d=e(8071);function C(A){this.fontDescriptors=A}function M(A){function t(A){var t=A.charAt(0).toUpperCase()+A.slice(1);return-1!==["Title","Author","Subject","Keywords","Creator","Producer","CreationDate","ModDate","Trapped"].indexOf(t)?t:A.replace(/\s+/g,"")}var e={Producer:"pdfmake",Creator:"pdfmake"};if(A.info)for(var n in A.info){var r=A.info[n];r&&(e[n=t(n)]=r)}return e}function I(A){if(u(A))A={left:A,right:A,top:A,bottom:A};else if(h(A))if(2===A.length)A={left:A[0],top:A[1],right:A[0],bottom:A[1]};else{if(4!==A.length)throw"Invalid pageMargins definition";A={left:A[0],top:A[1],right:A[2],bottom:A[3]}}return A}function p(A,t){var e=t.options.size[0]>t.options.size[1]?"landscape":"portrait";if(A.pageSize.orientation!==e){var n=t.options.size[0],r=t.options.size[1];t.options.size=[r,n]}}function D(A,t){var e=A;return t.sup&&(e-=.75*t.fontSize),t.sub&&(e+=.35*t.fontSize),e}function y(A,t,e,n,r){function i(A,t){var e,n,r=new B(null);if(E(A.positions))throw"Page reference id not found";var i=A.positions[0].pageNumber.toString();switch(t.text=i,e=r.widthOfString(t.text,t.font,t.fontSize,t.characterSpacing,t.fontFeatures),n=t.width-e,t.width=e,t.alignment){case"right":t.x+=n;break;case"center":t.x+=n/2}}A._pageNodeRef&&i(A._pageNodeRef,A.inlines[0]),t=t||0,e=e||0;var o=A.getHeight(),s=o-A.getAscenderHeight();c.drawBackground(A,t,e,n,r);for(var a=0,g=A.inlines.length;a<g;a++){var l=A.inlines[a],w=o-l.font.ascender/1e3*l.fontSize-s;l._pageNodeRef&&i(l._pageNodeRef,l);var h={lineBreak:!1,textWidth:l.width,characterSpacing:l.characterSpacing,wordCount:1,link:l.link};l.linkToDestination&&(h.goTo=l.linkToDestination),A.id&&0===a&&(h.destination=A.id),l.fontFeatures&&(h.features=l.fontFeatures);var f=u(l.opacity)?l.opacity:1;r.opacity(f),r.fill(l.color||"black"),r._font=l.font,r.fontSize(l.fontSize);var Q=D(e+w,l);r.text(l.text,t+l.x,Q,h),l.linkToPage&&(r.ref({Type:"Action",S:"GoTo",D:[l.linkToPage,0,0]}).end(),r.annotate(t+l.x,Q,l.width,l.height,{Subtype:"Link",Dest:[l.linkToPage-1,"XYZ",null,null,null]}))}c.drawDecorations(A,t,e,r)}function v(A,t){var e=A.watermark;t.fill(e.color),t.opacity(e.opacity),t.save(),t.rotate(e.angle,{origin:[t.page.width/2,t.page.height/2]});var n=t.page.width/2-e._size.size.width/2,r=t.page.height/2-e._size.size.height/2;t._font=e.font,t.fontSize(e.fontSize),t.text(e.text,n,r,{lineBreak:!1}),t.restore()}function m(A,t,e){e.lineWidth(A.lineWidth||1),A.dash?e.dash(A.dash.length,{space:A.dash.space||A.dash.length,phase:A.dash.phase||0}):e.undash(),e.lineJoin(A.lineJoin||"miter"),e.lineCap(A.lineCap||"butt");var n=null;switch(A.type){case"ellipse":e.ellipse(A.x,A.y,A.r1,A.r2),A.linearGradient&&(n=e.linearGradient(A.x-A.r1,A.y,A.x+A.r1,A.y));break;case"rect":A.r?e.roundedRect(A.x,A.y,A.w,A.h,A.r):e.rect(A.x,A.y,A.w,A.h),A.linearGradient&&(n=e.linearGradient(A.x,A.y,A.x+A.w,A.y));break;case"line":e.moveTo(A.x1,A.y1),e.lineTo(A.x2,A.y2);break;case"polyline":if(0===A.points.length)break;e.moveTo(A.points[0].x,A.points[0].y);for(var r=1,i=A.points.length;r<i;r++)e.lineTo(A.points[r].x,A.points[r].y);if(A.points.length>1){var o=A.points[0],s=A.points[A.points.length-1];(A.closePath||o.x===s.x&&o.y===s.y)&&e.closePath()}break;case"path":e.path(A.d)}if(A.linearGradient&&n){var a=1/(A.linearGradient.length-1);for(r=0;r<A.linearGradient.length;r++)n.stop(r*a,A.linearGradient[r]);A.color=n}f(A.color)&&(A.color=Q(A.color,t));var c=u(A.fillOpacity)?A.fillOpacity:1,B=u(A.strokeOpacity)?A.strokeOpacity:1;A.color&&A.lineColor?(e.fillColor(A.color,c),e.strokeColor(A.lineColor,B),e.fillAndStroke()):A.color?(e.fillColor(A.color,c),e.fill()):(e.strokeColor(A.lineColor||"black",B),e.stroke())}function F(A,t,e,n){var r=u(A.opacity)?A.opacity:1;if(n.opacity(r),A.cover){var i=A.cover.align||"center",o=A.cover.valign||"center",s=A.cover.width?A.cover.width:A.width,a=A.cover.height?A.cover.height:A.height;n.save(),n.rect(A.x,A.y,s,a).clip(),n.image(A.image,A.x,A.y,{cover:[s,a],align:i,valign:o}),n.restore()}else n.image(A.image,A.x,A.y,{width:A._width,height:A._height});A.link&&n.link(A.x,A.y,A._width,A._height,A.link),A.linkToPage&&(n.ref({Type:"Action",S:"GoTo",D:[A.linkToPage,0,0]}).end(),n.annotate(A.x,A.y,A._width,A._height,{Subtype:"Link",Dest:[A.linkToPage-1,"XYZ",null,null,null]})),A.linkToDestination&&n.goTo(A.x,A.y,A._width,A._height,A.linkToDestination)}function Y(A,t,e,n,r){var i=Object.assign({width:A._width,height:A._height,assumePt:!0},A.options);i.fontCallback=function(t,e,n){var i=t.split(",").map((function(A){return A.trim().replace(/('|")/g,"")})),o=function(A,t,e){for(var n=0;n<t.length;n++){var r=t[n].toLowerCase();for(var i in A)if(i.toLowerCase()===r)return i}return e}(r.fonts,i,A.font||"Roboto"),s=r.getFontFile(o,e,n);if(null===s){var a=r.getFontType(e,n);throw new Error("Font '"+o+"' in style '"+a+"' is not defined in the font section of the document definition.")}return s},d(n,A.svg,A.x,A.y,i)}function b(A,t){t.save(),t.addContent(A.x+" "+A.y+" "+A.width+" "+A.height+" re"),t.clip()}function z(A){A.restore()}C.prototype.createPdfKitDocument=function(A,t){t=t||{},A.version=A.version||"1.3",A.compress=!w(A.compress)||A.compress,A.images=A.images||{},A.pageMargins=void 0!==A.pageMargins&&null!==A.pageMargins?A.pageMargins:40;var e=function(A,t){A&&"auto"===A.height&&(A.height=1/0);var e=function(A){if(l(A)){var t=o[A.toUpperCase()];if(!t)throw"Page size "+A+" not recognized";return{width:t[0],height:t[1]}}return A}(A||"A4");return function(A){return!!l(A)&&("portrait"===(A=A.toLowerCase())&&e.width>e.height||"landscape"===A&&e.width<e.height)}(t)&&(e={width:e.height,height:e.width}),e.orientation=e.width>e.height?"landscape":"portrait",e}(A.pageSize,A.pageOrientation),c={size:[e.width,e.height],pdfVersion:A.version,compress:A.compress,userPassword:A.userPassword,ownerPassword:A.ownerPassword,permissions:A.permissions,fontLayoutCache:!w(t.fontLayoutCache)||t.fontLayoutCache,bufferPages:t.bufferPages||!1,autoFirstPage:!1,info:M(A),font:null};this.pdfKitDoc=n.createPdfDocument(c),this.fontProvider=new r(this.fontDescriptors,this.pdfKitDoc);var B=new i(e,I(A.pageMargins),new s(this.pdfKitDoc,A.images),new a);!function(A){A.registerTableLayouts({noBorders:{hLineWidth:function(A){return 0},vLineWidth:function(A){return 0},paddingLeft:function(A){return A?4:0},paddingRight:function(A,t){return A<t.table.widths.length-1?4:0}},headerLineOnly:{hLineWidth:function(A,t){return 0===A||A===t.table.body.length?0:A===t.table.headerRows?2:0},vLineWidth:function(A){return 0},paddingLeft:function(A){return 0===A?0:8},paddingRight:function(A,t){return A===t.table.widths.length-1?0:8}},lightHorizontalLines:{hLineWidth:function(A,t){return 0===A||A===t.table.body.length?0:A===t.table.headerRows?2:1},vLineWidth:function(A){return 0},hLineColor:function(A){return 1===A?"black":"#aaa"},paddingLeft:function(A){return 0===A?0:8},paddingRight:function(A,t){return A===t.table.widths.length-1?0:8}}})}(B),t.tableLayouts&&B.registerTableLayouts(t.tableLayouts);var h=B.layoutDocument(A.content,this.fontProvider,A.styles||{},A.defaultStyle||{fontSize:12,font:"Roboto"},A.background,A.header,A.footer,A.images,A.watermark,A.pageBreakBefore),E=A.maxPagesNumber||-1;if(u(E)&&E>-1&&(h=h.slice(0,E)),e.height===1/0){var f=function(A,t){function e(A){return(A.item.y||0)+function(A){return g(A.item.getHeight)?A.item.getHeight():A.item._height?A.item._height:"vector"===A.type?void 0!==A.item.y1?A.item.y1>A.item.y2?A.item.y1:A.item.y2:A.item.h:0}(A)}var n=I(t||40),r=n.top;return A.forEach((function(A){A.items.forEach((function(A){var t=e(A);t>r&&(r=t)}))})),r+=n.bottom}(h,A.pageMargins);this.pdfKitDoc.options.size=[e.width,f]}var Q=function(A,t){var e={};return Object.keys(A).forEach((function(n){var r=A[n];e[n]=t.pattern(r.boundingBox,r.xStep,r.yStep,r.pattern,r.colored)})),e}(A.patterns||{},this.pdfKitDoc);if(function(A,t,e,n,r){e._pdfMakePages=A,e.addPage();var i=0;r&&A.forEach((function(A){i+=A.items.length}));var o=0;r=r||function(){};for(var s=0;s<A.length;s++){s>0&&(p(A[s],e),e.addPage(e.options));for(var a=A[s],c=0,B=a.items.length;c<B;c++){var g=a.items[c];switch(g.type){case"vector":m(g.item,n,e);break;case"line":y(g.item,g.item.x,g.item.y,n,e);break;case"image":F(g.item,g.item.x,g.item.y,e);break;case"svg":Y(g.item,g.item.x,g.item.y,e,t);break;case"beginClip":b(g.item,e);break;case"endClip":z(e)}r(++o/i)}a.watermark&&v(a,e)}}(h,this.fontProvider,this.pdfKitDoc,Q,t.progressCallback),t.autoPrint){var d=this.pdfKitDoc.ref({Type:"Action",S:"Named",N:"Print"});this.pdfKitDoc._root.data.OpenAction=d,d.end()}return this.pdfKitDoc},A.exports=C},145:function(A){"use strict";for(var t=[null,[[10,7,17,13],[1,1,1,1],[]],[[16,10,28,22],[1,1,1,1],[4,16]],[[26,15,22,18],[1,1,2,2],[4,20]],[[18,20,16,26],[2,1,4,2],[4,24]],[[24,26,22,18],[2,1,4,4],[4,28]],[[16,18,28,24],[4,2,4,4],[4,32]],[[18,20,26,18],[4,2,5,6],[4,20,36]],[[22,24,26,22],[4,2,6,6],[4,22,40]],[[22,30,24,20],[5,2,8,8],[4,24,44]],[[26,18,28,24],[5,4,8,8],[4,26,48]],[[30,20,24,28],[5,4,11,8],[4,28,52]],[[22,24,28,26],[8,4,11,10],[4,30,56]],[[22,26,22,24],[9,4,16,12],[4,32,60]],[[24,30,24,20],[9,4,16,16],[4,24,44,64]],[[24,22,24,30],[10,6,18,12],[4,24,46,68]],[[28,24,30,24],[10,6,16,17],[4,24,48,72]],[[28,28,28,28],[11,6,19,16],[4,28,52,76]],[[26,30,28,28],[13,6,21,18],[4,28,54,80]],[[26,28,26,26],[14,7,25,21],[4,28,56,84]],[[26,28,28,30],[16,8,25,20],[4,32,60,88]],[[26,28,30,28],[17,8,25,23],[4,26,48,70,92]],[[28,28,24,30],[17,9,34,23],[4,24,48,72,96]],[[28,30,30,30],[18,9,30,25],[4,28,52,76,100]],[[28,30,30,30],[20,10,32,27],[4,26,52,78,104]],[[28,26,30,30],[21,12,35,29],[4,30,56,82,108]],[[28,28,30,28],[23,12,37,34],[4,28,56,84,112]],[[28,30,30,30],[25,12,40,34],[4,32,60,88,116]],[[28,30,30,30],[26,13,42,35],[4,24,48,72,96,120]],[[28,30,30,30],[28,14,45,38],[4,28,52,76,100,124]],[[28,30,30,30],[29,15,48,40],[4,24,50,76,102,128]],[[28,30,30,30],[31,16,51,43],[4,28,54,80,106,132]],[[28,30,30,30],[33,17,54,45],[4,32,58,84,110,136]],[[28,30,30,30],[35,18,57,48],[4,28,56,84,112,140]],[[28,30,30,30],[37,19,60,51],[4,32,60,88,116,144]],[[28,30,30,30],[38,19,63,53],[4,28,52,76,100,124,148]],[[28,30,30,30],[40,20,66,56],[4,22,48,74,100,126,152]],[[28,30,30,30],[43,21,70,59],[4,26,52,78,104,130,156]],[[28,30,30,30],[45,22,74,62],[4,30,56,82,108,134,160]],[[28,30,30,30],[47,24,77,65],[4,24,52,80,108,136,164]],[[28,30,30,30],[49,25,81,68],[4,28,56,84,112,140,168]]],e=/^\d*$/,n=/^[A-Za-z0-9 $%*+\-./:]*$/,r=/^[A-Z0-9 $%*+\-./:]*$/,i=[],o=[-1],s=0,a=1;s<255;++s)i.push(a),o[a]=s,a=2*a^(a>=128?285:0);var c=[[]];for(s=0;s<30;++s){for(var B=c[s],g=[],l=0;l<=s;++l){var u=l<s?i[B[l]]:0,w=i[(s+(B[l-1]||0))%255];g.push(o[u^w])}c.push(g)}var h={};for(s=0;s<45;++s)h["0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ $%*+-./:".charAt(s)]=s;var E=[function(A,t){return(A+t)%2==0},function(A,t){return A%2==0},function(A,t){return t%3==0},function(A,t){return(A+t)%3==0},function(A,t){return((A/2|0)+(t/3|0))%2==0},function(A,t){return A*t%2+A*t%3==0},function(A,t){return(A*t%2+A*t%3)%2==0},function(A,t){return((A+t)%2+A*t%3)%2==0}],f=function(A){return A>6},Q=function(A,e){var n=-8&function(A){var e=t[A],n=16*A*A+128*A+64;return f(A)&&(n-=36),e[2].length&&(n-=25*e[2].length*e[2].length-10*e[2].length-55),n}(A),r=t[A];return n-8*r[0][e]*r[1][e]},d=function(A,t){switch(t){case 1:return A<10?10:A<27?12:14;case 2:return A<10?9:A<27?11:13;case 4:return A<10?8:16;case 8:return A<10?8:A<27?10:12}},C=function(A,t,e){var n=Q(A,e)-4-d(A,t);switch(t){case 1:return 3*(n/10|0)+(n%10<4?0:n%10<7?1:2);case 2:return 2*(n/11|0)+(n%11<6?0:1);case 4:return n/8|0;case 8:return n/13|0}},M=function(A,t){for(var e=A.slice(0),n=A.length,r=t.length,s=0;s<r;++s)e.push(0);for(s=0;s<n;){var a=o[e[s++]];if(a>=0)for(var c=0;c<r;++c)e[s+c]^=i[(a+t[c])%255]}return e.slice(n)},I=function(A,t,e,n){for(var r=A<<n,i=t-1;i>=0;--i)r>>n+i&1&&(r^=e<<i);return A<<n|r},p=function(A,t,e){for(var n=E[e],r=A.length,i=0;i<r;++i)for(var o=0;o<r;++o)t[i][o]||(A[i][o]^=n(i,o));return A},D=function(A,t,e,n){for(var r=A.length,i=21522^I(e<<3|n,5,1335,10),o=0;o<15;++o){var s=[r-1,r-2,r-3,r-4,r-5,r-6,r-7,r-8,7,5,4,3,2,1,0][o];A[[0,1,2,3,4,5,7,8,r-7,r-6,r-5,r-4,r-3,r-2,r-1][o]][8]=A[8][s]=i>>o&1}return A},y=function(A){for(var t=function(A){for(var t=0,e=0;e<A.length;++e)A[e]>=5&&(t+=A[e]-5+3);for(e=5;e<A.length;e+=2){var n=A[e];A[e-1]==n&&A[e-2]==3*n&&A[e-3]==n&&A[e-4]==n&&(A[e-5]>=4*n||A[e+1]>=4*n)&&(t+=40)}return t},e=A.length,n=0,r=0,i=0;i<e;++i){var o,s=A[i];o=[0];for(var a=0;a<e;){for(c=0;a<e&&s[a];++c)++a;for(o.push(c),c=0;a<e&&!s[a];++c)++a;o.push(c)}for(n+=t(o),o=[0],a=0;a<e;){var c;for(c=0;a<e&&A[a][i];++c)++a;for(o.push(c),c=0;a<e&&!A[a][i];++c)++a;o.push(c)}n+=t(o);var B=A[i+1]||[];for(r+=s[0],a=1;a<e;++a){var g=s[a];r+=g,s[a-1]==g&&B[a]===g&&B[a-1]===g&&(n+=3)}}return n+10*(Math.abs(r/e/e-.5)/.05|0)},v=function(A,e,n,r,i){var o=t[e],s=function(A,t,e,n){var r=[],i=0,o=8,s=e.length,a=function(A,t){if(t>=o){for(r.push(i|A>>(t-=o));t>=8;)r.push(A>>(t-=8)&255);i=0,o=8}t>0&&(i|=(A&(1<<t)-1)<<(o-=t))},c=d(A,t);switch(a(t,4),a(s,c),t){case 1:for(var B=2;B<s;B+=3)a(parseInt(e.substring(B-2,B+1),10),10);a(parseInt(e.substring(B-2),10),[0,4,7][s%3]);break;case 2:for(B=1;B<s;B+=2)a(45*h[e.charAt(B-1)]+h[e.charAt(B)],11);s%2==1&&a(h[e.charAt(B-1)],6);break;case 4:for(B=0;B<s;++B)a(e[B],8)}for(a(0,4),o<8&&r.push(i);r.length+1<n;)r.push(236,17);return r.length<n&&r.push(236),r}(e,n,A,Q(e,r)>>3);s=function(A,t,e){for(var n=[],r=A.length/t|0,i=0,o=t-A.length%t,s=0;s<o;++s)n.push(i),i+=r;for(s=o;s<t;++s)n.push(i),i+=r+1;n.push(i);var a=[];for(s=0;s<t;++s)a.push(M(A.slice(n[s],n[s+1]),e));var c=[],B=A.length/t|0;for(s=0;s<B;++s)for(var g=0;g<t;++g)c.push(A[n[g]+s]);for(g=o;g<t;++g)c.push(A[n[g+1]-1]);for(s=0;s<e.length;++s)for(g=0;g<t;++g)c.push(a[g][s]);return c}(s,o[1][r],c[o[0][r]]);var a=function(A){for(var e=t[A],n=function(A){return 4*A+17}(A),r=[],i=[],o=0;o<n;++o)r.push([]),i.push([]);var s=function(A,t,e,n,o){for(var s=0;s<e;++s)for(var a=0;a<n;++a)r[A+s][t+a]=o[s]>>a&1,i[A+s][t+a]=1};for(s(0,0,9,9,[127,65,93,93,93,65,383,0,64]),s(n-8,0,8,9,[256,127,65,93,93,93,65,127]),s(0,n-8,9,8,[254,130,186,186,186,130,254,0,0]),o=9;o<n-8;++o)r[6][o]=r[o][6]=1&~o,i[6][o]=i[o][6]=1;var a=e[2],c=a.length;for(o=0;o<c;++o)for(var B=0===o?c-1:c,g=0===o||o===c-1?1:0;g<B;++g)s(a[o],a[g],5,5,[31,17,21,17,31]);if(f(A)){var l=I(A,6,7973,12),u=0;for(o=0;o<6;++o)for(g=0;g<3;++g)r[o][n-11+g]=r[n-11+g][o]=l>>u++&1,i[o][n-11+g]=i[n-11+g][o]=1}return{matrix:r,reserved:i}}(e),B=a.matrix,g=a.reserved;if(function(A,t,e){for(var n=A.length,r=0,i=-1,o=n-1;o>=0;o-=2){6==o&&--o;for(var s=i<0?n-1:0,a=0;a<n;++a){for(var c=o;c>o-2;--c)t[s][c]||(A[s][c]=e[r>>3]>>(7&~r)&1,++r);s+=i}i=-i}}(B,g,s),i<0){p(B,g,0),D(B,0,r,0);var l=0,u=y(B);for(p(B,g,0),i=1;i<8;++i){p(B,g,i),D(B,0,r,i);var w=y(B);u>w&&(u=w,l=i),p(B,g,i)}i=l}return p(B,g,i),D(B,0,r,i),B};function m(A,t){var i=(t=t||{}).version||-1,o={L:1,M:0,Q:3,H:2}[(t.eccLevel||"L").toUpperCase()],s=t.mode?{numeric:1,alphanumeric:2,octet:4}[t.mode.toLowerCase()]:-1,a="mask"in t?t.mask:-1;if(s<0)s="string"==typeof A?A.match(e)?1:A.match(r)?2:4:4;else if(1!=s&&2!=s&&4!=s)throw"invalid or unsupported mode";if(A=function(A,t){switch(A){case 1:return t.match(e)?t:null;case 2:return t.match(n)?t.toUpperCase():null;case 4:if("string"==typeof t){for(var r=[],i=0;i<t.length;++i){var o=t.charCodeAt(i);o<128?r.push(o):o<2048?r.push(192|o>>6,128|63&o):o<65536?r.push(224|o>>12,128|o>>6&63,128|63&o):r.push(240|o>>18,128|o>>12&63,128|o>>6&63,128|63&o)}return r}return t}}(s,A),null===A)throw"invalid data format";if(o<0||o>3)throw"invalid ECC level";if(i<0){for(i=1;i<=40&&!(A.length<=C(i,s,o));++i);if(i>40)throw"too large data for the Qr format"}else if(i<1||i>40)throw"invalid Qr version! should be between 1 and 40";if(-1!=a&&(a<0||a>8))throw"invalid mask";return v(A,i,s,o,a)}A.exports={measure:function(A){var t=function(A,t){var e=[],n=t.background||"#fff",r=t.foreground||"#000",i=m(A,t),o=i.length,s=Math.floor(t.fit?t.fit/o:5),a=o*s;e.push({type:"rect",x:0,y:0,w:a,h:a,lineWidth:0,color:n});for(var c=0;c<o;++c)for(var B=0;B<o;++B)i[c][B]&&e.push({type:"rect",x:s*B,y:s*c,w:s,h:s,lineWidth:0,color:r});return{canvas:e,size:a}}(A.qr,A);return A._canvas=t.canvas,A._width=A._height=A._minWidth=A._maxWidth=A._minHeight=A._maxHeight=t.size,A}}},4762:function(A){"use strict";A.exports={"4A0":[4767.87,6740.79],"2A0":[3370.39,4767.87],A0:[2383.94,3370.39],A1:[1683.78,2383.94],A2:[1190.55,1683.78],A3:[841.89,1190.55],A4:[595.28,841.89],A5:[419.53,595.28],A6:[297.64,419.53],A7:[209.76,297.64],A8:[147.4,209.76],A9:[104.88,147.4],A10:[73.7,104.88],B0:[2834.65,4008.19],B1:[2004.09,2834.65],B2:[1417.32,2004.09],B3:[1000.63,1417.32],B4:[708.66,1000.63],B5:[498.9,708.66],B6:[354.33,498.9],B7:[249.45,354.33],B8:[175.75,249.45],B9:[124.72,175.75],B10:[87.87,124.72],C0:[2599.37,3676.54],C1:[1836.85,2599.37],C2:[1298.27,1836.85],C3:[918.43,1298.27],C4:[649.13,918.43],C5:[459.21,649.13],C6:[323.15,459.21],C7:[229.61,323.15],C8:[161.57,229.61],C9:[113.39,161.57],C10:[79.37,113.39],RA0:[2437.8,3458.27],RA1:[1729.13,2437.8],RA2:[1218.9,1729.13],RA3:[864.57,1218.9],RA4:[609.45,864.57],SRA0:[2551.18,3628.35],SRA1:[1814.17,2551.18],SRA2:[1275.59,1814.17],SRA3:[907.09,1275.59],SRA4:[637.8,907.09],EXECUTIVE:[521.86,756],FOLIO:[612,936],LEGAL:[612,1008],LETTER:[612,792],TABLOID:[792,1224]}},7597:function(A,t,e){"use strict";var n=e(6225).isString,r=e(6225).isArray,i=e(6225).isUndefined,o=e(6225).isNull;function s(A,t){this.defaultStyle=t||{},this.styleDictionary=A,this.styleOverrides=[]}s.prototype.clone=function(){var A=new s(this.styleDictionary,this.defaultStyle);return this.styleOverrides.forEach((function(t){A.styleOverrides.push(t)})),A},s.prototype.push=function(A){this.styleOverrides.push(A)},s.prototype.pop=function(A){for(A=A||1;A-- >0;)this.styleOverrides.pop()},s.prototype.autopush=function(A){if(n(A))return 0;var t=[];A.style&&(t=r(A.style)?A.style:[A.style]);for(var e=0,s=t.length;e<s;e++)this.push(t[e]);var a={},c=!1;return["font","fontSize","fontFeatures","bold","italics","alignment","color","columnGap","fillColor","fillOpacity","decoration","decorationStyle","decorationColor","background","lineHeight","characterSpacing","noWrap","markerColor","leadingIndent","sup","sub"].forEach((function(t){i(A[t])||o(A[t])||(a[t]=A[t],c=!0)})),c&&this.push(a),t.length+(c?1:0)},s.prototype.auto=function(A,t){var e=this.autopush(A),n=t();return e>0&&this.pop(e),n},s.prototype.getProperty=function(A){if(this.styleOverrides)for(var t=this.styleOverrides.length-1;t>=0;t--){var e=this.styleOverrides[t];if(n(e)){var r=this.styleDictionary[e];if(r&&!i(r[A])&&!o(r[A]))return r[A]}else if(!i(e[A])&&!o(e[A]))return e[A]}return this.defaultStyle&&this.defaultStyle[A]},A.exports=s},7601:function(A,t,e){"use strict";var n=e(6513);function r(A){var t=parseFloat(A);if("number"==typeof t&&!isNaN(t))return t}function i(A){var t;try{t=new n.XmlDocument(A)}catch(A){throw new Error("SVGMeasure: "+A)}if("svg"!==t.name)throw new Error("SVGMeasure: expected <svg> document");return t}function o(){}o.prototype.measureSVG=function(A){var t=i(A),e=r(t.attr.width),n=r(t.attr.height);if((null==e||null==n)&&"string"==typeof t.attr.viewBox){var o=t.attr.viewBox.split(/[,\s]+/);if(4!==o.length)throw new Error("Unexpected svg viewbox format, should have 4 entries but found: '"+t.attr.viewBox+"'");null==e&&(e=r(o[2])),null==n&&(n=r(o[3]))}return{width:e,height:n}},o.prototype.writeDimensions=function(A,t){var e=i(A);return e.attr.width=""+t.width,e.attr.height=""+t.height,e.toString()},A.exports=o},9342:function(A,t,e){"use strict";var n=e(4498),r=e(6225).isFunction,i=e(6225).isNumber;function o(A){this.tableNode=A}o.prototype.beginTable=function(A){var t,e,r=this;t=this.tableNode,this.offsets=t._offsets,this.layout=t._layout,e=A.context().availableWidth-this.offsets.total,n.buildColumnWidths(t.table.widths,e),this.tableWidth=t._offsets.total+function(){var A=0;return t.table.widths.forEach((function(t){A+=t._calcWidth})),A}(),this.rowSpanData=function(){var A=[],t=0,e=0;A.push({left:0,rowSpan:0});for(var n=0,i=r.tableNode.table.body[0].length;n<i;n++)e=r.layout.paddingLeft(n,r.tableNode)+r.layout.paddingRight(n,r.tableNode)+r.layout.vLineWidth(n,r.tableNode)+r.tableNode.table.widths[n]._calcWidth,A[A.length-1].width=e,t+=e,A.push({left:t,rowSpan:0,width:0});return A}(),this.cleanUpRepeatables=!1,this.headerRows=t.table.headerRows||0,this.rowsWithoutPageBreak=this.headerRows+(t.table.keepWithHeaderRows||0),this.dontBreakRows=t.table.dontBreakRows||!1,this.rowsWithoutPageBreak&&A.beginUnbreakableBlock(),function(A){for(var t=0;t<A.length;t++)for(var e=A[t],n=0;n<e.length;n++){var r=e[n];if(r.border){for(var i=r.rowSpan||1,o=r.colSpan||1,s=0;s<i;s++)void 0!==r.border[0]&&s>0&&c(t+s,n,0,r.border[0]),void 0!==r.border[2]&&c(t+s,n+o-1,2,r.border[2]);for(var a=0;a<o;a++)void 0!==r.border[1]&&a>0&&c(t,n+a,1,r.border[1]),void 0!==r.border[3]&&c(t+i-1,n+a,3,r.border[3])}}function c(t,e,n,r){var i=A[t][e];i.border=i.border||{},i.border[n]=r}}(this.tableNode.table.body),this.drawHorizontalLine(0,A)},o.prototype.onRowBreak=function(A,t){var e=this;return function(){var A=e.rowPaddingTop+(e.headerRows?0:e.topLineWidth);t.context().availableHeight-=e.reservedAtBottom,t.context().moveDown(A)}},o.prototype.beginRow=function(A,t){this.topLineWidth=this.layout.hLineWidth(A,this.tableNode),this.rowPaddingTop=this.layout.paddingTop(A,this.tableNode),this.bottomLineWidth=this.layout.hLineWidth(A+1,this.tableNode),this.rowPaddingBottom=this.layout.paddingBottom(A,this.tableNode),this.rowCallback=this.onRowBreak(A,t),t.tracker.startTracking("pageChanged",this.rowCallback),this.dontBreakRows&&t.beginUnbreakableBlock(),this.rowTopY=t.context().y,this.reservedAtBottom=this.bottomLineWidth+this.rowPaddingBottom,t.context().availableHeight-=this.reservedAtBottom,t.context().moveDown(this.rowPaddingTop)},o.prototype.drawHorizontalLine=function(A,t,e){var n=this.layout.hLineWidth(A,this.tableNode);if(n){var i,o=this.layout.hLineStyle(A,this.tableNode);o&&o.dash&&(i=o.dash);for(var s,a,c,B=n/2,g=null,l=this.tableNode.table.body,u=0,w=this.rowSpanData.length;u<w;u++){var h=this.rowSpanData[u],E=!h.rowSpan,f=null;if(E&&u<w-1){var Q=!1,d=!1,C=!1;A>0&&(d=(s=l[A-1][u]).border?s.border[3]:this.layout.defaultBorder)&&s.borderColor&&(f=s.borderColor[3]),A<l.length&&(Q=(a=l[A][u]).border?a.border[1]:this.layout.defaultBorder)&&null==f&&a.borderColor&&(f=a.borderColor[1]),E=Q||d}if(s&&s._rowSpanCurrentOffset&&(C=(c=l[A-1-s._rowSpanCurrentOffset][u])&&c.border?c.border[3]:this.layout.defaultBorder)&&c&&c.borderColor&&(f=c.borderColor[3]),null==f&&(f=r(this.layout.hLineColor)?this.layout.hLineColor(A,this.tableNode,u):this.layout.hLineColor),!g&&E&&(g={left:h.left,width:0}),E){var M=0;if(c&&c.colSpan&&C){for(;c.colSpan>M;)g.width+=this.rowSpanData[u+M++].width||0;u+=M-1}else if(s&&s.colSpan&&d){for(;s.colSpan>M;)g.width+=this.rowSpanData[u+M++].width||0;u+=M-1}else if(a&&a.colSpan&&Q){for(;a.colSpan>M;)g.width+=this.rowSpanData[u+M++].width||0;u+=M-1}else g.width+=this.rowSpanData[u].width||0}var I=(e||0)+B;E&&g&&g.width&&(t.addVector({type:"line",x1:g.left,x2:g.left+g.width,y1:I,y2:I,lineWidth:n,dash:i,lineColor:f},!1,e),g=null,f=null,s=null,a=null,c=null)}t.context().moveDown(n)}},o.prototype.drawVerticalLine=function(A,t,e,n,i,o,s){var a=this.layout.vLineWidth(n,this.tableNode);if(0!==a){var c,B=this.layout.vLineStyle(n,this.tableNode);B&&B.dash&&(c=B.dash);var g,l,u,w=this.tableNode.table.body;if(n>0&&(g=w[o][s])&&g.borderColor&&(g.border?g.border[2]:this.layout.defaultBorder)&&(u=g.borderColor[2]),null==u&&n<w.length&&(l=w[o][n])&&l.borderColor&&(l.border?l.border[0]:this.layout.defaultBorder)&&(u=l.borderColor[0]),null==u&&g&&g._rowSpanCurrentOffset){var h=w[o-g._rowSpanCurrentOffset][s];h.borderColor&&(h.border?h.border[2]:this.layout.defaultBorder)&&(u=h.borderColor[2])}if(null==u&&l&&l._rowSpanCurrentOffset){var E=w[o-l._rowSpanCurrentOffset][n];E.borderColor&&(E.border?E.border[2]:this.layout.defaultBorder)&&(u=E.borderColor[2])}null==u&&(u=r(this.layout.vLineColor)?this.layout.vLineColor(n,this.tableNode,o):this.layout.vLineColor),i.addVector({type:"line",x1:A+a/2,x2:A+a/2,y1:t,y2:e,lineWidth:a,dash:c,lineColor:u},!1,!0),g=null,l=null,u=null}},o.prototype.endTable=function(A){this.cleanUpRepeatables&&A.popFromRepeatables()},o.prototype.endRow=function(A,t,e){var n,o,s=this;t.tracker.stopTracking("pageChanged",this.rowCallback),t.context().moveDown(this.layout.paddingBottom(A,this.tableNode)),t.context().availableHeight+=this.reservedAtBottom;var a=t.context().page,c=t.context().y,B=function(){for(var t=[],e=0,n=0,r=s.tableNode.table.body[A].length;n<r;n++){if(!e){t.push({x:s.rowSpanData[n].left,index:n});var i=s.tableNode.table.body[A][n];e=i._colSpan||i.colSpan||0}e>0&&e--}return t.push({x:s.rowSpanData[s.rowSpanData.length-1].left,index:s.rowSpanData.length-1}),t}(),g=[],l=e&&e.length>0,u=this.tableNode.table.body;if(g.push({y0:this.rowTopY,page:l?e[0].prevPage:a}),l)for(o=0,n=e.length;o<n;o++){var w=e[o];g[g.length-1].y1=w.prevY,g.push({y0:w.y,page:w.prevPage+1})}g[g.length-1].y1=c;for(var h=g[0].y1-g[0].y0===this.rowPaddingTop?1:0,E=g.length;h<E;h++){var f=h<g.length-1,Q=h>0&&!this.headerRows,d=Q?0:this.topLineWidth,C=g[h].y0,M=g[h].y1;for(f&&(M+=this.rowPaddingBottom),t.context().page!=g[h].page&&(t.context().page=g[h].page,this.reservedAtBottom=0),o=0,n=B.length;o<n;o++){var I,p=!1,D=!1,y=B[o].index;if(y<u[A].length&&(p=(I=u[A][y]).border?I.border[0]:this.layout.defaultBorder,D=I.border?I.border[2]:this.layout.defaultBorder),y>0&&!p&&(p=(I=u[A][y-1]).border?I.border[2]:this.layout.defaultBorder),y+1<u[A].length&&!D&&(D=(I=u[A][y+1]).border?I.border[0]:this.layout.defaultBorder),p&&this.drawVerticalLine(B[o].x,C-d,M+this.bottomLineWidth,B[o].index,t,A,B[o-1]?B[o-1].index:null),o<n-1){var v=u[A][y].fillColor,m=u[A][y].fillOpacity;v||(v=r(this.layout.fillColor)?this.layout.fillColor(A,this.tableNode,y):this.layout.fillColor),i(m)||(m=r(this.layout.fillOpacity)?this.layout.fillOpacity(A,this.tableNode,y):this.layout.fillOpacity);var F=u[A][y].overlayPattern,Y=u[A][y].overlayOpacity;if(v||F){var b,z=p?this.layout.vLineWidth(y,this.tableNode):0;b=0!==y&&y+1!=u[A].length||D?D?this.layout.vLineWidth(y+1,this.tableNode)/2:0:this.layout.vLineWidth(y+1,this.tableNode);var U=this.dontBreakRows?B[o].x+z:B[o].x+z/2,S=this.dontBreakRows?C:C-d/2,x=B[o+1].x+b-U,T=(this.dontBreakRows?M+this.bottomLineWidth:M+this.bottomLineWidth/2)-S;v&&t.addVector({type:"rect",x:U,y:S,w:x,h:T,lineWidth:0,color:v,fillOpacity:m},!1,!0,t.context().backgroundLength[t.context().page]),F&&t.addVector({type:"rect",x:U,y:S,w:x,h:T,lineWidth:0,color:F,fillOpacity:Y},!1,!0)}}}f&&!1!==this.layout.hLineWhenBroken&&this.drawHorizontalLine(A+1,t,M),Q&&!1!==this.layout.hLineWhenBroken&&this.drawHorizontalLine(A,t,C)}t.context().page=a,t.context().y=c;var P=this.tableNode.table.body[A];for(o=0,n=P.length;o<n;o++){if(P[o].rowSpan){if(this.rowSpanData[o].rowSpan=P[o].rowSpan,P[o].colSpan&&P[o].colSpan>1)for(var N=1;N<P[o].rowSpan;N++)this.tableNode.table.body[A+N][o]._colSpan=P[o].colSpan;if(P[o].rowSpan&&P[o].rowSpan>1)for(N=1;N<P[o].rowSpan;N++)this.tableNode.table.body[A+N][o]._rowSpanCurrentOffset=N}this.rowSpanData[o].rowSpan>0&&this.rowSpanData[o].rowSpan--}this.drawHorizontalLine(A+1,t),this.headerRows&&A===this.headerRows-1&&(this.headerRepeatable=t.currentBlockToRepeatable()),this.dontBreakRows&&t.tracker.auto("pageChanged",(function(){s.headerRows||!1===s.layout.hLineWhenBroken||s.drawHorizontalLine(A,t)}),(function(){t.commitUnbreakableBlock()})),!this.headerRepeatable||A!==this.rowsWithoutPageBreak-1&&A!==this.tableNode.table.body.length-1||(t.commitUnbreakableBlock(),t.pushToRepeatables(this.headerRepeatable),this.cleanUpRepeatables=!0,this.headerRepeatable=null)},A.exports=o},3497:function(A,t,e){"use strict";var n=e(6225).isArray,r=e(6225).isPattern,i=e(6225).getPattern;function o(A,t,e,n){var r=A.inlines[0],i=function(){for(var t=0,e=0,n=A.inlines.length;e<n;e++)t=A.inlines[e].fontSize>t?e:t;return A.inlines[t]}(),o=function(){for(var t=0,e=0,n=A.inlines.length;e<n;e++){var r=A.inlines[e].justifyShift||0;t+=A.inlines[e].width+r}return t}(),s=A.line.getAscenderHeight(),a=i.font.ascender/1e3*i.fontSize,c=i.height-a,B=.5+.12*Math.floor(Math.max(i.fontSize-8,0)/2);switch(A.decoration){case"underline":e+=s+.45*c;break;case"overline":e+=s-.85*a;break;case"lineThrough":e+=s-.25*a;break;default:throw"Unkown decoration : "+A.decoration}if(n.save(),"double"===A.decorationStyle){var g=Math.max(.5,2*B);n.fillColor(A.decorationColor).rect(t+r.x,e-B/2,o,B/2).fill().rect(t+r.x,e+g-B/2,o,B/2).fill()}else if("dashed"===A.decorationStyle){var l=Math.ceil(o/6.8),u=t+r.x;n.rect(u,e,o,B).clip(),n.fillColor(A.decorationColor);for(var w=0;w<l;w++)n.rect(u,e-B/2,3.96,B).fill(),u+=6.8}else if("dotted"===A.decorationStyle){var h=Math.ceil(o/(3*B)),E=t+r.x;n.rect(E,e,o,B).clip(),n.fillColor(A.decorationColor);for(var f=0;f<h;f++)n.rect(E,e-B/2,B,B).fill(),E+=3*B}else if("wavy"===A.decorationStyle){var Q=.7,d=Math.ceil(o/1.4)+1,C=t+r.x-1;n.rect(t+r.x,e-1,o,e+1).clip(),n.lineWidth(.24),n.moveTo(C,e);for(var M=0;M<d;M++)n.bezierCurveTo(C+Q,e-1,C+1.4,e-1,C+3*Q,e).bezierCurveTo(C+2.8,e+1,C+3.5,e+1,C+6*Q,e),C+=6*Q;n.stroke(A.decorationColor)}else n.fillColor(A.decorationColor).rect(t+r.x,e-B/2,o,B).fill();n.restore()}A.exports={drawBackground:function(A,t,e,n,o){for(var s=A.getHeight(),a=0,c=A.inlines.length;a<c;a++){var B=A.inlines[a];if(B.background){var g=B.background;r(B.background)&&(g=i(B.background,n));var l=B.justifyShift||0;o.fillColor(g).rect(t+B.x-l,e,B.width+l,s).fill()}}},drawDecorations:function(A,t,e,r){for(var i=function(A){for(var t=[],e=null,r=0,i=A.inlines.length;r<i;r++){var o=A.inlines[r],s=o.decoration;if(s){n(s)||(s=[s]);for(var a=o.decorationColor||o.color||"black",c=o.decorationStyle||"solid",B=0,g=s.length;B<g;B++){var l=s[B];e&&l===e.decoration&&c===e.decorationStyle&&a===e.decorationColor?e.inlines.push(o):(e={line:A,decoration:l,decorationColor:a,decorationStyle:c,inlines:[o]},t.push(e))}}else e=null}return t}(A),s=0,a=i.length;s<a;s++)o(i[s],t,e,r)}}},1350:function(A,t,e){"use strict";var n=e(6225).isString,r=e(6225).isNumber,i=e(6225).isObject,o=e(6225).isArray,s=e(6225).isUndefined,a=e(7337),c=/^(\s)+/g,B=/(\s)+$/g;function g(A){this.fontProvider=A}function l(A,t){var e=[];if(A=A.replace(/\t/g,"    "),t)return e.push({text:A}),e;for(var n,r=new a(A),i=0;n=r.nextBreak();){var o=A.slice(i,n.position);n.required||o.match(/\r?\n$|\r$/)?(o=o.replace(/\r?\n$|\r$/,""),e.push({text:o,lineEnd:!0})):e.push({text:o}),i=n.position}return e}function u(A,t){for(var e in t=t||{},A=A||{})"text"!=e&&A.hasOwnProperty(e)&&(t[e]=A[e]);return t}function w(A){return null==A?"":r(A)?A.toString():n(A)?A:A.toString()}function h(A,t,e,n){var r;return void 0!==A[e]&&null!==A[e]?A[e]:t?(t.auto(A,(function(){r=t.getProperty(e)})),null!=r?r:n):n}function E(A,t,e,n,r){return t.widthOfString(A,e,r)+(n||0)*(A.length-1)}g.prototype.buildInlines=function(A,t){var e,n=function(A,t,e){var n=function(A,t){function e(A,t,e){if(s(t[A]))return null;if(t[A].lineEnd)return null;var n=t[A].text;if(e){var r=l(w(n),!1);if(s(r[r.length-1]))return null;n=r[r.length-1].text}return n}var n=[];o(A)||(A=[A]),A=function A(t){return t.reduce((function(t,e){var n=o(e.text)?A(e.text):e,r=[].concat(n).some(Array.isArray);return t.concat(r?A(n):n)}),[])}(A);for(var r=null,a=0,c=A.length;a<c;a++){var B,g=A[a],E=null,f=h(g||{},t,"noWrap",!1);i(g)?(g._textRef&&g._textRef._textNodeRef.text&&(g.text=g._textRef._textNodeRef.text),B=l(w(g.text),f),E=u(g)):B=l(w(g),f),r&&B.length&&1===l(w(r+e(0,B,f)),!1).length&&(n[n.length-1].noNewLine=!0);for(var Q=0,d=B.length;Q<d;Q++){var C={text:B[Q].text};B[Q].lineEnd&&(C.lineEnd=!0),u(E,C),n.push(C)}r=null,a+1<c&&(r=e(B.length-1,B,f))}return n}(t,e);if(n.length){var r=h(n[0],e,"leadingIndent",0);r&&(n[0].leadingCut=-r,n[0].leadingIndent=r)}return n.forEach((function(t){var n=h(t,e,"font","Roboto"),r=h(t,e,"fontSize",12),i=h(t,e,"fontFeatures",null),o=h(t,e,"bold",!1),s=h(t,e,"italics",!1),a=h(t,e,"color","black"),g=h(t,e,"decoration",null),l=h(t,e,"decorationColor",null),u=h(t,e,"decorationStyle",null),w=h(t,e,"background",null),f=h(t,e,"lineHeight",1),Q=h(t,e,"characterSpacing",0),d=h(t,e,"link",null),C=h(t,e,"linkToPage",null),M=h(t,e,"linkToDestination",null),I=h(t,e,"noWrap",null),p=h(t,e,"preserveLeadingSpaces",!1),D=h(t,e,"preserveTrailingSpaces",!1),y=h(t,e,"opacity",1),v=h(t,e,"sup",!1),m=h(t,e,"sub",!1);(v||m)&&void 0===t.fontSize&&(r*=.58);var F,Y,b=A.provideFont(n,o,s);t.width=E(t.text,b,r,Q,i),t.height=b.lineHeight(r)*f,t.leadingCut||(t.leadingCut=0),!p&&(F=t.text.match(c))&&(t.leadingCut+=E(F[0],b,r,Q,i)),!D&&(Y=t.text.match(B))?t.trailingCut=E(Y[0],b,r,Q,i):t.trailingCut=0,t.alignment=h(t,e,"alignment","left"),t.font=b,t.fontSize=r,t.fontFeatures=i,t.characterSpacing=Q,t.color=a,t.decoration=g,t.decorationColor=l,t.decorationStyle=u,t.background=w,t.link=d,t.linkToPage=C,t.linkToDestination=M,t.noWrap=I,t.opacity=y,t.sup=v,t.sub=m})),n}(this.fontProvider,A,t),r=0,a=0;return n.forEach((function(A){r=Math.max(r,A.width-A.leadingCut-A.trailingCut),e||(e={width:0,leadingCut:A.leadingCut,trailingCut:0}),e.width+=A.width,e.trailingCut=A.trailingCut,a=Math.max(a,function(A){return Math.max(0,A.width-A.leadingCut-A.trailingCut)}(e)),A.lineEnd&&(e=null)})),h({},t,"noWrap",!1)&&(r=a),{items:n,minWidth:r,maxWidth:a}},g.prototype.sizeOfString=function(A,t){A=A?A.toString().replace(/\t/g,"    "):"";var e=h({},t,"font","Roboto"),n=h({},t,"fontSize",12),r=h({},t,"fontFeatures",null),i=h({},t,"bold",!1),o=h({},t,"italics",!1),s=h({},t,"lineHeight",1),a=h({},t,"characterSpacing",0),c=this.fontProvider.provideFont(e,i,o);return{width:E(A,c,n,a,r),height:c.lineHeight(n)*s,fontSize:n,lineHeight:s,ascender:c.ascender/1e3*n,descender:c.descender/1e3*n}},g.prototype.sizeOfRotatedText=function(A,t,e){var n=t*Math.PI/-180,r=this.sizeOfString(A,e);return{width:Math.abs(r.height*Math.sin(n))+Math.abs(r.width*Math.cos(n)),height:Math.abs(r.width*Math.sin(n))+Math.abs(r.height*Math.cos(n))}},g.prototype.widthOfString=function(A,t,e,n,r){return E(A,t,e,n,r)},A.exports=g},8537:function(A){"use strict";function t(){this.events={}}t.prototype.startTracking=function(A,t){var e=this.events[A]||(this.events[A]=[]);e.indexOf(t)<0&&e.push(t)},t.prototype.stopTracking=function(A,t){var e=this.events[A];if(e){var n=e.indexOf(t);n>=0&&e.splice(n,1)}},t.prototype.emit=function(A){var t=Array.prototype.slice.call(arguments,1),e=this.events[A];e&&e.forEach((function(A){A.apply(this,t)}))},t.prototype.auto=function(A,t,e){this.startTracking(A,t),e(),this.stopTracking(A,t)},A.exports=t},2480:function(){},5832:function(){},9862:function(){},964:function(){},3083:function(A,t,e){"use strict";var n=["BigInt64Array","BigUint64Array","Float32Array","Float64Array","Int16Array","Int32Array","Int8Array","Uint16Array","Uint32Array","Uint8Array","Uint8ClampedArray"],r="undefined"==typeof globalThis?e.g:globalThis;A.exports=function(){for(var A=[],t=0;t<n.length;t++)"function"==typeof r[n[t]]&&(A[A.length]=n[t]);return A}},3631:function(A,t,e){var n,r=e(9742),i=e(4781);function o(A){return A&&A.__esModule?A.default:A}function s(A,t,e,n){Object.defineProperty(A,t,{get:e,set:n,enumerable:!0,configurable:!0})}!function(A){Object.defineProperty(A,"__esModule",{value:!0,configurable:!0})}(A.exports),s(A.exports,"getCategory",(()=>I)),s(A.exports,"getCombiningClass",(()=>p)),s(A.exports,"getScript",(()=>D)),s(A.exports,"getEastAsianWidth",(()=>y)),s(A.exports,"getNumericValue",(()=>v)),s(A.exports,"isAlphabetic",(()=>m)),s(A.exports,"isDigit",(()=>F)),s(A.exports,"isPunctuation",(()=>Y)),s(A.exports,"isLowerCase",(()=>b)),s(A.exports,"isUpperCase",(()=>z)),s(A.exports,"isTitleCase",(()=>U)),s(A.exports,"isWhiteSpace",(()=>S)),s(A.exports,"isBaseForm",(()=>x)),s(A.exports,"isMark",(()=>T)),s(A.exports,"default",(()=>P)),n=JSON.parse('{"categories":["Cc","Zs","Po","Sc","Ps","Pe","Sm","Pd","Nd","Lu","Sk","Pc","Ll","So","Lo","Pi","Cf","No","Pf","Lt","Lm","Mn","Me","Mc","Nl","Zl","Zp","Cs","Co"],"combiningClasses":["Not_Reordered","Above","Above_Right","Below","Attached_Above_Right","Attached_Below","Overlay","Iota_Subscript","Double_Below","Double_Above","Below_Right","Above_Left","CCC10","CCC11","CCC12","CCC13","CCC14","CCC15","CCC16","CCC17","CCC18","CCC19","CCC20","CCC21","CCC22","CCC23","CCC24","CCC25","CCC30","CCC31","CCC32","CCC27","CCC28","CCC29","CCC33","CCC34","CCC35","CCC36","Nukta","Virama","CCC84","CCC91","CCC103","CCC107","CCC118","CCC122","CCC129","CCC130","CCC132","Attached_Above","Below_Left","Left","Kana_Voicing","CCC26","Right"],"scripts":["Common","Latin","Bopomofo","Inherited","Greek","Coptic","Cyrillic","Armenian","Hebrew","Arabic","Syriac","Thaana","Nko","Samaritan","Mandaic","Devanagari","Bengali","Gurmukhi","Gujarati","Oriya","Tamil","Telugu","Kannada","Malayalam","Sinhala","Thai","Lao","Tibetan","Myanmar","Georgian","Hangul","Ethiopic","Cherokee","Canadian_Aboriginal","Ogham","Runic","Tagalog","Hanunoo","Buhid","Tagbanwa","Khmer","Mongolian","Limbu","Tai_Le","New_Tai_Lue","Buginese","Tai_Tham","Balinese","Sundanese","Batak","Lepcha","Ol_Chiki","Braille","Glagolitic","Tifinagh","Han","Hiragana","Katakana","Yi","Lisu","Vai","Bamum","Syloti_Nagri","Phags_Pa","Saurashtra","Kayah_Li","Rejang","Javanese","Cham","Tai_Viet","Meetei_Mayek","null","Linear_B","Lycian","Carian","Old_Italic","Gothic","Old_Permic","Ugaritic","Old_Persian","Deseret","Shavian","Osmanya","Osage","Elbasan","Caucasian_Albanian","Linear_A","Cypriot","Imperial_Aramaic","Palmyrene","Nabataean","Hatran","Phoenician","Lydian","Meroitic_Hieroglyphs","Meroitic_Cursive","Kharoshthi","Old_South_Arabian","Old_North_Arabian","Manichaean","Avestan","Inscriptional_Parthian","Inscriptional_Pahlavi","Psalter_Pahlavi","Old_Turkic","Old_Hungarian","Hanifi_Rohingya","Old_Sogdian","Sogdian","Elymaic","Brahmi","Kaithi","Sora_Sompeng","Chakma","Mahajani","Sharada","Khojki","Multani","Khudawadi","Grantha","Newa","Tirhuta","Siddham","Modi","Takri","Ahom","Dogra","Warang_Citi","Nandinagari","Zanabazar_Square","Soyombo","Pau_Cin_Hau","Bhaiksuki","Marchen","Masaram_Gondi","Gunjala_Gondi","Makasar","Cuneiform","Egyptian_Hieroglyphs","Anatolian_Hieroglyphs","Mro","Bassa_Vah","Pahawh_Hmong","Medefaidrin","Miao","Tangut","Nushu","Duployan","SignWriting","Nyiakeng_Puachue_Hmong","Wancho","Mende_Kikakui","Adlam"],"eaw":["N","Na","A","W","H","F"]}');const a=new(o(i))(o(r).toByteArray(" ")),c=Math.log2||(A=>Math.log(A)/Math.LN2),B=A=>c(A)+1|0,g=B(o(n).categories.length-1),l=B(o(n).combiningClasses.length-1),u=B(o(n).scripts.length-1),w=B(o(n).eaw.length-1),h=l+u+w+10,E=u+w+10,f=w+10,Q=(1<<g)-1,d=(1<<l)-1,C=(1<<u)-1,M=(1<<w)-1;function I(A){const t=a.get(A);return o(n).categories[t>>h&Q]}function p(A){const t=a.get(A);return o(n).combiningClasses[t>>E&d]}function D(A){const t=a.get(A);return o(n).scripts[t>>f&C]}function y(A){const t=a.get(A);return o(n).eaw[t>>10&M]}function v(A){let t=a.get(A),e=1023&t;if(0===e)return null;if(e<=50)return e-1;if(e<480)return((e>>4)-12)/(1+(15&e));if(e<768){t=(e>>5)-14;let A=2+(31&e);for(;A>0;)t*=10,A--;return t}{t=(e>>2)-191;let A=1+(3&e);for(;A>0;)t*=60,A--;return t}}function m(A){const t=I(A);return"Lu"===t||"Ll"===t||"Lt"===t||"Lm"===t||"Lo"===t||"Nl"===t}function F(A){return"Nd"===I(A)}function Y(A){const t=I(A);return"Pc"===t||"Pd"===t||"Pe"===t||"Pf"===t||"Pi"===t||"Po"===t||"Ps"===t}function b(A){return"Ll"===I(A)}function z(A){return"Lu"===I(A)}function U(A){return"Lt"===I(A)}function S(A){const t=I(A);return"Zs"===t||"Zl"===t||"Zp"===t}function x(A){const t=I(A);return"Nd"===t||"No"===t||"Nl"===t||"Lu"===t||"Ll"===t||"Lt"===t||"Lm"===t||"Lo"===t||"Me"===t||"Mc"===t}function T(A){const t=I(A);return"Mn"===t||"Me"===t||"Mc"===t}var P={getCategory:I,getCombiningClass:p,getScript:D,getEastAsianWidth:y,getNumericValue:v,isAlphabetic:m,isDigit:F,isPunctuation:Y,isLowerCase:b,isUpperCase:z,isTitleCase:U,isWhiteSpace:S,isBaseForm:x,isMark:T}},3480:function(A){"use strict";A.exports=JSON.parse('[["8740","䏰䰲䘃䖦䕸𧉧䵷䖳𧲱䳢𧳅㮕䜶䝄䱇䱀𤊿𣘗𧍒𦺋𧃒䱗𪍑䝏䗚䲅𧱬䴇䪤䚡𦬣爥𥩔𡩣𣸆𣽡晍囻"],["8767","綕夝𨮹㷴霴𧯯寛𡵞媤㘥𩺰嫑宷峼杮薓𩥅瑡璝㡵𡵓𣚞𦀡㻬"],["87a1","𥣞㫵竼龗𤅡𨤍𣇪𠪊𣉞䌊蒄龖鐯䤰蘓墖靊鈘秐稲晠権袝瑌篅枂稬剏遆㓦珄𥶹瓆鿇垳䤯呌䄱𣚎堘穲𧭥讏䚮𦺈䆁𥶙箮𢒼鿈𢓁𢓉𢓌鿉蔄𣖻䂴鿊䓡𪷿拁灮鿋"],["8840","㇀",4,"𠄌㇅𠃑𠃍㇆㇇𠃋𡿨㇈𠃊㇉㇊㇋㇌𠄎㇍㇎ĀÁǍÀĒÉĚÈŌÓǑÒ࿿Ê̄Ế࿿Ê̌ỀÊāáǎàɑēéěèīíǐìōóǒòūúǔùǖǘǚ"],["88a1","ǜü࿿ê̄ế࿿ê̌ềêɡ⏚⏛"],["8940","𪎩𡅅"],["8943","攊"],["8946","丽滝鵎釟"],["894c","𧜵撑会伨侨兖兴农凤务动医华发变团声处备夲头学实実岚庆总斉柾栄桥济炼电纤纬纺织经统缆缷艺苏药视设询车轧轮"],["89a1","琑糼緍楆竉刧"],["89ab","醌碸酞肼"],["89b0","贋胶𠧧"],["89b5","肟黇䳍鷉鸌䰾𩷶𧀎鸊𪄳㗁"],["89c1","溚舾甙"],["89c5","䤑马骏龙禇𨑬𡷊𠗐𢫦两亁亀亇亿仫伷㑌侽㹈倃傈㑽㒓㒥円夅凛凼刅争剹劐匧㗇厩㕑厰㕓参吣㕭㕲㚁咓咣咴咹哐哯唘唣唨㖘唿㖥㖿嗗㗅"],["8a40","𧶄唥"],["8a43","𠱂𠴕𥄫喐𢳆㧬𠍁蹆𤶸𩓥䁓𨂾睺𢰸㨴䟕𨅝𦧲𤷪擝𠵼𠾴𠳕𡃴撍蹾𠺖𠰋𠽤𢲩𨉖𤓓"],["8a64","𠵆𩩍𨃩䟴𤺧𢳂骲㩧𩗴㿭㔆𥋇𩟔𧣈𢵄鵮頕"],["8a76","䏙𦂥撴哣𢵌𢯊𡁷㧻𡁯"],["8aa1","𦛚𦜖𧦠擪𥁒𠱃蹨𢆡𨭌𠜱"],["8aac","䠋𠆩㿺塳𢶍"],["8ab2","𤗈𠓼𦂗𠽌𠶖啹䂻䎺"],["8abb","䪴𢩦𡂝膪飵𠶜捹㧾𢝵跀嚡摼㹃"],["8ac9","𪘁𠸉𢫏𢳉"],["8ace","𡃈𣧂㦒㨆𨊛㕸𥹉𢃇噒𠼱𢲲𩜠㒼氽𤸻"],["8adf","𧕴𢺋𢈈𪙛𨳍𠹺𠰴𦠜羓𡃏𢠃𢤹㗻𥇣𠺌𠾍𠺪㾓𠼰𠵇𡅏𠹌"],["8af6","𠺫𠮩𠵈𡃀𡄽㿹𢚖搲𠾭"],["8b40","𣏴𧘹𢯎𠵾𠵿𢱑𢱕㨘𠺘𡃇𠼮𪘲𦭐𨳒𨶙𨳊閪哌苄喹"],["8b55","𩻃鰦骶𧝞𢷮煀腭胬尜𦕲脴㞗卟𨂽醶𠻺𠸏𠹷𠻻㗝𤷫㘉𠳖嚯𢞵𡃉𠸐𠹸𡁸𡅈𨈇𡑕𠹹𤹐𢶤婔𡀝𡀞𡃵𡃶垜𠸑"],["8ba1","𧚔𨋍𠾵𠹻𥅾㜃𠾶𡆀𥋘𪊽𤧚𡠺𤅷𨉼墙剨㘚𥜽箲孨䠀䬬鼧䧧鰟鮍𥭴𣄽嗻㗲嚉丨夂𡯁屮靑𠂆乛亻㔾尣彑忄㣺扌攵歺氵氺灬爫丬犭𤣩罒礻糹罓𦉪㓁"],["8bde","𦍋耂肀𦘒𦥑卝衤见𧢲讠贝钅镸长门𨸏韦页风飞饣𩠐鱼鸟黄歯龜丷𠂇阝户钢"],["8c40","倻淾𩱳龦㷉袏𤅎灷峵䬠𥇍㕙𥴰愢𨨲辧釶熑朙玺𣊁𪄇㲋𡦀䬐磤琂冮𨜏䀉橣𪊺䈣蘏𠩯稪𩥇𨫪靕灍匤𢁾鏴盙𨧣龧矝亣俰傼丯众龨吴綋墒壐𡶶庒庙忂𢜒斋"],["8ca1","𣏹椙橃𣱣泿"],["8ca7","爀𤔅玌㻛𤨓嬕璹讃𥲤𥚕窓篬糃繬苸薗龩袐龪躹龫迏蕟駠鈡龬𨶹𡐿䁱䊢娚"],["8cc9","顨杫䉶圽"],["8cce","藖𤥻芿𧄍䲁𦵴嵻𦬕𦾾龭龮宖龯曧繛湗秊㶈䓃𣉖𢞖䎚䔶"],["8ce6","峕𣬚諹屸㴒𣕑嵸龲煗䕘𤃬𡸣䱷㥸㑊𠆤𦱁諌侴𠈹妿腬顖𩣺弻"],["8d40","𠮟"],["8d42","𢇁𨥭䄂䚻𩁹㼇龳𪆵䃸㟖䛷𦱆䅼𨚲𧏿䕭㣔𥒚䕡䔛䶉䱻䵶䗪㿈𤬏㙡䓞䒽䇭崾嵈嵖㷼㠏嶤嶹㠠㠸幂庽弥徃㤈㤔㤿㥍惗愽峥㦉憷憹懏㦸戬抐拥挘㧸嚱"],["8da1","㨃揢揻搇摚㩋擀崕嘡龟㪗斆㪽旿晓㫲暒㬢朖㭂枤栀㭘桊梄㭲㭱㭻椉楃牜楤榟榅㮼槖㯝橥橴橱檂㯬檙㯲檫檵櫔櫶殁毁毪汵沪㳋洂洆洦涁㳯涤涱渕渘温溆𨧀溻滢滚齿滨滩漤漴㵆𣽁澁澾㵪㵵熷岙㶊瀬㶑灐灔灯灿炉𠌥䏁㗱𠻘"],["8e40","𣻗垾𦻓焾𥟠㙎榢𨯩孴穉𥣡𩓙穥穽𥦬窻窰竂竃燑𦒍䇊竚竝竪䇯咲𥰁笋筕笩𥌎𥳾箢筯莜𥮴𦱿篐萡箒箸𥴠㶭𥱥蒒篺簆簵𥳁籄粃𤢂粦晽𤕸糉糇糦籴糳糵糎"],["8ea1","繧䔝𦹄絝𦻖璍綉綫焵綳緒𤁗𦀩緤㴓緵𡟹緥𨍭縝𦄡𦅚繮纒䌫鑬縧罀罁罇礶𦋐駡羗𦍑羣𡙡𠁨䕜𣝦䔃𨌺翺𦒉者耈耝耨耯𪂇𦳃耻耼聡𢜔䦉𦘦𣷣𦛨朥肧𨩈脇脚墰𢛶汿𦒘𤾸擧𡒊舘𡡞橓𤩥𤪕䑺舩𠬍𦩒𣵾俹𡓽蓢荢𦬊𤦧𣔰𡝳𣷸芪椛芳䇛"],["8f40","蕋苐茚𠸖𡞴㛁𣅽𣕚艻苢茘𣺋𦶣𦬅𦮗𣗎㶿茝嗬莅䔋𦶥莬菁菓㑾𦻔橗蕚㒖𦹂𢻯葘𥯤葱㷓䓤檧葊𣲵祘蒨𦮖𦹷𦹃蓞萏莑䒠蒓蓤𥲑䉀𥳀䕃蔴嫲𦺙䔧蕳䔖枿蘖"],["8fa1","𨘥𨘻藁𧂈蘂𡖂𧃍䕫䕪蘨㙈𡢢号𧎚虾蝱𪃸蟮𢰧螱蟚蠏噡虬桖䘏衅衆𧗠𣶹𧗤衞袜䙛袴袵揁装睷𧜏覇覊覦覩覧覼𨨥觧𧤤𧪽誜瞓釾誐𧩙竩𧬺𣾏䜓𧬸煼謌謟𥐰𥕥謿譌譍誩𤩺讐讛誯𡛟䘕衏貛𧵔𧶏貫㜥𧵓賖𧶘𧶽贒贃𡤐賛灜贑𤳉㻐起"],["9040","趩𨀂𡀔𤦊㭼𨆼𧄌竧躭躶軃鋔輙輭𨍥𨐒辥錃𪊟𠩐辳䤪𨧞𨔽𣶻廸𣉢迹𪀔𨚼𨔁𢌥㦀𦻗逷𨔼𧪾遡𨕬𨘋邨𨜓郄𨛦邮都酧㫰醩釄粬𨤳𡺉鈎沟鉁鉢𥖹銹𨫆𣲛𨬌𥗛"],["90a1","𠴱錬鍫𨫡𨯫炏嫃𨫢𨫥䥥鉄𨯬𨰹𨯿鍳鑛躼閅閦鐦閠濶䊹𢙺𨛘𡉼𣸮䧟氜陻隖䅬隣𦻕懚隶磵𨫠隽双䦡𦲸𠉴𦐐𩂯𩃥𤫑𡤕𣌊霱虂霶䨏䔽䖅𤫩灵孁霛靜𩇕靗孊𩇫靟鐥僐𣂷𣂼鞉鞟鞱鞾韀韒韠𥑬韮琜𩐳響韵𩐝𧥺䫑頴頳顋顦㬎𧅵㵑𠘰𤅜"],["9140","𥜆飊颷飈飇䫿𦴧𡛓喰飡飦飬鍸餹𤨩䭲𩡗𩤅駵騌騻騐驘𥜥㛄𩂱𩯕髠髢𩬅髴䰎鬔鬭𨘀倴鬴𦦨㣃𣁽魐魀𩴾婅𡡣鮎𤉋鰂鯿鰌𩹨鷔𩾷𪆒𪆫𪃡𪄣𪇟鵾鶃𪄴鸎梈"],["91a1","鷄𢅛𪆓𪈠𡤻𪈳鴹𪂹𪊴麐麕麞麢䴴麪麯𤍤黁㭠㧥㴝伲㞾𨰫鼂鼈䮖鐤𦶢鼗鼖鼹嚟嚊齅馸𩂋韲葿齢齩竜龎爖䮾𤥵𤦻煷𤧸𤍈𤩑玞𨯚𡣺禟𨥾𨸶鍩鏳𨩄鋬鎁鏋𨥬𤒹爗㻫睲穃烐𤑳𤏸煾𡟯炣𡢾𣖙㻇𡢅𥐯𡟸㜢𡛻𡠹㛡𡝴𡣑𥽋㜣𡛀坛𤨥𡏾𡊨"],["9240","𡏆𡒶蔃𣚦蔃葕𤦔𧅥𣸱𥕜𣻻𧁒䓴𣛮𩦝𦼦柹㜳㰕㷧塬𡤢栐䁗𣜿𤃡𤂋𤄏𦰡哋嚞𦚱嚒𠿟𠮨𠸍鏆𨬓鎜仸儫㠙𤐶亼𠑥𠍿佋侊𥙑婨𠆫𠏋㦙𠌊𠐔㐵伩𠋀𨺳𠉵諚𠈌亘"],["92a1","働儍侢伃𤨎𣺊佂倮偬傁俌俥偘僼兙兛兝兞湶𣖕𣸹𣺿浲𡢄𣺉冨凃𠗠䓝𠒣𠒒𠒑赺𨪜𠜎剙劤𠡳勡鍮䙺熌𤎌𠰠𤦬𡃤槑𠸝瑹㻞璙琔瑖玘䮎𤪼𤂍叐㖄爏𤃉喴𠍅响𠯆圝鉝雴鍦埝垍坿㘾壋媙𨩆𡛺𡝯𡜐娬妸銏婾嫏娒𥥆𡧳𡡡𤊕㛵洅瑃娡𥺃"],["9340","媁𨯗𠐓鏠璌𡌃焅䥲鐈𨧻鎽㞠尞岞幞幈𡦖𡥼𣫮廍孏𡤃𡤄㜁𡢠㛝𡛾㛓脪𨩇𡶺𣑲𨦨弌弎𡤧𡞫婫𡜻孄蘔𧗽衠恾𢡠𢘫忛㺸𢖯𢖾𩂈𦽳懀𠀾𠁆𢘛憙憘恵𢲛𢴇𤛔𩅍"],["93a1","摱𤙥𢭪㨩𢬢𣑐𩣪𢹸挷𪑛撶挱揑𤧣𢵧护𢲡搻敫楲㯴𣂎𣊭𤦉𣊫唍𣋠𡣙𩐿曎𣊉𣆳㫠䆐𥖄𨬢𥖏𡛼𥕛𥐥磮𣄃𡠪𣈴㑤𣈏𣆂𤋉暎𦴤晫䮓昰𧡰𡷫晣𣋒𣋡昞𥡲㣑𣠺𣞼㮙𣞢𣏾瓐㮖枏𤘪梶栞㯄檾㡣𣟕𤒇樳橒櫉欅𡤒攑梘橌㯗橺歗𣿀𣲚鎠鋲𨯪𨫋"],["9440","銉𨀞𨧜鑧涥漋𤧬浧𣽿㶏渄𤀼娽渊塇洤硂焻𤌚𤉶烱牐犇犔𤞏𤜥兹𤪤𠗫瑺𣻸𣙟𤩊𤤗𥿡㼆㺱𤫟𨰣𣼵悧㻳瓌琼鎇琷䒟𦷪䕑疃㽣𤳙𤴆㽘畕癳𪗆㬙瑨𨫌𤦫𤦎㫻"],["94a1","㷍𤩎㻿𤧅𤣳釺圲鍂𨫣𡡤僟𥈡𥇧睸𣈲眎眏睻𤚗𣞁㩞𤣰琸璛㺿𤪺𤫇䃈𤪖𦆮錇𥖁砞碍碈磒珐祙𧝁𥛣䄎禛蒖禥樭𣻺稺秴䅮𡛦䄲鈵秱𠵌𤦌𠊙𣶺𡝮㖗啫㕰㚪𠇔𠰍竢婙𢛵𥪯𥪜娍𠉛磰娪𥯆竾䇹籝籭䈑𥮳𥺼𥺦糍𤧹𡞰粎籼粮檲緜縇緓罎𦉡"],["9540","𦅜𧭈綗𥺂䉪𦭵𠤖柖𠁎𣗏埄𦐒𦏸𤥢翝笧𠠬𥫩𥵃笌𥸎駦虅驣樜𣐿㧢𤧷𦖭騟𦖠蒀𧄧𦳑䓪脷䐂胆脉腂𦞴飃𦩂艢艥𦩑葓𦶧蘐𧈛媆䅿𡡀嬫𡢡嫤𡣘蚠蜨𣶏蠭𧐢娂"],["95a1","衮佅袇袿裦襥襍𥚃襔𧞅𧞄𨯵𨯙𨮜𨧹㺭蒣䛵䛏㟲訽訜𩑈彍鈫𤊄旔焩烄𡡅鵭貟賩𧷜妚矃姰䍮㛔踪躧𤰉輰轊䋴汘澻𢌡䢛潹溋𡟚鯩㚵𤤯邻邗啱䤆醻鐄𨩋䁢𨫼鐧𨰝𨰻蓥訫閙閧閗閖𨴴瑅㻂𤣿𤩂𤏪㻧𣈥随𨻧𨹦𨹥㻌𤧭𤩸𣿮琒瑫㻼靁𩂰"],["9640","桇䨝𩂓𥟟靝鍨𨦉𨰦𨬯𦎾銺嬑譩䤼珹𤈛鞛靱餸𠼦巁𨯅𤪲頟𩓚鋶𩗗釥䓀𨭐𤩧𨭤飜𨩅㼀鈪䤥萔餻饍𧬆㷽馛䭯馪驜𨭥𥣈檏騡嫾騯𩣱䮐𩥈馼䮽䮗鍽塲𡌂堢𤦸"],["96a1","𡓨硄𢜟𣶸棅㵽鑘㤧慐𢞁𢥫愇鱏鱓鱻鰵鰐魿鯏𩸭鮟𪇵𪃾鴡䲮𤄄鸘䲰鴌𪆴𪃭𪃳𩤯鶥蒽𦸒𦿟𦮂藼䔳𦶤𦺄𦷰萠藮𦸀𣟗𦁤秢𣖜𣙀䤭𤧞㵢鏛銾鍈𠊿碹鉷鑍俤㑀遤𥕝砽硔碶硋𡝗𣇉𤥁㚚佲濚濙瀞瀞吔𤆵垻壳垊鴖埗焴㒯𤆬燫𦱀𤾗嬨𡞵𨩉"],["9740","愌嫎娋䊼𤒈㜬䭻𨧼鎻鎸𡣖𠼝葲𦳀𡐓𤋺𢰦𤏁妔𣶷𦝁綨𦅛𦂤𤦹𤦋𨧺鋥珢㻩璴𨭣𡢟㻡𤪳櫘珳珻㻖𤨾𤪔𡟙𤩦𠎧𡐤𤧥瑈𤤖炥𤥶銄珦鍟𠓾錱𨫎𨨖鎆𨯧𥗕䤵𨪂煫"],["97a1","𤥃𠳿嚤𠘚𠯫𠲸唂秄𡟺緾𡛂𤩐𡡒䔮鐁㜊𨫀𤦭妰𡢿𡢃𧒄媡㛢𣵛㚰鉟婹𨪁𡡢鍴㳍𠪴䪖㦊僴㵩㵌𡎜煵䋻𨈘渏𩃤䓫浗𧹏灧沯㳖𣿭𣸭渂漌㵯𠏵畑㚼㓈䚀㻚䡱姄鉮䤾轁𨰜𦯀堒埈㛖𡑒烾𤍢𤩱𢿣𡊰𢎽梹楧𡎘𣓥𧯴𣛟𨪃𣟖𣏺𤲟樚𣚭𦲷萾䓟䓎"],["9840","𦴦𦵑𦲂𦿞漗𧄉茽𡜺菭𦲀𧁓𡟛妉媂𡞳婡婱𡤅𤇼㜭姯𡜼㛇熎鎐暚𤊥婮娫𤊓樫𣻹𧜶𤑛𤋊焝𤉙𨧡侰𦴨峂𤓎𧹍𤎽樌𤉖𡌄炦焳𤏩㶥泟勇𤩏繥姫崯㷳彜𤩝𡟟綤萦"],["98a1","咅𣫺𣌀𠈔坾𠣕𠘙㿥𡾞𪊶瀃𩅛嵰玏糓𨩙𩐠俈翧狍猐𧫴猸猹𥛶獁獈㺩𧬘遬燵𤣲珡臶㻊県㻑沢国琙琞琟㻢㻰㻴㻺瓓㼎㽓畂畭畲疍㽼痈痜㿀癍㿗癴㿜発𤽜熈嘣覀塩䀝睃䀹条䁅㗛瞘䁪䁯属瞾矋売砘点砜䂨砹硇硑硦葈𥔵礳栃礲䄃"],["9940","䄉禑禙辻稆込䅧窑䆲窼艹䇄竏竛䇏両筢筬筻簒簛䉠䉺类粜䊌粸䊔糭输烀𠳏総緔緐緽羮羴犟䎗耠耥笹耮耱联㷌垴炠肷胩䏭脌猪脎脒畠脔䐁㬹腖腙腚"],["99a1","䐓堺腼膄䐥膓䐭膥埯臁臤艔䒏芦艶苊苘苿䒰荗险榊萅烵葤惣蒈䔄蒾蓡蓸蔐蔸蕒䔻蕯蕰藠䕷虲蚒蚲蛯际螋䘆䘗袮裿褤襇覑𧥧訩訸誔誴豑賔賲贜䞘塟跃䟭仮踺嗘坔蹱嗵躰䠷軎転軤軭軲辷迁迊迌逳駄䢭飠鈓䤞鈨鉘鉫銱銮銿"],["9a40","鋣鋫鋳鋴鋽鍃鎄鎭䥅䥑麿鐗匁鐝鐭鐾䥪鑔鑹锭関䦧间阳䧥枠䨤靀䨵鞲韂噔䫤惨颹䬙飱塄餎餙冴餜餷饂饝饢䭰駅䮝騼鬏窃魩鮁鯝鯱鯴䱭鰠㝯𡯂鵉鰺"],["9aa1","黾噐鶓鶽鷀鷼银辶鹻麬麱麽黆铜黢黱黸竈齄𠂔𠊷𠎠椚铃妬𠓗塀铁㞹𠗕𠘕𠙶𡚺块煳𠫂𠫍𠮿呪吆𠯋咞𠯻𠰻𠱓𠱥𠱼惧𠲍噺𠲵𠳝𠳭𠵯𠶲𠷈楕鰯螥𠸄𠸎𠻗𠾐𠼭𠹳尠𠾼帋𡁜𡁏𡁶朞𡁻𡂈𡂖㙇𡂿𡃓𡄯𡄻卤蒭𡋣𡍵𡌶讁𡕷𡘙𡟃𡟇乸炻𡠭𡥪"],["9b40","𡨭𡩅𡰪𡱰𡲬𡻈拃𡻕𡼕熘桕𢁅槩㛈𢉼𢏗𢏺𢜪𢡱𢥏苽𢥧𢦓𢫕覥𢫨辠𢬎鞸𢬿顇骽𢱌"],["9b62","𢲈𢲷𥯨𢴈𢴒𢶷𢶕𢹂𢽴𢿌𣀳𣁦𣌟𣏞徱晈暿𧩹𣕧𣗳爁𤦺矗𣘚𣜖纇𠍆墵朎"],["9ba1","椘𣪧𧙗𥿢𣸑𣺹𧗾𢂚䣐䪸𤄙𨪚𤋮𤌍𤀻𤌴𤎖𤩅𠗊凒𠘑妟𡺨㮾𣳿𤐄𤓖垈𤙴㦛𤜯𨗨𩧉㝢𢇃譞𨭎駖𤠒𤣻𤨕爉𤫀𠱸奥𤺥𤾆𠝹軚𥀬劏圿煱𥊙𥐙𣽊𤪧喼𥑆𥑮𦭒釔㑳𥔿𧘲𥕞䜘𥕢𥕦𥟇𤤿𥡝偦㓻𣏌惞𥤃䝼𨥈𥪮𥮉𥰆𡶐垡煑澶𦄂𧰒遖𦆲𤾚譢𦐂𦑊"],["9c40","嵛𦯷輶𦒄𡤜諪𤧶𦒈𣿯𦔒䯀𦖿𦚵𢜛鑥𥟡憕娧晉侻嚹𤔡𦛼乪𤤴陖涏𦲽㘘襷𦞙𦡮𦐑𦡞營𦣇筂𩃀𠨑𦤦鄄𦤹穅鷰𦧺騦𦨭㙟𦑩𠀡禃𦨴𦭛崬𣔙菏𦮝䛐𦲤画补𦶮墶"],["9ca1","㜜𢖍𧁋𧇍㱔𧊀𧊅銁𢅺𧊋錰𧋦𤧐氹钟𧑐𠻸蠧裵𢤦𨑳𡞱溸𤨪𡠠㦤㚹尐秣䔿暶𩲭𩢤襃𧟌𧡘囖䃟𡘊㦡𣜯𨃨𡏅熭荦𧧝𩆨婧䲷𧂯𨦫𧧽𧨊𧬋𧵦𤅺筃祾𨀉澵𪋟樃𨌘厢𦸇鎿栶靝𨅯𨀣𦦵𡏭𣈯𨁈嶅𨰰𨂃圕頣𨥉嶫𤦈斾槕叒𤪥𣾁㰑朶𨂐𨃴𨄮𡾡𨅏"],["9d40","𨆉𨆯𨈚𨌆𨌯𨎊㗊𨑨𨚪䣺揦𨥖砈鉕𨦸䏲𨧧䏟𨧨𨭆𨯔姸𨰉輋𨿅𩃬筑𩄐𩄼㷷𩅞𤫊运犏嚋𩓧𩗩𩖰𩖸𩜲𩣑𩥉𩥪𩧃𩨨𩬎𩵚𩶛纟𩻸𩼣䲤镇𪊓熢𪋿䶑递𪗋䶜𠲜达嗁"],["9da1","辺𢒰边𤪓䔉繿潖檱仪㓤𨬬𧢝㜺躀𡟵𨀤𨭬𨮙𧨾𦚯㷫𧙕𣲷𥘵𥥖亚𥺁𦉘嚿𠹭踎孭𣺈𤲞揞拐𡟶𡡻攰嘭𥱊吚𥌑㷆𩶘䱽嘢嘞罉𥻘奵𣵀蝰东𠿪𠵉𣚺脗鵞贘瘻鱅癎瞹鍅吲腈苷嘥脲萘肽嗪祢噃吖𠺝㗎嘅嗱曱𨋢㘭甴嗰喺咗啲𠱁𠲖廐𥅈𠹶𢱢"],["9e40","𠺢麫絚嗞𡁵抝靭咔賍燶酶揼掹揾啩𢭃鱲𢺳冚㓟𠶧冧呍唞唓癦踭𦢊疱肶蠄螆裇膶萜𡃁䓬猄𤜆宐茋𦢓噻𢛴𧴯𤆣𧵳𦻐𧊶酰𡇙鈈𣳼𪚩𠺬𠻹牦𡲢䝎𤿂𧿹𠿫䃺"],["9ea1","鱝攟𢶠䣳𤟠𩵼𠿬𠸊恢𧖣𠿭"],["9ead","𦁈𡆇熣纎鵐业丄㕷嬍沲卧㚬㧜卽㚥𤘘墚𤭮舭呋垪𥪕𠥹"],["9ec5","㩒𢑥獴𩺬䴉鯭𣳾𩼰䱛𤾩𩖞𩿞葜𣶶𧊲𦞳𣜠挮紥𣻷𣸬㨪逈勌㹴㙺䗩𠒎癀嫰𠺶硺𧼮墧䂿噼鮋嵴癔𪐴麅䳡痹㟻愙𣃚𤏲"],["9ef5","噝𡊩垧𤥣𩸆刴𧂮㖭汊鵼"],["9f40","籖鬹埞𡝬屓擓𩓐𦌵𧅤蚭𠴨𦴢𤫢𠵱"],["9f4f","凾𡼏嶎霃𡷑麁遌笟鬂峑箣扨挵髿篏鬪籾鬮籂粆鰕篼鬉鼗鰛𤤾齚啳寃俽麘俲剠㸆勑坧偖妷帒韈鶫轜呩鞴饀鞺匬愰"],["9fa1","椬叚鰊鴂䰻陁榀傦畆𡝭駚剳"],["9fae","酙隁酜"],["9fb2","酑𨺗捿𦴣櫊嘑醎畺抅𠏼獏籰𥰡𣳽"],["9fc1","𤤙盖鮝个𠳔莾衂"],["9fc9","届槀僭坺刟巵从氱𠇲伹咜哚劚趂㗾弌㗳"],["9fdb","歒酼龥鮗頮颴骺麨麄煺笔"],["9fe7","毺蠘罸"],["9feb","嘠𪙊蹷齓"],["9ff0","跔蹏鸜踁抂𨍽踨蹵竓𤩷稾磘泪詧瘇"],["a040","𨩚鼦泎蟖痃𪊲硓咢贌狢獱謭猂瓱賫𤪻蘯徺袠䒷"],["a055","𡠻𦸅"],["a058","詾𢔛"],["a05b","惽癧髗鵄鍮鮏蟵"],["a063","蠏賷猬霡鮰㗖犲䰇籑饊𦅙慙䰄麖慽"],["a073","坟慯抦戹拎㩜懢厪𣏵捤栂㗒"],["a0a1","嵗𨯂迚𨸹"],["a0a6","僙𡵆礆匲阸𠼻䁥"],["a0ae","矾"],["a0b0","糂𥼚糚稭聦聣絍甅瓲覔舚朌聢𧒆聛瓰脃眤覉𦟌畓𦻑螩蟎臈螌詉貭譃眫瓸蓚㘵榲趦"],["a0d4","覩瑨涹蟁𤀑瓧㷛煶悤憜㳑煢恷"],["a0e2","罱𨬭牐惩䭾删㰘𣳇𥻗𧙖𥔱𡥄𡋾𩤃𦷜𧂭峁𦆭𨨏𣙷𠃮𦡆𤼎䕢嬟𦍌齐麦𦉫"],["a3c0","␀",31,"␡"],["c6a1","①",9,"⑴",9,"ⅰ",9,"丶丿亅亠冂冖冫勹匸卩厶夊宀巛⼳广廴彐彡攴无疒癶辵隶¨ˆヽヾゝゞ〃仝々〆〇ー［］✽ぁ",23],["c740","す",58,"ァアィイ"],["c7a1","ゥ",81,"А",5,"ЁЖ",4],["c840","Л",26,"ёж",25,"⇧↸↹㇏𠃌乚𠂊刂䒑"],["c8a1","龰冈龱𧘇"],["c8cd","￢￤＇＂㈱№℡゛゜⺀⺄⺆⺇⺈⺊⺌⺍⺕⺜⺝⺥⺧⺪⺬⺮⺶⺼⺾⻆⻊⻌⻍⻏⻖⻗⻞⻣"],["c8f5","ʃɐɛɔɵœøŋʊɪ"],["f9fe","￭"],["fa40","𠕇鋛𠗟𣿅蕌䊵珯况㙉𤥂𨧤鍄𡧛苮𣳈砼杄拟𤤳𨦪𠊠𦮳𡌅侫𢓭倈𦴩𧪄𣘀𤪱𢔓倩𠍾徤𠎀𠍇滛𠐟偽儁㑺儎顬㝃萖𤦤𠒇兠𣎴兪𠯿𢃼𠋥𢔰𠖎𣈳𡦃宂蝽𠖳𣲙冲冸"],["faa1","鴴凉减凑㳜凓𤪦决凢卂凭菍椾𣜭彻刋刦刼劵剗劔効勅簕蕂勠蘍𦬓包𨫞啉滙𣾀𠥔𣿬匳卄𠯢泋𡜦栛珕恊㺪㣌𡛨燝䒢卭却𨚫卾卿𡖖𡘓矦厓𨪛厠厫厮玧𥝲㽙玜叁叅汉义埾叙㪫𠮏叠𣿫𢶣叶𠱷吓灹唫晗浛呭𦭓𠵴啝咏咤䞦𡜍𠻝㶴𠵍"],["fb40","𨦼𢚘啇䳭启琗喆喩嘅𡣗𤀺䕒𤐵暳𡂴嘷曍𣊊暤暭噍噏磱囱鞇叾圀囯园𨭦㘣𡉏坆𤆥汮炋坂㚱𦱾埦𡐖堃𡑔𤍣堦𤯵塜墪㕡壠壜𡈼壻寿坃𪅐𤉸鏓㖡够梦㛃湙"],["fba1","𡘾娤啓𡚒蔅姉𠵎𦲁𦴪𡟜姙𡟻𡞲𦶦浱𡠨𡛕姹𦹅媫婣㛦𤦩婷㜈媖瑥嫓𦾡𢕔㶅𡤑㜲𡚸広勐孶斈孼𧨎䀄䡝𠈄寕慠𡨴𥧌𠖥寳宝䴐尅𡭄尓珎尔𡲥𦬨屉䣝岅峩峯嶋𡷹𡸷崐崘嵆𡺤岺巗苼㠭𤤁𢁉𢅳芇㠶㯂帮檊幵幺𤒼𠳓厦亷廐厨𡝱帉廴𨒂"],["fc40","廹廻㢠廼栾鐛弍𠇁弢㫞䢮𡌺强𦢈𢏐彘𢑱彣鞽𦹮彲鍀𨨶徧嶶㵟𥉐𡽪𧃸𢙨釖𠊞𨨩怱暅𡡷㥣㷇㘹垐𢞴祱㹀悞悤悳𤦂𤦏𧩓璤僡媠慤萤慂慈𦻒憁凴𠙖憇宪𣾷"],["fca1","𢡟懓𨮝𩥝懐㤲𢦀𢣁怣慜攞掋𠄘担𡝰拕𢸍捬𤧟㨗搸揸𡎎𡟼撐澊𢸶頔𤂌𥜝擡擥鑻㩦携㩗敍漖𤨨𤨣斅敭敟𣁾斵𤥀䬷旑䃘𡠩无旣忟𣐀昘𣇷𣇸晄𣆤𣆥晋𠹵晧𥇦晳晴𡸽𣈱𨗴𣇈𥌓矅𢣷馤朂𤎜𤨡㬫槺𣟂杞杧杢𤇍𩃭柗䓩栢湐鈼栁𣏦𦶠桝"],["fd40","𣑯槡樋𨫟楳棃𣗍椁椀㴲㨁𣘼㮀枬楡𨩊䋼椶榘㮡𠏉荣傐槹𣙙𢄪橅𣜃檝㯳枱櫈𩆜㰍欝𠤣惞欵歴𢟍溵𣫛𠎵𡥘㝀吡𣭚毡𣻼毜氷𢒋𤣱𦭑汚舦汹𣶼䓅𣶽𤆤𤤌𤤀"],["fda1","𣳉㛥㳫𠴲鮃𣇹𢒑羏样𦴥𦶡𦷫涖浜湼漄𤥿𤂅𦹲蔳𦽴凇沜渝萮𨬡港𣸯瑓𣾂秌湏媑𣁋濸㜍澝𣸰滺𡒗𤀽䕕鏰潄潜㵎潴𩅰㴻澟𤅄濓𤂑𤅕𤀹𣿰𣾴𤄿凟𤅖𤅗𤅀𦇝灋灾炧炁烌烕烖烟䄄㷨熴熖𤉷焫煅媈煊煮岜𤍥煏鍢𤋁焬𤑚𤨧𤨢熺𨯨炽爎"],["fe40","鑂爕夑鑃爤鍁𥘅爮牀𤥴梽牕牗㹕𣁄栍漽犂猪猫𤠣𨠫䣭𨠄猨献珏玪𠰺𦨮珉瑉𤇢𡛧𤨤昣㛅𤦷𤦍𤧻珷琕椃𤨦琹𠗃㻗瑜𢢭瑠𨺲瑇珤瑶莹瑬㜰瑴鏱樬璂䥓𤪌"],["fea1","𤅟𤩹𨮏孆𨰃𡢞瓈𡦈甎瓩甞𨻙𡩋寗𨺬鎅畍畊畧畮𤾂㼄𤴓疎瑝疞疴瘂瘬癑癏癯癶𦏵皐臯㟸𦤑𦤎皡皥皷盌𦾟葢𥂝𥅽𡸜眞眦着撯𥈠睘𣊬瞯𨥤𨥨𡛁矴砉𡍶𤨒棊碯磇磓隥礮𥗠磗礴碱𧘌辸袄𨬫𦂃𢘜禆褀椂禀𥡗禝𧬹礼禩渪𧄦㺨秆𩄍秔"]]')},3336:function(A){"use strict";A.exports=JSON.parse('[["0","\\u0000",127,"€"],["8140","丂丄丅丆丏丒丗丟丠両丣並丩丮丯丱丳丵丷丼乀乁乂乄乆乊乑乕乗乚乛乢乣乤乥乧乨乪",5,"乲乴",9,"乿",6,"亇亊"],["8180","亐亖亗亙亜亝亞亣亪亯亰亱亴亶亷亸亹亼亽亾仈仌仏仐仒仚仛仜仠仢仦仧仩仭仮仯仱仴仸仹仺仼仾伀伂",6,"伋伌伒",4,"伜伝伡伣伨伩伬伭伮伱伳伵伷伹伻伾",4,"佄佅佇",5,"佒佔佖佡佢佦佨佪佫佭佮佱佲併佷佸佹佺佽侀侁侂侅來侇侊侌侎侐侒侓侕侖侘侙侚侜侞侟価侢"],["8240","侤侫侭侰",4,"侶",8,"俀俁係俆俇俈俉俋俌俍俒",4,"俙俛俠俢俤俥俧俫俬俰俲俴俵俶俷俹俻俼俽俿",11],["8280","個倎倐們倓倕倖倗倛倝倞倠倢倣値倧倫倯",10,"倻倽倿偀偁偂偄偅偆偉偊偋偍偐",4,"偖偗偘偙偛偝",7,"偦",5,"偭",8,"偸偹偺偼偽傁傂傃傄傆傇傉傊傋傌傎",20,"傤傦傪傫傭",4,"傳",6,"傼"],["8340","傽",17,"僐",5,"僗僘僙僛",10,"僨僩僪僫僯僰僱僲僴僶",4,"僼",9,"儈"],["8380","儉儊儌",5,"儓",13,"儢",28,"兂兇兊兌兎兏児兒兓兗兘兙兛兝",4,"兣兤兦內兩兪兯兲兺兾兿冃冄円冇冊冋冎冏冐冑冓冔冘冚冝冞冟冡冣冦",4,"冭冮冴冸冹冺冾冿凁凂凃凅凈凊凍凎凐凒",5],["8440","凘凙凚凜凞凟凢凣凥",5,"凬凮凱凲凴凷凾刄刅刉刋刌刏刐刓刔刕刜刞刟刡刢刣別刦刧刪刬刯刱刲刴刵刼刾剄",5,"剋剎剏剒剓剕剗剘"],["8480","剙剚剛剝剟剠剢剣剤剦剨剫剬剭剮剰剱剳",9,"剾劀劃",4,"劉",6,"劑劒劔",6,"劜劤劥劦劧劮劯劰労",9,"勀勁勂勄勅勆勈勊勌勍勎勏勑勓勔動勗務",5,"勠勡勢勣勥",10,"勱",7,"勻勼勽匁匂匃匄匇匉匊匋匌匎"],["8540","匑匒匓匔匘匛匜匞匟匢匤匥匧匨匩匫匬匭匯",9,"匼匽區卂卄卆卋卌卍卐協単卙卛卝卥卨卪卬卭卲卶卹卻卼卽卾厀厁厃厇厈厊厎厏"],["8580","厐",4,"厖厗厙厛厜厞厠厡厤厧厪厫厬厭厯",6,"厷厸厹厺厼厽厾叀參",4,"収叏叐叒叓叕叚叜叝叞叡叢叧叴叺叾叿吀吂吅吇吋吔吘吙吚吜吢吤吥吪吰吳吶吷吺吽吿呁呂呄呅呇呉呌呍呎呏呑呚呝",4,"呣呥呧呩",7,"呴呹呺呾呿咁咃咅咇咈咉咊咍咑咓咗咘咜咞咟咠咡"],["8640","咢咥咮咰咲咵咶咷咹咺咼咾哃哅哊哋哖哘哛哠",4,"哫哬哯哰哱哴",5,"哻哾唀唂唃唄唅唈唊",4,"唒唓唕",5,"唜唝唞唟唡唥唦"],["8680","唨唩唫唭唲唴唵唶唸唹唺唻唽啀啂啅啇啈啋",4,"啑啒啓啔啗",4,"啝啞啟啠啢啣啨啩啫啯",5,"啹啺啽啿喅喆喌喍喎喐喒喓喕喖喗喚喛喞喠",6,"喨",8,"喲喴営喸喺喼喿",4,"嗆嗇嗈嗊嗋嗎嗏嗐嗕嗗",4,"嗞嗠嗢嗧嗩嗭嗮嗰嗱嗴嗶嗸",4,"嗿嘂嘃嘄嘅"],["8740","嘆嘇嘊嘋嘍嘐",7,"嘙嘚嘜嘝嘠嘡嘢嘥嘦嘨嘩嘪嘫嘮嘯嘰嘳嘵嘷嘸嘺嘼嘽嘾噀",11,"噏",4,"噕噖噚噛噝",4],["8780","噣噥噦噧噭噮噯噰噲噳噴噵噷噸噹噺噽",7,"嚇",6,"嚐嚑嚒嚔",14,"嚤",10,"嚰",6,"嚸嚹嚺嚻嚽",12,"囋",8,"囕囖囘囙囜団囥",5,"囬囮囯囲図囶囷囸囻囼圀圁圂圅圇國",6],["8840","園",9,"圝圞圠圡圢圤圥圦圧圫圱圲圴",4,"圼圽圿坁坃坄坅坆坈坉坋坒",4,"坘坙坢坣坥坧坬坮坰坱坲坴坵坸坹坺坽坾坿垀"],["8880","垁垇垈垉垊垍",4,"垔",6,"垜垝垞垟垥垨垪垬垯垰垱垳垵垶垷垹",8,"埄",6,"埌埍埐埑埓埖埗埛埜埞埡埢埣埥",7,"埮埰埱埲埳埵埶執埻埼埾埿堁堃堄堅堈堉堊堌堎堏堐堒堓堔堖堗堘堚堛堜堝堟堢堣堥",4,"堫",4,"報堲堳場堶",7],["8940","堾",5,"塅",6,"塎塏塐塒塓塕塖塗塙",4,"塟",5,"塦",4,"塭",16,"塿墂墄墆墇墈墊墋墌"],["8980","墍",4,"墔",4,"墛墜墝墠",7,"墪",17,"墽墾墿壀壂壃壄壆",10,"壒壓壔壖",13,"壥",5,"壭壯壱売壴壵壷壸壺",7,"夃夅夆夈",4,"夎夐夑夒夓夗夘夛夝夞夠夡夢夣夦夨夬夰夲夳夵夶夻"],["8a40","夽夾夿奀奃奅奆奊奌奍奐奒奓奙奛",4,"奡奣奤奦",12,"奵奷奺奻奼奾奿妀妅妉妋妌妎妏妐妑妔妕妘妚妛妜妝妟妠妡妢妦"],["8a80","妧妬妭妰妱妳",5,"妺妼妽妿",6,"姇姈姉姌姍姎姏姕姖姙姛姞",4,"姤姦姧姩姪姫姭",11,"姺姼姽姾娀娂娊娋娍娎娏娐娒娔娕娖娗娙娚娛娝娞娡娢娤娦娧娨娪",6,"娳娵娷",4,"娽娾娿婁",4,"婇婈婋",9,"婖婗婘婙婛",5],["8b40","婡婣婤婥婦婨婩婫",8,"婸婹婻婼婽婾媀",17,"媓",6,"媜",13,"媫媬"],["8b80","媭",4,"媴媶媷媹",4,"媿嫀嫃",5,"嫊嫋嫍",4,"嫓嫕嫗嫙嫚嫛嫝嫞嫟嫢嫤嫥嫧嫨嫪嫬",4,"嫲",22,"嬊",11,"嬘",25,"嬳嬵嬶嬸",7,"孁",6],["8c40","孈",7,"孒孖孞孠孡孧孨孫孭孮孯孲孴孶孷學孹孻孼孾孿宂宆宊宍宎宐宑宒宔宖実宧宨宩宬宭宮宯宱宲宷宺宻宼寀寁寃寈寉寊寋寍寎寏"],["8c80","寑寔",8,"寠寢寣實寧審",4,"寯寱",6,"寽対尀専尃尅將專尋尌對導尐尒尓尗尙尛尞尟尠尡尣尦尨尩尪尫尭尮尯尰尲尳尵尶尷屃屄屆屇屌屍屒屓屔屖屗屘屚屛屜屝屟屢層屧",6,"屰屲",6,"屻屼屽屾岀岃",4,"岉岊岋岎岏岒岓岕岝",4,"岤",4],["8d40","岪岮岯岰岲岴岶岹岺岻岼岾峀峂峃峅",5,"峌",5,"峓",5,"峚",6,"峢峣峧峩峫峬峮峯峱",9,"峼",4],["8d80","崁崄崅崈",5,"崏",4,"崕崗崘崙崚崜崝崟",4,"崥崨崪崫崬崯",4,"崵",7,"崿",7,"嵈嵉嵍",10,"嵙嵚嵜嵞",10,"嵪嵭嵮嵰嵱嵲嵳嵵",12,"嶃",21,"嶚嶛嶜嶞嶟嶠"],["8e40","嶡",21,"嶸",12,"巆",6,"巎",12,"巜巟巠巣巤巪巬巭"],["8e80","巰巵巶巸",4,"巿帀帄帇帉帊帋帍帎帒帓帗帞",7,"帨",4,"帯帰帲",4,"帹帺帾帿幀幁幃幆",5,"幍",6,"幖",4,"幜幝幟幠幣",14,"幵幷幹幾庁庂広庅庈庉庌庍庎庒庘庛庝庡庢庣庤庨",4,"庮",4,"庴庺庻庼庽庿",6],["8f40","廆廇廈廋",5,"廔廕廗廘廙廚廜",11,"廩廫",8,"廵廸廹廻廼廽弅弆弇弉弌弍弎弐弒弔弖弙弚弜弝弞弡弢弣弤"],["8f80","弨弫弬弮弰弲",6,"弻弽弾弿彁",14,"彑彔彙彚彛彜彞彟彠彣彥彧彨彫彮彯彲彴彵彶彸彺彽彾彿徃徆徍徎徏徑従徔徖徚徛徝從徟徠徢",5,"復徫徬徯",5,"徶徸徹徺徻徾",4,"忇忈忊忋忎忓忔忕忚忛応忞忟忢忣忥忦忨忩忬忯忰忲忳忴忶忷忹忺忼怇"],["9040","怈怉怋怌怐怑怓怗怘怚怞怟怢怣怤怬怭怮怰",4,"怶",4,"怽怾恀恄",6,"恌恎恏恑恓恔恖恗恘恛恜恞恟恠恡恥恦恮恱恲恴恵恷恾悀"],["9080","悁悂悅悆悇悈悊悋悎悏悐悑悓悕悗悘悙悜悞悡悢悤悥悧悩悪悮悰悳悵悶悷悹悺悽",7,"惇惈惉惌",4,"惒惓惔惖惗惙惛惞惡",4,"惪惱惲惵惷惸惻",4,"愂愃愄愅愇愊愋愌愐",4,"愖愗愘愙愛愜愝愞愡愢愥愨愩愪愬",18,"慀",6],["9140","慇慉態慍慏慐慒慓慔慖",6,"慞慟慠慡慣慤慥慦慩",6,"慱慲慳慴慶慸",18,"憌憍憏",4,"憕"],["9180","憖",6,"憞",8,"憪憫憭",9,"憸",5,"憿懀懁懃",4,"應懌",4,"懓懕",16,"懧",13,"懶",8,"戀",5,"戇戉戓戔戙戜戝戞戠戣戦戧戨戩戫戭戯戰戱戲戵戶戸",4,"扂扄扅扆扊"],["9240","扏扐払扖扗扙扚扜",6,"扤扥扨扱扲扴扵扷扸扺扻扽抁抂抃抅抆抇抈抋",5,"抔抙抜抝択抣抦抧抩抪抭抮抯抰抲抳抴抶抷抸抺抾拀拁"],["9280","拃拋拏拑拕拝拞拠拡拤拪拫拰拲拵拸拹拺拻挀挃挄挅挆挊挋挌挍挏挐挒挓挔挕挗挘挙挜挦挧挩挬挭挮挰挱挳",5,"挻挼挾挿捀捁捄捇捈捊捑捒捓捔捖",7,"捠捤捥捦捨捪捫捬捯捰捲捳捴捵捸捹捼捽捾捿掁掃掄掅掆掋掍掑掓掔掕掗掙",6,"採掤掦掫掯掱掲掵掶掹掻掽掿揀"],["9340","揁揂揃揅揇揈揊揋揌揑揓揔揕揗",6,"揟揢揤",4,"揫揬揮揯揰揱揳揵揷揹揺揻揼揾搃搄搆",4,"損搎搑搒搕",5,"搝搟搢搣搤"],["9380","搥搧搨搩搫搮",5,"搵",4,"搻搼搾摀摂摃摉摋",6,"摓摕摖摗摙",4,"摟",7,"摨摪摫摬摮",9,"摻",6,"撃撆撈",8,"撓撔撗撘撚撛撜撝撟",4,"撥撦撧撨撪撫撯撱撲撳撴撶撹撻撽撾撿擁擃擄擆",6,"擏擑擓擔擕擖擙據"],["9440","擛擜擝擟擠擡擣擥擧",24,"攁",7,"攊",7,"攓",4,"攙",8],["9480","攢攣攤攦",4,"攬攭攰攱攲攳攷攺攼攽敀",4,"敆敇敊敋敍敎敐敒敓敔敗敘敚敜敟敠敡敤敥敧敨敩敪敭敮敯敱敳敵敶數",14,"斈斉斊斍斎斏斒斔斕斖斘斚斝斞斠斢斣斦斨斪斬斮斱",7,"斺斻斾斿旀旂旇旈旉旊旍旐旑旓旔旕旘",7,"旡旣旤旪旫"],["9540","旲旳旴旵旸旹旻",4,"昁昄昅昇昈昉昋昍昐昑昒昖昗昘昚昛昜昞昡昢昣昤昦昩昪昫昬昮昰昲昳昷",4,"昽昿晀時晄",6,"晍晎晐晑晘"],["9580","晙晛晜晝晞晠晢晣晥晧晩",4,"晱晲晳晵晸晹晻晼晽晿暀暁暃暅暆暈暉暊暋暍暎暏暐暒暓暔暕暘",4,"暞",8,"暩",4,"暯",4,"暵暶暷暸暺暻暼暽暿",25,"曚曞",7,"曧曨曪",5,"曱曵曶書曺曻曽朁朂會"],["9640","朄朅朆朇朌朎朏朑朒朓朖朘朙朚朜朞朠",5,"朧朩朮朰朲朳朶朷朸朹朻朼朾朿杁杄杅杇杊杋杍杒杔杕杗",4,"杝杢杣杤杦杧杫杬杮東杴杶"],["9680","杸杹杺杻杽枀枂枃枅枆枈枊枌枍枎枏枑枒枓枔枖枙枛枟枠枡枤枦枩枬枮枱枲枴枹",7,"柂柅",9,"柕柖柗柛柟柡柣柤柦柧柨柪柫柭柮柲柵",7,"柾栁栂栃栄栆栍栐栒栔栕栘",4,"栞栟栠栢",6,"栫",6,"栴栵栶栺栻栿桇桋桍桏桒桖",5],["9740","桜桝桞桟桪桬",7,"桵桸",8,"梂梄梇",7,"梐梑梒梔梕梖梘",9,"梣梤梥梩梪梫梬梮梱梲梴梶梷梸"],["9780","梹",6,"棁棃",5,"棊棌棎棏棐棑棓棔棖棗棙棛",4,"棡棢棤",9,"棯棲棳棴棶棷棸棻棽棾棿椀椂椃椄椆",4,"椌椏椑椓",11,"椡椢椣椥",7,"椮椯椱椲椳椵椶椷椸椺椻椼椾楀楁楃",16,"楕楖楘楙楛楜楟"],["9840","楡楢楤楥楧楨楩楪楬業楯楰楲",4,"楺楻楽楾楿榁榃榅榊榋榌榎",5,"榖榗榙榚榝",9,"榩榪榬榮榯榰榲榳榵榶榸榹榺榼榽"],["9880","榾榿槀槂",7,"構槍槏槑槒槓槕",5,"槜槝槞槡",11,"槮槯槰槱槳",9,"槾樀",9,"樋",11,"標",5,"樠樢",5,"権樫樬樭樮樰樲樳樴樶",6,"樿",4,"橅橆橈",7,"橑",6,"橚"],["9940","橜",4,"橢橣橤橦",10,"橲",6,"橺橻橽橾橿檁檂檃檅",8,"檏檒",4,"檘",7,"檡",5],["9980","檧檨檪檭",114,"欥欦欨",6],["9a40","欯欰欱欳欴欵欶欸欻欼欽欿歀歁歂歄歅歈歊歋歍",11,"歚",7,"歨歩歫",13,"歺歽歾歿殀殅殈"],["9a80","殌殎殏殐殑殔殕殗殘殙殜",4,"殢",7,"殫",7,"殶殸",6,"毀毃毄毆",4,"毌毎毐毑毘毚毜",4,"毢",7,"毬毭毮毰毱毲毴毶毷毸毺毻毼毾",6,"氈",4,"氎氒気氜氝氞氠氣氥氫氬氭氱氳氶氷氹氺氻氼氾氿汃汄汅汈汋",4,"汑汒汓汖汘"],["9b40","汙汚汢汣汥汦汧汫",4,"汱汳汵汷汸決汻汼汿沀沄沇沊沋沍沎沑沒沕沖沗沘沚沜沝沞沠沢沨沬沯沰沴沵沶沷沺泀況泂泃泆泇泈泋泍泎泏泑泒泘"],["9b80","泙泚泜泝泟泤泦泧泩泬泭泲泴泹泿洀洂洃洅洆洈洉洊洍洏洐洑洓洔洕洖洘洜洝洟",5,"洦洨洩洬洭洯洰洴洶洷洸洺洿浀浂浄浉浌浐浕浖浗浘浛浝浟浡浢浤浥浧浨浫浬浭浰浱浲浳浵浶浹浺浻浽",4,"涃涄涆涇涊涋涍涏涐涒涖",4,"涜涢涥涬涭涰涱涳涴涶涷涹",5,"淁淂淃淈淉淊"],["9c40","淍淎淏淐淒淓淔淕淗淚淛淜淟淢淣淥淧淨淩淪淭淯淰淲淴淵淶淸淺淽",7,"渆渇済渉渋渏渒渓渕渘渙減渜渞渟渢渦渧渨渪測渮渰渱渳渵"],["9c80","渶渷渹渻",7,"湅",7,"湏湐湑湒湕湗湙湚湜湝湞湠",10,"湬湭湯",14,"満溁溂溄溇溈溊",4,"溑",6,"溙溚溛溝溞溠溡溣溤溦溨溩溫溬溭溮溰溳溵溸溹溼溾溿滀滃滄滅滆滈滉滊滌滍滎滐滒滖滘滙滛滜滝滣滧滪",5],["9d40","滰滱滲滳滵滶滷滸滺",7,"漃漄漅漇漈漊",4,"漐漑漒漖",9,"漡漢漣漥漦漧漨漬漮漰漲漴漵漷",6,"漿潀潁潂"],["9d80","潃潄潅潈潉潊潌潎",9,"潙潚潛潝潟潠潡潣潤潥潧",5,"潯潰潱潳潵潶潷潹潻潽",6,"澅澆澇澊澋澏",12,"澝澞澟澠澢",4,"澨",10,"澴澵澷澸澺",5,"濁濃",5,"濊",6,"濓",10,"濟濢濣濤濥"],["9e40","濦",7,"濰",32,"瀒",7,"瀜",6,"瀤",6],["9e80","瀫",9,"瀶瀷瀸瀺",17,"灍灎灐",13,"灟",11,"灮灱灲灳灴灷灹灺灻災炁炂炃炄炆炇炈炋炌炍炏炐炑炓炗炘炚炛炞",12,"炰炲炴炵炶為炾炿烄烅烆烇烉烋",12,"烚"],["9f40","烜烝烞烠烡烢烣烥烪烮烰",6,"烸烺烻烼烾",10,"焋",4,"焑焒焔焗焛",10,"焧",7,"焲焳焴"],["9f80","焵焷",13,"煆煇煈煉煋煍煏",12,"煝煟",4,"煥煩",4,"煯煰煱煴煵煶煷煹煻煼煾",5,"熅",4,"熋熌熍熎熐熑熒熓熕熖熗熚",4,"熡",6,"熩熪熫熭",5,"熴熶熷熸熺",8,"燄",9,"燏",4],["a040","燖",9,"燡燢燣燤燦燨",5,"燯",9,"燺",11,"爇",19],["a080","爛爜爞",9,"爩爫爭爮爯爲爳爴爺爼爾牀",6,"牉牊牋牎牏牐牑牓牔牕牗牘牚牜牞牠牣牤牥牨牪牫牬牭牰牱牳牴牶牷牸牻牼牽犂犃犅",4,"犌犎犐犑犓",11,"犠",11,"犮犱犲犳犵犺",6,"狅狆狇狉狊狋狌狏狑狓狔狕狖狘狚狛"],["a1a1","　、。·ˉˇ¨〃々—～‖…‘’“”〔〕〈",7,"〖〗【】±×÷∶∧∨∑∏∪∩∈∷√⊥∥∠⌒⊙∫∮≡≌≈∽∝≠≮≯≤≥∞∵∴♂♀°′″℃＄¤￠￡‰§№☆★○●◎◇◆□■△▲※→←↑↓〓"],["a2a1","ⅰ",9],["a2b1","⒈",19,"⑴",19,"①",9],["a2e5","㈠",9],["a2f1","Ⅰ",11],["a3a1","！＂＃￥％",88,"￣"],["a4a1","ぁ",82],["a5a1","ァ",85],["a6a1","Α",16,"Σ",6],["a6c1","α",16,"σ",6],["a6e0","︵︶︹︺︿﹀︽︾﹁﹂﹃﹄"],["a6ee","︻︼︷︸︱"],["a6f4","︳︴"],["a7a1","А",5,"ЁЖ",25],["a7d1","а",5,"ёж",25],["a840","ˊˋ˙–―‥‵℅℉↖↗↘↙∕∟∣≒≦≧⊿═",35,"▁",6],["a880","█",7,"▓▔▕▼▽◢◣◤◥☉⊕〒〝〞"],["a8a1","āáǎàēéěèīíǐìōóǒòūúǔùǖǘǚǜüêɑ"],["a8bd","ńň"],["a8c0","ɡ"],["a8c5","ㄅ",36],["a940","〡",8,"㊣㎎㎏㎜㎝㎞㎡㏄㏎㏑㏒㏕︰￢￤"],["a959","℡㈱"],["a95c","‐"],["a960","ー゛゜ヽヾ〆ゝゞ﹉",9,"﹔﹕﹖﹗﹙",8],["a980","﹢",4,"﹨﹩﹪﹫"],["a996","〇"],["a9a4","─",75],["aa40","狜狝狟狢",5,"狪狫狵狶狹狽狾狿猀猂猄",5,"猋猌猍猏猐猑猒猔猘猙猚猟猠猣猤猦猧猨猭猯猰猲猳猵猶猺猻猼猽獀",8],["aa80","獉獊獋獌獎獏獑獓獔獕獖獘",7,"獡",10,"獮獰獱"],["ab40","獲",11,"獿",4,"玅玆玈玊玌玍玏玐玒玓玔玕玗玘玙玚玜玝玞玠玡玣",5,"玪玬玭玱玴玵玶玸玹玼玽玾玿珁珃",4],["ab80","珋珌珎珒",6,"珚珛珜珝珟珡珢珣珤珦珨珪珫珬珮珯珰珱珳",4],["ac40","珸",10,"琄琇琈琋琌琍琎琑",8,"琜",5,"琣琤琧琩琫琭琯琱琲琷",4,"琽琾琿瑀瑂",11],["ac80","瑎",6,"瑖瑘瑝瑠",12,"瑮瑯瑱",4,"瑸瑹瑺"],["ad40","瑻瑼瑽瑿璂璄璅璆璈璉璊璌璍璏璑",10,"璝璟",7,"璪",15,"璻",12],["ad80","瓈",9,"瓓",8,"瓝瓟瓡瓥瓧",6,"瓰瓱瓲"],["ae40","瓳瓵瓸",6,"甀甁甂甃甅",7,"甎甐甒甔甕甖甗甛甝甞甠",4,"甦甧甪甮甴甶甹甼甽甿畁畂畃畄畆畇畉畊畍畐畑畒畓畕畖畗畘"],["ae80","畝",7,"畧畨畩畫",6,"畳畵當畷畺",4,"疀疁疂疄疅疇"],["af40","疈疉疊疌疍疎疐疓疕疘疛疜疞疢疦",4,"疭疶疷疺疻疿痀痁痆痋痌痎痏痐痑痓痗痙痚痜痝痟痠痡痥痩痬痭痮痯痲痳痵痶痷痸痺痻痽痾瘂瘄瘆瘇"],["af80","瘈瘉瘋瘍瘎瘏瘑瘒瘓瘔瘖瘚瘜瘝瘞瘡瘣瘧瘨瘬瘮瘯瘱瘲瘶瘷瘹瘺瘻瘽癁療癄"],["b040","癅",6,"癎",5,"癕癗",4,"癝癟癠癡癢癤",6,"癬癭癮癰",7,"癹発發癿皀皁皃皅皉皊皌皍皏皐皒皔皕皗皘皚皛"],["b080","皜",7,"皥",8,"皯皰皳皵",9,"盀盁盃啊阿埃挨哎唉哀皑癌蔼矮艾碍爱隘鞍氨安俺按暗岸胺案肮昂盎凹敖熬翱袄傲奥懊澳芭捌扒叭吧笆八疤巴拔跋靶把耙坝霸罢爸白柏百摆佰败拜稗斑班搬扳般颁板版扮拌伴瓣半办绊邦帮梆榜膀绑棒磅蚌镑傍谤苞胞包褒剥"],["b140","盄盇盉盋盌盓盕盙盚盜盝盞盠",4,"盦",7,"盰盳盵盶盷盺盻盽盿眀眂眃眅眆眊県眎",10,"眛眜眝眞眡眣眤眥眧眪眫"],["b180","眬眮眰",4,"眹眻眽眾眿睂睄睅睆睈",7,"睒",7,"睜薄雹保堡饱宝抱报暴豹鲍爆杯碑悲卑北辈背贝钡倍狈备惫焙被奔苯本笨崩绷甭泵蹦迸逼鼻比鄙笔彼碧蓖蔽毕毙毖币庇痹闭敝弊必辟壁臂避陛鞭边编贬扁便变卞辨辩辫遍标彪膘表鳖憋别瘪彬斌濒滨宾摈兵冰柄丙秉饼炳"],["b240","睝睞睟睠睤睧睩睪睭",11,"睺睻睼瞁瞂瞃瞆",5,"瞏瞐瞓",11,"瞡瞣瞤瞦瞨瞫瞭瞮瞯瞱瞲瞴瞶",4],["b280","瞼瞾矀",12,"矎",8,"矘矙矚矝",4,"矤病并玻菠播拨钵波博勃搏铂箔伯帛舶脖膊渤泊驳捕卜哺补埠不布步簿部怖擦猜裁材才财睬踩采彩菜蔡餐参蚕残惭惨灿苍舱仓沧藏操糙槽曹草厕策侧册测层蹭插叉茬茶查碴搽察岔差诧拆柴豺搀掺蝉馋谗缠铲产阐颤昌猖"],["b340","矦矨矪矯矰矱矲矴矵矷矹矺矻矼砃",5,"砊砋砎砏砐砓砕砙砛砞砠砡砢砤砨砪砫砮砯砱砲砳砵砶砽砿硁硂硃硄硆硈硉硊硋硍硏硑硓硔硘硙硚"],["b380","硛硜硞",11,"硯",7,"硸硹硺硻硽",6,"场尝常长偿肠厂敞畅唱倡超抄钞朝嘲潮巢吵炒车扯撤掣彻澈郴臣辰尘晨忱沉陈趁衬撑称城橙成呈乘程惩澄诚承逞骋秤吃痴持匙池迟弛驰耻齿侈尺赤翅斥炽充冲虫崇宠抽酬畴踌稠愁筹仇绸瞅丑臭初出橱厨躇锄雏滁除楚"],["b440","碄碅碆碈碊碋碏碐碒碔碕碖碙碝碞碠碢碤碦碨",7,"碵碶碷碸確碻碼碽碿磀磂磃磄磆磇磈磌磍磎磏磑磒磓磖磗磘磚",9],["b480","磤磥磦磧磩磪磫磭",4,"磳磵磶磸磹磻",5,"礂礃礄礆",6,"础储矗搐触处揣川穿椽传船喘串疮窗幢床闯创吹炊捶锤垂春椿醇唇淳纯蠢戳绰疵茨磁雌辞慈瓷词此刺赐次聪葱囱匆从丛凑粗醋簇促蹿篡窜摧崔催脆瘁粹淬翠村存寸磋撮搓措挫错搭达答瘩打大呆歹傣戴带殆代贷袋待逮"],["b540","礍",5,"礔",9,"礟",4,"礥",14,"礵",4,"礽礿祂祃祄祅祇祊",8,"祔祕祘祙祡祣"],["b580","祤祦祩祪祫祬祮祰",6,"祹祻",4,"禂禃禆禇禈禉禋禌禍禎禐禑禒怠耽担丹单郸掸胆旦氮但惮淡诞弹蛋当挡党荡档刀捣蹈倒岛祷导到稻悼道盗德得的蹬灯登等瞪凳邓堤低滴迪敌笛狄涤翟嫡抵底地蒂第帝弟递缔颠掂滇碘点典靛垫电佃甸店惦奠淀殿碉叼雕凋刁掉吊钓调跌爹碟蝶迭谍叠"],["b640","禓",6,"禛",11,"禨",10,"禴",4,"禼禿秂秄秅秇秈秊秌秎秏秐秓秔秖秗秙",5,"秠秡秢秥秨秪"],["b680","秬秮秱",6,"秹秺秼秾秿稁稄稅稇稈稉稊稌稏",4,"稕稖稘稙稛稜丁盯叮钉顶鼎锭定订丢东冬董懂动栋侗恫冻洞兜抖斗陡豆逗痘都督毒犊独读堵睹赌杜镀肚度渡妒端短锻段断缎堆兑队对墩吨蹲敦顿囤钝盾遁掇哆多夺垛躲朵跺舵剁惰堕蛾峨鹅俄额讹娥恶厄扼遏鄂饿恩而儿耳尔饵洱二"],["b740","稝稟稡稢稤",14,"稴稵稶稸稺稾穀",5,"穇",9,"穒",4,"穘",16],["b780","穩",6,"穱穲穳穵穻穼穽穾窂窅窇窉窊窋窌窎窏窐窓窔窙窚窛窞窡窢贰发罚筏伐乏阀法珐藩帆番翻樊矾钒繁凡烦反返范贩犯饭泛坊芳方肪房防妨仿访纺放菲非啡飞肥匪诽吠肺废沸费芬酚吩氛分纷坟焚汾粉奋份忿愤粪丰封枫蜂峰锋风疯烽逢冯缝讽奉凤佛否夫敷肤孵扶拂辐幅氟符伏俘服"],["b840","窣窤窧窩窪窫窮",4,"窴",10,"竀",10,"竌",9,"竗竘竚竛竜竝竡竢竤竧",5,"竮竰竱竲竳"],["b880","竴",4,"竻竼竾笀笁笂笅笇笉笌笍笎笐笒笓笖笗笘笚笜笝笟笡笢笣笧笩笭浮涪福袱弗甫抚辅俯釜斧脯腑府腐赴副覆赋复傅付阜父腹负富讣附妇缚咐噶嘎该改概钙盖溉干甘杆柑竿肝赶感秆敢赣冈刚钢缸肛纲岗港杠篙皋高膏羔糕搞镐稿告哥歌搁戈鸽胳疙割革葛格蛤阁隔铬个各给根跟耕更庚羹"],["b940","笯笰笲笴笵笶笷笹笻笽笿",5,"筆筈筊筍筎筓筕筗筙筜筞筟筡筣",10,"筯筰筳筴筶筸筺筼筽筿箁箂箃箄箆",6,"箎箏"],["b980","箑箒箓箖箘箙箚箛箞箟箠箣箤箥箮箯箰箲箳箵箶箷箹",7,"篂篃範埂耿梗工攻功恭龚供躬公宫弓巩汞拱贡共钩勾沟苟狗垢构购够辜菇咕箍估沽孤姑鼓古蛊骨谷股故顾固雇刮瓜剐寡挂褂乖拐怪棺关官冠观管馆罐惯灌贯光广逛瑰规圭硅归龟闺轨鬼诡癸桂柜跪贵刽辊滚棍锅郭国果裹过哈"],["ba40","篅篈築篊篋篍篎篏篐篒篔",4,"篛篜篞篟篠篢篣篤篧篨篩篫篬篭篯篰篲",4,"篸篹篺篻篽篿",7,"簈簉簊簍簎簐",5,"簗簘簙"],["ba80","簚",4,"簠",5,"簨簩簫",12,"簹",5,"籂骸孩海氦亥害骇酣憨邯韩含涵寒函喊罕翰撼捍旱憾悍焊汗汉夯杭航壕嚎豪毫郝好耗号浩呵喝荷菏核禾和何合盒貉阂河涸赫褐鹤贺嘿黑痕很狠恨哼亨横衡恒轰哄烘虹鸿洪宏弘红喉侯猴吼厚候后呼乎忽瑚壶葫胡蝴狐糊湖"],["bb40","籃",9,"籎",36,"籵",5,"籾",9],["bb80","粈粊",6,"粓粔粖粙粚粛粠粡粣粦粧粨粩粫粬粭粯粰粴",4,"粺粻弧虎唬护互沪户花哗华猾滑画划化话槐徊怀淮坏欢环桓还缓换患唤痪豢焕涣宦幻荒慌黄磺蝗簧皇凰惶煌晃幌恍谎灰挥辉徽恢蛔回毁悔慧卉惠晦贿秽会烩汇讳诲绘荤昏婚魂浑混豁活伙火获或惑霍货祸击圾基机畸稽积箕"],["bc40","粿糀糂糃糄糆糉糋糎",6,"糘糚糛糝糞糡",6,"糩",5,"糰",7,"糹糺糼",13,"紋",5],["bc80","紑",14,"紡紣紤紥紦紨紩紪紬紭紮細",6,"肌饥迹激讥鸡姬绩缉吉极棘辑籍集及急疾汲即嫉级挤几脊己蓟技冀季伎祭剂悸济寄寂计记既忌际妓继纪嘉枷夹佳家加荚颊贾甲钾假稼价架驾嫁歼监坚尖笺间煎兼肩艰奸缄茧检柬碱硷拣捡简俭剪减荐槛鉴践贱见键箭件"],["bd40","紷",54,"絯",7],["bd80","絸",32,"健舰剑饯渐溅涧建僵姜将浆江疆蒋桨奖讲匠酱降蕉椒礁焦胶交郊浇骄娇嚼搅铰矫侥脚狡角饺缴绞剿教酵轿较叫窖揭接皆秸街阶截劫节桔杰捷睫竭洁结解姐戒藉芥界借介疥诫届巾筋斤金今津襟紧锦仅谨进靳晋禁近烬浸"],["be40","継",12,"綧",6,"綯",42],["be80","線",32,"尽劲荆兢茎睛晶鲸京惊精粳经井警景颈静境敬镜径痉靖竟竞净炯窘揪究纠玖韭久灸九酒厩救旧臼舅咎就疚鞠拘狙疽居驹菊局咀矩举沮聚拒据巨具距踞锯俱句惧炬剧捐鹃娟倦眷卷绢撅攫抉掘倔爵觉决诀绝均菌钧军君峻"],["bf40","緻",62],["bf80","縺縼",4,"繂",4,"繈",21,"俊竣浚郡骏喀咖卡咯开揩楷凯慨刊堪勘坎砍看康慷糠扛抗亢炕考拷烤靠坷苛柯棵磕颗科壳咳可渴克刻客课肯啃垦恳坑吭空恐孔控抠口扣寇枯哭窟苦酷库裤夸垮挎跨胯块筷侩快宽款匡筐狂框矿眶旷况亏盔岿窥葵奎魁傀"],["c040","繞",35,"纃",23,"纜纝纞"],["c080","纮纴纻纼绖绤绬绹缊缐缞缷缹缻",6,"罃罆",9,"罒罓馈愧溃坤昆捆困括扩廓阔垃拉喇蜡腊辣啦莱来赖蓝婪栏拦篮阑兰澜谰揽览懒缆烂滥琅榔狼廊郎朗浪捞劳牢老佬姥酪烙涝勒乐雷镭蕾磊累儡垒擂肋类泪棱楞冷厘梨犁黎篱狸离漓理李里鲤礼莉荔吏栗丽厉励砾历利傈例俐"],["c140","罖罙罛罜罝罞罠罣",4,"罫罬罭罯罰罳罵罶罷罸罺罻罼罽罿羀羂",7,"羋羍羏",4,"羕",4,"羛羜羠羢羣羥羦羨",6,"羱"],["c180","羳",4,"羺羻羾翀翂翃翄翆翇翈翉翋翍翏",4,"翖翗翙",5,"翢翣痢立粒沥隶力璃哩俩联莲连镰廉怜涟帘敛脸链恋炼练粮凉梁粱良两辆量晾亮谅撩聊僚疗燎寥辽潦了撂镣廖料列裂烈劣猎琳林磷霖临邻鳞淋凛赁吝拎玲菱零龄铃伶羚凌灵陵岭领另令溜琉榴硫馏留刘瘤流柳六龙聋咙笼窿"],["c240","翤翧翨翪翫翬翭翯翲翴",6,"翽翾翿耂耇耈耉耊耎耏耑耓耚耛耝耞耟耡耣耤耫",5,"耲耴耹耺耼耾聀聁聄聅聇聈聉聎聏聐聑聓聕聖聗"],["c280","聙聛",13,"聫",5,"聲",11,"隆垄拢陇楼娄搂篓漏陋芦卢颅庐炉掳卤虏鲁麓碌露路赂鹿潞禄录陆戮驴吕铝侣旅履屡缕虑氯律率滤绿峦挛孪滦卵乱掠略抡轮伦仑沦纶论萝螺罗逻锣箩骡裸落洛骆络妈麻玛码蚂马骂嘛吗埋买麦卖迈脉瞒馒蛮满蔓曼慢漫"],["c340","聾肁肂肅肈肊肍",5,"肔肕肗肙肞肣肦肧肨肬肰肳肵肶肸肹肻胅胇",4,"胏",6,"胘胟胠胢胣胦胮胵胷胹胻胾胿脀脁脃脄脅脇脈脋"],["c380","脌脕脗脙脛脜脝脟",12,"脭脮脰脳脴脵脷脹",4,"脿谩芒茫盲氓忙莽猫茅锚毛矛铆卯茂冒帽貌贸么玫枚梅酶霉煤没眉媒镁每美昧寐妹媚门闷们萌蒙檬盟锰猛梦孟眯醚靡糜迷谜弥米秘觅泌蜜密幂棉眠绵冕免勉娩缅面苗描瞄藐秒渺庙妙蔑灭民抿皿敏悯闽明螟鸣铭名命谬摸"],["c440","腀",5,"腇腉腍腎腏腒腖腗腘腛",4,"腡腢腣腤腦腨腪腫腬腯腲腳腵腶腷腸膁膃",4,"膉膋膌膍膎膐膒",5,"膙膚膞",4,"膤膥"],["c480","膧膩膫",7,"膴",5,"膼膽膾膿臄臅臇臈臉臋臍",6,"摹蘑模膜磨摩魔抹末莫墨默沫漠寞陌谋牟某拇牡亩姆母墓暮幕募慕木目睦牧穆拿哪呐钠那娜纳氖乃奶耐奈南男难囊挠脑恼闹淖呢馁内嫩能妮霓倪泥尼拟你匿腻逆溺蔫拈年碾撵捻念娘酿鸟尿捏聂孽啮镊镍涅您柠狞凝宁"],["c540","臔",14,"臤臥臦臨臩臫臮",4,"臵",5,"臽臿舃與",4,"舎舏舑舓舕",5,"舝舠舤舥舦舧舩舮舲舺舼舽舿"],["c580","艀艁艂艃艅艆艈艊艌艍艎艐",7,"艙艛艜艝艞艠",7,"艩拧泞牛扭钮纽脓浓农弄奴努怒女暖虐疟挪懦糯诺哦欧鸥殴藕呕偶沤啪趴爬帕怕琶拍排牌徘湃派攀潘盘磐盼畔判叛乓庞旁耪胖抛咆刨炮袍跑泡呸胚培裴赔陪配佩沛喷盆砰抨烹澎彭蓬棚硼篷膨朋鹏捧碰坯砒霹批披劈琵毗"],["c640","艪艫艬艭艱艵艶艷艸艻艼芀芁芃芅芆芇芉芌芐芓芔芕芖芚芛芞芠芢芣芧芲芵芶芺芻芼芿苀苂苃苅苆苉苐苖苙苚苝苢苧苨苩苪苬苭苮苰苲苳苵苶苸"],["c680","苺苼",4,"茊茋茍茐茒茓茖茘茙茝",9,"茩茪茮茰茲茷茻茽啤脾疲皮匹痞僻屁譬篇偏片骗飘漂瓢票撇瞥拼频贫品聘乒坪苹萍平凭瓶评屏坡泼颇婆破魄迫粕剖扑铺仆莆葡菩蒲埔朴圃普浦谱曝瀑期欺栖戚妻七凄漆柒沏其棋奇歧畦崎脐齐旗祈祁骑起岂乞企启契砌器气迄弃汽泣讫掐"],["c740","茾茿荁荂荄荅荈荊",4,"荓荕",4,"荝荢荰",6,"荹荺荾",6,"莇莈莊莋莌莍莏莐莑莔莕莖莗莙莚莝莟莡",6,"莬莭莮"],["c780","莯莵莻莾莿菂菃菄菆菈菉菋菍菎菐菑菒菓菕菗菙菚菛菞菢菣菤菦菧菨菫菬菭恰洽牵扦钎铅千迁签仟谦乾黔钱钳前潜遣浅谴堑嵌欠歉枪呛腔羌墙蔷强抢橇锹敲悄桥瞧乔侨巧鞘撬翘峭俏窍切茄且怯窃钦侵亲秦琴勤芹擒禽寝沁青轻氢倾卿清擎晴氰情顷请庆琼穷秋丘邱球求囚酋泅趋区蛆曲躯屈驱渠"],["c840","菮華菳",4,"菺菻菼菾菿萀萂萅萇萈萉萊萐萒",5,"萙萚萛萞",5,"萩",7,"萲",5,"萹萺萻萾",7,"葇葈葉"],["c880","葊",6,"葒",4,"葘葝葞葟葠葢葤",4,"葪葮葯葰葲葴葷葹葻葼取娶龋趣去圈颧权醛泉全痊拳犬券劝缺炔瘸却鹊榷确雀裙群然燃冉染瓤壤攘嚷让饶扰绕惹热壬仁人忍韧任认刃妊纫扔仍日戎茸蓉荣融熔溶容绒冗揉柔肉茹蠕儒孺如辱乳汝入褥软阮蕊瑞锐闰润若弱撒洒萨腮鳃塞赛三叁"],["c940","葽",4,"蒃蒄蒅蒆蒊蒍蒏",7,"蒘蒚蒛蒝蒞蒟蒠蒢",12,"蒰蒱蒳蒵蒶蒷蒻蒼蒾蓀蓂蓃蓅蓆蓇蓈蓋蓌蓎蓏蓒蓔蓕蓗"],["c980","蓘",4,"蓞蓡蓢蓤蓧",4,"蓭蓮蓯蓱",10,"蓽蓾蔀蔁蔂伞散桑嗓丧搔骚扫嫂瑟色涩森僧莎砂杀刹沙纱傻啥煞筛晒珊苫杉山删煽衫闪陕擅赡膳善汕扇缮墒伤商赏晌上尚裳梢捎稍烧芍勺韶少哨邵绍奢赊蛇舌舍赦摄射慑涉社设砷申呻伸身深娠绅神沈审婶甚肾慎渗声生甥牲升绳"],["ca40","蔃",8,"蔍蔎蔏蔐蔒蔔蔕蔖蔘蔙蔛蔜蔝蔞蔠蔢",8,"蔭",9,"蔾",4,"蕄蕅蕆蕇蕋",10],["ca80","蕗蕘蕚蕛蕜蕝蕟",4,"蕥蕦蕧蕩",8,"蕳蕵蕶蕷蕸蕼蕽蕿薀薁省盛剩胜圣师失狮施湿诗尸虱十石拾时什食蚀实识史矢使屎驶始式示士世柿事拭誓逝势是嗜噬适仕侍释饰氏市恃室视试收手首守寿授售受瘦兽蔬枢梳殊抒输叔舒淑疏书赎孰熟薯暑曙署蜀黍鼠属术述树束戍竖墅庶数漱"],["cb40","薂薃薆薈",6,"薐",10,"薝",6,"薥薦薧薩薫薬薭薱",5,"薸薺",6,"藂",6,"藊",4,"藑藒"],["cb80","藔藖",5,"藝",6,"藥藦藧藨藪",14,"恕刷耍摔衰甩帅栓拴霜双爽谁水睡税吮瞬顺舜说硕朔烁斯撕嘶思私司丝死肆寺嗣四伺似饲巳松耸怂颂送宋讼诵搜艘擞嗽苏酥俗素速粟僳塑溯宿诉肃酸蒜算虽隋随绥髓碎岁穗遂隧祟孙损笋蓑梭唆缩琐索锁所塌他它她塔"],["cc40","藹藺藼藽藾蘀",4,"蘆",10,"蘒蘓蘔蘕蘗",15,"蘨蘪",13,"蘹蘺蘻蘽蘾蘿虀"],["cc80","虁",11,"虒虓處",4,"虛虜虝號虠虡虣",7,"獭挞蹋踏胎苔抬台泰酞太态汰坍摊贪瘫滩坛檀痰潭谭谈坦毯袒碳探叹炭汤塘搪堂棠膛唐糖倘躺淌趟烫掏涛滔绦萄桃逃淘陶讨套特藤腾疼誊梯剔踢锑提题蹄啼体替嚏惕涕剃屉天添填田甜恬舔腆挑条迢眺跳贴铁帖厅听烃"],["cd40","虭虯虰虲",6,"蚃",6,"蚎",4,"蚔蚖",5,"蚞",4,"蚥蚦蚫蚭蚮蚲蚳蚷蚸蚹蚻",4,"蛁蛂蛃蛅蛈蛌蛍蛒蛓蛕蛖蛗蛚蛜"],["cd80","蛝蛠蛡蛢蛣蛥蛦蛧蛨蛪蛫蛬蛯蛵蛶蛷蛺蛻蛼蛽蛿蜁蜄蜅蜆蜋蜌蜎蜏蜐蜑蜔蜖汀廷停亭庭挺艇通桐酮瞳同铜彤童桶捅筒统痛偷投头透凸秃突图徒途涂屠土吐兔湍团推颓腿蜕褪退吞屯臀拖托脱鸵陀驮驼椭妥拓唾挖哇蛙洼娃瓦袜歪外豌弯湾玩顽丸烷完碗挽晚皖惋宛婉万腕汪王亡枉网往旺望忘妄威"],["ce40","蜙蜛蜝蜟蜠蜤蜦蜧蜨蜪蜫蜬蜭蜯蜰蜲蜳蜵蜶蜸蜹蜺蜼蜽蝀",6,"蝊蝋蝍蝏蝐蝑蝒蝔蝕蝖蝘蝚",5,"蝡蝢蝦",7,"蝯蝱蝲蝳蝵"],["ce80","蝷蝸蝹蝺蝿螀螁螄螆螇螉螊螌螎",4,"螔螕螖螘",6,"螠",4,"巍微危韦违桅围唯惟为潍维苇萎委伟伪尾纬未蔚味畏胃喂魏位渭谓尉慰卫瘟温蚊文闻纹吻稳紊问嗡翁瓮挝蜗涡窝我斡卧握沃巫呜钨乌污诬屋无芜梧吾吴毋武五捂午舞伍侮坞戊雾晤物勿务悟误昔熙析西硒矽晰嘻吸锡牺"],["cf40","螥螦螧螩螪螮螰螱螲螴螶螷螸螹螻螼螾螿蟁",4,"蟇蟈蟉蟌",4,"蟔",6,"蟜蟝蟞蟟蟡蟢蟣蟤蟦蟧蟨蟩蟫蟬蟭蟯",9],["cf80","蟺蟻蟼蟽蟿蠀蠁蠂蠄",5,"蠋",7,"蠔蠗蠘蠙蠚蠜",4,"蠣稀息希悉膝夕惜熄烯溪汐犀檄袭席习媳喜铣洗系隙戏细瞎虾匣霞辖暇峡侠狭下厦夏吓掀锨先仙鲜纤咸贤衔舷闲涎弦嫌显险现献县腺馅羡宪陷限线相厢镶香箱襄湘乡翔祥详想响享项巷橡像向象萧硝霄削哮嚣销消宵淆晓"],["d040","蠤",13,"蠳",5,"蠺蠻蠽蠾蠿衁衂衃衆",5,"衎",5,"衕衖衘衚",6,"衦衧衪衭衯衱衳衴衵衶衸衹衺"],["d080","衻衼袀袃袆袇袉袊袌袎袏袐袑袓袔袕袗",4,"袝",4,"袣袥",5,"小孝校肖啸笑效楔些歇蝎鞋协挟携邪斜胁谐写械卸蟹懈泄泻谢屑薪芯锌欣辛新忻心信衅星腥猩惺兴刑型形邢行醒幸杏性姓兄凶胸匈汹雄熊休修羞朽嗅锈秀袖绣墟戌需虚嘘须徐许蓄酗叙旭序畜恤絮婿绪续轩喧宣悬旋玄"],["d140","袬袮袯袰袲",4,"袸袹袺袻袽袾袿裀裃裄裇裈裊裋裌裍裏裐裑裓裖裗裚",4,"裠裡裦裧裩",6,"裲裵裶裷裺裻製裿褀褁褃",5],["d180","褉褋",4,"褑褔",4,"褜",4,"褢褣褤褦褧褨褩褬褭褮褯褱褲褳褵褷选癣眩绚靴薛学穴雪血勋熏循旬询寻驯巡殉汛训讯逊迅压押鸦鸭呀丫芽牙蚜崖衙涯雅哑亚讶焉咽阉烟淹盐严研蜒岩延言颜阎炎沿奄掩眼衍演艳堰燕厌砚雁唁彦焰宴谚验殃央鸯秧杨扬佯疡羊洋阳氧仰痒养样漾邀腰妖瑶"],["d240","褸",8,"襂襃襅",24,"襠",5,"襧",19,"襼"],["d280","襽襾覀覂覄覅覇",26,"摇尧遥窑谣姚咬舀药要耀椰噎耶爷野冶也页掖业叶曳腋夜液一壹医揖铱依伊衣颐夷遗移仪胰疑沂宜姨彝椅蚁倚已乙矣以艺抑易邑屹亿役臆逸肄疫亦裔意毅忆义益溢诣议谊译异翼翌绎茵荫因殷音阴姻吟银淫寅饮尹引隐"],["d340","覢",30,"觃觍觓觔觕觗觘觙觛觝觟觠觡觢觤觧觨觩觪觬觭觮觰觱觲觴",6],["d380","觻",4,"訁",5,"計",21,"印英樱婴鹰应缨莹萤营荧蝇迎赢盈影颖硬映哟拥佣臃痈庸雍踊蛹咏泳涌永恿勇用幽优悠忧尤由邮铀犹油游酉有友右佑釉诱又幼迂淤于盂榆虞愚舆余俞逾鱼愉渝渔隅予娱雨与屿禹宇语羽玉域芋郁吁遇喻峪御愈欲狱育誉"],["d440","訞",31,"訿",8,"詉",21],["d480","詟",25,"詺",6,"浴寓裕预豫驭鸳渊冤元垣袁原援辕园员圆猿源缘远苑愿怨院曰约越跃钥岳粤月悦阅耘云郧匀陨允运蕴酝晕韵孕匝砸杂栽哉灾宰载再在咱攒暂赞赃脏葬遭糟凿藻枣早澡蚤躁噪造皂灶燥责择则泽贼怎增憎曾赠扎喳渣札轧"],["d540","誁",7,"誋",7,"誔",46],["d580","諃",32,"铡闸眨栅榨咋乍炸诈摘斋宅窄债寨瞻毡詹粘沾盏斩辗崭展蘸栈占战站湛绽樟章彰漳张掌涨杖丈帐账仗胀瘴障招昭找沼赵照罩兆肇召遮折哲蛰辙者锗蔗这浙珍斟真甄砧臻贞针侦枕疹诊震振镇阵蒸挣睁征狰争怔整拯正政"],["d640","諤",34,"謈",27],["d680","謤謥謧",30,"帧症郑证芝枝支吱蜘知肢脂汁之织职直植殖执值侄址指止趾只旨纸志挚掷至致置帜峙制智秩稚质炙痔滞治窒中盅忠钟衷终种肿重仲众舟周州洲诌粥轴肘帚咒皱宙昼骤珠株蛛朱猪诸诛逐竹烛煮拄瞩嘱主著柱助蛀贮铸筑"],["d740","譆",31,"譧",4,"譭",25],["d780","讇",24,"讬讱讻诇诐诪谉谞住注祝驻抓爪拽专砖转撰赚篆桩庄装妆撞壮状椎锥追赘坠缀谆准捉拙卓桌琢茁酌啄着灼浊兹咨资姿滋淄孜紫仔籽滓子自渍字鬃棕踪宗综总纵邹走奏揍租足卒族祖诅阻组钻纂嘴醉最罪尊遵昨左佐柞做作坐座"],["d840","谸",8,"豂豃豄豅豈豊豋豍",7,"豖豗豘豙豛",5,"豣",6,"豬",6,"豴豵豶豷豻",6,"貃貄貆貇"],["d880","貈貋貍",6,"貕貖貗貙",20,"亍丌兀丐廿卅丕亘丞鬲孬噩丨禺丿匕乇夭爻卮氐囟胤馗毓睾鼗丶亟鼐乜乩亓芈孛啬嘏仄厍厝厣厥厮靥赝匚叵匦匮匾赜卦卣刂刈刎刭刳刿剀剌剞剡剜蒯剽劂劁劐劓冂罔亻仃仉仂仨仡仫仞伛仳伢佤仵伥伧伉伫佞佧攸佚佝"],["d940","貮",62],["d980","賭",32,"佟佗伲伽佶佴侑侉侃侏佾佻侪佼侬侔俦俨俪俅俚俣俜俑俟俸倩偌俳倬倏倮倭俾倜倌倥倨偾偃偕偈偎偬偻傥傧傩傺僖儆僭僬僦僮儇儋仝氽佘佥俎龠汆籴兮巽黉馘冁夔勹匍訇匐凫夙兕亠兖亳衮袤亵脔裒禀嬴蠃羸冫冱冽冼"],["da40","贎",14,"贠赑赒赗赟赥赨赩赪赬赮赯赱赲赸",8,"趂趃趆趇趈趉趌",4,"趒趓趕",9,"趠趡"],["da80","趢趤",12,"趲趶趷趹趻趽跀跁跂跅跇跈跉跊跍跐跒跓跔凇冖冢冥讠讦讧讪讴讵讷诂诃诋诏诎诒诓诔诖诘诙诜诟诠诤诨诩诮诰诳诶诹诼诿谀谂谄谇谌谏谑谒谔谕谖谙谛谘谝谟谠谡谥谧谪谫谮谯谲谳谵谶卩卺阝阢阡阱阪阽阼陂陉陔陟陧陬陲陴隈隍隗隰邗邛邝邙邬邡邴邳邶邺"],["db40","跕跘跙跜跠跡跢跥跦跧跩跭跮跰跱跲跴跶跼跾",6,"踆踇踈踋踍踎踐踑踒踓踕",7,"踠踡踤",4,"踫踭踰踲踳踴踶踷踸踻踼踾"],["db80","踿蹃蹅蹆蹌",4,"蹓",5,"蹚",11,"蹧蹨蹪蹫蹮蹱邸邰郏郅邾郐郄郇郓郦郢郜郗郛郫郯郾鄄鄢鄞鄣鄱鄯鄹酃酆刍奂劢劬劭劾哿勐勖勰叟燮矍廴凵凼鬯厶弁畚巯坌垩垡塾墼壅壑圩圬圪圳圹圮圯坜圻坂坩垅坫垆坼坻坨坭坶坳垭垤垌垲埏垧垴垓垠埕埘埚埙埒垸埴埯埸埤埝"],["dc40","蹳蹵蹷",4,"蹽蹾躀躂躃躄躆躈",6,"躑躒躓躕",6,"躝躟",11,"躭躮躰躱躳",6,"躻",7],["dc80","軃",10,"軏",21,"堋堍埽埭堀堞堙塄堠塥塬墁墉墚墀馨鼙懿艹艽艿芏芊芨芄芎芑芗芙芫芸芾芰苈苊苣芘芷芮苋苌苁芩芴芡芪芟苄苎芤苡茉苷苤茏茇苜苴苒苘茌苻苓茑茚茆茔茕苠苕茜荑荛荜茈莒茼茴茱莛荞茯荏荇荃荟荀茗荠茭茺茳荦荥"],["dd40","軥",62],["dd80","輤",32,"荨茛荩荬荪荭荮莰荸莳莴莠莪莓莜莅荼莶莩荽莸荻莘莞莨莺莼菁萁菥菘堇萘萋菝菽菖萜萸萑萆菔菟萏萃菸菹菪菅菀萦菰菡葜葑葚葙葳蒇蒈葺蒉葸萼葆葩葶蒌蒎萱葭蓁蓍蓐蓦蒽蓓蓊蒿蒺蓠蒡蒹蒴蒗蓥蓣蔌甍蔸蓰蔹蔟蔺"],["de40","轅",32,"轪辀辌辒辝辠辡辢辤辥辦辧辪辬辭辮辯農辳辴辵辷辸辺辻込辿迀迃迆"],["de80","迉",4,"迏迒迖迗迚迠迡迣迧迬迯迱迲迴迵迶迺迻迼迾迿逇逈逌逎逓逕逘蕖蔻蓿蓼蕙蕈蕨蕤蕞蕺瞢蕃蕲蕻薤薨薇薏蕹薮薜薅薹薷薰藓藁藜藿蘧蘅蘩蘖蘼廾弈夼奁耷奕奚奘匏尢尥尬尴扌扪抟抻拊拚拗拮挢拶挹捋捃掭揶捱捺掎掴捭掬掊捩掮掼揲揸揠揿揄揞揎摒揆掾摅摁搋搛搠搌搦搡摞撄摭撖"],["df40","這逜連逤逥逧",5,"逰",4,"逷逹逺逽逿遀遃遅遆遈",4,"過達違遖遙遚遜",5,"遤遦遧適遪遫遬遯",4,"遶",6,"遾邁"],["df80","還邅邆邇邉邊邌",4,"邒邔邖邘邚邜邞邟邠邤邥邧邨邩邫邭邲邷邼邽邿郀摺撷撸撙撺擀擐擗擤擢攉攥攮弋忒甙弑卟叱叽叩叨叻吒吖吆呋呒呓呔呖呃吡呗呙吣吲咂咔呷呱呤咚咛咄呶呦咝哐咭哂咴哒咧咦哓哔呲咣哕咻咿哌哙哚哜咩咪咤哝哏哞唛哧唠哽唔哳唢唣唏唑唧唪啧喏喵啉啭啁啕唿啐唼"],["e040","郂郃郆郈郉郋郌郍郒郔郕郖郘郙郚郞郟郠郣郤郥郩郪郬郮郰郱郲郳郵郶郷郹郺郻郼郿鄀鄁鄃鄅",19,"鄚鄛鄜"],["e080","鄝鄟鄠鄡鄤",10,"鄰鄲",6,"鄺",8,"酄唷啖啵啶啷唳唰啜喋嗒喃喱喹喈喁喟啾嗖喑啻嗟喽喾喔喙嗪嗷嗉嘟嗑嗫嗬嗔嗦嗝嗄嗯嗥嗲嗳嗌嗍嗨嗵嗤辔嘞嘈嘌嘁嘤嘣嗾嘀嘧嘭噘嘹噗嘬噍噢噙噜噌噔嚆噤噱噫噻噼嚅嚓嚯囔囗囝囡囵囫囹囿圄圊圉圜帏帙帔帑帱帻帼"],["e140","酅酇酈酑酓酔酕酖酘酙酛酜酟酠酦酧酨酫酭酳酺酻酼醀",4,"醆醈醊醎醏醓",6,"醜",5,"醤",5,"醫醬醰醱醲醳醶醷醸醹醻"],["e180","醼",10,"釈釋釐釒",9,"針",8,"帷幄幔幛幞幡岌屺岍岐岖岈岘岙岑岚岜岵岢岽岬岫岱岣峁岷峄峒峤峋峥崂崃崧崦崮崤崞崆崛嵘崾崴崽嵬嵛嵯嵝嵫嵋嵊嵩嵴嶂嶙嶝豳嶷巅彳彷徂徇徉後徕徙徜徨徭徵徼衢彡犭犰犴犷犸狃狁狎狍狒狨狯狩狲狴狷猁狳猃狺"],["e240","釦",62],["e280","鈥",32,"狻猗猓猡猊猞猝猕猢猹猥猬猸猱獐獍獗獠獬獯獾舛夥飧夤夂饣饧",5,"饴饷饽馀馄馇馊馍馐馑馓馔馕庀庑庋庖庥庠庹庵庾庳赓廒廑廛廨廪膺忄忉忖忏怃忮怄忡忤忾怅怆忪忭忸怙怵怦怛怏怍怩怫怊怿怡恸恹恻恺恂"],["e340","鉆",45,"鉵",16],["e380","銆",7,"銏",24,"恪恽悖悚悭悝悃悒悌悛惬悻悱惝惘惆惚悴愠愦愕愣惴愀愎愫慊慵憬憔憧憷懔懵忝隳闩闫闱闳闵闶闼闾阃阄阆阈阊阋阌阍阏阒阕阖阗阙阚丬爿戕氵汔汜汊沣沅沐沔沌汨汩汴汶沆沩泐泔沭泷泸泱泗沲泠泖泺泫泮沱泓泯泾"],["e440","銨",5,"銯",24,"鋉",31],["e480","鋩",32,"洹洧洌浃浈洇洄洙洎洫浍洮洵洚浏浒浔洳涑浯涞涠浞涓涔浜浠浼浣渚淇淅淞渎涿淠渑淦淝淙渖涫渌涮渫湮湎湫溲湟溆湓湔渲渥湄滟溱溘滠漭滢溥溧溽溻溷滗溴滏溏滂溟潢潆潇漤漕滹漯漶潋潴漪漉漩澉澍澌潸潲潼潺濑"],["e540","錊",51,"錿",10],["e580","鍊",31,"鍫濉澧澹澶濂濡濮濞濠濯瀚瀣瀛瀹瀵灏灞宀宄宕宓宥宸甯骞搴寤寮褰寰蹇謇辶迓迕迥迮迤迩迦迳迨逅逄逋逦逑逍逖逡逵逶逭逯遄遑遒遐遨遘遢遛暹遴遽邂邈邃邋彐彗彖彘尻咫屐屙孱屣屦羼弪弩弭艴弼鬻屮妁妃妍妩妪妣"],["e640","鍬",34,"鎐",27],["e680","鎬",29,"鏋鏌鏍妗姊妫妞妤姒妲妯姗妾娅娆姝娈姣姘姹娌娉娲娴娑娣娓婀婧婊婕娼婢婵胬媪媛婷婺媾嫫媲嫒嫔媸嫠嫣嫱嫖嫦嫘嫜嬉嬗嬖嬲嬷孀尕尜孚孥孳孑孓孢驵驷驸驺驿驽骀骁骅骈骊骐骒骓骖骘骛骜骝骟骠骢骣骥骧纟纡纣纥纨纩"],["e740","鏎",7,"鏗",54],["e780","鐎",32,"纭纰纾绀绁绂绉绋绌绐绔绗绛绠绡绨绫绮绯绱绲缍绶绺绻绾缁缂缃缇缈缋缌缏缑缒缗缙缜缛缟缡",6,"缪缫缬缭缯",4,"缵幺畿巛甾邕玎玑玮玢玟珏珂珑玷玳珀珉珈珥珙顼琊珩珧珞玺珲琏琪瑛琦琥琨琰琮琬"],["e840","鐯",14,"鐿",43,"鑬鑭鑮鑯"],["e880","鑰",20,"钑钖钘铇铏铓铔铚铦铻锜锠琛琚瑁瑜瑗瑕瑙瑷瑭瑾璜璎璀璁璇璋璞璨璩璐璧瓒璺韪韫韬杌杓杞杈杩枥枇杪杳枘枧杵枨枞枭枋杷杼柰栉柘栊柩枰栌柙枵柚枳柝栀柃枸柢栎柁柽栲栳桠桡桎桢桄桤梃栝桕桦桁桧桀栾桊桉栩梵梏桴桷梓桫棂楮棼椟椠棹"],["e940","锧锳锽镃镈镋镕镚镠镮镴镵長",7,"門",42],["e980","閫",32,"椤棰椋椁楗棣椐楱椹楠楂楝榄楫榀榘楸椴槌榇榈槎榉楦楣楹榛榧榻榫榭槔榱槁槊槟榕槠榍槿樯槭樗樘橥槲橄樾檠橐橛樵檎橹樽樨橘橼檑檐檩檗檫猷獒殁殂殇殄殒殓殍殚殛殡殪轫轭轱轲轳轵轶轸轷轹轺轼轾辁辂辄辇辋"],["ea40","闌",27,"闬闿阇阓阘阛阞阠阣",6,"阫阬阭阯阰阷阸阹阺阾陁陃陊陎陏陑陒陓陖陗"],["ea80","陘陙陚陜陝陞陠陣陥陦陫陭",4,"陳陸",12,"隇隉隊辍辎辏辘辚軎戋戗戛戟戢戡戥戤戬臧瓯瓴瓿甏甑甓攴旮旯旰昊昙杲昃昕昀炅曷昝昴昱昶昵耆晟晔晁晏晖晡晗晷暄暌暧暝暾曛曜曦曩贲贳贶贻贽赀赅赆赈赉赇赍赕赙觇觊觋觌觎觏觐觑牮犟牝牦牯牾牿犄犋犍犏犒挈挲掰"],["eb40","隌階隑隒隓隕隖隚際隝",9,"隨",7,"隱隲隴隵隷隸隺隻隿雂雃雈雊雋雐雑雓雔雖",9,"雡",6,"雫"],["eb80","雬雭雮雰雱雲雴雵雸雺電雼雽雿霂霃霅霊霋霌霐霑霒霔霕霗",4,"霝霟霠搿擘耄毪毳毽毵毹氅氇氆氍氕氘氙氚氡氩氤氪氲攵敕敫牍牒牖爰虢刖肟肜肓肼朊肽肱肫肭肴肷胧胨胩胪胛胂胄胙胍胗朐胝胫胱胴胭脍脎胲胼朕脒豚脶脞脬脘脲腈腌腓腴腙腚腱腠腩腼腽腭腧塍媵膈膂膑滕膣膪臌朦臊膻"],["ec40","霡",8,"霫霬霮霯霱霳",4,"霺霻霼霽霿",18,"靔靕靗靘靚靜靝靟靣靤靦靧靨靪",7],["ec80","靲靵靷",4,"靽",7,"鞆",4,"鞌鞎鞏鞐鞓鞕鞖鞗鞙",4,"臁膦欤欷欹歃歆歙飑飒飓飕飙飚殳彀毂觳斐齑斓於旆旄旃旌旎旒旖炀炜炖炝炻烀炷炫炱烨烊焐焓焖焯焱煳煜煨煅煲煊煸煺熘熳熵熨熠燠燔燧燹爝爨灬焘煦熹戾戽扃扈扉礻祀祆祉祛祜祓祚祢祗祠祯祧祺禅禊禚禧禳忑忐"],["ed40","鞞鞟鞡鞢鞤",6,"鞬鞮鞰鞱鞳鞵",46],["ed80","韤韥韨韮",4,"韴韷",23,"怼恝恚恧恁恙恣悫愆愍慝憩憝懋懑戆肀聿沓泶淼矶矸砀砉砗砘砑斫砭砜砝砹砺砻砟砼砥砬砣砩硎硭硖硗砦硐硇硌硪碛碓碚碇碜碡碣碲碹碥磔磙磉磬磲礅磴礓礤礞礴龛黹黻黼盱眄眍盹眇眈眚眢眙眭眦眵眸睐睑睇睃睚睨"],["ee40","頏",62],["ee80","顎",32,"睢睥睿瞍睽瞀瞌瞑瞟瞠瞰瞵瞽町畀畎畋畈畛畲畹疃罘罡罟詈罨罴罱罹羁罾盍盥蠲钅钆钇钋钊钌钍钏钐钔钗钕钚钛钜钣钤钫钪钭钬钯钰钲钴钶",4,"钼钽钿铄铈",6,"铐铑铒铕铖铗铙铘铛铞铟铠铢铤铥铧铨铪"],["ef40","顯",5,"颋颎颒颕颙颣風",37,"飏飐飔飖飗飛飜飝飠",4],["ef80","飥飦飩",30,"铩铫铮铯铳铴铵铷铹铼铽铿锃锂锆锇锉锊锍锎锏锒",4,"锘锛锝锞锟锢锪锫锩锬锱锲锴锶锷锸锼锾锿镂锵镄镅镆镉镌镎镏镒镓镔镖镗镘镙镛镞镟镝镡镢镤",8,"镯镱镲镳锺矧矬雉秕秭秣秫稆嵇稃稂稞稔"],["f040","餈",4,"餎餏餑",28,"餯",26],["f080","饊",9,"饖",12,"饤饦饳饸饹饻饾馂馃馉稹稷穑黏馥穰皈皎皓皙皤瓞瓠甬鸠鸢鸨",4,"鸲鸱鸶鸸鸷鸹鸺鸾鹁鹂鹄鹆鹇鹈鹉鹋鹌鹎鹑鹕鹗鹚鹛鹜鹞鹣鹦",6,"鹱鹭鹳疒疔疖疠疝疬疣疳疴疸痄疱疰痃痂痖痍痣痨痦痤痫痧瘃痱痼痿瘐瘀瘅瘌瘗瘊瘥瘘瘕瘙"],["f140","馌馎馚",10,"馦馧馩",47],["f180","駙",32,"瘛瘼瘢瘠癀瘭瘰瘿瘵癃瘾瘳癍癞癔癜癖癫癯翊竦穸穹窀窆窈窕窦窠窬窨窭窳衤衩衲衽衿袂袢裆袷袼裉裢裎裣裥裱褚裼裨裾裰褡褙褓褛褊褴褫褶襁襦襻疋胥皲皴矜耒耔耖耜耠耢耥耦耧耩耨耱耋耵聃聆聍聒聩聱覃顸颀颃"],["f240","駺",62],["f280","騹",32,"颉颌颍颏颔颚颛颞颟颡颢颥颦虍虔虬虮虿虺虼虻蚨蚍蚋蚬蚝蚧蚣蚪蚓蚩蚶蛄蚵蛎蚰蚺蚱蚯蛉蛏蚴蛩蛱蛲蛭蛳蛐蜓蛞蛴蛟蛘蛑蜃蜇蛸蜈蜊蜍蜉蜣蜻蜞蜥蜮蜚蜾蝈蜴蜱蜩蜷蜿螂蜢蝽蝾蝻蝠蝰蝌蝮螋蝓蝣蝼蝤蝙蝥螓螯螨蟒"],["f340","驚",17,"驲骃骉骍骎骔骕骙骦骩",6,"骲骳骴骵骹骻骽骾骿髃髄髆",4,"髍髎髏髐髒體髕髖髗髙髚髛髜"],["f380","髝髞髠髢髣髤髥髧髨髩髪髬髮髰",8,"髺髼",6,"鬄鬅鬆蟆螈螅螭螗螃螫蟥螬螵螳蟋蟓螽蟑蟀蟊蟛蟪蟠蟮蠖蠓蟾蠊蠛蠡蠹蠼缶罂罄罅舐竺竽笈笃笄笕笊笫笏筇笸笪笙笮笱笠笥笤笳笾笞筘筚筅筵筌筝筠筮筻筢筲筱箐箦箧箸箬箝箨箅箪箜箢箫箴篑篁篌篝篚篥篦篪簌篾篼簏簖簋"],["f440","鬇鬉",5,"鬐鬑鬒鬔",10,"鬠鬡鬢鬤",10,"鬰鬱鬳",7,"鬽鬾鬿魀魆魊魋魌魎魐魒魓魕",5],["f480","魛",32,"簟簪簦簸籁籀臾舁舂舄臬衄舡舢舣舭舯舨舫舸舻舳舴舾艄艉艋艏艚艟艨衾袅袈裘裟襞羝羟羧羯羰羲籼敉粑粝粜粞粢粲粼粽糁糇糌糍糈糅糗糨艮暨羿翎翕翥翡翦翩翮翳糸絷綦綮繇纛麸麴赳趄趔趑趱赧赭豇豉酊酐酎酏酤"],["f540","魼",62],["f580","鮻",32,"酢酡酰酩酯酽酾酲酴酹醌醅醐醍醑醢醣醪醭醮醯醵醴醺豕鹾趸跫踅蹙蹩趵趿趼趺跄跖跗跚跞跎跏跛跆跬跷跸跣跹跻跤踉跽踔踝踟踬踮踣踯踺蹀踹踵踽踱蹉蹁蹂蹑蹒蹊蹰蹶蹼蹯蹴躅躏躔躐躜躞豸貂貊貅貘貔斛觖觞觚觜"],["f640","鯜",62],["f680","鰛",32,"觥觫觯訾謦靓雩雳雯霆霁霈霏霎霪霭霰霾龀龃龅",5,"龌黾鼋鼍隹隼隽雎雒瞿雠銎銮鋈錾鍪鏊鎏鐾鑫鱿鲂鲅鲆鲇鲈稣鲋鲎鲐鲑鲒鲔鲕鲚鲛鲞",5,"鲥",4,"鲫鲭鲮鲰",7,"鲺鲻鲼鲽鳄鳅鳆鳇鳊鳋"],["f740","鰼",62],["f780","鱻鱽鱾鲀鲃鲄鲉鲊鲌鲏鲓鲖鲗鲘鲙鲝鲪鲬鲯鲹鲾",4,"鳈鳉鳑鳒鳚鳛鳠鳡鳌",4,"鳓鳔鳕鳗鳘鳙鳜鳝鳟鳢靼鞅鞑鞒鞔鞯鞫鞣鞲鞴骱骰骷鹘骶骺骼髁髀髅髂髋髌髑魅魃魇魉魈魍魑飨餍餮饕饔髟髡髦髯髫髻髭髹鬈鬏鬓鬟鬣麽麾縻麂麇麈麋麒鏖麝麟黛黜黝黠黟黢黩黧黥黪黯鼢鼬鼯鼹鼷鼽鼾齄"],["f840","鳣",62],["f880","鴢",32],["f940","鵃",62],["f980","鶂",32],["fa40","鶣",62],["fa80","鷢",32],["fb40","鸃",27,"鸤鸧鸮鸰鸴鸻鸼鹀鹍鹐鹒鹓鹔鹖鹙鹝鹟鹠鹡鹢鹥鹮鹯鹲鹴",9,"麀"],["fb80","麁麃麄麅麆麉麊麌",5,"麔",8,"麞麠",5,"麧麨麩麪"],["fc40","麫",8,"麵麶麷麹麺麼麿",4,"黅黆黇黈黊黋黌黐黒黓黕黖黗黙黚點黡黣黤黦黨黫黬黭黮黰",8,"黺黽黿",6],["fc80","鼆",4,"鼌鼏鼑鼒鼔鼕鼖鼘鼚",5,"鼡鼣",8,"鼭鼮鼰鼱"],["fd40","鼲",4,"鼸鼺鼼鼿",4,"齅",10,"齒",38],["fd80","齹",5,"龁龂龍",11,"龜龝龞龡",4,"郎凉秊裏隣"],["fe40","兀嗀﨎﨏﨑﨓﨔礼﨟蘒﨡﨣﨤﨧﨨﨩"]]')},7348:function(A){"use strict";A.exports=JSON.parse('[["0","\\u0000",127],["8141","갂갃갅갆갋",4,"갘갞갟갡갢갣갥",6,"갮갲갳갴"],["8161","갵갶갷갺갻갽갾갿걁",9,"걌걎",5,"걕"],["8181","걖걗걙걚걛걝",18,"걲걳걵걶걹걻",4,"겂겇겈겍겎겏겑겒겓겕",6,"겞겢",5,"겫겭겮겱",6,"겺겾겿곀곂곃곅곆곇곉곊곋곍",7,"곖곘",7,"곢곣곥곦곩곫곭곮곲곴곷",4,"곾곿괁괂괃괅괇",4,"괎괐괒괓"],["8241","괔괕괖괗괙괚괛괝괞괟괡",7,"괪괫괮",5],["8261","괶괷괹괺괻괽",6,"굆굈굊",5,"굑굒굓굕굖굗"],["8281","굙",7,"굢굤",7,"굮굯굱굲굷굸굹굺굾궀궃",4,"궊궋궍궎궏궑",10,"궞",5,"궥",17,"궸",7,"귂귃귅귆귇귉",6,"귒귔",7,"귝귞귟귡귢귣귥",18],["8341","귺귻귽귾긂",5,"긊긌긎",5,"긕",7],["8361","긝",18,"긲긳긵긶긹긻긼"],["8381","긽긾긿깂깄깇깈깉깋깏깑깒깓깕깗",4,"깞깢깣깤깦깧깪깫깭깮깯깱",6,"깺깾",5,"꺆",5,"꺍",46,"꺿껁껂껃껅",6,"껎껒",5,"껚껛껝",8],["8441","껦껧껩껪껬껮",5,"껵껶껷껹껺껻껽",8],["8461","꼆꼉꼊꼋꼌꼎꼏꼑",18],["8481","꼤",7,"꼮꼯꼱꼳꼵",6,"꼾꽀꽄꽅꽆꽇꽊",5,"꽑",10,"꽞",5,"꽦",18,"꽺",5,"꾁꾂꾃꾅꾆꾇꾉",6,"꾒꾓꾔꾖",5,"꾝",26,"꾺꾻꾽꾾"],["8541","꾿꿁",5,"꿊꿌꿏",4,"꿕",6,"꿝",4],["8561","꿢",5,"꿪",5,"꿲꿳꿵꿶꿷꿹",6,"뀂뀃"],["8581","뀅",6,"뀍뀎뀏뀑뀒뀓뀕",6,"뀞",9,"뀩",26,"끆끇끉끋끍끏끐끑끒끖끘끚끛끜끞",29,"끾끿낁낂낃낅",6,"낎낐낒",5,"낛낝낞낣낤"],["8641","낥낦낧낪낰낲낶낷낹낺낻낽",6,"냆냊",5,"냒"],["8661","냓냕냖냗냙",6,"냡냢냣냤냦",10],["8681","냱",22,"넊넍넎넏넑넔넕넖넗넚넞",4,"넦넧넩넪넫넭",6,"넶넺",5,"녂녃녅녆녇녉",6,"녒녓녖녗녙녚녛녝녞녟녡",22,"녺녻녽녾녿놁놃",4,"놊놌놎놏놐놑놕놖놗놙놚놛놝"],["8741","놞",9,"놩",15],["8761","놹",18,"뇍뇎뇏뇑뇒뇓뇕"],["8781","뇖",5,"뇞뇠",7,"뇪뇫뇭뇮뇯뇱",7,"뇺뇼뇾",5,"눆눇눉눊눍",6,"눖눘눚",5,"눡",18,"눵",6,"눽",26,"뉙뉚뉛뉝뉞뉟뉡",6,"뉪",4],["8841","뉯",4,"뉶",5,"뉽",6,"늆늇늈늊",4],["8861","늏늒늓늕늖늗늛",4,"늢늤늧늨늩늫늭늮늯늱늲늳늵늶늷"],["8881","늸",15,"닊닋닍닎닏닑닓",4,"닚닜닞닟닠닡닣닧닩닪닰닱닲닶닼닽닾댂댃댅댆댇댉",6,"댒댖",5,"댝",54,"덗덙덚덝덠덡덢덣"],["8941","덦덨덪덬덭덯덲덳덵덶덷덹",6,"뎂뎆",5,"뎍"],["8961","뎎뎏뎑뎒뎓뎕",10,"뎢",5,"뎩뎪뎫뎭"],["8981","뎮",21,"돆돇돉돊돍돏돑돒돓돖돘돚돜돞돟돡돢돣돥돦돧돩",18,"돽",18,"됑",6,"됙됚됛됝됞됟됡",6,"됪됬",7,"됵",15],["8a41","둅",10,"둒둓둕둖둗둙",6,"둢둤둦"],["8a61","둧",4,"둭",18,"뒁뒂"],["8a81","뒃",4,"뒉",19,"뒞",5,"뒥뒦뒧뒩뒪뒫뒭",7,"뒶뒸뒺",5,"듁듂듃듅듆듇듉",6,"듑듒듓듔듖",5,"듞듟듡듢듥듧",4,"듮듰듲",5,"듹",26,"딖딗딙딚딝"],["8b41","딞",5,"딦딫",4,"딲딳딵딶딷딹",6,"땂땆"],["8b61","땇땈땉땊땎땏땑땒땓땕",6,"땞땢",8],["8b81","땫",52,"떢떣떥떦떧떩떬떭떮떯떲떶",4,"떾떿뗁뗂뗃뗅",6,"뗎뗒",5,"뗙",18,"뗭",18],["8c41","똀",15,"똒똓똕똖똗똙",4],["8c61","똞",6,"똦",5,"똭",6,"똵",5],["8c81","똻",12,"뙉",26,"뙥뙦뙧뙩",50,"뚞뚟뚡뚢뚣뚥",5,"뚭뚮뚯뚰뚲",16],["8d41","뛃",16,"뛕",8],["8d61","뛞",17,"뛱뛲뛳뛵뛶뛷뛹뛺"],["8d81","뛻",4,"뜂뜃뜄뜆",33,"뜪뜫뜭뜮뜱",6,"뜺뜼",7,"띅띆띇띉띊띋띍",6,"띖",9,"띡띢띣띥띦띧띩",6,"띲띴띶",5,"띾띿랁랂랃랅",6,"랎랓랔랕랚랛랝랞"],["8e41","랟랡",6,"랪랮",5,"랶랷랹",8],["8e61","럂",4,"럈럊",19],["8e81","럞",13,"럮럯럱럲럳럵",6,"럾렂",4,"렊렋렍렎렏렑",6,"렚렜렞",5,"렦렧렩렪렫렭",6,"렶렺",5,"롁롂롃롅",11,"롒롔",7,"롞롟롡롢롣롥",6,"롮롰롲",5,"롹롺롻롽",7],["8f41","뢅",7,"뢎",17],["8f61","뢠",7,"뢩",6,"뢱뢲뢳뢵뢶뢷뢹",4],["8f81","뢾뢿룂룄룆",5,"룍룎룏룑룒룓룕",7,"룞룠룢",5,"룪룫룭룮룯룱",6,"룺룼룾",5,"뤅",18,"뤙",6,"뤡",26,"뤾뤿륁륂륃륅",6,"륍륎륐륒",5],["9041","륚륛륝륞륟륡",6,"륪륬륮",5,"륶륷륹륺륻륽"],["9061","륾",5,"릆릈릋릌릏",15],["9081","릟",12,"릮릯릱릲릳릵",6,"릾맀맂",5,"맊맋맍맓",4,"맚맜맟맠맢맦맧맩맪맫맭",6,"맶맻",4,"먂",5,"먉",11,"먖",33,"먺먻먽먾먿멁멃멄멅멆"],["9141","멇멊멌멏멐멑멒멖멗멙멚멛멝",6,"멦멪",5],["9161","멲멳멵멶멷멹",9,"몆몈몉몊몋몍",5],["9181","몓",20,"몪몭몮몯몱몳",4,"몺몼몾",5,"뫅뫆뫇뫉",14,"뫚",33,"뫽뫾뫿묁묂묃묅",7,"묎묐묒",5,"묙묚묛묝묞묟묡",6],["9241","묨묪묬",7,"묷묹묺묿",4,"뭆뭈뭊뭋뭌뭎뭑뭒"],["9261","뭓뭕뭖뭗뭙",7,"뭢뭤",7,"뭭",4],["9281","뭲",21,"뮉뮊뮋뮍뮎뮏뮑",18,"뮥뮦뮧뮩뮪뮫뮭",6,"뮵뮶뮸",7,"믁믂믃믅믆믇믉",6,"믑믒믔",35,"믺믻믽믾밁"],["9341","밃",4,"밊밎밐밒밓밙밚밠밡밢밣밦밨밪밫밬밮밯밲밳밵"],["9361","밶밷밹",6,"뱂뱆뱇뱈뱊뱋뱎뱏뱑",8],["9381","뱚뱛뱜뱞",37,"벆벇벉벊벍벏",4,"벖벘벛",4,"벢벣벥벦벩",6,"벲벶",5,"벾벿볁볂볃볅",7,"볎볒볓볔볖볗볙볚볛볝",22,"볷볹볺볻볽"],["9441","볾",5,"봆봈봊",5,"봑봒봓봕",8],["9461","봞",5,"봥",6,"봭",12],["9481","봺",5,"뵁",6,"뵊뵋뵍뵎뵏뵑",6,"뵚",9,"뵥뵦뵧뵩",22,"붂붃붅붆붋",4,"붒붔붖붗붘붛붝",6,"붥",10,"붱",6,"붹",24],["9541","뷒뷓뷖뷗뷙뷚뷛뷝",11,"뷪",5,"뷱"],["9561","뷲뷳뷵뷶뷷뷹",6,"븁븂븄븆",5,"븎븏븑븒븓"],["9581","븕",6,"븞븠",35,"빆빇빉빊빋빍빏",4,"빖빘빜빝빞빟빢빣빥빦빧빩빫",4,"빲빶",4,"빾빿뺁뺂뺃뺅",6,"뺎뺒",5,"뺚",13,"뺩",14],["9641","뺸",23,"뻒뻓"],["9661","뻕뻖뻙",6,"뻡뻢뻦",5,"뻭",8],["9681","뻶",10,"뼂",5,"뼊",13,"뼚뼞",33,"뽂뽃뽅뽆뽇뽉",6,"뽒뽓뽔뽖",44],["9741","뾃",16,"뾕",8],["9761","뾞",17,"뾱",7],["9781","뾹",11,"뿆",5,"뿎뿏뿑뿒뿓뿕",6,"뿝뿞뿠뿢",89,"쀽쀾쀿"],["9841","쁀",16,"쁒",5,"쁙쁚쁛"],["9861","쁝쁞쁟쁡",6,"쁪",15],["9881","쁺",21,"삒삓삕삖삗삙",6,"삢삤삦",5,"삮삱삲삷",4,"삾샂샃샄샆샇샊샋샍샎샏샑",6,"샚샞",5,"샦샧샩샪샫샭",6,"샶샸샺",5,"섁섂섃섅섆섇섉",6,"섑섒섓섔섖",5,"섡섢섥섨섩섪섫섮"],["9941","섲섳섴섵섷섺섻섽섾섿셁",6,"셊셎",5,"셖셗"],["9961","셙셚셛셝",6,"셦셪",5,"셱셲셳셵셶셷셹셺셻"],["9981","셼",8,"솆",5,"솏솑솒솓솕솗",4,"솞솠솢솣솤솦솧솪솫솭솮솯솱",11,"솾",5,"쇅쇆쇇쇉쇊쇋쇍",6,"쇕쇖쇙",6,"쇡쇢쇣쇥쇦쇧쇩",6,"쇲쇴",7,"쇾쇿숁숂숃숅",6,"숎숐숒",5,"숚숛숝숞숡숢숣"],["9a41","숤숥숦숧숪숬숮숰숳숵",16],["9a61","쉆쉇쉉",6,"쉒쉓쉕쉖쉗쉙",6,"쉡쉢쉣쉤쉦"],["9a81","쉧",4,"쉮쉯쉱쉲쉳쉵",6,"쉾슀슂",5,"슊",5,"슑",6,"슙슚슜슞",5,"슦슧슩슪슫슮",5,"슶슸슺",33,"싞싟싡싢싥",5,"싮싰싲싳싴싵싷싺싽싾싿쌁",6,"쌊쌋쌎쌏"],["9b41","쌐쌑쌒쌖쌗쌙쌚쌛쌝",6,"쌦쌧쌪",8],["9b61","쌳",17,"썆",7],["9b81","썎",25,"썪썫썭썮썯썱썳",4,"썺썻썾",5,"쎅쎆쎇쎉쎊쎋쎍",50,"쏁",22,"쏚"],["9c41","쏛쏝쏞쏡쏣",4,"쏪쏫쏬쏮",5,"쏶쏷쏹",5],["9c61","쏿",8,"쐉",6,"쐑",9],["9c81","쐛",8,"쐥",6,"쐭쐮쐯쐱쐲쐳쐵",6,"쐾",9,"쑉",26,"쑦쑧쑩쑪쑫쑭",6,"쑶쑷쑸쑺",5,"쒁",18,"쒕",6,"쒝",12],["9d41","쒪",13,"쒹쒺쒻쒽",8],["9d61","쓆",25],["9d81","쓠",8,"쓪",5,"쓲쓳쓵쓶쓷쓹쓻쓼쓽쓾씂",9,"씍씎씏씑씒씓씕",6,"씝",10,"씪씫씭씮씯씱",6,"씺씼씾",5,"앆앇앋앏앐앑앒앖앚앛앜앟앢앣앥앦앧앩",6,"앲앶",5,"앾앿얁얂얃얅얆얈얉얊얋얎얐얒얓얔"],["9e41","얖얙얚얛얝얞얟얡",7,"얪",9,"얶"],["9e61","얷얺얿",4,"엋엍엏엒엓엕엖엗엙",6,"엢엤엦엧"],["9e81","엨엩엪엫엯엱엲엳엵엸엹엺엻옂옃옄옉옊옋옍옎옏옑",6,"옚옝",6,"옦옧옩옪옫옯옱옲옶옸옺옼옽옾옿왂왃왅왆왇왉",6,"왒왖",5,"왞왟왡",10,"왭왮왰왲",5,"왺왻왽왾왿욁",6,"욊욌욎",5,"욖욗욙욚욛욝",6,"욦"],["9f41","욨욪",5,"욲욳욵욶욷욻",4,"웂웄웆",5,"웎"],["9f61","웏웑웒웓웕",6,"웞웟웢",5,"웪웫웭웮웯웱웲"],["9f81","웳",4,"웺웻웼웾",5,"윆윇윉윊윋윍",6,"윖윘윚",5,"윢윣윥윦윧윩",6,"윲윴윶윸윹윺윻윾윿읁읂읃읅",4,"읋읎읐읙읚읛읝읞읟읡",6,"읩읪읬",7,"읶읷읹읺읻읿잀잁잂잆잋잌잍잏잒잓잕잙잛",4,"잢잧",4,"잮잯잱잲잳잵잶잷"],["a041","잸잹잺잻잾쟂",5,"쟊쟋쟍쟏쟑",6,"쟙쟚쟛쟜"],["a061","쟞",5,"쟥쟦쟧쟩쟪쟫쟭",13],["a081","쟻",4,"젂젃젅젆젇젉젋",4,"젒젔젗",4,"젞젟젡젢젣젥",6,"젮젰젲",5,"젹젺젻젽젾젿졁",6,"졊졋졎",5,"졕",26,"졲졳졵졶졷졹졻",4,"좂좄좈좉좊좎",5,"좕",7,"좞좠좢좣좤"],["a141","좥좦좧좩",18,"좾좿죀죁"],["a161","죂죃죅죆죇죉죊죋죍",6,"죖죘죚",5,"죢죣죥"],["a181","죦",14,"죶",5,"죾죿줁줂줃줇",4,"줎　、。·‥…¨〃­―∥＼∼‘’“”〔〕〈",9,"±×÷≠≤≥∞∴°′″℃Å￠￡￥♂♀∠⊥⌒∂∇≡≒§※☆★○●◎◇◆□■△▲▽▼→←↑↓↔〓≪≫√∽∝∵∫∬∈∋⊆⊇⊂⊃∪∩∧∨￢"],["a241","줐줒",5,"줙",18],["a261","줭",6,"줵",18],["a281","쥈",7,"쥒쥓쥕쥖쥗쥙",6,"쥢쥤",7,"쥭쥮쥯⇒⇔∀∃´～ˇ˘˝˚˙¸˛¡¿ː∮∑∏¤℉‰◁◀▷▶♤♠♡♥♧♣⊙◈▣◐◑▒▤▥▨▧▦▩♨☏☎☜☞¶†‡↕↗↙↖↘♭♩♪♬㉿㈜№㏇™㏂㏘℡€®"],["a341","쥱쥲쥳쥵",6,"쥽",10,"즊즋즍즎즏"],["a361","즑",6,"즚즜즞",16],["a381","즯",16,"짂짃짅짆짉짋",4,"짒짔짗짘짛！",58,"￦］",32,"￣"],["a441","짞짟짡짣짥짦짨짩짪짫짮짲",5,"짺짻짽짾짿쨁쨂쨃쨄"],["a461","쨅쨆쨇쨊쨎",5,"쨕쨖쨗쨙",12],["a481","쨦쨧쨨쨪",28,"ㄱ",93],["a541","쩇",4,"쩎쩏쩑쩒쩓쩕",6,"쩞쩢",5,"쩩쩪"],["a561","쩫",17,"쩾",5,"쪅쪆"],["a581","쪇",16,"쪙",14,"ⅰ",9],["a5b0","Ⅰ",9],["a5c1","Α",16,"Σ",6],["a5e1","α",16,"σ",6],["a641","쪨",19,"쪾쪿쫁쫂쫃쫅"],["a661","쫆",5,"쫎쫐쫒쫔쫕쫖쫗쫚",5,"쫡",6],["a681","쫨쫩쫪쫫쫭",6,"쫵",18,"쬉쬊─│┌┐┘└├┬┤┴┼━┃┏┓┛┗┣┳┫┻╋┠┯┨┷┿┝┰┥┸╂┒┑┚┙┖┕┎┍┞┟┡┢┦┧┩┪┭┮┱┲┵┶┹┺┽┾╀╁╃",7],["a741","쬋",4,"쬑쬒쬓쬕쬖쬗쬙",6,"쬢",7],["a761","쬪",22,"쭂쭃쭄"],["a781","쭅쭆쭇쭊쭋쭍쭎쭏쭑",6,"쭚쭛쭜쭞",5,"쭥",7,"㎕㎖㎗ℓ㎘㏄㎣㎤㎥㎦㎙",9,"㏊㎍㎎㎏㏏㎈㎉㏈㎧㎨㎰",9,"㎀",4,"㎺",5,"㎐",4,"Ω㏀㏁㎊㎋㎌㏖㏅㎭㎮㎯㏛㎩㎪㎫㎬㏝㏐㏓㏃㏉㏜㏆"],["a841","쭭",10,"쭺",14],["a861","쮉",18,"쮝",6],["a881","쮤",19,"쮹",11,"ÆÐªĦ"],["a8a6","Ĳ"],["a8a8","ĿŁØŒºÞŦŊ"],["a8b1","㉠",27,"ⓐ",25,"①",14,"½⅓⅔¼¾⅛⅜⅝⅞"],["a941","쯅",14,"쯕",10],["a961","쯠쯡쯢쯣쯥쯦쯨쯪",18],["a981","쯽",14,"찎찏찑찒찓찕",6,"찞찟찠찣찤æđðħıĳĸŀłøœßþŧŋŉ㈀",27,"⒜",25,"⑴",14,"¹²³⁴ⁿ₁₂₃₄"],["aa41","찥찦찪찫찭찯찱",6,"찺찿",4,"챆챇챉챊챋챍챎"],["aa61","챏",4,"챖챚",5,"챡챢챣챥챧챩",6,"챱챲"],["aa81","챳챴챶",29,"ぁ",82],["ab41","첔첕첖첗첚첛첝첞첟첡",6,"첪첮",5,"첶첷첹"],["ab61","첺첻첽",6,"쳆쳈쳊",5,"쳑쳒쳓쳕",5],["ab81","쳛",8,"쳥",6,"쳭쳮쳯쳱",12,"ァ",85],["ac41","쳾쳿촀촂",5,"촊촋촍촎촏촑",6,"촚촜촞촟촠"],["ac61","촡촢촣촥촦촧촩촪촫촭",11,"촺",4],["ac81","촿",28,"쵝쵞쵟А",5,"ЁЖ",25],["acd1","а",5,"ёж",25],["ad41","쵡쵢쵣쵥",6,"쵮쵰쵲",5,"쵹",7],["ad61","춁",6,"춉",10,"춖춗춙춚춛춝춞춟"],["ad81","춠춡춢춣춦춨춪",5,"춱",18,"췅"],["ae41","췆",5,"췍췎췏췑",16],["ae61","췢",5,"췩췪췫췭췮췯췱",6,"췺췼췾",4],["ae81","츃츅츆츇츉츊츋츍",6,"츕츖츗츘츚",5,"츢츣츥츦츧츩츪츫"],["af41","츬츭츮츯츲츴츶",19],["af61","칊",13,"칚칛칝칞칢",5,"칪칬"],["af81","칮",5,"칶칷칹칺칻칽",6,"캆캈캊",5,"캒캓캕캖캗캙"],["b041","캚",5,"캢캦",5,"캮",12],["b061","캻",5,"컂",19],["b081","컖",13,"컦컧컩컪컭",6,"컶컺",5,"가각간갇갈갉갊감",7,"같",4,"갠갤갬갭갯갰갱갸갹갼걀걋걍걔걘걜거걱건걷걸걺검겁것겄겅겆겉겊겋게겐겔겜겝겟겠겡겨격겪견겯결겸겹겻겼경곁계곈곌곕곗고곡곤곧골곪곬곯곰곱곳공곶과곽관괄괆"],["b141","켂켃켅켆켇켉",6,"켒켔켖",5,"켝켞켟켡켢켣"],["b161","켥",6,"켮켲",5,"켹",11],["b181","콅",14,"콖콗콙콚콛콝",6,"콦콨콪콫콬괌괍괏광괘괜괠괩괬괭괴괵괸괼굄굅굇굉교굔굘굡굣구국군굳굴굵굶굻굼굽굿궁궂궈궉권궐궜궝궤궷귀귁귄귈귐귑귓규균귤그극근귿글긁금급긋긍긔기긱긴긷길긺김깁깃깅깆깊까깍깎깐깔깖깜깝깟깠깡깥깨깩깬깰깸"],["b241","콭콮콯콲콳콵콶콷콹",6,"쾁쾂쾃쾄쾆",5,"쾍"],["b261","쾎",18,"쾢",5,"쾩"],["b281","쾪",5,"쾱",18,"쿅",6,"깹깻깼깽꺄꺅꺌꺼꺽꺾껀껄껌껍껏껐껑께껙껜껨껫껭껴껸껼꼇꼈꼍꼐꼬꼭꼰꼲꼴꼼꼽꼿꽁꽂꽃꽈꽉꽐꽜꽝꽤꽥꽹꾀꾄꾈꾐꾑꾕꾜꾸꾹꾼꿀꿇꿈꿉꿋꿍꿎꿔꿜꿨꿩꿰꿱꿴꿸뀀뀁뀄뀌뀐뀔뀜뀝뀨끄끅끈끊끌끎끓끔끕끗끙"],["b341","쿌",19,"쿢쿣쿥쿦쿧쿩"],["b361","쿪",5,"쿲쿴쿶",5,"쿽쿾쿿퀁퀂퀃퀅",5],["b381","퀋",5,"퀒",5,"퀙",19,"끝끼끽낀낄낌낍낏낑나낙낚난낟날낡낢남납낫",4,"낱낳내낵낸낼냄냅냇냈냉냐냑냔냘냠냥너넉넋넌널넒넓넘넙넛넜넝넣네넥넨넬넴넵넷넸넹녀녁년녈념녑녔녕녘녜녠노녹논놀놂놈놉놋농높놓놔놘놜놨뇌뇐뇔뇜뇝"],["b441","퀮",5,"퀶퀷퀹퀺퀻퀽",6,"큆큈큊",5],["b461","큑큒큓큕큖큗큙",6,"큡",10,"큮큯"],["b481","큱큲큳큵",6,"큾큿킀킂",18,"뇟뇨뇩뇬뇰뇹뇻뇽누눅눈눋눌눔눕눗눙눠눴눼뉘뉜뉠뉨뉩뉴뉵뉼늄늅늉느늑는늘늙늚늠늡늣능늦늪늬늰늴니닉닌닐닒님닙닛닝닢다닥닦단닫",4,"닳담답닷",4,"닿대댁댄댈댐댑댓댔댕댜더덕덖던덛덜덞덟덤덥"],["b541","킕",14,"킦킧킩킪킫킭",5],["b561","킳킶킸킺",5,"탂탃탅탆탇탊",5,"탒탖",4],["b581","탛탞탟탡탢탣탥",6,"탮탲",5,"탹",11,"덧덩덫덮데덱덴델뎀뎁뎃뎄뎅뎌뎐뎔뎠뎡뎨뎬도독돈돋돌돎돐돔돕돗동돛돝돠돤돨돼됐되된될됨됩됫됴두둑둔둘둠둡둣둥둬뒀뒈뒝뒤뒨뒬뒵뒷뒹듀듄듈듐듕드득든듣들듦듬듭듯등듸디딕딘딛딜딤딥딧딨딩딪따딱딴딸"],["b641","턅",7,"턎",17],["b661","턠",15,"턲턳턵턶턷턹턻턼턽턾"],["b681","턿텂텆",5,"텎텏텑텒텓텕",6,"텞텠텢",5,"텩텪텫텭땀땁땃땄땅땋때땍땐땔땜땝땟땠땡떠떡떤떨떪떫떰떱떳떴떵떻떼떽뗀뗄뗌뗍뗏뗐뗑뗘뗬또똑똔똘똥똬똴뙈뙤뙨뚜뚝뚠뚤뚫뚬뚱뛔뛰뛴뛸뜀뜁뜅뜨뜩뜬뜯뜰뜸뜹뜻띄띈띌띔띕띠띤띨띰띱띳띵라락란랄람랍랏랐랑랒랖랗"],["b741","텮",13,"텽",6,"톅톆톇톉톊"],["b761","톋",20,"톢톣톥톦톧"],["b781","톩",6,"톲톴톶톷톸톹톻톽톾톿퇁",14,"래랙랜랠램랩랫랬랭랴략랸럇량러럭런럴럼럽럿렀렁렇레렉렌렐렘렙렛렝려력련렬렴렵렷렸령례롄롑롓로록론롤롬롭롯롱롸롼뢍뢨뢰뢴뢸룀룁룃룅료룐룔룝룟룡루룩룬룰룸룹룻룽뤄뤘뤠뤼뤽륀륄륌륏륑류륙륜률륨륩"],["b841","퇐",7,"퇙",17],["b861","퇫",8,"퇵퇶퇷퇹",13],["b881","툈툊",5,"툑",24,"륫륭르륵른를름릅릇릉릊릍릎리릭린릴림립릿링마막만많",4,"맘맙맛망맞맡맣매맥맨맬맴맵맷맸맹맺먀먁먈먕머먹먼멀멂멈멉멋멍멎멓메멕멘멜멤멥멧멨멩며멱면멸몃몄명몇몌모목몫몬몰몲몸몹못몽뫄뫈뫘뫙뫼"],["b941","툪툫툮툯툱툲툳툵",6,"툾퉀퉂",5,"퉉퉊퉋퉌"],["b961","퉍",14,"퉝",6,"퉥퉦퉧퉨"],["b981","퉩",22,"튂튃튅튆튇튉튊튋튌묀묄묍묏묑묘묜묠묩묫무묵묶문묻물묽묾뭄뭅뭇뭉뭍뭏뭐뭔뭘뭡뭣뭬뮈뮌뮐뮤뮨뮬뮴뮷므믄믈믐믓미믹민믿밀밂밈밉밋밌밍및밑바",4,"받",4,"밤밥밧방밭배백밴밸뱀뱁뱃뱄뱅뱉뱌뱍뱐뱝버벅번벋벌벎범법벗"],["ba41","튍튎튏튒튓튔튖",5,"튝튞튟튡튢튣튥",6,"튭"],["ba61","튮튯튰튲",5,"튺튻튽튾틁틃",4,"틊틌",5],["ba81","틒틓틕틖틗틙틚틛틝",6,"틦",9,"틲틳틵틶틷틹틺벙벚베벡벤벧벨벰벱벳벴벵벼벽변별볍볏볐병볕볘볜보복볶본볼봄봅봇봉봐봔봤봬뵀뵈뵉뵌뵐뵘뵙뵤뵨부북분붇불붉붊붐붑붓붕붙붚붜붤붰붸뷔뷕뷘뷜뷩뷰뷴뷸븀븃븅브븍븐블븜븝븟비빅빈빌빎빔빕빗빙빚빛빠빡빤"],["bb41","틻",4,"팂팄팆",5,"팏팑팒팓팕팗",4,"팞팢팣"],["bb61","팤팦팧팪팫팭팮팯팱",6,"팺팾",5,"퍆퍇퍈퍉"],["bb81","퍊",31,"빨빪빰빱빳빴빵빻빼빽뺀뺄뺌뺍뺏뺐뺑뺘뺙뺨뻐뻑뻔뻗뻘뻠뻣뻤뻥뻬뼁뼈뼉뼘뼙뼛뼜뼝뽀뽁뽄뽈뽐뽑뽕뾔뾰뿅뿌뿍뿐뿔뿜뿟뿡쀼쁑쁘쁜쁠쁨쁩삐삑삔삘삠삡삣삥사삭삯산삳살삵삶삼삽삿샀상샅새색샌샐샘샙샛샜생샤"],["bc41","퍪",17,"퍾퍿펁펂펃펅펆펇"],["bc61","펈펉펊펋펎펒",5,"펚펛펝펞펟펡",6,"펪펬펮"],["bc81","펯",4,"펵펶펷펹펺펻펽",6,"폆폇폊",5,"폑",5,"샥샨샬샴샵샷샹섀섄섈섐섕서",4,"섣설섦섧섬섭섯섰성섶세섹센셀셈셉셋셌셍셔셕션셜셤셥셧셨셩셰셴셸솅소속솎손솔솖솜솝솟송솥솨솩솬솰솽쇄쇈쇌쇔쇗쇘쇠쇤쇨쇰쇱쇳쇼쇽숀숄숌숍숏숑수숙순숟술숨숩숫숭"],["bd41","폗폙",7,"폢폤",7,"폮폯폱폲폳폵폶폷"],["bd61","폸폹폺폻폾퐀퐂",5,"퐉",13],["bd81","퐗",5,"퐞",25,"숯숱숲숴쉈쉐쉑쉔쉘쉠쉥쉬쉭쉰쉴쉼쉽쉿슁슈슉슐슘슛슝스슥슨슬슭슴습슷승시식신싣실싫심십싯싱싶싸싹싻싼쌀쌈쌉쌌쌍쌓쌔쌕쌘쌜쌤쌥쌨쌩썅써썩썬썰썲썸썹썼썽쎄쎈쎌쏀쏘쏙쏜쏟쏠쏢쏨쏩쏭쏴쏵쏸쐈쐐쐤쐬쐰"],["be41","퐸",7,"푁푂푃푅",14],["be61","푔",7,"푝푞푟푡푢푣푥",7,"푮푰푱푲"],["be81","푳",4,"푺푻푽푾풁풃",4,"풊풌풎",5,"풕",8,"쐴쐼쐽쑈쑤쑥쑨쑬쑴쑵쑹쒀쒔쒜쒸쒼쓩쓰쓱쓴쓸쓺쓿씀씁씌씐씔씜씨씩씬씰씸씹씻씽아악안앉않알앍앎앓암압앗았앙앝앞애액앤앨앰앱앳앴앵야약얀얄얇얌얍얏양얕얗얘얜얠얩어억언얹얻얼얽얾엄",6,"엌엎"],["bf41","풞",10,"풪",14],["bf61","풹",18,"퓍퓎퓏퓑퓒퓓퓕"],["bf81","퓖",5,"퓝퓞퓠",7,"퓩퓪퓫퓭퓮퓯퓱",6,"퓹퓺퓼에엑엔엘엠엡엣엥여역엮연열엶엷염",5,"옅옆옇예옌옐옘옙옛옜오옥온올옭옮옰옳옴옵옷옹옻와왁완왈왐왑왓왔왕왜왝왠왬왯왱외왹왼욀욈욉욋욍요욕욘욜욤욥욧용우욱운울욹욺움웁웃웅워웍원월웜웝웠웡웨"],["c041","퓾",5,"픅픆픇픉픊픋픍",6,"픖픘",5],["c061","픞",25],["c081","픸픹픺픻픾픿핁핂핃핅",6,"핎핐핒",5,"핚핛핝핞핟핡핢핣웩웬웰웸웹웽위윅윈윌윔윕윗윙유육윤율윰윱윳융윷으윽은을읊음읍읏응",7,"읜읠읨읫이익인일읽읾잃임입잇있잉잊잎자작잔잖잗잘잚잠잡잣잤장잦재잭잰잴잼잽잿쟀쟁쟈쟉쟌쟎쟐쟘쟝쟤쟨쟬저적전절젊"],["c141","핤핦핧핪핬핮",5,"핶핷핹핺핻핽",6,"햆햊햋"],["c161","햌햍햎햏햑",19,"햦햧"],["c181","햨",31,"점접젓정젖제젝젠젤젬젭젯젱져젼졀졈졉졌졍졔조족존졸졺좀좁좃종좆좇좋좌좍좔좝좟좡좨좼좽죄죈죌죔죕죗죙죠죡죤죵주죽준줄줅줆줌줍줏중줘줬줴쥐쥑쥔쥘쥠쥡쥣쥬쥰쥴쥼즈즉즌즐즘즙즛증지직진짇질짊짐집짓"],["c241","헊헋헍헎헏헑헓",4,"헚헜헞",5,"헦헧헩헪헫헭헮"],["c261","헯",4,"헶헸헺",5,"혂혃혅혆혇혉",6,"혒"],["c281","혖",5,"혝혞혟혡혢혣혥",7,"혮",9,"혺혻징짖짙짚짜짝짠짢짤짧짬짭짯짰짱째짹짼쨀쨈쨉쨋쨌쨍쨔쨘쨩쩌쩍쩐쩔쩜쩝쩟쩠쩡쩨쩽쪄쪘쪼쪽쫀쫄쫌쫍쫏쫑쫓쫘쫙쫠쫬쫴쬈쬐쬔쬘쬠쬡쭁쭈쭉쭌쭐쭘쭙쭝쭤쭸쭹쮜쮸쯔쯤쯧쯩찌찍찐찔찜찝찡찢찧차착찬찮찰참찹찻"],["c341","혽혾혿홁홂홃홄홆홇홊홌홎홏홐홒홓홖홗홙홚홛홝",4],["c361","홢",4,"홨홪",5,"홲홳홵",11],["c381","횁횂횄횆",5,"횎횏횑횒횓횕",7,"횞횠횢",5,"횩횪찼창찾채책챈챌챔챕챗챘챙챠챤챦챨챰챵처척천철첨첩첫첬청체첵첸첼쳄쳅쳇쳉쳐쳔쳤쳬쳰촁초촉촌촐촘촙촛총촤촨촬촹최쵠쵤쵬쵭쵯쵱쵸춈추축춘출춤춥춧충춰췄췌췐취췬췰췸췹췻췽츄츈츌츔츙츠측츤츨츰츱츳층"],["c441","횫횭횮횯횱",7,"횺횼",7,"훆훇훉훊훋"],["c461","훍훎훏훐훒훓훕훖훘훚",5,"훡훢훣훥훦훧훩",4],["c481","훮훯훱훲훳훴훶",5,"훾훿휁휂휃휅",11,"휒휓휔치칙친칟칠칡침칩칫칭카칵칸칼캄캅캇캉캐캑캔캘캠캡캣캤캥캬캭컁커컥컨컫컬컴컵컷컸컹케켁켄켈켐켑켓켕켜켠켤켬켭켯켰켱켸코콕콘콜콤콥콧콩콰콱콴콸쾀쾅쾌쾡쾨쾰쿄쿠쿡쿤쿨쿰쿱쿳쿵쿼퀀퀄퀑퀘퀭퀴퀵퀸퀼"],["c541","휕휖휗휚휛휝휞휟휡",6,"휪휬휮",5,"휶휷휹"],["c561","휺휻휽",6,"흅흆흈흊",5,"흒흓흕흚",4],["c581","흟흢흤흦흧흨흪흫흭흮흯흱흲흳흵",6,"흾흿힀힂",5,"힊힋큄큅큇큉큐큔큘큠크큭큰클큼큽킁키킥킨킬킴킵킷킹타탁탄탈탉탐탑탓탔탕태택탠탤탬탭탯탰탱탸턍터턱턴털턺텀텁텃텄텅테텍텐텔템텝텟텡텨텬텼톄톈토톡톤톨톰톱톳통톺톼퇀퇘퇴퇸툇툉툐투툭툰툴툼툽툿퉁퉈퉜"],["c641","힍힎힏힑",6,"힚힜힞",5],["c6a1","퉤튀튁튄튈튐튑튕튜튠튤튬튱트특튼튿틀틂틈틉틋틔틘틜틤틥티틱틴틸팀팁팃팅파팍팎판팔팖팜팝팟팠팡팥패팩팬팰팸팹팻팼팽퍄퍅퍼퍽펀펄펌펍펏펐펑페펙펜펠펨펩펫펭펴편펼폄폅폈평폐폘폡폣포폭폰폴폼폽폿퐁"],["c7a1","퐈퐝푀푄표푠푤푭푯푸푹푼푿풀풂품풉풋풍풔풩퓌퓐퓔퓜퓟퓨퓬퓰퓸퓻퓽프픈플픔픕픗피픽핀필핌핍핏핑하학한할핥함합핫항해핵핸핼햄햅햇했행햐향허헉헌헐헒험헙헛헝헤헥헨헬헴헵헷헹혀혁현혈혐협혓혔형혜혠"],["c8a1","혤혭호혹혼홀홅홈홉홋홍홑화확환활홧황홰홱홴횃횅회획횐횔횝횟횡효횬횰횹횻후훅훈훌훑훔훗훙훠훤훨훰훵훼훽휀휄휑휘휙휜휠휨휩휫휭휴휵휸휼흄흇흉흐흑흔흖흗흘흙흠흡흣흥흩희흰흴흼흽힁히힉힌힐힘힙힛힝"],["caa1","伽佳假價加可呵哥嘉嫁家暇架枷柯歌珂痂稼苛茄街袈訶賈跏軻迦駕刻却各恪慤殼珏脚覺角閣侃刊墾奸姦干幹懇揀杆柬桿澗癎看磵稈竿簡肝艮艱諫間乫喝曷渴碣竭葛褐蝎鞨勘坎堪嵌感憾戡敢柑橄減甘疳監瞰紺邯鑑鑒龕"],["cba1","匣岬甲胛鉀閘剛堈姜岡崗康强彊慷江畺疆糠絳綱羌腔舡薑襁講鋼降鱇介价個凱塏愷愾慨改槪漑疥皆盖箇芥蓋豈鎧開喀客坑更粳羹醵倨去居巨拒据據擧渠炬祛距踞車遽鉅鋸乾件健巾建愆楗腱虔蹇鍵騫乞傑杰桀儉劍劒檢"],["cca1","瞼鈐黔劫怯迲偈憩揭擊格檄激膈覡隔堅牽犬甄絹繭肩見譴遣鵑抉決潔結缺訣兼慊箝謙鉗鎌京俓倞傾儆勁勍卿坰境庚徑慶憬擎敬景暻更梗涇炅烱璟璥瓊痙硬磬竟競絅經耕耿脛莖警輕逕鏡頃頸驚鯨係啓堺契季屆悸戒桂械"],["cda1","棨溪界癸磎稽系繫繼計誡谿階鷄古叩告呱固姑孤尻庫拷攷故敲暠枯槁沽痼皐睾稿羔考股膏苦苽菰藁蠱袴誥賈辜錮雇顧高鼓哭斛曲梏穀谷鵠困坤崑昆梱棍滾琨袞鯤汨滑骨供公共功孔工恐恭拱控攻珙空蚣貢鞏串寡戈果瓜"],["cea1","科菓誇課跨過鍋顆廓槨藿郭串冠官寬慣棺款灌琯瓘管罐菅觀貫關館刮恝括适侊光匡壙廣曠洸炚狂珖筐胱鑛卦掛罫乖傀塊壞怪愧拐槐魁宏紘肱轟交僑咬喬嬌嶠巧攪敎校橋狡皎矯絞翹膠蕎蛟較轎郊餃驕鮫丘久九仇俱具勾"],["cfa1","區口句咎嘔坵垢寇嶇廐懼拘救枸柩構歐毆毬求溝灸狗玖球瞿矩究絿耉臼舅舊苟衢謳購軀逑邱鉤銶駒驅鳩鷗龜國局菊鞠鞫麴君窘群裙軍郡堀屈掘窟宮弓穹窮芎躬倦券勸卷圈拳捲權淃眷厥獗蕨蹶闕机櫃潰詭軌饋句晷歸貴"],["d0a1","鬼龜叫圭奎揆槻珪硅窺竅糾葵規赳逵閨勻均畇筠菌鈞龜橘克剋劇戟棘極隙僅劤勤懃斤根槿瑾筋芹菫覲謹近饉契今妗擒昑檎琴禁禽芩衾衿襟金錦伋及急扱汲級給亘兢矜肯企伎其冀嗜器圻基埼夔奇妓寄岐崎己幾忌技旗旣"],["d1a1","朞期杞棋棄機欺氣汽沂淇玘琦琪璂璣畸畿碁磯祁祇祈祺箕紀綺羈耆耭肌記譏豈起錡錤飢饑騎騏驥麒緊佶吉拮桔金喫儺喇奈娜懦懶拏拿癩",5,"那樂",4,"諾酪駱亂卵暖欄煖爛蘭難鸞捏捺南嵐枏楠湳濫男藍襤拉"],["d2a1","納臘蠟衲囊娘廊",4,"乃來內奈柰耐冷女年撚秊念恬拈捻寧寗努勞奴弩怒擄櫓爐瑙盧",5,"駑魯",10,"濃籠聾膿農惱牢磊腦賂雷尿壘",7,"嫩訥杻紐勒",5,"能菱陵尼泥匿溺多茶"],["d3a1","丹亶但單團壇彖斷旦檀段湍短端簞緞蛋袒鄲鍛撻澾獺疸達啖坍憺擔曇淡湛潭澹痰聃膽蕁覃談譚錟沓畓答踏遝唐堂塘幢戇撞棠當糖螳黨代垈坮大對岱帶待戴擡玳臺袋貸隊黛宅德悳倒刀到圖堵塗導屠島嶋度徒悼挑掉搗桃"],["d4a1","棹櫂淘渡滔濤燾盜睹禱稻萄覩賭跳蹈逃途道都鍍陶韜毒瀆牘犢獨督禿篤纛讀墩惇敦旽暾沌焞燉豚頓乭突仝冬凍動同憧東桐棟洞潼疼瞳童胴董銅兜斗杜枓痘竇荳讀豆逗頭屯臀芚遁遯鈍得嶝橙燈登等藤謄鄧騰喇懶拏癩羅"],["d5a1","蘿螺裸邏樂洛烙珞絡落諾酪駱丹亂卵欄欒瀾爛蘭鸞剌辣嵐擥攬欖濫籃纜藍襤覽拉臘蠟廊朗浪狼琅瑯螂郞來崍徠萊冷掠略亮倆兩凉梁樑粮粱糧良諒輛量侶儷勵呂廬慮戾旅櫚濾礪藜蠣閭驢驪麗黎力曆歷瀝礫轢靂憐戀攣漣"],["d6a1","煉璉練聯蓮輦連鍊冽列劣洌烈裂廉斂殮濂簾獵令伶囹寧岺嶺怜玲笭羚翎聆逞鈴零靈領齡例澧禮醴隷勞怒撈擄櫓潞瀘爐盧老蘆虜路輅露魯鷺鹵碌祿綠菉錄鹿麓論壟弄朧瀧瓏籠聾儡瀨牢磊賂賚賴雷了僚寮廖料燎療瞭聊蓼"],["d7a1","遼鬧龍壘婁屢樓淚漏瘻累縷蔞褸鏤陋劉旒柳榴流溜瀏琉瑠留瘤硫謬類六戮陸侖倫崙淪綸輪律慄栗率隆勒肋凜凌楞稜綾菱陵俚利厘吏唎履悧李梨浬犁狸理璃異痢籬罹羸莉裏裡里釐離鯉吝潾燐璘藺躪隣鱗麟林淋琳臨霖砬"],["d8a1","立笠粒摩瑪痲碼磨馬魔麻寞幕漠膜莫邈万卍娩巒彎慢挽晩曼滿漫灣瞞萬蔓蠻輓饅鰻唜抹末沫茉襪靺亡妄忘忙望網罔芒茫莽輞邙埋妹媒寐昧枚梅每煤罵買賣邁魅脈貊陌驀麥孟氓猛盲盟萌冪覓免冕勉棉沔眄眠綿緬面麵滅"],["d9a1","蔑冥名命明暝椧溟皿瞑茗蓂螟酩銘鳴袂侮冒募姆帽慕摸摹暮某模母毛牟牡瑁眸矛耗芼茅謀謨貌木沐牧目睦穆鶩歿沒夢朦蒙卯墓妙廟描昴杳渺猫竗苗錨務巫憮懋戊拇撫无楙武毋無珷畝繆舞茂蕪誣貿霧鵡墨默們刎吻問文"],["daa1","汶紊紋聞蚊門雯勿沕物味媚尾嵋彌微未梶楣渼湄眉米美薇謎迷靡黴岷悶愍憫敏旻旼民泯玟珉緡閔密蜜謐剝博拍搏撲朴樸泊珀璞箔粕縛膊舶薄迫雹駁伴半反叛拌搬攀斑槃泮潘班畔瘢盤盼磐磻礬絆般蟠返頒飯勃拔撥渤潑"],["dba1","發跋醱鉢髮魃倣傍坊妨尨幇彷房放方旁昉枋榜滂磅紡肪膀舫芳蒡蚌訪謗邦防龐倍俳北培徘拜排杯湃焙盃背胚裴裵褙賠輩配陪伯佰帛柏栢白百魄幡樊煩燔番磻繁蕃藩飜伐筏罰閥凡帆梵氾汎泛犯範范法琺僻劈壁擘檗璧癖"],["dca1","碧蘗闢霹便卞弁變辨辯邊別瞥鱉鼈丙倂兵屛幷昞昺柄棅炳甁病秉竝輧餠騈保堡報寶普步洑湺潽珤甫菩補褓譜輔伏僕匐卜宓復服福腹茯蔔複覆輹輻馥鰒本乶俸奉封峯峰捧棒烽熢琫縫蓬蜂逢鋒鳳不付俯傅剖副否咐埠夫婦"],["dda1","孚孵富府復扶敷斧浮溥父符簿缶腐腑膚艀芙莩訃負賦賻赴趺部釜阜附駙鳧北分吩噴墳奔奮忿憤扮昐汾焚盆粉糞紛芬賁雰不佛弗彿拂崩朋棚硼繃鵬丕備匕匪卑妃婢庇悲憊扉批斐枇榧比毖毗毘沸泌琵痺砒碑秕秘粃緋翡肥"],["dea1","脾臂菲蜚裨誹譬費鄙非飛鼻嚬嬪彬斌檳殯浜濱瀕牝玭貧賓頻憑氷聘騁乍事些仕伺似使俟僿史司唆嗣四士奢娑寫寺射巳師徙思捨斜斯柶査梭死沙泗渣瀉獅砂社祀祠私篩紗絲肆舍莎蓑蛇裟詐詞謝賜赦辭邪飼駟麝削數朔索"],["dfa1","傘刪山散汕珊産疝算蒜酸霰乷撒殺煞薩三參杉森渗芟蔘衫揷澁鈒颯上傷像償商喪嘗孀尙峠常床庠廂想桑橡湘爽牀狀相祥箱翔裳觴詳象賞霜塞璽賽嗇塞穡索色牲生甥省笙墅壻嶼序庶徐恕抒捿敍暑曙書栖棲犀瑞筮絮緖署"],["e0a1","胥舒薯西誓逝鋤黍鼠夕奭席惜昔晳析汐淅潟石碩蓆釋錫仙僊先善嬋宣扇敾旋渲煽琁瑄璇璿癬禪線繕羨腺膳船蘚蟬詵跣選銑鐥饍鮮卨屑楔泄洩渫舌薛褻設說雪齧剡暹殲纖蟾贍閃陝攝涉燮葉城姓宬性惺成星晟猩珹盛省筬"],["e1a1","聖聲腥誠醒世勢歲洗稅笹細說貰召嘯塑宵小少巢所掃搔昭梳沼消溯瀟炤燒甦疏疎瘙笑篠簫素紹蔬蕭蘇訴逍遡邵銷韶騷俗屬束涑粟續謖贖速孫巽損蓀遜飡率宋悚松淞訟誦送頌刷殺灑碎鎖衰釗修受嗽囚垂壽嫂守岫峀帥愁"],["e2a1","戍手授搜收數樹殊水洙漱燧狩獸琇璲瘦睡秀穗竪粹綏綬繡羞脩茱蒐蓚藪袖誰讐輸遂邃酬銖銹隋隧隨雖需須首髓鬚叔塾夙孰宿淑潚熟琡璹肅菽巡徇循恂旬栒楯橓殉洵淳珣盾瞬筍純脣舜荀蓴蕣詢諄醇錞順馴戌術述鉥崇崧"],["e3a1","嵩瑟膝蝨濕拾習褶襲丞乘僧勝升承昇繩蠅陞侍匙嘶始媤尸屎屍市弑恃施是時枾柴猜矢示翅蒔蓍視試詩諡豕豺埴寔式息拭植殖湜熄篒蝕識軾食飾伸侁信呻娠宸愼新晨燼申神紳腎臣莘薪藎蜃訊身辛辰迅失室實悉審尋心沁"],["e4a1","沈深瀋甚芯諶什十拾雙氏亞俄兒啞娥峨我牙芽莪蛾衙訝阿雅餓鴉鵝堊岳嶽幄惡愕握樂渥鄂鍔顎鰐齷安岸按晏案眼雁鞍顔鮟斡謁軋閼唵岩巖庵暗癌菴闇壓押狎鴨仰央怏昻殃秧鴦厓哀埃崖愛曖涯碍艾隘靄厄扼掖液縊腋額"],["e5a1","櫻罌鶯鸚也倻冶夜惹揶椰爺耶若野弱掠略約若葯蒻藥躍亮佯兩凉壤孃恙揚攘敭暘梁楊樣洋瀁煬痒瘍禳穰糧羊良襄諒讓釀陽量養圄御於漁瘀禦語馭魚齬億憶抑檍臆偃堰彦焉言諺孼蘖俺儼嚴奄掩淹嶪業円予余勵呂女如廬"],["e6a1","旅歟汝濾璵礖礪與艅茹輿轝閭餘驪麗黎亦力域役易曆歷疫繹譯轢逆驛嚥堧姸娟宴年延憐戀捐挻撚椽沇沿涎涓淵演漣烟然煙煉燃燕璉硏硯秊筵緣練縯聯衍軟輦蓮連鉛鍊鳶列劣咽悅涅烈熱裂說閱厭廉念捻染殮炎焰琰艶苒"],["e7a1","簾閻髥鹽曄獵燁葉令囹塋寧嶺嶸影怜映暎楹榮永泳渶潁濚瀛瀯煐營獰玲瑛瑩瓔盈穎纓羚聆英詠迎鈴鍈零霙靈領乂倪例刈叡曳汭濊猊睿穢芮藝蘂禮裔詣譽豫醴銳隸霓預五伍俉傲午吾吳嗚塢墺奧娛寤悟惡懊敖旿晤梧汚澳"],["e8a1","烏熬獒筽蜈誤鰲鼇屋沃獄玉鈺溫瑥瘟穩縕蘊兀壅擁瓮甕癰翁邕雍饔渦瓦窩窪臥蛙蝸訛婉完宛梡椀浣玩琓琬碗緩翫脘腕莞豌阮頑曰往旺枉汪王倭娃歪矮外嵬巍猥畏了僚僥凹堯夭妖姚寥寮尿嶢拗搖撓擾料曜樂橈燎燿瑤療"],["e9a1","窈窯繇繞耀腰蓼蟯要謠遙遼邀饒慾欲浴縟褥辱俑傭冗勇埇墉容庸慂榕涌湧溶熔瑢用甬聳茸蓉踊鎔鏞龍于佑偶優又友右宇寓尤愚憂旴牛玗瑀盂祐禑禹紆羽芋藕虞迂遇郵釪隅雨雩勖彧旭昱栯煜稶郁頊云暈橒殞澐熉耘芸蕓"],["eaa1","運隕雲韻蔚鬱亐熊雄元原員圓園垣媛嫄寃怨愿援沅洹湲源爰猿瑗苑袁轅遠阮院願鴛月越鉞位偉僞危圍委威尉慰暐渭爲瑋緯胃萎葦蔿蝟衛褘謂違韋魏乳侑儒兪劉唯喩孺宥幼幽庾悠惟愈愉揄攸有杻柔柚柳楡楢油洧流游溜"],["eba1","濡猶猷琉瑜由留癒硫紐維臾萸裕誘諛諭踰蹂遊逾遺酉釉鍮類六堉戮毓肉育陸倫允奫尹崙淪潤玧胤贇輪鈗閏律慄栗率聿戎瀜絨融隆垠恩慇殷誾銀隱乙吟淫蔭陰音飮揖泣邑凝應膺鷹依倚儀宜意懿擬椅毅疑矣義艤薏蟻衣誼"],["eca1","議醫二以伊利吏夷姨履已弛彛怡易李梨泥爾珥理異痍痢移罹而耳肄苡荑裏裡貽貳邇里離飴餌匿溺瀷益翊翌翼謚人仁刃印吝咽因姻寅引忍湮燐璘絪茵藺蚓認隣靭靷鱗麟一佚佾壹日溢逸鎰馹任壬妊姙恁林淋稔臨荏賃入卄"],["eda1","立笠粒仍剩孕芿仔刺咨姉姿子字孜恣慈滋炙煮玆瓷疵磁紫者自茨蔗藉諮資雌作勺嚼斫昨灼炸爵綽芍酌雀鵲孱棧殘潺盞岑暫潛箴簪蠶雜丈仗匠場墻壯奬將帳庄張掌暲杖樟檣欌漿牆狀獐璋章粧腸臟臧莊葬蔣薔藏裝贓醬長"],["eea1","障再哉在宰才材栽梓渽滓災縡裁財載齋齎爭箏諍錚佇低儲咀姐底抵杵楮樗沮渚狙猪疽箸紵苧菹著藷詛貯躇這邸雎齟勣吊嫡寂摘敵滴狄炙的積笛籍績翟荻謫賊赤跡蹟迪迹適鏑佃佺傳全典前剪塡塼奠專展廛悛戰栓殿氈澱"],["efa1","煎琠田甸畑癲筌箋箭篆纏詮輾轉鈿銓錢鐫電顚顫餞切截折浙癤竊節絶占岾店漸点粘霑鮎點接摺蝶丁井亭停偵呈姃定幀庭廷征情挺政整旌晶晸柾楨檉正汀淀淨渟湞瀞炡玎珽町睛碇禎程穽精綎艇訂諪貞鄭酊釘鉦鋌錠霆靖"],["f0a1","靜頂鼎制劑啼堤帝弟悌提梯濟祭第臍薺製諸蹄醍除際霽題齊俎兆凋助嘲弔彫措操早晁曺曹朝條棗槽漕潮照燥爪璪眺祖祚租稠窕粗糟組繰肇藻蚤詔調趙躁造遭釣阻雕鳥族簇足鏃存尊卒拙猝倧宗從悰慫棕淙琮種終綜縱腫"],["f1a1","踪踵鍾鐘佐坐左座挫罪主住侏做姝胄呪周嗾奏宙州廚晝朱柱株注洲湊澍炷珠疇籌紂紬綢舟蛛註誅走躊輳週酎酒鑄駐竹粥俊儁准埈寯峻晙樽浚準濬焌畯竣蠢逡遵雋駿茁中仲衆重卽櫛楫汁葺增憎曾拯烝甑症繒蒸證贈之只"],["f2a1","咫地址志持指摯支旨智枝枳止池沚漬知砥祉祗紙肢脂至芝芷蜘誌識贄趾遲直稙稷織職唇嗔塵振搢晉晋桭榛殄津溱珍瑨璡畛疹盡眞瞋秦縉縝臻蔯袗診賑軫辰進鎭陣陳震侄叱姪嫉帙桎瓆疾秩窒膣蛭質跌迭斟朕什執潗緝輯"],["f3a1","鏶集徵懲澄且侘借叉嗟嵯差次此磋箚茶蹉車遮捉搾着窄錯鑿齪撰澯燦璨瓚竄簒纂粲纘讚贊鑽餐饌刹察擦札紮僭參塹慘慙懺斬站讒讖倉倡創唱娼廠彰愴敞昌昶暢槍滄漲猖瘡窓脹艙菖蒼債埰寀寨彩採砦綵菜蔡采釵冊柵策"],["f4a1","責凄妻悽處倜刺剔尺慽戚拓擲斥滌瘠脊蹠陟隻仟千喘天川擅泉淺玔穿舛薦賤踐遷釧闡阡韆凸哲喆徹撤澈綴輟轍鐵僉尖沾添甛瞻簽籤詹諂堞妾帖捷牒疊睫諜貼輒廳晴淸聽菁請靑鯖切剃替涕滯締諦逮遞體初剿哨憔抄招梢"],["f5a1","椒楚樵炒焦硝礁礎秒稍肖艸苕草蕉貂超酢醋醮促囑燭矗蜀觸寸忖村邨叢塚寵悤憁摠總聰蔥銃撮催崔最墜抽推椎楸樞湫皺秋芻萩諏趨追鄒酋醜錐錘鎚雛騶鰍丑畜祝竺筑築縮蓄蹙蹴軸逐春椿瑃出朮黜充忠沖蟲衝衷悴膵萃"],["f6a1","贅取吹嘴娶就炊翠聚脆臭趣醉驟鷲側仄厠惻測層侈値嗤峙幟恥梔治淄熾痔痴癡稚穉緇緻置致蚩輜雉馳齒則勅飭親七柒漆侵寢枕沈浸琛砧針鍼蟄秤稱快他咤唾墮妥惰打拖朶楕舵陀馱駝倬卓啄坼度托拓擢晫柝濁濯琢琸託"],["f7a1","鐸呑嘆坦彈憚歎灘炭綻誕奪脫探眈耽貪塔搭榻宕帑湯糖蕩兌台太怠態殆汰泰笞胎苔跆邰颱宅擇澤撑攄兎吐土討慟桶洞痛筒統通堆槌腿褪退頹偸套妬投透鬪慝特闖坡婆巴把播擺杷波派爬琶破罷芭跛頗判坂板版瓣販辦鈑"],["f8a1","阪八叭捌佩唄悖敗沛浿牌狽稗覇貝彭澎烹膨愎便偏扁片篇編翩遍鞭騙貶坪平枰萍評吠嬖幣廢弊斃肺蔽閉陛佈包匍匏咆哺圃布怖抛抱捕暴泡浦疱砲胞脯苞葡蒲袍褒逋鋪飽鮑幅暴曝瀑爆輻俵剽彪慓杓標漂瓢票表豹飇飄驃"],["f9a1","品稟楓諷豊風馮彼披疲皮被避陂匹弼必泌珌畢疋筆苾馝乏逼下何厦夏廈昰河瑕荷蝦賀遐霞鰕壑學虐謔鶴寒恨悍旱汗漢澣瀚罕翰閑閒限韓割轄函含咸啣喊檻涵緘艦銜陷鹹合哈盒蛤閤闔陜亢伉姮嫦巷恒抗杭桁沆港缸肛航"],["faa1","行降項亥偕咳垓奚孩害懈楷海瀣蟹解該諧邂駭骸劾核倖幸杏荇行享向嚮珦鄕響餉饗香噓墟虛許憲櫶獻軒歇險驗奕爀赫革俔峴弦懸晛泫炫玄玹現眩睍絃絢縣舷衒見賢鉉顯孑穴血頁嫌俠協夾峽挾浹狹脅脇莢鋏頰亨兄刑型"],["fba1","形泂滎瀅灐炯熒珩瑩荊螢衡逈邢鎣馨兮彗惠慧暳蕙蹊醯鞋乎互呼壕壺好岵弧戶扈昊晧毫浩淏湖滸澔濠濩灝狐琥瑚瓠皓祜糊縞胡芦葫蒿虎號蝴護豪鎬頀顥惑或酷婚昏混渾琿魂忽惚笏哄弘汞泓洪烘紅虹訌鴻化和嬅樺火畵"],["fca1","禍禾花華話譁貨靴廓擴攫確碻穫丸喚奐宦幻患換歡晥桓渙煥環紈還驩鰥活滑猾豁闊凰幌徨恍惶愰慌晃晄榥況湟滉潢煌璜皇篁簧荒蝗遑隍黃匯回廻徊恢悔懷晦會檜淮澮灰獪繪膾茴蛔誨賄劃獲宖橫鐄哮嚆孝效斅曉梟涍淆"],["fda1","爻肴酵驍侯候厚后吼喉嗅帿後朽煦珝逅勛勳塤壎焄熏燻薰訓暈薨喧暄煊萱卉喙毁彙徽揮暉煇諱輝麾休携烋畦虧恤譎鷸兇凶匈洶胸黑昕欣炘痕吃屹紇訖欠欽歆吸恰洽翕興僖凞喜噫囍姬嬉希憙憘戱晞曦熙熹熺犧禧稀羲詰"]]')},4284:function(A){"use strict";A.exports=JSON.parse('[["0","\\u0000",127],["a140","　，、。．‧；：？！︰…‥﹐﹑﹒·﹔﹕﹖﹗｜–︱—︳╴︴﹏（）︵︶｛｝︷︸〔〕︹︺【】︻︼《》︽︾〈〉︿﹀「」﹁﹂『』﹃﹄﹙﹚"],["a1a1","﹛﹜﹝﹞‘’“”〝〞‵′＃＆＊※§〃○●△▲◎☆★◇◆□■▽▼㊣℅¯￣＿ˍ﹉﹊﹍﹎﹋﹌﹟﹠﹡＋－×÷±√＜＞＝≦≧≠∞≒≡﹢",4,"～∩∪⊥∠∟⊿㏒㏑∫∮∵∴♀♂⊕⊙↑↓←→↖↗↙↘∥∣／"],["a240","＼∕﹨＄￥〒￠￡％＠℃℉﹩﹪﹫㏕㎜㎝㎞㏎㎡㎎㎏㏄°兙兛兞兝兡兣嗧瓩糎▁",7,"▏▎▍▌▋▊▉┼┴┬┤├▔─│▕┌┐└┘╭"],["a2a1","╮╰╯═╞╪╡◢◣◥◤╱╲╳０",9,"Ⅰ",9,"〡",8,"十卄卅Ａ",25,"ａ",21],["a340","ｗｘｙｚΑ",16,"Σ",6,"α",16,"σ",6,"ㄅ",10],["a3a1","ㄐ",25,"˙ˉˊˇˋ"],["a3e1","€"],["a440","一乙丁七乃九了二人儿入八几刀刁力匕十卜又三下丈上丫丸凡久么也乞于亡兀刃勺千叉口土士夕大女子孑孓寸小尢尸山川工己已巳巾干廾弋弓才"],["a4a1","丑丐不中丰丹之尹予云井互五亢仁什仃仆仇仍今介仄元允內六兮公冗凶分切刈勻勾勿化匹午升卅卞厄友及反壬天夫太夭孔少尤尺屯巴幻廿弔引心戈戶手扎支文斗斤方日曰月木欠止歹毋比毛氏水火爪父爻片牙牛犬王丙"],["a540","世丕且丘主乍乏乎以付仔仕他仗代令仙仞充兄冉冊冬凹出凸刊加功包匆北匝仟半卉卡占卯卮去可古右召叮叩叨叼司叵叫另只史叱台句叭叻四囚外"],["a5a1","央失奴奶孕它尼巨巧左市布平幼弁弘弗必戊打扔扒扑斥旦朮本未末札正母民氐永汁汀氾犯玄玉瓜瓦甘生用甩田由甲申疋白皮皿目矛矢石示禾穴立丞丟乒乓乩亙交亦亥仿伉伙伊伕伍伐休伏仲件任仰仳份企伋光兇兆先全"],["a640","共再冰列刑划刎刖劣匈匡匠印危吉吏同吊吐吁吋各向名合吃后吆吒因回囝圳地在圭圬圯圩夙多夷夸妄奸妃好她如妁字存宇守宅安寺尖屹州帆并年"],["a6a1","式弛忙忖戎戌戍成扣扛托收早旨旬旭曲曳有朽朴朱朵次此死氖汝汗汙江池汐汕污汛汍汎灰牟牝百竹米糸缶羊羽老考而耒耳聿肉肋肌臣自至臼舌舛舟艮色艾虫血行衣西阡串亨位住佇佗佞伴佛何估佐佑伽伺伸佃佔似但佣"],["a740","作你伯低伶余佝佈佚兌克免兵冶冷別判利刪刨劫助努劬匣即卵吝吭吞吾否呎吧呆呃吳呈呂君吩告吹吻吸吮吵吶吠吼呀吱含吟听囪困囤囫坊坑址坍"],["a7a1","均坎圾坐坏圻壯夾妝妒妨妞妣妙妖妍妤妓妊妥孝孜孚孛完宋宏尬局屁尿尾岐岑岔岌巫希序庇床廷弄弟彤形彷役忘忌志忍忱快忸忪戒我抄抗抖技扶抉扭把扼找批扳抒扯折扮投抓抑抆改攻攸旱更束李杏材村杜杖杞杉杆杠"],["a840","杓杗步每求汞沙沁沈沉沅沛汪決沐汰沌汨沖沒汽沃汲汾汴沆汶沍沔沘沂灶灼災灸牢牡牠狄狂玖甬甫男甸皂盯矣私秀禿究系罕肖肓肝肘肛肚育良芒"],["a8a1","芋芍見角言谷豆豕貝赤走足身車辛辰迂迆迅迄巡邑邢邪邦那酉釆里防阮阱阪阬並乖乳事些亞享京佯依侍佳使佬供例來侃佰併侈佩佻侖佾侏侑佺兔兒兕兩具其典冽函刻券刷刺到刮制剁劾劻卒協卓卑卦卷卸卹取叔受味呵"],["a940","咖呸咕咀呻呷咄咒咆呼咐呱呶和咚呢周咋命咎固垃坷坪坩坡坦坤坼夜奉奇奈奄奔妾妻委妹妮姑姆姐姍始姓姊妯妳姒姅孟孤季宗定官宜宙宛尚屈居"],["a9a1","屆岷岡岸岩岫岱岳帘帚帖帕帛帑幸庚店府底庖延弦弧弩往征彿彼忝忠忽念忿怏怔怯怵怖怪怕怡性怩怫怛或戕房戾所承拉拌拄抿拂抹拒招披拓拔拋拈抨抽押拐拙拇拍抵拚抱拘拖拗拆抬拎放斧於旺昔易昌昆昂明昀昏昕昊"],["aa40","昇服朋杭枋枕東果杳杷枇枝林杯杰板枉松析杵枚枓杼杪杲欣武歧歿氓氛泣注泳沱泌泥河沽沾沼波沫法泓沸泄油況沮泗泅泱沿治泡泛泊沬泯泜泖泠"],["aaa1","炕炎炒炊炙爬爭爸版牧物狀狎狙狗狐玩玨玟玫玥甽疝疙疚的盂盲直知矽社祀祁秉秈空穹竺糾罔羌羋者肺肥肢肱股肫肩肴肪肯臥臾舍芳芝芙芭芽芟芹花芬芥芯芸芣芰芾芷虎虱初表軋迎返近邵邸邱邶采金長門阜陀阿阻附"],["ab40","陂隹雨青非亟亭亮信侵侯便俠俑俏保促侶俘俟俊俗侮俐俄係俚俎俞侷兗冒冑冠剎剃削前剌剋則勇勉勃勁匍南卻厚叛咬哀咨哎哉咸咦咳哇哂咽咪品"],["aba1","哄哈咯咫咱咻咩咧咿囿垂型垠垣垢城垮垓奕契奏奎奐姜姘姿姣姨娃姥姪姚姦威姻孩宣宦室客宥封屎屏屍屋峙峒巷帝帥帟幽庠度建弈弭彥很待徊律徇後徉怒思怠急怎怨恍恰恨恢恆恃恬恫恪恤扁拜挖按拼拭持拮拽指拱拷"],["ac40","拯括拾拴挑挂政故斫施既春昭映昧是星昨昱昤曷柿染柱柔某柬架枯柵柩柯柄柑枴柚查枸柏柞柳枰柙柢柝柒歪殃殆段毒毗氟泉洋洲洪流津洌洱洞洗"],["aca1","活洽派洶洛泵洹洧洸洩洮洵洎洫炫為炳炬炯炭炸炮炤爰牲牯牴狩狠狡玷珊玻玲珍珀玳甚甭畏界畎畋疫疤疥疢疣癸皆皇皈盈盆盃盅省盹相眉看盾盼眇矜砂研砌砍祆祉祈祇禹禺科秒秋穿突竿竽籽紂紅紀紉紇約紆缸美羿耄"],["ad40","耐耍耑耶胖胥胚胃胄背胡胛胎胞胤胝致舢苧范茅苣苛苦茄若茂茉苒苗英茁苜苔苑苞苓苟苯茆虐虹虻虺衍衫要觔計訂訃貞負赴赳趴軍軌述迦迢迪迥"],["ada1","迭迫迤迨郊郎郁郃酋酊重閂限陋陌降面革韋韭音頁風飛食首香乘亳倌倍倣俯倦倥俸倩倖倆值借倚倒們俺倀倔倨俱倡個候倘俳修倭倪俾倫倉兼冤冥冢凍凌准凋剖剜剔剛剝匪卿原厝叟哨唐唁唷哼哥哲唆哺唔哩哭員唉哮哪"],["ae40","哦唧唇哽唏圃圄埂埔埋埃堉夏套奘奚娑娘娜娟娛娓姬娠娣娩娥娌娉孫屘宰害家宴宮宵容宸射屑展屐峭峽峻峪峨峰島崁峴差席師庫庭座弱徒徑徐恙"],["aea1","恣恥恐恕恭恩息悄悟悚悍悔悌悅悖扇拳挈拿捎挾振捕捂捆捏捉挺捐挽挪挫挨捍捌效敉料旁旅時晉晏晃晒晌晅晁書朔朕朗校核案框桓根桂桔栩梳栗桌桑栽柴桐桀格桃株桅栓栘桁殊殉殷氣氧氨氦氤泰浪涕消涇浦浸海浙涓"],["af40","浬涉浮浚浴浩涌涊浹涅浥涔烊烘烤烙烈烏爹特狼狹狽狸狷玆班琉珮珠珪珞畔畝畜畚留疾病症疲疳疽疼疹痂疸皋皰益盍盎眩真眠眨矩砰砧砸砝破砷"],["afa1","砥砭砠砟砲祕祐祠祟祖神祝祗祚秤秣秧租秦秩秘窄窈站笆笑粉紡紗紋紊素索純紐紕級紜納紙紛缺罟羔翅翁耆耘耕耙耗耽耿胱脂胰脅胭胴脆胸胳脈能脊胼胯臭臬舀舐航舫舨般芻茫荒荔荊茸荐草茵茴荏茲茹茶茗荀茱茨荃"],["b040","虔蚊蚪蚓蚤蚩蚌蚣蚜衰衷袁袂衽衹記訐討訌訕訊託訓訖訏訑豈豺豹財貢起躬軒軔軏辱送逆迷退迺迴逃追逅迸邕郡郝郢酒配酌釘針釗釜釙閃院陣陡"],["b0a1","陛陝除陘陞隻飢馬骨高鬥鬲鬼乾偺偽停假偃偌做偉健偶偎偕偵側偷偏倏偯偭兜冕凰剪副勒務勘動匐匏匙匿區匾參曼商啪啦啄啞啡啃啊唱啖問啕唯啤唸售啜唬啣唳啁啗圈國圉域堅堊堆埠埤基堂堵執培夠奢娶婁婉婦婪婀"],["b140","娼婢婚婆婊孰寇寅寄寂宿密尉專將屠屜屝崇崆崎崛崖崢崑崩崔崙崤崧崗巢常帶帳帷康庸庶庵庾張強彗彬彩彫得徙從徘御徠徜恿患悉悠您惋悴惦悽"],["b1a1","情悻悵惜悼惘惕惆惟悸惚惇戚戛扈掠控捲掖探接捷捧掘措捱掩掉掃掛捫推掄授掙採掬排掏掀捻捩捨捺敝敖救教敗啟敏敘敕敔斜斛斬族旋旌旎晝晚晤晨晦晞曹勗望梁梯梢梓梵桿桶梱梧梗械梃棄梭梆梅梔條梨梟梡梂欲殺"],["b240","毫毬氫涎涼淳淙液淡淌淤添淺清淇淋涯淑涮淞淹涸混淵淅淒渚涵淚淫淘淪深淮淨淆淄涪淬涿淦烹焉焊烽烯爽牽犁猜猛猖猓猙率琅琊球理現琍瓠瓶"],["b2a1","瓷甜產略畦畢異疏痔痕疵痊痍皎盔盒盛眷眾眼眶眸眺硫硃硎祥票祭移窒窕笠笨笛第符笙笞笮粒粗粕絆絃統紮紹紼絀細紳組累終紲紱缽羞羚翌翎習耜聊聆脯脖脣脫脩脰脤舂舵舷舶船莎莞莘荸莢莖莽莫莒莊莓莉莠荷荻荼"],["b340","莆莧處彪蛇蛀蚶蛄蚵蛆蛋蚱蚯蛉術袞袈被袒袖袍袋覓規訪訝訣訥許設訟訛訢豉豚販責貫貨貪貧赧赦趾趺軛軟這逍通逗連速逝逐逕逞造透逢逖逛途"],["b3a1","部郭都酗野釵釦釣釧釭釩閉陪陵陳陸陰陴陶陷陬雀雪雩章竟頂頃魚鳥鹵鹿麥麻傢傍傅備傑傀傖傘傚最凱割剴創剩勞勝勛博厥啻喀喧啼喊喝喘喂喜喪喔喇喋喃喳單喟唾喲喚喻喬喱啾喉喫喙圍堯堪場堤堰報堡堝堠壹壺奠"],["b440","婷媚婿媒媛媧孳孱寒富寓寐尊尋就嵌嵐崴嵇巽幅帽幀幃幾廊廁廂廄弼彭復循徨惑惡悲悶惠愜愣惺愕惰惻惴慨惱愎惶愉愀愒戟扉掣掌描揀揩揉揆揍"],["b4a1","插揣提握揖揭揮捶援揪換摒揚揹敞敦敢散斑斐斯普晰晴晶景暑智晾晷曾替期朝棺棕棠棘棗椅棟棵森棧棹棒棲棣棋棍植椒椎棉棚楮棻款欺欽殘殖殼毯氮氯氬港游湔渡渲湧湊渠渥渣減湛湘渤湖湮渭渦湯渴湍渺測湃渝渾滋"],["b540","溉渙湎湣湄湲湩湟焙焚焦焰無然煮焜牌犄犀猶猥猴猩琺琪琳琢琥琵琶琴琯琛琦琨甥甦畫番痢痛痣痙痘痞痠登發皖皓皴盜睏短硝硬硯稍稈程稅稀窘"],["b5a1","窗窖童竣等策筆筐筒答筍筋筏筑粟粥絞結絨絕紫絮絲絡給絢絰絳善翔翕耋聒肅腕腔腋腑腎脹腆脾腌腓腴舒舜菩萃菸萍菠菅萋菁華菱菴著萊菰萌菌菽菲菊萸萎萄菜萇菔菟虛蛟蛙蛭蛔蛛蛤蛐蛞街裁裂袱覃視註詠評詞証詁"],["b640","詔詛詐詆訴診訶詖象貂貯貼貳貽賁費賀貴買貶貿貸越超趁跎距跋跚跑跌跛跆軻軸軼辜逮逵週逸進逶鄂郵鄉郾酣酥量鈔鈕鈣鈉鈞鈍鈐鈇鈑閔閏開閑"],["b6a1","間閒閎隊階隋陽隅隆隍陲隄雁雅雄集雇雯雲韌項順須飧飪飯飩飲飭馮馭黃黍黑亂傭債傲傳僅傾催傷傻傯僇剿剷剽募勦勤勢勣匯嗟嗨嗓嗦嗎嗜嗇嗑嗣嗤嗯嗚嗡嗅嗆嗥嗉園圓塞塑塘塗塚塔填塌塭塊塢塒塋奧嫁嫉嫌媾媽媼"],["b740","媳嫂媲嵩嵯幌幹廉廈弒彙徬微愚意慈感想愛惹愁愈慎慌慄慍愾愴愧愍愆愷戡戢搓搾搞搪搭搽搬搏搜搔損搶搖搗搆敬斟新暗暉暇暈暖暄暘暍會榔業"],["b7a1","楚楷楠楔極椰概楊楨楫楞楓楹榆楝楣楛歇歲毀殿毓毽溢溯滓溶滂源溝滇滅溥溘溼溺溫滑準溜滄滔溪溧溴煎煙煩煤煉照煜煬煦煌煥煞煆煨煖爺牒猷獅猿猾瑯瑚瑕瑟瑞瑁琿瑙瑛瑜當畸瘀痰瘁痲痱痺痿痴痳盞盟睛睫睦睞督"],["b840","睹睪睬睜睥睨睢矮碎碰碗碘碌碉硼碑碓硿祺祿禁萬禽稜稚稠稔稟稞窟窠筷節筠筮筧粱粳粵經絹綑綁綏絛置罩罪署義羨群聖聘肆肄腱腰腸腥腮腳腫"],["b8a1","腹腺腦舅艇蒂葷落萱葵葦葫葉葬葛萼萵葡董葩葭葆虞虜號蛹蜓蜈蜇蜀蛾蛻蜂蜃蜆蜊衙裟裔裙補裘裝裡裊裕裒覜解詫該詳試詩詰誇詼詣誠話誅詭詢詮詬詹詻訾詨豢貊貉賊資賈賄貲賃賂賅跡跟跨路跳跺跪跤跦躲較載軾輊"],["b940","辟農運遊道遂達逼違遐遇遏過遍遑逾遁鄒鄗酬酪酩釉鈷鉗鈸鈽鉀鈾鉛鉋鉤鉑鈴鉉鉍鉅鈹鈿鉚閘隘隔隕雍雋雉雊雷電雹零靖靴靶預頑頓頊頒頌飼飴"],["b9a1","飽飾馳馱馴髡鳩麂鼎鼓鼠僧僮僥僖僭僚僕像僑僱僎僩兢凳劃劂匱厭嗾嘀嘛嘗嗽嘔嘆嘉嘍嘎嗷嘖嘟嘈嘐嗶團圖塵塾境墓墊塹墅塽壽夥夢夤奪奩嫡嫦嫩嫗嫖嫘嫣孵寞寧寡寥實寨寢寤察對屢嶄嶇幛幣幕幗幔廓廖弊彆彰徹慇"],["ba40","愿態慷慢慣慟慚慘慵截撇摘摔撤摸摟摺摑摧搴摭摻敲斡旗旖暢暨暝榜榨榕槁榮槓構榛榷榻榫榴槐槍榭槌榦槃榣歉歌氳漳演滾漓滴漩漾漠漬漏漂漢"],["baa1","滿滯漆漱漸漲漣漕漫漯澈漪滬漁滲滌滷熔熙煽熊熄熒爾犒犖獄獐瑤瑣瑪瑰瑭甄疑瘧瘍瘋瘉瘓盡監瞄睽睿睡磁碟碧碳碩碣禎福禍種稱窪窩竭端管箕箋筵算箝箔箏箸箇箄粹粽精綻綰綜綽綾綠緊綴網綱綺綢綿綵綸維緒緇綬"],["bb40","罰翠翡翟聞聚肇腐膀膏膈膊腿膂臧臺與舔舞艋蓉蒿蓆蓄蒙蒞蒲蒜蓋蒸蓀蓓蒐蒼蓑蓊蜿蜜蜻蜢蜥蜴蜘蝕蜷蜩裳褂裴裹裸製裨褚裯誦誌語誣認誡誓誤"],["bba1","說誥誨誘誑誚誧豪貍貌賓賑賒赫趙趕跼輔輒輕輓辣遠遘遜遣遙遞遢遝遛鄙鄘鄞酵酸酷酴鉸銀銅銘銖鉻銓銜銨鉼銑閡閨閩閣閥閤隙障際雌雒需靼鞅韶頗領颯颱餃餅餌餉駁骯骰髦魁魂鳴鳶鳳麼鼻齊億儀僻僵價儂儈儉儅凜"],["bc40","劇劈劉劍劊勰厲嘮嘻嘹嘲嘿嘴嘩噓噎噗噴嘶嘯嘰墀墟增墳墜墮墩墦奭嬉嫻嬋嫵嬌嬈寮寬審寫層履嶝嶔幢幟幡廢廚廟廝廣廠彈影德徵慶慧慮慝慕憂"],["bca1","慼慰慫慾憧憐憫憎憬憚憤憔憮戮摩摯摹撞撲撈撐撰撥撓撕撩撒撮播撫撚撬撙撢撳敵敷數暮暫暴暱樣樟槨樁樞標槽模樓樊槳樂樅槭樑歐歎殤毅毆漿潼澄潑潦潔澆潭潛潸潮澎潺潰潤澗潘滕潯潠潟熟熬熱熨牖犛獎獗瑩璋璃"],["bd40","瑾璀畿瘠瘩瘟瘤瘦瘡瘢皚皺盤瞎瞇瞌瞑瞋磋磅確磊碾磕碼磐稿稼穀稽稷稻窯窮箭箱範箴篆篇篁箠篌糊締練緯緻緘緬緝編緣線緞緩綞緙緲緹罵罷羯"],["bda1","翩耦膛膜膝膠膚膘蔗蔽蔚蓮蔬蔭蔓蔑蔣蔡蔔蓬蔥蓿蔆螂蝴蝶蝠蝦蝸蝨蝙蝗蝌蝓衛衝褐複褒褓褕褊誼諒談諄誕請諸課諉諂調誰論諍誶誹諛豌豎豬賠賞賦賤賬賭賢賣賜質賡赭趟趣踫踐踝踢踏踩踟踡踞躺輝輛輟輩輦輪輜輞"],["be40","輥適遮遨遭遷鄰鄭鄧鄱醇醉醋醃鋅銻銷鋪銬鋤鋁銳銼鋒鋇鋰銲閭閱霄霆震霉靠鞍鞋鞏頡頫頜颳養餓餒餘駝駐駟駛駑駕駒駙骷髮髯鬧魅魄魷魯鴆鴉"],["bea1","鴃麩麾黎墨齒儒儘儔儐儕冀冪凝劑劓勳噙噫噹噩噤噸噪器噥噱噯噬噢噶壁墾壇壅奮嬝嬴學寰導彊憲憑憩憊懍憶憾懊懈戰擅擁擋撻撼據擄擇擂操撿擒擔撾整曆曉暹曄曇暸樽樸樺橙橫橘樹橄橢橡橋橇樵機橈歙歷氅濂澱澡"],["bf40","濃澤濁澧澳激澹澶澦澠澴熾燉燐燒燈燕熹燎燙燜燃燄獨璜璣璘璟璞瓢甌甍瘴瘸瘺盧盥瞠瞞瞟瞥磨磚磬磧禦積穎穆穌穋窺篙簑築篤篛篡篩篦糕糖縊"],["bfa1","縑縈縛縣縞縝縉縐罹羲翰翱翮耨膳膩膨臻興艘艙蕊蕙蕈蕨蕩蕃蕉蕭蕪蕞螃螟螞螢融衡褪褲褥褫褡親覦諦諺諫諱謀諜諧諮諾謁謂諷諭諳諶諼豫豭貓賴蹄踱踴蹂踹踵輻輯輸輳辨辦遵遴選遲遼遺鄴醒錠錶鋸錳錯錢鋼錫錄錚"],["c040","錐錦錡錕錮錙閻隧隨險雕霎霑霖霍霓霏靛靜靦鞘頰頸頻頷頭頹頤餐館餞餛餡餚駭駢駱骸骼髻髭鬨鮑鴕鴣鴦鴨鴒鴛默黔龍龜優償儡儲勵嚎嚀嚐嚅嚇"],["c0a1","嚏壕壓壑壎嬰嬪嬤孺尷屨嶼嶺嶽嶸幫彌徽應懂懇懦懋戲戴擎擊擘擠擰擦擬擱擢擭斂斃曙曖檀檔檄檢檜櫛檣橾檗檐檠歜殮毚氈濘濱濟濠濛濤濫濯澀濬濡濩濕濮濰燧營燮燦燥燭燬燴燠爵牆獰獲璩環璦璨癆療癌盪瞳瞪瞰瞬"],["c140","瞧瞭矯磷磺磴磯礁禧禪穗窿簇簍篾篷簌篠糠糜糞糢糟糙糝縮績繆縷縲繃縫總縱繅繁縴縹繈縵縿縯罄翳翼聱聲聰聯聳臆臃膺臂臀膿膽臉膾臨舉艱薪"],["c1a1","薄蕾薜薑薔薯薛薇薨薊虧蟀蟑螳蟒蟆螫螻螺蟈蟋褻褶襄褸褽覬謎謗謙講謊謠謝謄謐豁谿豳賺賽購賸賻趨蹉蹋蹈蹊轄輾轂轅輿避遽還邁邂邀鄹醣醞醜鍍鎂錨鍵鍊鍥鍋錘鍾鍬鍛鍰鍚鍔闊闋闌闈闆隱隸雖霜霞鞠韓顆颶餵騁"],["c240","駿鮮鮫鮪鮭鴻鴿麋黏點黜黝黛鼾齋叢嚕嚮壙壘嬸彝懣戳擴擲擾攆擺擻擷斷曜朦檳檬櫃檻檸櫂檮檯歟歸殯瀉瀋濾瀆濺瀑瀏燻燼燾燸獷獵璧璿甕癖癘"],["c2a1","癒瞽瞿瞻瞼礎禮穡穢穠竄竅簫簧簪簞簣簡糧織繕繞繚繡繒繙罈翹翻職聶臍臏舊藏薩藍藐藉薰薺薹薦蟯蟬蟲蟠覆覲觴謨謹謬謫豐贅蹙蹣蹦蹤蹟蹕軀轉轍邇邃邈醫醬釐鎔鎊鎖鎢鎳鎮鎬鎰鎘鎚鎗闔闖闐闕離雜雙雛雞霤鞣鞦"],["c340","鞭韹額顏題顎顓颺餾餿餽餮馥騎髁鬃鬆魏魎魍鯊鯉鯽鯈鯀鵑鵝鵠黠鼕鼬儳嚥壞壟壢寵龐廬懲懷懶懵攀攏曠曝櫥櫝櫚櫓瀛瀟瀨瀚瀝瀕瀘爆爍牘犢獸"],["c3a1","獺璽瓊瓣疇疆癟癡矇礙禱穫穩簾簿簸簽簷籀繫繭繹繩繪羅繳羶羹羸臘藩藝藪藕藤藥藷蟻蠅蠍蟹蟾襠襟襖襞譁譜識證譚譎譏譆譙贈贊蹼蹲躇蹶蹬蹺蹴轔轎辭邊邋醱醮鏡鏑鏟鏃鏈鏜鏝鏖鏢鏍鏘鏤鏗鏨關隴難霪霧靡韜韻類"],["c440","願顛颼饅饉騖騙鬍鯨鯧鯖鯛鶉鵡鵲鵪鵬麒麗麓麴勸嚨嚷嚶嚴嚼壤孀孃孽寶巉懸懺攘攔攙曦朧櫬瀾瀰瀲爐獻瓏癢癥礦礪礬礫竇競籌籃籍糯糰辮繽繼"],["c4a1","纂罌耀臚艦藻藹蘑藺蘆蘋蘇蘊蠔蠕襤覺觸議譬警譯譟譫贏贍躉躁躅躂醴釋鐘鐃鏽闡霰飄饒饑馨騫騰騷騵鰓鰍鹹麵黨鼯齟齣齡儷儸囁囀囂夔屬巍懼懾攝攜斕曩櫻欄櫺殲灌爛犧瓖瓔癩矓籐纏續羼蘗蘭蘚蠣蠢蠡蠟襪襬覽譴"],["c540","護譽贓躊躍躋轟辯醺鐮鐳鐵鐺鐸鐲鐫闢霸霹露響顧顥饗驅驃驀騾髏魔魑鰭鰥鶯鶴鷂鶸麝黯鼙齜齦齧儼儻囈囊囉孿巔巒彎懿攤權歡灑灘玀瓤疊癮癬"],["c5a1","禳籠籟聾聽臟襲襯觼讀贖贗躑躓轡酈鑄鑑鑒霽霾韃韁顫饕驕驍髒鬚鱉鰱鰾鰻鷓鷗鼴齬齪龔囌巖戀攣攫攪曬欐瓚竊籤籣籥纓纖纔臢蘸蘿蠱變邐邏鑣鑠鑤靨顯饜驚驛驗髓體髑鱔鱗鱖鷥麟黴囑壩攬灞癱癲矗罐羈蠶蠹衢讓讒"],["c640","讖艷贛釀鑪靂靈靄韆顰驟鬢魘鱟鷹鷺鹼鹽鼇齷齲廳欖灣籬籮蠻觀躡釁鑲鑰顱饞髖鬣黌灤矚讚鑷韉驢驥纜讜躪釅鑽鑾鑼鱷鱸黷豔鑿鸚爨驪鬱鸛鸞籲"],["c940","乂乜凵匚厂万丌乇亍囗兀屮彳丏冇与丮亓仂仉仈冘勼卬厹圠夃夬尐巿旡殳毌气爿丱丼仨仜仩仡仝仚刌匜卌圢圣夗夯宁宄尒尻屴屳帄庀庂忉戉扐氕"],["c9a1","氶汃氿氻犮犰玊禸肊阞伎优伬仵伔仱伀价伈伝伂伅伢伓伄仴伒冱刓刉刐劦匢匟卍厊吇囡囟圮圪圴夼妀奼妅奻奾奷奿孖尕尥屼屺屻屾巟幵庄异弚彴忕忔忏扜扞扤扡扦扢扙扠扚扥旯旮朾朹朸朻机朿朼朳氘汆汒汜汏汊汔汋"],["ca40","汌灱牞犴犵玎甪癿穵网艸艼芀艽艿虍襾邙邗邘邛邔阢阤阠阣佖伻佢佉体佤伾佧佒佟佁佘伭伳伿佡冏冹刜刞刡劭劮匉卣卲厎厏吰吷吪呔呅吙吜吥吘"],["caa1","吽呏呁吨吤呇囮囧囥坁坅坌坉坋坒夆奀妦妘妠妗妎妢妐妏妧妡宎宒尨尪岍岏岈岋岉岒岊岆岓岕巠帊帎庋庉庌庈庍弅弝彸彶忒忑忐忭忨忮忳忡忤忣忺忯忷忻怀忴戺抃抌抎抏抔抇扱扻扺扰抁抈扷扽扲扴攷旰旴旳旲旵杅杇"],["cb40","杙杕杌杈杝杍杚杋毐氙氚汸汧汫沄沋沏汱汯汩沚汭沇沕沜汦汳汥汻沎灴灺牣犿犽狃狆狁犺狅玕玗玓玔玒町甹疔疕皁礽耴肕肙肐肒肜芐芏芅芎芑芓"],["cba1","芊芃芄豸迉辿邟邡邥邞邧邠阰阨阯阭丳侘佼侅佽侀侇佶佴侉侄佷佌侗佪侚佹侁佸侐侜侔侞侒侂侕佫佮冞冼冾刵刲刳剆刱劼匊匋匼厒厔咇呿咁咑咂咈呫呺呾呥呬呴呦咍呯呡呠咘呣呧呤囷囹坯坲坭坫坱坰坶垀坵坻坳坴坢"],["cc40","坨坽夌奅妵妺姏姎妲姌姁妶妼姃姖妱妽姀姈妴姇孢孥宓宕屄屇岮岤岠岵岯岨岬岟岣岭岢岪岧岝岥岶岰岦帗帔帙弨弢弣弤彔徂彾彽忞忥怭怦怙怲怋"],["cca1","怴怊怗怳怚怞怬怢怍怐怮怓怑怌怉怜戔戽抭抴拑抾抪抶拊抮抳抯抻抩抰抸攽斨斻昉旼昄昒昈旻昃昋昍昅旽昑昐曶朊枅杬枎枒杶杻枘枆构杴枍枌杺枟枑枙枃杽极杸杹枔欥殀歾毞氝沓泬泫泮泙沶泔沭泧沷泐泂沺泃泆泭泲"],["cd40","泒泝沴沊沝沀泞泀洰泍泇沰泹泏泩泑炔炘炅炓炆炄炑炖炂炚炃牪狖狋狘狉狜狒狔狚狌狑玤玡玭玦玢玠玬玝瓝瓨甿畀甾疌疘皯盳盱盰盵矸矼矹矻矺"],["cda1","矷祂礿秅穸穻竻籵糽耵肏肮肣肸肵肭舠芠苀芫芚芘芛芵芧芮芼芞芺芴芨芡芩苂芤苃芶芢虰虯虭虮豖迒迋迓迍迖迕迗邲邴邯邳邰阹阽阼阺陃俍俅俓侲俉俋俁俔俜俙侻侳俛俇俖侺俀侹俬剄剉勀勂匽卼厗厖厙厘咺咡咭咥哏"],["ce40","哃茍咷咮哖咶哅哆咠呰咼咢咾呲哞咰垵垞垟垤垌垗垝垛垔垘垏垙垥垚垕壴复奓姡姞姮娀姱姝姺姽姼姶姤姲姷姛姩姳姵姠姾姴姭宨屌峐峘峌峗峋峛"],["cea1","峞峚峉峇峊峖峓峔峏峈峆峎峟峸巹帡帢帣帠帤庰庤庢庛庣庥弇弮彖徆怷怹恔恲恞恅恓恇恉恛恌恀恂恟怤恄恘恦恮扂扃拏挍挋拵挎挃拫拹挏挌拸拶挀挓挔拺挕拻拰敁敃斪斿昶昡昲昵昜昦昢昳昫昺昝昴昹昮朏朐柁柲柈枺"],["cf40","柜枻柸柘柀枷柅柫柤柟枵柍枳柷柶柮柣柂枹柎柧柰枲柼柆柭柌枮柦柛柺柉柊柃柪柋欨殂殄殶毖毘毠氠氡洨洴洭洟洼洿洒洊泚洳洄洙洺洚洑洀洝浂"],["cfa1","洁洘洷洃洏浀洇洠洬洈洢洉洐炷炟炾炱炰炡炴炵炩牁牉牊牬牰牳牮狊狤狨狫狟狪狦狣玅珌珂珈珅玹玶玵玴珫玿珇玾珃珆玸珋瓬瓮甮畇畈疧疪癹盄眈眃眄眅眊盷盻盺矧矨砆砑砒砅砐砏砎砉砃砓祊祌祋祅祄秕种秏秖秎窀"],["d040","穾竑笀笁籺籸籹籿粀粁紃紈紁罘羑羍羾耇耎耏耔耷胘胇胠胑胈胂胐胅胣胙胜胊胕胉胏胗胦胍臿舡芔苙苾苹茇苨茀苕茺苫苖苴苬苡苲苵茌苻苶苰苪"],["d0a1","苤苠苺苳苭虷虴虼虳衁衎衧衪衩觓訄訇赲迣迡迮迠郱邽邿郕郅邾郇郋郈釔釓陔陏陑陓陊陎倞倅倇倓倢倰倛俵俴倳倷倬俶俷倗倜倠倧倵倯倱倎党冔冓凊凄凅凈凎剡剚剒剞剟剕剢勍匎厞唦哢唗唒哧哳哤唚哿唄唈哫唑唅哱"],["d140","唊哻哷哸哠唎唃唋圁圂埌堲埕埒垺埆垽垼垸垶垿埇埐垹埁夎奊娙娖娭娮娕娏娗娊娞娳孬宧宭宬尃屖屔峬峿峮峱峷崀峹帩帨庨庮庪庬弳弰彧恝恚恧"],["d1a1","恁悢悈悀悒悁悝悃悕悛悗悇悜悎戙扆拲挐捖挬捄捅挶捃揤挹捋捊挼挩捁挴捘捔捙挭捇挳捚捑挸捗捀捈敊敆旆旃旄旂晊晟晇晑朒朓栟栚桉栲栳栻桋桏栖栱栜栵栫栭栯桎桄栴栝栒栔栦栨栮桍栺栥栠欬欯欭欱欴歭肂殈毦毤"],["d240","毨毣毢毧氥浺浣浤浶洍浡涒浘浢浭浯涑涍淯浿涆浞浧浠涗浰浼浟涂涘洯浨涋浾涀涄洖涃浻浽浵涐烜烓烑烝烋缹烢烗烒烞烠烔烍烅烆烇烚烎烡牂牸"],["d2a1","牷牶猀狺狴狾狶狳狻猁珓珙珥珖玼珧珣珩珜珒珛珔珝珚珗珘珨瓞瓟瓴瓵甡畛畟疰痁疻痄痀疿疶疺皊盉眝眛眐眓眒眣眑眕眙眚眢眧砣砬砢砵砯砨砮砫砡砩砳砪砱祔祛祏祜祓祒祑秫秬秠秮秭秪秜秞秝窆窉窅窋窌窊窇竘笐"],["d340","笄笓笅笏笈笊笎笉笒粄粑粊粌粈粍粅紞紝紑紎紘紖紓紟紒紏紌罜罡罞罠罝罛羖羒翃翂翀耖耾耹胺胲胹胵脁胻脀舁舯舥茳茭荄茙荑茥荖茿荁茦茜茢"],["d3a1","荂荎茛茪茈茼荍茖茤茠茷茯茩荇荅荌荓茞茬荋茧荈虓虒蚢蚨蚖蚍蚑蚞蚇蚗蚆蚋蚚蚅蚥蚙蚡蚧蚕蚘蚎蚝蚐蚔衃衄衭衵衶衲袀衱衿衯袃衾衴衼訒豇豗豻貤貣赶赸趵趷趶軑軓迾迵适迿迻逄迼迶郖郠郙郚郣郟郥郘郛郗郜郤酐"],["d440","酎酏釕釢釚陜陟隼飣髟鬯乿偰偪偡偞偠偓偋偝偲偈偍偁偛偊偢倕偅偟偩偫偣偤偆偀偮偳偗偑凐剫剭剬剮勖勓匭厜啵啶唼啍啐唴唪啑啢唶唵唰啒啅"],["d4a1","唌唲啥啎唹啈唭唻啀啋圊圇埻堔埢埶埜埴堀埭埽堈埸堋埳埏堇埮埣埲埥埬埡堎埼堐埧堁堌埱埩埰堍堄奜婠婘婕婧婞娸娵婭婐婟婥婬婓婤婗婃婝婒婄婛婈媎娾婍娹婌婰婩婇婑婖婂婜孲孮寁寀屙崞崋崝崚崠崌崨崍崦崥崏"],["d540","崰崒崣崟崮帾帴庱庴庹庲庳弶弸徛徖徟悊悐悆悾悰悺惓惔惏惤惙惝惈悱惛悷惊悿惃惍惀挲捥掊掂捽掽掞掭掝掗掫掎捯掇掐据掯捵掜捭掮捼掤挻掟"],["d5a1","捸掅掁掑掍捰敓旍晥晡晛晙晜晢朘桹梇梐梜桭桮梮梫楖桯梣梬梩桵桴梲梏桷梒桼桫桲梪梀桱桾梛梖梋梠梉梤桸桻梑梌梊桽欶欳欷欸殑殏殍殎殌氪淀涫涴涳湴涬淩淢涷淶淔渀淈淠淟淖涾淥淜淝淛淴淊涽淭淰涺淕淂淏淉"],["d640","淐淲淓淽淗淍淣涻烺焍烷焗烴焌烰焄烳焐烼烿焆焓焀烸烶焋焂焎牾牻牼牿猝猗猇猑猘猊猈狿猏猞玈珶珸珵琄琁珽琇琀珺珼珿琌琋珴琈畤畣痎痒痏"],["d6a1","痋痌痑痐皏皉盓眹眯眭眱眲眴眳眽眥眻眵硈硒硉硍硊硌砦硅硐祤祧祩祪祣祫祡离秺秸秶秷窏窔窐笵筇笴笥笰笢笤笳笘笪笝笱笫笭笯笲笸笚笣粔粘粖粣紵紽紸紶紺絅紬紩絁絇紾紿絊紻紨罣羕羜羝羛翊翋翍翐翑翇翏翉耟"],["d740","耞耛聇聃聈脘脥脙脛脭脟脬脞脡脕脧脝脢舑舸舳舺舴舲艴莐莣莨莍荺荳莤荴莏莁莕莙荵莔莩荽莃莌莝莛莪莋荾莥莯莈莗莰荿莦莇莮荶莚虙虖蚿蚷"],["d7a1","蛂蛁蛅蚺蚰蛈蚹蚳蚸蛌蚴蚻蚼蛃蚽蚾衒袉袕袨袢袪袚袑袡袟袘袧袙袛袗袤袬袌袓袎覂觖觙觕訰訧訬訞谹谻豜豝豽貥赽赻赹趼跂趹趿跁軘軞軝軜軗軠軡逤逋逑逜逌逡郯郪郰郴郲郳郔郫郬郩酖酘酚酓酕釬釴釱釳釸釤釹釪"],["d840","釫釷釨釮镺閆閈陼陭陫陱陯隿靪頄飥馗傛傕傔傞傋傣傃傌傎傝偨傜傒傂傇兟凔匒匑厤厧喑喨喥喭啷噅喢喓喈喏喵喁喣喒喤啽喌喦啿喕喡喎圌堩堷"],["d8a1","堙堞堧堣堨埵塈堥堜堛堳堿堶堮堹堸堭堬堻奡媯媔媟婺媢媞婸媦婼媥媬媕媮娷媄媊媗媃媋媩婻婽媌媜媏媓媝寪寍寋寔寑寊寎尌尰崷嵃嵫嵁嵋崿崵嵑嵎嵕崳崺嵒崽崱嵙嵂崹嵉崸崼崲崶嵀嵅幄幁彘徦徥徫惉悹惌惢惎惄愔"],["d940","惲愊愖愅惵愓惸惼惾惁愃愘愝愐惿愄愋扊掔掱掰揎揥揨揯揃撝揳揊揠揶揕揲揵摡揟掾揝揜揄揘揓揂揇揌揋揈揰揗揙攲敧敪敤敜敨敥斌斝斞斮旐旒"],["d9a1","晼晬晻暀晱晹晪晲朁椌棓椄棜椪棬棪棱椏棖棷棫棤棶椓椐棳棡椇棌椈楰梴椑棯棆椔棸棐棽棼棨椋椊椗棎棈棝棞棦棴棑椆棔棩椕椥棇欹欻欿欼殔殗殙殕殽毰毲毳氰淼湆湇渟湉溈渼渽湅湢渫渿湁湝湳渜渳湋湀湑渻渃渮湞"],["da40","湨湜湡渱渨湠湱湫渹渢渰湓湥渧湸湤湷湕湹湒湦渵渶湚焠焞焯烻焮焱焣焥焢焲焟焨焺焛牋牚犈犉犆犅犋猒猋猰猢猱猳猧猲猭猦猣猵猌琮琬琰琫琖"],["daa1","琚琡琭琱琤琣琝琩琠琲瓻甯畯畬痧痚痡痦痝痟痤痗皕皒盚睆睇睄睍睅睊睎睋睌矞矬硠硤硥硜硭硱硪确硰硩硨硞硢祴祳祲祰稂稊稃稌稄窙竦竤筊笻筄筈筌筎筀筘筅粢粞粨粡絘絯絣絓絖絧絪絏絭絜絫絒絔絩絑絟絎缾缿罥"],["db40","罦羢羠羡翗聑聏聐胾胔腃腊腒腏腇脽腍脺臦臮臷臸臹舄舼舽舿艵茻菏菹萣菀菨萒菧菤菼菶萐菆菈菫菣莿萁菝菥菘菿菡菋菎菖菵菉萉萏菞萑萆菂菳"],["dba1","菕菺菇菑菪萓菃菬菮菄菻菗菢萛菛菾蛘蛢蛦蛓蛣蛚蛪蛝蛫蛜蛬蛩蛗蛨蛑衈衖衕袺裗袹袸裀袾袶袼袷袽袲褁裉覕覘覗觝觚觛詎詍訹詙詀詗詘詄詅詒詈詑詊詌詏豟貁貀貺貾貰貹貵趄趀趉跘跓跍跇跖跜跏跕跙跈跗跅軯軷軺"],["dc40","軹軦軮軥軵軧軨軶軫軱軬軴軩逭逴逯鄆鄬鄄郿郼鄈郹郻鄁鄀鄇鄅鄃酡酤酟酢酠鈁鈊鈥鈃鈚鈦鈏鈌鈀鈒釿釽鈆鈄鈧鈂鈜鈤鈙鈗鈅鈖镻閍閌閐隇陾隈"],["dca1","隉隃隀雂雈雃雱雰靬靰靮頇颩飫鳦黹亃亄亶傽傿僆傮僄僊傴僈僂傰僁傺傱僋僉傶傸凗剺剸剻剼嗃嗛嗌嗐嗋嗊嗝嗀嗔嗄嗩喿嗒喍嗏嗕嗢嗖嗈嗲嗍嗙嗂圔塓塨塤塏塍塉塯塕塎塝塙塥塛堽塣塱壼嫇嫄嫋媺媸媱媵媰媿嫈媻嫆"],["dd40","媷嫀嫊媴媶嫍媹媐寖寘寙尟尳嵱嵣嵊嵥嵲嵬嵞嵨嵧嵢巰幏幎幊幍幋廅廌廆廋廇彀徯徭惷慉慊愫慅愶愲愮慆愯慏愩慀戠酨戣戥戤揅揱揫搐搒搉搠搤"],["dda1","搳摃搟搕搘搹搷搢搣搌搦搰搨摁搵搯搊搚摀搥搧搋揧搛搮搡搎敯斒旓暆暌暕暐暋暊暙暔晸朠楦楟椸楎楢楱椿楅楪椹楂楗楙楺楈楉椵楬椳椽楥棰楸椴楩楀楯楄楶楘楁楴楌椻楋椷楜楏楑椲楒椯楻椼歆歅歃歂歈歁殛嗀毻毼"],["de40","毹毷毸溛滖滈溏滀溟溓溔溠溱溹滆滒溽滁溞滉溷溰滍溦滏溲溾滃滜滘溙溒溎溍溤溡溿溳滐滊溗溮溣煇煔煒煣煠煁煝煢煲煸煪煡煂煘煃煋煰煟煐煓"],["dea1","煄煍煚牏犍犌犑犐犎猼獂猻猺獀獊獉瑄瑊瑋瑒瑑瑗瑀瑏瑐瑎瑂瑆瑍瑔瓡瓿瓾瓽甝畹畷榃痯瘏瘃痷痾痼痹痸瘐痻痶痭痵痽皙皵盝睕睟睠睒睖睚睩睧睔睙睭矠碇碚碔碏碄碕碅碆碡碃硹碙碀碖硻祼禂祽祹稑稘稙稒稗稕稢稓"],["df40","稛稐窣窢窞竫筦筤筭筴筩筲筥筳筱筰筡筸筶筣粲粴粯綈綆綀綍絿綅絺綎絻綃絼綌綔綄絽綒罭罫罧罨罬羦羥羧翛翜耡腤腠腷腜腩腛腢腲朡腞腶腧腯"],["dfa1","腄腡舝艉艄艀艂艅蓱萿葖葶葹蒏蒍葥葑葀蒆葧萰葍葽葚葙葴葳葝蔇葞萷萺萴葺葃葸萲葅萩菙葋萯葂萭葟葰萹葎葌葒葯蓅蒎萻葇萶萳葨葾葄萫葠葔葮葐蜋蜄蛷蜌蛺蛖蛵蝍蛸蜎蜉蜁蛶蜍蜅裖裋裍裎裞裛裚裌裐覅覛觟觥觤"],["e040","觡觠觢觜触詶誆詿詡訿詷誂誄詵誃誁詴詺谼豋豊豥豤豦貆貄貅賌赨赩趑趌趎趏趍趓趔趐趒跰跠跬跱跮跐跩跣跢跧跲跫跴輆軿輁輀輅輇輈輂輋遒逿"],["e0a1","遄遉逽鄐鄍鄏鄑鄖鄔鄋鄎酮酯鉈鉒鈰鈺鉦鈳鉥鉞銃鈮鉊鉆鉭鉬鉏鉠鉧鉯鈶鉡鉰鈱鉔鉣鉐鉲鉎鉓鉌鉖鈲閟閜閞閛隒隓隑隗雎雺雽雸雵靳靷靸靲頏頍頎颬飶飹馯馲馰馵骭骫魛鳪鳭鳧麀黽僦僔僗僨僳僛僪僝僤僓僬僰僯僣僠"],["e140","凘劀劁勩勫匰厬嘧嘕嘌嘒嗼嘏嘜嘁嘓嘂嗺嘝嘄嗿嗹墉塼墐墘墆墁塿塴墋塺墇墑墎塶墂墈塻墔墏壾奫嫜嫮嫥嫕嫪嫚嫭嫫嫳嫢嫠嫛嫬嫞嫝嫙嫨嫟孷寠"],["e1a1","寣屣嶂嶀嵽嶆嵺嶁嵷嶊嶉嶈嵾嵼嶍嵹嵿幘幙幓廘廑廗廎廜廕廙廒廔彄彃彯徶愬愨慁慞慱慳慒慓慲慬憀慴慔慺慛慥愻慪慡慖戩戧戫搫摍摛摝摴摶摲摳摽摵摦撦摎撂摞摜摋摓摠摐摿搿摬摫摙摥摷敳斠暡暠暟朅朄朢榱榶槉"],["e240","榠槎榖榰榬榼榑榙榎榧榍榩榾榯榿槄榽榤槔榹槊榚槏榳榓榪榡榞槙榗榐槂榵榥槆歊歍歋殞殟殠毃毄毾滎滵滱漃漥滸漷滻漮漉潎漙漚漧漘漻漒滭漊"],["e2a1","漶潳滹滮漭潀漰漼漵滫漇漎潃漅滽滶漹漜滼漺漟漍漞漈漡熇熐熉熀熅熂熏煻熆熁熗牄牓犗犕犓獃獍獑獌瑢瑳瑱瑵瑲瑧瑮甀甂甃畽疐瘖瘈瘌瘕瘑瘊瘔皸瞁睼瞅瞂睮瞀睯睾瞃碲碪碴碭碨硾碫碞碥碠碬碢碤禘禊禋禖禕禔禓"],["e340","禗禈禒禐稫穊稰稯稨稦窨窫窬竮箈箜箊箑箐箖箍箌箛箎箅箘劄箙箤箂粻粿粼粺綧綷緂綣綪緁緀緅綝緎緄緆緋緌綯綹綖綼綟綦綮綩綡緉罳翢翣翥翞"],["e3a1","耤聝聜膉膆膃膇膍膌膋舕蒗蒤蒡蒟蒺蓎蓂蒬蒮蒫蒹蒴蓁蓍蒪蒚蒱蓐蒝蒧蒻蒢蒔蓇蓌蒛蒩蒯蒨蓖蒘蒶蓏蒠蓗蓔蓒蓛蒰蒑虡蜳蜣蜨蝫蝀蜮蜞蜡蜙蜛蝃蜬蝁蜾蝆蜠蜲蜪蜭蜼蜒蜺蜱蜵蝂蜦蜧蜸蜤蜚蜰蜑裷裧裱裲裺裾裮裼裶裻"],["e440","裰裬裫覝覡覟覞觩觫觨誫誙誋誒誏誖谽豨豩賕賏賗趖踉踂跿踍跽踊踃踇踆踅跾踀踄輐輑輎輍鄣鄜鄠鄢鄟鄝鄚鄤鄡鄛酺酲酹酳銥銤鉶銛鉺銠銔銪銍"],["e4a1","銦銚銫鉹銗鉿銣鋮銎銂銕銢鉽銈銡銊銆銌銙銧鉾銇銩銝銋鈭隞隡雿靘靽靺靾鞃鞀鞂靻鞄鞁靿韎韍頖颭颮餂餀餇馝馜駃馹馻馺駂馽駇骱髣髧鬾鬿魠魡魟鳱鳲鳵麧僿儃儰僸儆儇僶僾儋儌僽儊劋劌勱勯噈噂噌嘵噁噊噉噆噘"],["e540","噚噀嘳嘽嘬嘾嘸嘪嘺圚墫墝墱墠墣墯墬墥墡壿嫿嫴嫽嫷嫶嬃嫸嬂嫹嬁嬇嬅嬏屧嶙嶗嶟嶒嶢嶓嶕嶠嶜嶡嶚嶞幩幝幠幜緳廛廞廡彉徲憋憃慹憱憰憢憉"],["e5a1","憛憓憯憭憟憒憪憡憍慦憳戭摮摰撖撠撅撗撜撏撋撊撌撣撟摨撱撘敶敺敹敻斲斳暵暰暩暲暷暪暯樀樆樗槥槸樕槱槤樠槿槬槢樛樝槾樧槲槮樔槷槧橀樈槦槻樍槼槫樉樄樘樥樏槶樦樇槴樖歑殥殣殢殦氁氀毿氂潁漦潾澇濆澒"],["e640","澍澉澌潢潏澅潚澖潶潬澂潕潲潒潐潗澔澓潝漀潡潫潽潧澐潓澋潩潿澕潣潷潪潻熲熯熛熰熠熚熩熵熝熥熞熤熡熪熜熧熳犘犚獘獒獞獟獠獝獛獡獚獙"],["e6a1","獢璇璉璊璆璁瑽璅璈瑼瑹甈甇畾瘥瘞瘙瘝瘜瘣瘚瘨瘛皜皝皞皛瞍瞏瞉瞈磍碻磏磌磑磎磔磈磃磄磉禚禡禠禜禢禛歶稹窲窴窳箷篋箾箬篎箯箹篊箵糅糈糌糋緷緛緪緧緗緡縃緺緦緶緱緰緮緟罶羬羰羭翭翫翪翬翦翨聤聧膣膟"],["e740","膞膕膢膙膗舖艏艓艒艐艎艑蔤蔻蔏蔀蔩蔎蔉蔍蔟蔊蔧蔜蓻蔫蓺蔈蔌蓴蔪蓲蔕蓷蓫蓳蓼蔒蓪蓩蔖蓾蔨蔝蔮蔂蓽蔞蓶蔱蔦蓧蓨蓰蓯蓹蔘蔠蔰蔋蔙蔯虢"],["e7a1","蝖蝣蝤蝷蟡蝳蝘蝔蝛蝒蝡蝚蝑蝞蝭蝪蝐蝎蝟蝝蝯蝬蝺蝮蝜蝥蝏蝻蝵蝢蝧蝩衚褅褌褔褋褗褘褙褆褖褑褎褉覢覤覣觭觰觬諏諆誸諓諑諔諕誻諗誾諀諅諘諃誺誽諙谾豍貏賥賟賙賨賚賝賧趠趜趡趛踠踣踥踤踮踕踛踖踑踙踦踧"],["e840","踔踒踘踓踜踗踚輬輤輘輚輠輣輖輗遳遰遯遧遫鄯鄫鄩鄪鄲鄦鄮醅醆醊醁醂醄醀鋐鋃鋄鋀鋙銶鋏鋱鋟鋘鋩鋗鋝鋌鋯鋂鋨鋊鋈鋎鋦鋍鋕鋉鋠鋞鋧鋑鋓"],["e8a1","銵鋡鋆銴镼閬閫閮閰隤隢雓霅霈霂靚鞊鞎鞈韐韏頞頝頦頩頨頠頛頧颲餈飺餑餔餖餗餕駜駍駏駓駔駎駉駖駘駋駗駌骳髬髫髳髲髱魆魃魧魴魱魦魶魵魰魨魤魬鳼鳺鳽鳿鳷鴇鴀鳹鳻鴈鴅鴄麃黓鼏鼐儜儓儗儚儑凞匴叡噰噠噮"],["e940","噳噦噣噭噲噞噷圜圛壈墽壉墿墺壂墼壆嬗嬙嬛嬡嬔嬓嬐嬖嬨嬚嬠嬞寯嶬嶱嶩嶧嶵嶰嶮嶪嶨嶲嶭嶯嶴幧幨幦幯廩廧廦廨廥彋徼憝憨憖懅憴懆懁懌憺"],["e9a1","憿憸憌擗擖擐擏擉撽撉擃擛擳擙攳敿敼斢曈暾曀曊曋曏暽暻暺曌朣樴橦橉橧樲橨樾橝橭橶橛橑樨橚樻樿橁橪橤橐橏橔橯橩橠樼橞橖橕橍橎橆歕歔歖殧殪殫毈毇氄氃氆澭濋澣濇澼濎濈潞濄澽澞濊澨瀄澥澮澺澬澪濏澿澸"],["ea40","澢濉澫濍澯澲澰燅燂熿熸燖燀燁燋燔燊燇燏熽燘熼燆燚燛犝犞獩獦獧獬獥獫獪瑿璚璠璔璒璕璡甋疀瘯瘭瘱瘽瘳瘼瘵瘲瘰皻盦瞚瞝瞡瞜瞛瞢瞣瞕瞙"],["eaa1","瞗磝磩磥磪磞磣磛磡磢磭磟磠禤穄穈穇窶窸窵窱窷篞篣篧篝篕篥篚篨篹篔篪篢篜篫篘篟糒糔糗糐糑縒縡縗縌縟縠縓縎縜縕縚縢縋縏縖縍縔縥縤罃罻罼罺羱翯耪耩聬膱膦膮膹膵膫膰膬膴膲膷膧臲艕艖艗蕖蕅蕫蕍蕓蕡蕘"],["eb40","蕀蕆蕤蕁蕢蕄蕑蕇蕣蔾蕛蕱蕎蕮蕵蕕蕧蕠薌蕦蕝蕔蕥蕬虣虥虤螛螏螗螓螒螈螁螖螘蝹螇螣螅螐螑螝螄螔螜螚螉褞褦褰褭褮褧褱褢褩褣褯褬褟觱諠"],["eba1","諢諲諴諵諝謔諤諟諰諈諞諡諨諿諯諻貑貒貐賵賮賱賰賳赬赮趥趧踳踾踸蹀蹅踶踼踽蹁踰踿躽輶輮輵輲輹輷輴遶遹遻邆郺鄳鄵鄶醓醐醑醍醏錧錞錈錟錆錏鍺錸錼錛錣錒錁鍆錭錎錍鋋錝鋺錥錓鋹鋷錴錂錤鋿錩錹錵錪錔錌"],["ec40","錋鋾錉錀鋻錖閼闍閾閹閺閶閿閵閽隩雔霋霒霐鞙鞗鞔韰韸頵頯頲餤餟餧餩馞駮駬駥駤駰駣駪駩駧骹骿骴骻髶髺髹髷鬳鮀鮅鮇魼魾魻鮂鮓鮒鮐魺鮕"],["eca1","魽鮈鴥鴗鴠鴞鴔鴩鴝鴘鴢鴐鴙鴟麈麆麇麮麭黕黖黺鼒鼽儦儥儢儤儠儩勴嚓嚌嚍嚆嚄嚃噾嚂噿嚁壖壔壏壒嬭嬥嬲嬣嬬嬧嬦嬯嬮孻寱寲嶷幬幪徾徻懃憵憼懧懠懥懤懨懞擯擩擣擫擤擨斁斀斶旚曒檍檖檁檥檉檟檛檡檞檇檓檎"],["ed40","檕檃檨檤檑橿檦檚檅檌檒歛殭氉濌澩濴濔濣濜濭濧濦濞濲濝濢濨燡燱燨燲燤燰燢獳獮獯璗璲璫璐璪璭璱璥璯甐甑甒甏疄癃癈癉癇皤盩瞵瞫瞲瞷瞶"],["eda1","瞴瞱瞨矰磳磽礂磻磼磲礅磹磾礄禫禨穜穛穖穘穔穚窾竀竁簅簏篲簀篿篻簎篴簋篳簂簉簃簁篸篽簆篰篱簐簊糨縭縼繂縳顈縸縪繉繀繇縩繌縰縻縶繄縺罅罿罾罽翴翲耬膻臄臌臊臅臇膼臩艛艚艜薃薀薏薧薕薠薋薣蕻薤薚薞"],["ee40","蕷蕼薉薡蕺蕸蕗薎薖薆薍薙薝薁薢薂薈薅蕹蕶薘薐薟虨螾螪螭蟅螰螬螹螵螼螮蟉蟃蟂蟌螷螯蟄蟊螴螶螿螸螽蟞螲褵褳褼褾襁襒褷襂覭覯覮觲觳謞"],["eea1","謘謖謑謅謋謢謏謒謕謇謍謈謆謜謓謚豏豰豲豱豯貕貔賹赯蹎蹍蹓蹐蹌蹇轃轀邅遾鄸醚醢醛醙醟醡醝醠鎡鎃鎯鍤鍖鍇鍼鍘鍜鍶鍉鍐鍑鍠鍭鎏鍌鍪鍹鍗鍕鍒鍏鍱鍷鍻鍡鍞鍣鍧鎀鍎鍙闇闀闉闃闅閷隮隰隬霠霟霘霝霙鞚鞡鞜"],["ef40","鞞鞝韕韔韱顁顄顊顉顅顃餥餫餬餪餳餲餯餭餱餰馘馣馡騂駺駴駷駹駸駶駻駽駾駼騃骾髾髽鬁髼魈鮚鮨鮞鮛鮦鮡鮥鮤鮆鮢鮠鮯鴳鵁鵧鴶鴮鴯鴱鴸鴰"],["efa1","鵅鵂鵃鴾鴷鵀鴽翵鴭麊麉麍麰黈黚黻黿鼤鼣鼢齔龠儱儭儮嚘嚜嚗嚚嚝嚙奰嬼屩屪巀幭幮懘懟懭懮懱懪懰懫懖懩擿攄擽擸攁攃擼斔旛曚曛曘櫅檹檽櫡櫆檺檶檷櫇檴檭歞毉氋瀇瀌瀍瀁瀅瀔瀎濿瀀濻瀦濼濷瀊爁燿燹爃燽獶"],["f040","璸瓀璵瓁璾璶璻瓂甔甓癜癤癙癐癓癗癚皦皽盬矂瞺磿礌礓礔礉礐礒礑禭禬穟簜簩簙簠簟簭簝簦簨簢簥簰繜繐繖繣繘繢繟繑繠繗繓羵羳翷翸聵臑臒"],["f0a1","臐艟艞薴藆藀藃藂薳薵薽藇藄薿藋藎藈藅薱薶藒蘤薸薷薾虩蟧蟦蟢蟛蟫蟪蟥蟟蟳蟤蟔蟜蟓蟭蟘蟣螤蟗蟙蠁蟴蟨蟝襓襋襏襌襆襐襑襉謪謧謣謳謰謵譇謯謼謾謱謥謷謦謶謮謤謻謽謺豂豵貙貘貗賾贄贂贀蹜蹢蹠蹗蹖蹞蹥蹧"],["f140","蹛蹚蹡蹝蹩蹔轆轇轈轋鄨鄺鄻鄾醨醥醧醯醪鎵鎌鎒鎷鎛鎝鎉鎧鎎鎪鎞鎦鎕鎈鎙鎟鎍鎱鎑鎲鎤鎨鎴鎣鎥闒闓闑隳雗雚巂雟雘雝霣霢霥鞬鞮鞨鞫鞤鞪"],["f1a1","鞢鞥韗韙韖韘韺顐顑顒颸饁餼餺騏騋騉騍騄騑騊騅騇騆髀髜鬈鬄鬅鬩鬵魊魌魋鯇鯆鯃鮿鯁鮵鮸鯓鮶鯄鮹鮽鵜鵓鵏鵊鵛鵋鵙鵖鵌鵗鵒鵔鵟鵘鵚麎麌黟鼁鼀鼖鼥鼫鼪鼩鼨齌齕儴儵劖勷厴嚫嚭嚦嚧嚪嚬壚壝壛夒嬽嬾嬿巃幰"],["f240","徿懻攇攐攍攉攌攎斄旞旝曞櫧櫠櫌櫑櫙櫋櫟櫜櫐櫫櫏櫍櫞歠殰氌瀙瀧瀠瀖瀫瀡瀢瀣瀩瀗瀤瀜瀪爌爊爇爂爅犥犦犤犣犡瓋瓅璷瓃甖癠矉矊矄矱礝礛"],["f2a1","礡礜礗礞禰穧穨簳簼簹簬簻糬糪繶繵繸繰繷繯繺繲繴繨罋罊羃羆羷翽翾聸臗臕艤艡艣藫藱藭藙藡藨藚藗藬藲藸藘藟藣藜藑藰藦藯藞藢蠀蟺蠃蟶蟷蠉蠌蠋蠆蟼蠈蟿蠊蠂襢襚襛襗襡襜襘襝襙覈覷覶觶譐譈譊譀譓譖譔譋譕"],["f340","譑譂譒譗豃豷豶貚贆贇贉趬趪趭趫蹭蹸蹳蹪蹯蹻軂轒轑轏轐轓辴酀鄿醰醭鏞鏇鏏鏂鏚鏐鏹鏬鏌鏙鎩鏦鏊鏔鏮鏣鏕鏄鏎鏀鏒鏧镽闚闛雡霩霫霬霨霦"],["f3a1","鞳鞷鞶韝韞韟顜顙顝顗颿颽颻颾饈饇饃馦馧騚騕騥騝騤騛騢騠騧騣騞騜騔髂鬋鬊鬎鬌鬷鯪鯫鯠鯞鯤鯦鯢鯰鯔鯗鯬鯜鯙鯥鯕鯡鯚鵷鶁鶊鶄鶈鵱鶀鵸鶆鶋鶌鵽鵫鵴鵵鵰鵩鶅鵳鵻鶂鵯鵹鵿鶇鵨麔麑黀黼鼭齀齁齍齖齗齘匷嚲"],["f440","嚵嚳壣孅巆巇廮廯忀忁懹攗攖攕攓旟曨曣曤櫳櫰櫪櫨櫹櫱櫮櫯瀼瀵瀯瀷瀴瀱灂瀸瀿瀺瀹灀瀻瀳灁爓爔犨獽獼璺皫皪皾盭矌矎矏矍矲礥礣礧礨礤礩"],["f4a1","禲穮穬穭竷籉籈籊籇籅糮繻繾纁纀羺翿聹臛臙舋艨艩蘢藿蘁藾蘛蘀藶蘄蘉蘅蘌藽蠙蠐蠑蠗蠓蠖襣襦覹觷譠譪譝譨譣譥譧譭趮躆躈躄轙轖轗轕轘轚邍酃酁醷醵醲醳鐋鐓鏻鐠鐏鐔鏾鐕鐐鐨鐙鐍鏵鐀鏷鐇鐎鐖鐒鏺鐉鏸鐊鏿"],["f540","鏼鐌鏶鐑鐆闞闠闟霮霯鞹鞻韽韾顠顢顣顟飁飂饐饎饙饌饋饓騲騴騱騬騪騶騩騮騸騭髇髊髆鬐鬒鬑鰋鰈鯷鰅鰒鯸鱀鰇鰎鰆鰗鰔鰉鶟鶙鶤鶝鶒鶘鶐鶛"],["f5a1","鶠鶔鶜鶪鶗鶡鶚鶢鶨鶞鶣鶿鶩鶖鶦鶧麙麛麚黥黤黧黦鼰鼮齛齠齞齝齙龑儺儹劘劗囃嚽嚾孈孇巋巏廱懽攛欂櫼欃櫸欀灃灄灊灈灉灅灆爝爚爙獾甗癪矐礭礱礯籔籓糲纊纇纈纋纆纍罍羻耰臝蘘蘪蘦蘟蘣蘜蘙蘧蘮蘡蘠蘩蘞蘥"],["f640","蠩蠝蠛蠠蠤蠜蠫衊襭襩襮襫觺譹譸譅譺譻贐贔趯躎躌轞轛轝酆酄酅醹鐿鐻鐶鐩鐽鐼鐰鐹鐪鐷鐬鑀鐱闥闤闣霵霺鞿韡顤飉飆飀饘饖騹騽驆驄驂驁騺"],["f6a1","騿髍鬕鬗鬘鬖鬺魒鰫鰝鰜鰬鰣鰨鰩鰤鰡鶷鶶鶼鷁鷇鷊鷏鶾鷅鷃鶻鶵鷎鶹鶺鶬鷈鶱鶭鷌鶳鷍鶲鹺麜黫黮黭鼛鼘鼚鼱齎齥齤龒亹囆囅囋奱孋孌巕巑廲攡攠攦攢欋欈欉氍灕灖灗灒爞爟犩獿瓘瓕瓙瓗癭皭礵禴穰穱籗籜籙籛籚"],["f740","糴糱纑罏羇臞艫蘴蘵蘳蘬蘲蘶蠬蠨蠦蠪蠥襱覿覾觻譾讄讂讆讅譿贕躕躔躚躒躐躖躗轠轢酇鑌鑐鑊鑋鑏鑇鑅鑈鑉鑆霿韣顪顩飋饔饛驎驓驔驌驏驈驊"],["f7a1","驉驒驐髐鬙鬫鬻魖魕鱆鱈鰿鱄鰹鰳鱁鰼鰷鰴鰲鰽鰶鷛鷒鷞鷚鷋鷐鷜鷑鷟鷩鷙鷘鷖鷵鷕鷝麶黰鼵鼳鼲齂齫龕龢儽劙壨壧奲孍巘蠯彏戁戃戄攩攥斖曫欑欒欏毊灛灚爢玂玁玃癰矔籧籦纕艬蘺虀蘹蘼蘱蘻蘾蠰蠲蠮蠳襶襴襳觾"],["f840","讌讎讋讈豅贙躘轤轣醼鑢鑕鑝鑗鑞韄韅頀驖驙鬞鬟鬠鱒鱘鱐鱊鱍鱋鱕鱙鱌鱎鷻鷷鷯鷣鷫鷸鷤鷶鷡鷮鷦鷲鷰鷢鷬鷴鷳鷨鷭黂黐黲黳鼆鼜鼸鼷鼶齃齏"],["f8a1","齱齰齮齯囓囍孎屭攭曭曮欓灟灡灝灠爣瓛瓥矕礸禷禶籪纗羉艭虃蠸蠷蠵衋讔讕躞躟躠躝醾醽釂鑫鑨鑩雥靆靃靇韇韥驞髕魙鱣鱧鱦鱢鱞鱠鸂鷾鸇鸃鸆鸅鸀鸁鸉鷿鷽鸄麠鼞齆齴齵齶囔攮斸欘欙欗欚灢爦犪矘矙礹籩籫糶纚"],["f940","纘纛纙臠臡虆虇虈襹襺襼襻觿讘讙躥躤躣鑮鑭鑯鑱鑳靉顲饟鱨鱮鱭鸋鸍鸐鸏鸒鸑麡黵鼉齇齸齻齺齹圞灦籯蠼趲躦釃鑴鑸鑶鑵驠鱴鱳鱱鱵鸔鸓黶鼊"],["f9a1","龤灨灥糷虪蠾蠽蠿讞貜躩軉靋顳顴飌饡馫驤驦驧鬤鸕鸗齈戇欞爧虌躨钂钀钁驩驨鬮鸙爩虋讟钃鱹麷癵驫鱺鸝灩灪麤齾齉龘碁銹裏墻恒粧嫺╔╦╗╠╬╣╚╩╝╒╤╕╞╪╡╘╧╛╓╥╖╟╫╢╙╨╜║═╭╮╰╯▓"]]')},5633:function(A){"use strict";A.exports=JSON.parse('[["0","\\u0000",127],["8ea1","｡",62],["a1a1","　、。，．・：；？！゛゜´｀¨＾￣＿ヽヾゝゞ〃仝々〆〇ー―‐／＼～∥｜…‥‘’“”（）〔〕［］｛｝〈",9,"＋－±×÷＝≠＜＞≦≧∞∴♂♀°′″℃￥＄￠￡％＃＆＊＠§☆★○●◎◇"],["a2a1","◆□■△▲▽▼※〒→←↑↓〓"],["a2ba","∈∋⊆⊇⊂⊃∪∩"],["a2ca","∧∨￢⇒⇔∀∃"],["a2dc","∠⊥⌒∂∇≡≒≪≫√∽∝∵∫∬"],["a2f2","Å‰♯♭♪†‡¶"],["a2fe","◯"],["a3b0","０",9],["a3c1","Ａ",25],["a3e1","ａ",25],["a4a1","ぁ",82],["a5a1","ァ",85],["a6a1","Α",16,"Σ",6],["a6c1","α",16,"σ",6],["a7a1","А",5,"ЁЖ",25],["a7d1","а",5,"ёж",25],["a8a1","─│┌┐┘└├┬┤┴┼━┃┏┓┛┗┣┳┫┻╋┠┯┨┷┿┝┰┥┸╂"],["ada1","①",19,"Ⅰ",9],["adc0","㍉㌔㌢㍍㌘㌧㌃㌶㍑㍗㌍㌦㌣㌫㍊㌻㎜㎝㎞㎎㎏㏄㎡"],["addf","㍻〝〟№㏍℡㊤",4,"㈱㈲㈹㍾㍽㍼≒≡∫∮∑√⊥∠∟⊿∵∩∪"],["b0a1","亜唖娃阿哀愛挨姶逢葵茜穐悪握渥旭葦芦鯵梓圧斡扱宛姐虻飴絢綾鮎或粟袷安庵按暗案闇鞍杏以伊位依偉囲夷委威尉惟意慰易椅為畏異移維緯胃萎衣謂違遺医井亥域育郁磯一壱溢逸稲茨芋鰯允印咽員因姻引飲淫胤蔭"],["b1a1","院陰隠韻吋右宇烏羽迂雨卯鵜窺丑碓臼渦嘘唄欝蔚鰻姥厩浦瓜閏噂云運雲荏餌叡営嬰影映曳栄永泳洩瑛盈穎頴英衛詠鋭液疫益駅悦謁越閲榎厭円園堰奄宴延怨掩援沿演炎焔煙燕猿縁艶苑薗遠鉛鴛塩於汚甥凹央奥往応"],["b2a1","押旺横欧殴王翁襖鴬鴎黄岡沖荻億屋憶臆桶牡乙俺卸恩温穏音下化仮何伽価佳加可嘉夏嫁家寡科暇果架歌河火珂禍禾稼箇花苛茄荷華菓蝦課嘩貨迦過霞蚊俄峨我牙画臥芽蛾賀雅餓駕介会解回塊壊廻快怪悔恢懐戒拐改"],["b3a1","魁晦械海灰界皆絵芥蟹開階貝凱劾外咳害崖慨概涯碍蓋街該鎧骸浬馨蛙垣柿蛎鈎劃嚇各廓拡撹格核殻獲確穫覚角赫較郭閣隔革学岳楽額顎掛笠樫橿梶鰍潟割喝恰括活渇滑葛褐轄且鰹叶椛樺鞄株兜竃蒲釜鎌噛鴨栢茅萱"],["b4a1","粥刈苅瓦乾侃冠寒刊勘勧巻喚堪姦完官寛干幹患感慣憾換敢柑桓棺款歓汗漢澗潅環甘監看竿管簡緩缶翰肝艦莞観諌貫還鑑間閑関陥韓館舘丸含岸巌玩癌眼岩翫贋雁頑顔願企伎危喜器基奇嬉寄岐希幾忌揮机旗既期棋棄"],["b5a1","機帰毅気汽畿祈季稀紀徽規記貴起軌輝飢騎鬼亀偽儀妓宜戯技擬欺犠疑祇義蟻誼議掬菊鞠吉吃喫桔橘詰砧杵黍却客脚虐逆丘久仇休及吸宮弓急救朽求汲泣灸球究窮笈級糾給旧牛去居巨拒拠挙渠虚許距鋸漁禦魚亨享京"],["b6a1","供侠僑兇競共凶協匡卿叫喬境峡強彊怯恐恭挟教橋況狂狭矯胸脅興蕎郷鏡響饗驚仰凝尭暁業局曲極玉桐粁僅勤均巾錦斤欣欽琴禁禽筋緊芹菌衿襟謹近金吟銀九倶句区狗玖矩苦躯駆駈駒具愚虞喰空偶寓遇隅串櫛釧屑屈"],["b7a1","掘窟沓靴轡窪熊隈粂栗繰桑鍬勲君薫訓群軍郡卦袈祁係傾刑兄啓圭珪型契形径恵慶慧憩掲携敬景桂渓畦稽系経継繋罫茎荊蛍計詣警軽頚鶏芸迎鯨劇戟撃激隙桁傑欠決潔穴結血訣月件倹倦健兼券剣喧圏堅嫌建憲懸拳捲"],["b8a1","検権牽犬献研硯絹県肩見謙賢軒遣鍵険顕験鹸元原厳幻弦減源玄現絃舷言諺限乎個古呼固姑孤己庫弧戸故枯湖狐糊袴股胡菰虎誇跨鈷雇顧鼓五互伍午呉吾娯後御悟梧檎瑚碁語誤護醐乞鯉交佼侯候倖光公功効勾厚口向"],["b9a1","后喉坑垢好孔孝宏工巧巷幸広庚康弘恒慌抗拘控攻昂晃更杭校梗構江洪浩港溝甲皇硬稿糠紅紘絞綱耕考肯肱腔膏航荒行衡講貢購郊酵鉱砿鋼閤降項香高鴻剛劫号合壕拷濠豪轟麹克刻告国穀酷鵠黒獄漉腰甑忽惚骨狛込"],["baa1","此頃今困坤墾婚恨懇昏昆根梱混痕紺艮魂些佐叉唆嵯左差査沙瑳砂詐鎖裟坐座挫債催再最哉塞妻宰彩才採栽歳済災采犀砕砦祭斎細菜裁載際剤在材罪財冴坂阪堺榊肴咲崎埼碕鷺作削咋搾昨朔柵窄策索錯桜鮭笹匙冊刷"],["bba1","察拶撮擦札殺薩雑皐鯖捌錆鮫皿晒三傘参山惨撒散桟燦珊産算纂蚕讃賛酸餐斬暫残仕仔伺使刺司史嗣四士始姉姿子屍市師志思指支孜斯施旨枝止死氏獅祉私糸紙紫肢脂至視詞詩試誌諮資賜雌飼歯事似侍児字寺慈持時"],["bca1","次滋治爾璽痔磁示而耳自蒔辞汐鹿式識鴫竺軸宍雫七叱執失嫉室悉湿漆疾質実蔀篠偲柴芝屡蕊縞舎写射捨赦斜煮社紗者謝車遮蛇邪借勺尺杓灼爵酌釈錫若寂弱惹主取守手朱殊狩珠種腫趣酒首儒受呪寿授樹綬需囚収周"],["bda1","宗就州修愁拾洲秀秋終繍習臭舟蒐衆襲讐蹴輯週酋酬集醜什住充十従戎柔汁渋獣縦重銃叔夙宿淑祝縮粛塾熟出術述俊峻春瞬竣舜駿准循旬楯殉淳準潤盾純巡遵醇順処初所暑曙渚庶緒署書薯藷諸助叙女序徐恕鋤除傷償"],["bea1","勝匠升召哨商唱嘗奨妾娼宵将小少尚庄床廠彰承抄招掌捷昇昌昭晶松梢樟樵沼消渉湘焼焦照症省硝礁祥称章笑粧紹肖菖蒋蕉衝裳訟証詔詳象賞醤鉦鍾鐘障鞘上丈丞乗冗剰城場壌嬢常情擾条杖浄状畳穣蒸譲醸錠嘱埴飾"],["bfa1","拭植殖燭織職色触食蝕辱尻伸信侵唇娠寝審心慎振新晋森榛浸深申疹真神秦紳臣芯薪親診身辛進針震人仁刃塵壬尋甚尽腎訊迅陣靭笥諏須酢図厨逗吹垂帥推水炊睡粋翠衰遂酔錐錘随瑞髄崇嵩数枢趨雛据杉椙菅頗雀裾"],["c0a1","澄摺寸世瀬畝是凄制勢姓征性成政整星晴棲栖正清牲生盛精聖声製西誠誓請逝醒青静斉税脆隻席惜戚斥昔析石積籍績脊責赤跡蹟碩切拙接摂折設窃節説雪絶舌蝉仙先千占宣専尖川戦扇撰栓栴泉浅洗染潜煎煽旋穿箭線"],["c1a1","繊羨腺舛船薦詮賎践選遷銭銑閃鮮前善漸然全禅繕膳糎噌塑岨措曾曽楚狙疏疎礎祖租粗素組蘇訴阻遡鼠僧創双叢倉喪壮奏爽宋層匝惣想捜掃挿掻操早曹巣槍槽漕燥争痩相窓糟総綜聡草荘葬蒼藻装走送遭鎗霜騒像増憎"],["c2a1","臓蔵贈造促側則即息捉束測足速俗属賊族続卒袖其揃存孫尊損村遜他多太汰詑唾堕妥惰打柁舵楕陀駄騨体堆対耐岱帯待怠態戴替泰滞胎腿苔袋貸退逮隊黛鯛代台大第醍題鷹滝瀧卓啄宅托択拓沢濯琢託鐸濁諾茸凧蛸只"],["c3a1","叩但達辰奪脱巽竪辿棚谷狸鱈樽誰丹単嘆坦担探旦歎淡湛炭短端箪綻耽胆蛋誕鍛団壇弾断暖檀段男談値知地弛恥智池痴稚置致蜘遅馳築畜竹筑蓄逐秩窒茶嫡着中仲宙忠抽昼柱注虫衷註酎鋳駐樗瀦猪苧著貯丁兆凋喋寵"],["c4a1","帖帳庁弔張彫徴懲挑暢朝潮牒町眺聴脹腸蝶調諜超跳銚長頂鳥勅捗直朕沈珍賃鎮陳津墜椎槌追鎚痛通塚栂掴槻佃漬柘辻蔦綴鍔椿潰坪壷嬬紬爪吊釣鶴亭低停偵剃貞呈堤定帝底庭廷弟悌抵挺提梯汀碇禎程締艇訂諦蹄逓"],["c5a1","邸鄭釘鼎泥摘擢敵滴的笛適鏑溺哲徹撤轍迭鉄典填天展店添纏甜貼転顛点伝殿澱田電兎吐堵塗妬屠徒斗杜渡登菟賭途都鍍砥砺努度土奴怒倒党冬凍刀唐塔塘套宕島嶋悼投搭東桃梼棟盗淘湯涛灯燈当痘祷等答筒糖統到"],["c6a1","董蕩藤討謄豆踏逃透鐙陶頭騰闘働動同堂導憧撞洞瞳童胴萄道銅峠鴇匿得徳涜特督禿篤毒独読栃橡凸突椴届鳶苫寅酉瀞噸屯惇敦沌豚遁頓呑曇鈍奈那内乍凪薙謎灘捺鍋楢馴縄畷南楠軟難汝二尼弐迩匂賑肉虹廿日乳入"],["c7a1","如尿韮任妊忍認濡禰祢寧葱猫熱年念捻撚燃粘乃廼之埜嚢悩濃納能脳膿農覗蚤巴把播覇杷波派琶破婆罵芭馬俳廃拝排敗杯盃牌背肺輩配倍培媒梅楳煤狽買売賠陪這蝿秤矧萩伯剥博拍柏泊白箔粕舶薄迫曝漠爆縛莫駁麦"],["c8a1","函箱硲箸肇筈櫨幡肌畑畠八鉢溌発醗髪伐罰抜筏閥鳩噺塙蛤隼伴判半反叛帆搬斑板氾汎版犯班畔繁般藩販範釆煩頒飯挽晩番盤磐蕃蛮匪卑否妃庇彼悲扉批披斐比泌疲皮碑秘緋罷肥被誹費避非飛樋簸備尾微枇毘琵眉美"],["c9a1","鼻柊稗匹疋髭彦膝菱肘弼必畢筆逼桧姫媛紐百謬俵彪標氷漂瓢票表評豹廟描病秒苗錨鋲蒜蛭鰭品彬斌浜瀕貧賓頻敏瓶不付埠夫婦富冨布府怖扶敷斧普浮父符腐膚芙譜負賦赴阜附侮撫武舞葡蕪部封楓風葺蕗伏副復幅服"],["caa1","福腹複覆淵弗払沸仏物鮒分吻噴墳憤扮焚奮粉糞紛雰文聞丙併兵塀幣平弊柄並蔽閉陛米頁僻壁癖碧別瞥蔑箆偏変片篇編辺返遍便勉娩弁鞭保舗鋪圃捕歩甫補輔穂募墓慕戊暮母簿菩倣俸包呆報奉宝峰峯崩庖抱捧放方朋"],["cba1","法泡烹砲縫胞芳萌蓬蜂褒訪豊邦鋒飽鳳鵬乏亡傍剖坊妨帽忘忙房暴望某棒冒紡肪膨謀貌貿鉾防吠頬北僕卜墨撲朴牧睦穆釦勃没殆堀幌奔本翻凡盆摩磨魔麻埋妹昧枚毎哩槙幕膜枕鮪柾鱒桝亦俣又抹末沫迄侭繭麿万慢満"],["cca1","漫蔓味未魅巳箕岬密蜜湊蓑稔脈妙粍民眠務夢無牟矛霧鵡椋婿娘冥名命明盟迷銘鳴姪牝滅免棉綿緬面麺摸模茂妄孟毛猛盲網耗蒙儲木黙目杢勿餅尤戻籾貰問悶紋門匁也冶夜爺耶野弥矢厄役約薬訳躍靖柳薮鑓愉愈油癒"],["cda1","諭輸唯佑優勇友宥幽悠憂揖有柚湧涌猶猷由祐裕誘遊邑郵雄融夕予余与誉輿預傭幼妖容庸揚揺擁曜楊様洋溶熔用窯羊耀葉蓉要謡踊遥陽養慾抑欲沃浴翌翼淀羅螺裸来莱頼雷洛絡落酪乱卵嵐欄濫藍蘭覧利吏履李梨理璃"],["cea1","痢裏裡里離陸律率立葎掠略劉流溜琉留硫粒隆竜龍侶慮旅虜了亮僚両凌寮料梁涼猟療瞭稜糧良諒遼量陵領力緑倫厘林淋燐琳臨輪隣鱗麟瑠塁涙累類令伶例冷励嶺怜玲礼苓鈴隷零霊麗齢暦歴列劣烈裂廉恋憐漣煉簾練聯"],["cfa1","蓮連錬呂魯櫓炉賂路露労婁廊弄朗楼榔浪漏牢狼篭老聾蝋郎六麓禄肋録論倭和話歪賄脇惑枠鷲亙亘鰐詫藁蕨椀湾碗腕"],["d0a1","弌丐丕个丱丶丼丿乂乖乘亂亅豫亊舒弍于亞亟亠亢亰亳亶从仍仄仆仂仗仞仭仟价伉佚估佛佝佗佇佶侈侏侘佻佩佰侑佯來侖儘俔俟俎俘俛俑俚俐俤俥倚倨倔倪倥倅伜俶倡倩倬俾俯們倆偃假會偕偐偈做偖偬偸傀傚傅傴傲"],["d1a1","僉僊傳僂僖僞僥僭僣僮價僵儉儁儂儖儕儔儚儡儺儷儼儻儿兀兒兌兔兢竸兩兪兮冀冂囘册冉冏冑冓冕冖冤冦冢冩冪冫决冱冲冰况冽凅凉凛几處凩凭凰凵凾刄刋刔刎刧刪刮刳刹剏剄剋剌剞剔剪剴剩剳剿剽劍劔劒剱劈劑辨"],["d2a1","辧劬劭劼劵勁勍勗勞勣勦飭勠勳勵勸勹匆匈甸匍匐匏匕匚匣匯匱匳匸區卆卅丗卉卍凖卞卩卮夘卻卷厂厖厠厦厥厮厰厶參簒雙叟曼燮叮叨叭叺吁吽呀听吭吼吮吶吩吝呎咏呵咎呟呱呷呰咒呻咀呶咄咐咆哇咢咸咥咬哄哈咨"],["d3a1","咫哂咤咾咼哘哥哦唏唔哽哮哭哺哢唹啀啣啌售啜啅啖啗唸唳啝喙喀咯喊喟啻啾喘喞單啼喃喩喇喨嗚嗅嗟嗄嗜嗤嗔嘔嗷嘖嗾嗽嘛嗹噎噐營嘴嘶嘲嘸噫噤嘯噬噪嚆嚀嚊嚠嚔嚏嚥嚮嚶嚴囂嚼囁囃囀囈囎囑囓囗囮囹圀囿圄圉"],["d4a1","圈國圍圓團圖嗇圜圦圷圸坎圻址坏坩埀垈坡坿垉垓垠垳垤垪垰埃埆埔埒埓堊埖埣堋堙堝塲堡塢塋塰毀塒堽塹墅墹墟墫墺壞墻墸墮壅壓壑壗壙壘壥壜壤壟壯壺壹壻壼壽夂夊夐夛梦夥夬夭夲夸夾竒奕奐奎奚奘奢奠奧奬奩"],["d5a1","奸妁妝佞侫妣妲姆姨姜妍姙姚娥娟娑娜娉娚婀婬婉娵娶婢婪媚媼媾嫋嫂媽嫣嫗嫦嫩嫖嫺嫻嬌嬋嬖嬲嫐嬪嬶嬾孃孅孀孑孕孚孛孥孩孰孳孵學斈孺宀它宦宸寃寇寉寔寐寤實寢寞寥寫寰寶寳尅將專對尓尠尢尨尸尹屁屆屎屓"],["d6a1","屐屏孱屬屮乢屶屹岌岑岔妛岫岻岶岼岷峅岾峇峙峩峽峺峭嶌峪崋崕崗嵜崟崛崑崔崢崚崙崘嵌嵒嵎嵋嵬嵳嵶嶇嶄嶂嶢嶝嶬嶮嶽嶐嶷嶼巉巍巓巒巖巛巫已巵帋帚帙帑帛帶帷幄幃幀幎幗幔幟幢幤幇幵并幺麼广庠廁廂廈廐廏"],["d7a1","廖廣廝廚廛廢廡廨廩廬廱廳廰廴廸廾弃弉彝彜弋弑弖弩弭弸彁彈彌彎弯彑彖彗彙彡彭彳彷徃徂彿徊很徑徇從徙徘徠徨徭徼忖忻忤忸忱忝悳忿怡恠怙怐怩怎怱怛怕怫怦怏怺恚恁恪恷恟恊恆恍恣恃恤恂恬恫恙悁悍惧悃悚"],["d8a1","悄悛悖悗悒悧悋惡悸惠惓悴忰悽惆悵惘慍愕愆惶惷愀惴惺愃愡惻惱愍愎慇愾愨愧慊愿愼愬愴愽慂慄慳慷慘慙慚慫慴慯慥慱慟慝慓慵憙憖憇憬憔憚憊憑憫憮懌懊應懷懈懃懆憺懋罹懍懦懣懶懺懴懿懽懼懾戀戈戉戍戌戔戛"],["d9a1","戞戡截戮戰戲戳扁扎扞扣扛扠扨扼抂抉找抒抓抖拔抃抔拗拑抻拏拿拆擔拈拜拌拊拂拇抛拉挌拮拱挧挂挈拯拵捐挾捍搜捏掖掎掀掫捶掣掏掉掟掵捫捩掾揩揀揆揣揉插揶揄搖搴搆搓搦搶攝搗搨搏摧摯摶摎攪撕撓撥撩撈撼"],["daa1","據擒擅擇撻擘擂擱擧舉擠擡抬擣擯攬擶擴擲擺攀擽攘攜攅攤攣攫攴攵攷收攸畋效敖敕敍敘敞敝敲數斂斃變斛斟斫斷旃旆旁旄旌旒旛旙无旡旱杲昊昃旻杳昵昶昴昜晏晄晉晁晞晝晤晧晨晟晢晰暃暈暎暉暄暘暝曁暹曉暾暼"],["dba1","曄暸曖曚曠昿曦曩曰曵曷朏朖朞朦朧霸朮朿朶杁朸朷杆杞杠杙杣杤枉杰枩杼杪枌枋枦枡枅枷柯枴柬枳柩枸柤柞柝柢柮枹柎柆柧檜栞框栩桀桍栲桎梳栫桙档桷桿梟梏梭梔條梛梃檮梹桴梵梠梺椏梍桾椁棊椈棘椢椦棡椌棍"],["dca1","棔棧棕椶椒椄棗棣椥棹棠棯椨椪椚椣椡棆楹楷楜楸楫楔楾楮椹楴椽楙椰楡楞楝榁楪榲榮槐榿槁槓榾槎寨槊槝榻槃榧樮榑榠榜榕榴槞槨樂樛槿權槹槲槧樅榱樞槭樔槫樊樒櫁樣樓橄樌橲樶橸橇橢橙橦橈樸樢檐檍檠檄檢檣"],["dda1","檗蘗檻櫃櫂檸檳檬櫞櫑櫟檪櫚櫪櫻欅蘖櫺欒欖鬱欟欸欷盜欹飮歇歃歉歐歙歔歛歟歡歸歹歿殀殄殃殍殘殕殞殤殪殫殯殲殱殳殷殼毆毋毓毟毬毫毳毯麾氈氓气氛氤氣汞汕汢汪沂沍沚沁沛汾汨汳沒沐泄泱泓沽泗泅泝沮沱沾"],["dea1","沺泛泯泙泪洟衍洶洫洽洸洙洵洳洒洌浣涓浤浚浹浙涎涕濤涅淹渕渊涵淇淦涸淆淬淞淌淨淒淅淺淙淤淕淪淮渭湮渮渙湲湟渾渣湫渫湶湍渟湃渺湎渤滿渝游溂溪溘滉溷滓溽溯滄溲滔滕溏溥滂溟潁漑灌滬滸滾漿滲漱滯漲滌"],["dfa1","漾漓滷澆潺潸澁澀潯潛濳潭澂潼潘澎澑濂潦澳澣澡澤澹濆澪濟濕濬濔濘濱濮濛瀉瀋濺瀑瀁瀏濾瀛瀚潴瀝瀘瀟瀰瀾瀲灑灣炙炒炯烱炬炸炳炮烟烋烝烙焉烽焜焙煥煕熈煦煢煌煖煬熏燻熄熕熨熬燗熹熾燒燉燔燎燠燬燧燵燼"],["e0a1","燹燿爍爐爛爨爭爬爰爲爻爼爿牀牆牋牘牴牾犂犁犇犒犖犢犧犹犲狃狆狄狎狒狢狠狡狹狷倏猗猊猜猖猝猴猯猩猥猾獎獏默獗獪獨獰獸獵獻獺珈玳珎玻珀珥珮珞璢琅瑯琥珸琲琺瑕琿瑟瑙瑁瑜瑩瑰瑣瑪瑶瑾璋璞璧瓊瓏瓔珱"],["e1a1","瓠瓣瓧瓩瓮瓲瓰瓱瓸瓷甄甃甅甌甎甍甕甓甞甦甬甼畄畍畊畉畛畆畚畩畤畧畫畭畸當疆疇畴疊疉疂疔疚疝疥疣痂疳痃疵疽疸疼疱痍痊痒痙痣痞痾痿痼瘁痰痺痲痳瘋瘍瘉瘟瘧瘠瘡瘢瘤瘴瘰瘻癇癈癆癜癘癡癢癨癩癪癧癬癰"],["e2a1","癲癶癸發皀皃皈皋皎皖皓皙皚皰皴皸皹皺盂盍盖盒盞盡盥盧盪蘯盻眈眇眄眩眤眞眥眦眛眷眸睇睚睨睫睛睥睿睾睹瞎瞋瞑瞠瞞瞰瞶瞹瞿瞼瞽瞻矇矍矗矚矜矣矮矼砌砒礦砠礪硅碎硴碆硼碚碌碣碵碪碯磑磆磋磔碾碼磅磊磬"],["e3a1","磧磚磽磴礇礒礑礙礬礫祀祠祗祟祚祕祓祺祿禊禝禧齋禪禮禳禹禺秉秕秧秬秡秣稈稍稘稙稠稟禀稱稻稾稷穃穗穉穡穢穩龝穰穹穽窈窗窕窘窖窩竈窰窶竅竄窿邃竇竊竍竏竕竓站竚竝竡竢竦竭竰笂笏笊笆笳笘笙笞笵笨笶筐"],["e4a1","筺笄筍笋筌筅筵筥筴筧筰筱筬筮箝箘箟箍箜箚箋箒箏筝箙篋篁篌篏箴篆篝篩簑簔篦篥籠簀簇簓篳篷簗簍篶簣簧簪簟簷簫簽籌籃籔籏籀籐籘籟籤籖籥籬籵粃粐粤粭粢粫粡粨粳粲粱粮粹粽糀糅糂糘糒糜糢鬻糯糲糴糶糺紆"],["e5a1","紂紜紕紊絅絋紮紲紿紵絆絳絖絎絲絨絮絏絣經綉絛綏絽綛綺綮綣綵緇綽綫總綢綯緜綸綟綰緘緝緤緞緻緲緡縅縊縣縡縒縱縟縉縋縢繆繦縻縵縹繃縷縲縺繧繝繖繞繙繚繹繪繩繼繻纃緕繽辮繿纈纉續纒纐纓纔纖纎纛纜缸缺"],["e6a1","罅罌罍罎罐网罕罔罘罟罠罨罩罧罸羂羆羃羈羇羌羔羞羝羚羣羯羲羹羮羶羸譱翅翆翊翕翔翡翦翩翳翹飜耆耄耋耒耘耙耜耡耨耿耻聊聆聒聘聚聟聢聨聳聲聰聶聹聽聿肄肆肅肛肓肚肭冐肬胛胥胙胝胄胚胖脉胯胱脛脩脣脯腋"],["e7a1","隋腆脾腓腑胼腱腮腥腦腴膃膈膊膀膂膠膕膤膣腟膓膩膰膵膾膸膽臀臂膺臉臍臑臙臘臈臚臟臠臧臺臻臾舁舂舅與舊舍舐舖舩舫舸舳艀艙艘艝艚艟艤艢艨艪艫舮艱艷艸艾芍芒芫芟芻芬苡苣苟苒苴苳苺莓范苻苹苞茆苜茉苙"],["e8a1","茵茴茖茲茱荀茹荐荅茯茫茗茘莅莚莪莟莢莖茣莎莇莊荼莵荳荵莠莉莨菴萓菫菎菽萃菘萋菁菷萇菠菲萍萢萠莽萸蔆菻葭萪萼蕚蒄葷葫蒭葮蒂葩葆萬葯葹萵蓊葢蒹蒿蒟蓙蓍蒻蓚蓐蓁蓆蓖蒡蔡蓿蓴蔗蔘蔬蔟蔕蔔蓼蕀蕣蕘蕈"],["e9a1","蕁蘂蕋蕕薀薤薈薑薊薨蕭薔薛藪薇薜蕷蕾薐藉薺藏薹藐藕藝藥藜藹蘊蘓蘋藾藺蘆蘢蘚蘰蘿虍乕虔號虧虱蚓蚣蚩蚪蚋蚌蚶蚯蛄蛆蚰蛉蠣蚫蛔蛞蛩蛬蛟蛛蛯蜒蜆蜈蜀蜃蛻蜑蜉蜍蛹蜊蜴蜿蜷蜻蜥蜩蜚蝠蝟蝸蝌蝎蝴蝗蝨蝮蝙"],["eaa1","蝓蝣蝪蠅螢螟螂螯蟋螽蟀蟐雖螫蟄螳蟇蟆螻蟯蟲蟠蠏蠍蟾蟶蟷蠎蟒蠑蠖蠕蠢蠡蠱蠶蠹蠧蠻衄衂衒衙衞衢衫袁衾袞衵衽袵衲袂袗袒袮袙袢袍袤袰袿袱裃裄裔裘裙裝裹褂裼裴裨裲褄褌褊褓襃褞褥褪褫襁襄褻褶褸襌褝襠襞"],["eba1","襦襤襭襪襯襴襷襾覃覈覊覓覘覡覩覦覬覯覲覺覽覿觀觚觜觝觧觴觸訃訖訐訌訛訝訥訶詁詛詒詆詈詼詭詬詢誅誂誄誨誡誑誥誦誚誣諄諍諂諚諫諳諧諤諱謔諠諢諷諞諛謌謇謚諡謖謐謗謠謳鞫謦謫謾謨譁譌譏譎證譖譛譚譫"],["eca1","譟譬譯譴譽讀讌讎讒讓讖讙讚谺豁谿豈豌豎豐豕豢豬豸豺貂貉貅貊貍貎貔豼貘戝貭貪貽貲貳貮貶賈賁賤賣賚賽賺賻贄贅贊贇贏贍贐齎贓賍贔贖赧赭赱赳趁趙跂趾趺跏跚跖跌跛跋跪跫跟跣跼踈踉跿踝踞踐踟蹂踵踰踴蹊"],["eda1","蹇蹉蹌蹐蹈蹙蹤蹠踪蹣蹕蹶蹲蹼躁躇躅躄躋躊躓躑躔躙躪躡躬躰軆躱躾軅軈軋軛軣軼軻軫軾輊輅輕輒輙輓輜輟輛輌輦輳輻輹轅轂輾轌轉轆轎轗轜轢轣轤辜辟辣辭辯辷迚迥迢迪迯邇迴逅迹迺逑逕逡逍逞逖逋逧逶逵逹迸"],["eea1","遏遐遑遒逎遉逾遖遘遞遨遯遶隨遲邂遽邁邀邊邉邏邨邯邱邵郢郤扈郛鄂鄒鄙鄲鄰酊酖酘酣酥酩酳酲醋醉醂醢醫醯醪醵醴醺釀釁釉釋釐釖釟釡釛釼釵釶鈞釿鈔鈬鈕鈑鉞鉗鉅鉉鉤鉈銕鈿鉋鉐銜銖銓銛鉚鋏銹銷鋩錏鋺鍄錮"],["efa1","錙錢錚錣錺錵錻鍜鍠鍼鍮鍖鎰鎬鎭鎔鎹鏖鏗鏨鏥鏘鏃鏝鏐鏈鏤鐚鐔鐓鐃鐇鐐鐶鐫鐵鐡鐺鑁鑒鑄鑛鑠鑢鑞鑪鈩鑰鑵鑷鑽鑚鑼鑾钁鑿閂閇閊閔閖閘閙閠閨閧閭閼閻閹閾闊濶闃闍闌闕闔闖關闡闥闢阡阨阮阯陂陌陏陋陷陜陞"],["f0a1","陝陟陦陲陬隍隘隕隗險隧隱隲隰隴隶隸隹雎雋雉雍襍雜霍雕雹霄霆霈霓霎霑霏霖霙霤霪霰霹霽霾靄靆靈靂靉靜靠靤靦靨勒靫靱靹鞅靼鞁靺鞆鞋鞏鞐鞜鞨鞦鞣鞳鞴韃韆韈韋韜韭齏韲竟韶韵頏頌頸頤頡頷頽顆顏顋顫顯顰"],["f1a1","顱顴顳颪颯颱颶飄飃飆飩飫餃餉餒餔餘餡餝餞餤餠餬餮餽餾饂饉饅饐饋饑饒饌饕馗馘馥馭馮馼駟駛駝駘駑駭駮駱駲駻駸騁騏騅駢騙騫騷驅驂驀驃騾驕驍驛驗驟驢驥驤驩驫驪骭骰骼髀髏髑髓體髞髟髢髣髦髯髫髮髴髱髷"],["f2a1","髻鬆鬘鬚鬟鬢鬣鬥鬧鬨鬩鬪鬮鬯鬲魄魃魏魍魎魑魘魴鮓鮃鮑鮖鮗鮟鮠鮨鮴鯀鯊鮹鯆鯏鯑鯒鯣鯢鯤鯔鯡鰺鯲鯱鯰鰕鰔鰉鰓鰌鰆鰈鰒鰊鰄鰮鰛鰥鰤鰡鰰鱇鰲鱆鰾鱚鱠鱧鱶鱸鳧鳬鳰鴉鴈鳫鴃鴆鴪鴦鶯鴣鴟鵄鴕鴒鵁鴿鴾鵆鵈"],["f3a1","鵝鵞鵤鵑鵐鵙鵲鶉鶇鶫鵯鵺鶚鶤鶩鶲鷄鷁鶻鶸鶺鷆鷏鷂鷙鷓鷸鷦鷭鷯鷽鸚鸛鸞鹵鹹鹽麁麈麋麌麒麕麑麝麥麩麸麪麭靡黌黎黏黐黔黜點黝黠黥黨黯黴黶黷黹黻黼黽鼇鼈皷鼕鼡鼬鼾齊齒齔齣齟齠齡齦齧齬齪齷齲齶龕龜龠"],["f4a1","堯槇遙瑤凜熙"],["f9a1","纊褜鍈銈蓜俉炻昱棈鋹曻彅丨仡仼伀伃伹佖侒侊侚侔俍偀倢俿倞偆偰偂傔僴僘兊兤冝冾凬刕劜劦勀勛匀匇匤卲厓厲叝﨎咜咊咩哿喆坙坥垬埈埇﨏塚增墲夋奓奛奝奣妤妺孖寀甯寘寬尞岦岺峵崧嵓﨑嵂嵭嶸嶹巐弡弴彧德"],["faa1","忞恝悅悊惞惕愠惲愑愷愰憘戓抦揵摠撝擎敎昀昕昻昉昮昞昤晥晗晙晴晳暙暠暲暿曺朎朗杦枻桒柀栁桄棏﨓楨﨔榘槢樰橫橆橳橾櫢櫤毖氿汜沆汯泚洄涇浯涖涬淏淸淲淼渹湜渧渼溿澈澵濵瀅瀇瀨炅炫焏焄煜煆煇凞燁燾犱"],["fba1","犾猤猪獷玽珉珖珣珒琇珵琦琪琩琮瑢璉璟甁畯皂皜皞皛皦益睆劯砡硎硤硺礰礼神祥禔福禛竑竧靖竫箞精絈絜綷綠緖繒罇羡羽茁荢荿菇菶葈蒴蕓蕙蕫﨟薰蘒﨡蠇裵訒訷詹誧誾諟諸諶譓譿賰賴贒赶﨣軏﨤逸遧郞都鄕鄧釚"],["fca1","釗釞釭釮釤釥鈆鈐鈊鈺鉀鈼鉎鉙鉑鈹鉧銧鉷鉸鋧鋗鋙鋐﨧鋕鋠鋓錥錡鋻﨨錞鋿錝錂鍰鍗鎤鏆鏞鏸鐱鑅鑈閒隆﨩隝隯霳霻靃靍靏靑靕顗顥飯飼餧館馞驎髙髜魵魲鮏鮱鮻鰀鵰鵫鶴鸙黑"],["fcf1","ⅰ",9,"￢￤＇＂"],["8fa2af","˘ˇ¸˙˝¯˛˚～΄΅"],["8fa2c2","¡¦¿"],["8fa2eb","ºª©®™¤№"],["8fa6e1","ΆΈΉΊΪ"],["8fa6e7","Ό"],["8fa6e9","ΎΫ"],["8fa6ec","Ώ"],["8fa6f1","άέήίϊΐόςύϋΰώ"],["8fa7c2","Ђ",10,"ЎЏ"],["8fa7f2","ђ",10,"ўџ"],["8fa9a1","ÆĐ"],["8fa9a4","Ħ"],["8fa9a6","Ĳ"],["8fa9a8","ŁĿ"],["8fa9ab","ŊØŒ"],["8fa9af","ŦÞ"],["8fa9c1","æđðħıĳĸłŀŉŋøœßŧþ"],["8faaa1","ÁÀÄÂĂǍĀĄÅÃĆĈČÇĊĎÉÈËÊĚĖĒĘ"],["8faaba","ĜĞĢĠĤÍÌÏÎǏİĪĮĨĴĶĹĽĻŃŇŅÑÓÒÖÔǑŐŌÕŔŘŖŚŜŠŞŤŢÚÙÜÛŬǓŰŪŲŮŨǗǛǙǕŴÝŸŶŹŽŻ"],["8faba1","áàäâăǎāąåãćĉčçċďéèëêěėēęǵĝğ"],["8fabbd","ġĥíìïîǐ"],["8fabc5","īįĩĵķĺľļńňņñóòöôǒőōõŕřŗśŝšşťţúùüûŭǔűūųůũǘǜǚǖŵýÿŷźžż"],["8fb0a1","丂丄丅丌丒丟丣两丨丫丮丯丰丵乀乁乄乇乑乚乜乣乨乩乴乵乹乿亍亖亗亝亯亹仃仐仚仛仠仡仢仨仯仱仳仵份仾仿伀伂伃伈伋伌伒伕伖众伙伮伱你伳伵伷伹伻伾佀佂佈佉佋佌佒佔佖佘佟佣佪佬佮佱佷佸佹佺佽佾侁侂侄"],["8fb1a1","侅侉侊侌侎侐侒侓侔侗侙侚侞侟侲侷侹侻侼侽侾俀俁俅俆俈俉俋俌俍俏俒俜俠俢俰俲俼俽俿倀倁倄倇倊倌倎倐倓倗倘倛倜倝倞倢倧倮倰倲倳倵偀偁偂偅偆偊偌偎偑偒偓偗偙偟偠偢偣偦偧偪偭偰偱倻傁傃傄傆傊傎傏傐"],["8fb2a1","傒傓傔傖傛傜傞",4,"傪傯傰傹傺傽僀僃僄僇僌僎僐僓僔僘僜僝僟僢僤僦僨僩僯僱僶僺僾儃儆儇儈儋儌儍儎僲儐儗儙儛儜儝儞儣儧儨儬儭儯儱儳儴儵儸儹兂兊兏兓兕兗兘兟兤兦兾冃冄冋冎冘冝冡冣冭冸冺冼冾冿凂"],["8fb3a1","凈减凑凒凓凕凘凞凢凥凮凲凳凴凷刁刂刅划刓刕刖刘刢刨刱刲刵刼剅剉剕剗剘剚剜剟剠剡剦剮剷剸剹劀劂劅劊劌劓劕劖劗劘劚劜劤劥劦劧劯劰劶劷劸劺劻劽勀勄勆勈勌勏勑勔勖勛勜勡勥勨勩勪勬勰勱勴勶勷匀匃匊匋"],["8fb4a1","匌匑匓匘匛匜匞匟匥匧匨匩匫匬匭匰匲匵匼匽匾卂卌卋卙卛卡卣卥卬卭卲卹卾厃厇厈厎厓厔厙厝厡厤厪厫厯厲厴厵厷厸厺厽叀叅叏叒叓叕叚叝叞叠另叧叵吂吓吚吡吧吨吪启吱吴吵呃呄呇呍呏呞呢呤呦呧呩呫呭呮呴呿"],["8fb5a1","咁咃咅咈咉咍咑咕咖咜咟咡咦咧咩咪咭咮咱咷咹咺咻咿哆哊响哎哠哪哬哯哶哼哾哿唀唁唅唈唉唌唍唎唕唪唫唲唵唶唻唼唽啁啇啉啊啍啐啑啘啚啛啞啠啡啤啦啿喁喂喆喈喎喏喑喒喓喔喗喣喤喭喲喿嗁嗃嗆嗉嗋嗌嗎嗑嗒"],["8fb6a1","嗓嗗嗘嗛嗞嗢嗩嗶嗿嘅嘈嘊嘍",5,"嘙嘬嘰嘳嘵嘷嘹嘻嘼嘽嘿噀噁噃噄噆噉噋噍噏噔噞噠噡噢噣噦噩噭噯噱噲噵嚄嚅嚈嚋嚌嚕嚙嚚嚝嚞嚟嚦嚧嚨嚩嚫嚬嚭嚱嚳嚷嚾囅囉囊囋囏囐囌囍囙囜囝囟囡囤",4,"囱囫园"],["8fb7a1","囶囷圁圂圇圊圌圑圕圚圛圝圠圢圣圤圥圩圪圬圮圯圳圴圽圾圿坅坆坌坍坒坢坥坧坨坫坭",4,"坳坴坵坷坹坺坻坼坾垁垃垌垔垗垙垚垜垝垞垟垡垕垧垨垩垬垸垽埇埈埌埏埕埝埞埤埦埧埩埭埰埵埶埸埽埾埿堃堄堈堉埡"],["8fb8a1","堌堍堛堞堟堠堦堧堭堲堹堿塉塌塍塏塐塕塟塡塤塧塨塸塼塿墀墁墇墈墉墊墌墍墏墐墔墖墝墠墡墢墦墩墱墲壄墼壂壈壍壎壐壒壔壖壚壝壡壢壩壳夅夆夋夌夒夓夔虁夝夡夣夤夨夯夰夳夵夶夿奃奆奒奓奙奛奝奞奟奡奣奫奭"],["8fb9a1","奯奲奵奶她奻奼妋妌妎妒妕妗妟妤妧妭妮妯妰妳妷妺妼姁姃姄姈姊姍姒姝姞姟姣姤姧姮姯姱姲姴姷娀娄娌娍娎娒娓娞娣娤娧娨娪娭娰婄婅婇婈婌婐婕婞婣婥婧婭婷婺婻婾媋媐媓媖媙媜媞媟媠媢媧媬媱媲媳媵媸媺媻媿"],["8fbaa1","嫄嫆嫈嫏嫚嫜嫠嫥嫪嫮嫵嫶嫽嬀嬁嬈嬗嬴嬙嬛嬝嬡嬥嬭嬸孁孋孌孒孖孞孨孮孯孼孽孾孿宁宄宆宊宎宐宑宓宔宖宨宩宬宭宯宱宲宷宺宼寀寁寍寏寖",4,"寠寯寱寴寽尌尗尞尟尣尦尩尫尬尮尰尲尵尶屙屚屜屢屣屧屨屩"],["8fbba1","屭屰屴屵屺屻屼屽岇岈岊岏岒岝岟岠岢岣岦岪岲岴岵岺峉峋峒峝峗峮峱峲峴崁崆崍崒崫崣崤崦崧崱崴崹崽崿嵂嵃嵆嵈嵕嵑嵙嵊嵟嵠嵡嵢嵤嵪嵭嵰嵹嵺嵾嵿嶁嶃嶈嶊嶒嶓嶔嶕嶙嶛嶟嶠嶧嶫嶰嶴嶸嶹巃巇巋巐巎巘巙巠巤"],["8fbca1","巩巸巹帀帇帍帒帔帕帘帟帠帮帨帲帵帾幋幐幉幑幖幘幛幜幞幨幪",4,"幰庀庋庎庢庤庥庨庪庬庱庳庽庾庿廆廌廋廎廑廒廔廕廜廞廥廫异弆弇弈弎弙弜弝弡弢弣弤弨弫弬弮弰弴弶弻弽弿彀彄彅彇彍彐彔彘彛彠彣彤彧"],["8fbda1","彯彲彴彵彸彺彽彾徉徍徏徖徜徝徢徧徫徤徬徯徰徱徸忄忇忈忉忋忐",4,"忞忡忢忨忩忪忬忭忮忯忲忳忶忺忼怇怊怍怓怔怗怘怚怟怤怭怳怵恀恇恈恉恌恑恔恖恗恝恡恧恱恾恿悂悆悈悊悎悑悓悕悘悝悞悢悤悥您悰悱悷"],["8fbea1","悻悾惂惄惈惉惊惋惎惏惔惕惙惛惝惞惢惥惲惵惸惼惽愂愇愊愌愐",4,"愖愗愙愜愞愢愪愫愰愱愵愶愷愹慁慅慆慉慞慠慬慲慸慻慼慿憀憁憃憄憋憍憒憓憗憘憜憝憟憠憥憨憪憭憸憹憼懀懁懂懎懏懕懜懝懞懟懡懢懧懩懥"],["8fbfa1","懬懭懯戁戃戄戇戓戕戜戠戢戣戧戩戫戹戽扂扃扄扆扌扐扑扒扔扖扚扜扤扭扯扳扺扽抍抎抏抐抦抨抳抶抷抺抾抿拄拎拕拖拚拪拲拴拼拽挃挄挊挋挍挐挓挖挘挩挪挭挵挶挹挼捁捂捃捄捆捊捋捎捒捓捔捘捛捥捦捬捭捱捴捵"],["8fc0a1","捸捼捽捿掂掄掇掊掐掔掕掙掚掞掤掦掭掮掯掽揁揅揈揎揑揓揔揕揜揠揥揪揬揲揳揵揸揹搉搊搐搒搔搘搞搠搢搤搥搩搪搯搰搵搽搿摋摏摑摒摓摔摚摛摜摝摟摠摡摣摭摳摴摻摽撅撇撏撐撑撘撙撛撝撟撡撣撦撨撬撳撽撾撿"],["8fc1a1","擄擉擊擋擌擎擐擑擕擗擤擥擩擪擭擰擵擷擻擿攁攄攈攉攊攏攓攔攖攙攛攞攟攢攦攩攮攱攺攼攽敃敇敉敐敒敔敟敠敧敫敺敽斁斅斊斒斕斘斝斠斣斦斮斲斳斴斿旂旈旉旎旐旔旖旘旟旰旲旴旵旹旾旿昀昄昈昉昍昑昒昕昖昝"],["8fc2a1","昞昡昢昣昤昦昩昪昫昬昮昰昱昳昹昷晀晅晆晊晌晑晎晗晘晙晛晜晠晡曻晪晫晬晾晳晵晿晷晸晹晻暀晼暋暌暍暐暒暙暚暛暜暟暠暤暭暱暲暵暻暿曀曂曃曈曌曎曏曔曛曟曨曫曬曮曺朅朇朎朓朙朜朠朢朳朾杅杇杈杌杔杕杝"],["8fc3a1","杦杬杮杴杶杻极构枎枏枑枓枖枘枙枛枰枱枲枵枻枼枽柹柀柂柃柅柈柉柒柗柙柜柡柦柰柲柶柷桒栔栙栝栟栨栧栬栭栯栰栱栳栻栿桄桅桊桌桕桗桘桛桫桮",4,"桵桹桺桻桼梂梄梆梈梖梘梚梜梡梣梥梩梪梮梲梻棅棈棌棏"],["8fc4a1","棐棑棓棖棙棜棝棥棨棪棫棬棭棰棱棵棶棻棼棽椆椉椊椐椑椓椖椗椱椳椵椸椻楂楅楉楎楗楛楣楤楥楦楨楩楬楰楱楲楺楻楿榀榍榒榖榘榡榥榦榨榫榭榯榷榸榺榼槅槈槑槖槗槢槥槮槯槱槳槵槾樀樁樃樏樑樕樚樝樠樤樨樰樲"],["8fc5a1","樴樷樻樾樿橅橆橉橊橎橐橑橒橕橖橛橤橧橪橱橳橾檁檃檆檇檉檋檑檛檝檞檟檥檫檯檰檱檴檽檾檿櫆櫉櫈櫌櫐櫔櫕櫖櫜櫝櫤櫧櫬櫰櫱櫲櫼櫽欂欃欆欇欉欏欐欑欗欛欞欤欨欫欬欯欵欶欻欿歆歊歍歒歖歘歝歠歧歫歮歰歵歽"],["8fc6a1","歾殂殅殗殛殟殠殢殣殨殩殬殭殮殰殸殹殽殾毃毄毉毌毖毚毡毣毦毧毮毱毷毹毿氂氄氅氉氍氎氐氒氙氟氦氧氨氬氮氳氵氶氺氻氿汊汋汍汏汒汔汙汛汜汫汭汯汴汶汸汹汻沅沆沇沉沔沕沗沘沜沟沰沲沴泂泆泍泏泐泑泒泔泖"],["8fc7a1","泚泜泠泧泩泫泬泮泲泴洄洇洊洎洏洑洓洚洦洧洨汧洮洯洱洹洼洿浗浞浟浡浥浧浯浰浼涂涇涑涒涔涖涗涘涪涬涴涷涹涽涿淄淈淊淎淏淖淛淝淟淠淢淥淩淯淰淴淶淼渀渄渞渢渧渲渶渹渻渼湄湅湈湉湋湏湑湒湓湔湗湜湝湞"],["8fc8a1","湢湣湨湳湻湽溍溓溙溠溧溭溮溱溳溻溿滀滁滃滇滈滊滍滎滏滫滭滮滹滻滽漄漈漊漌漍漖漘漚漛漦漩漪漯漰漳漶漻漼漭潏潑潒潓潗潙潚潝潞潡潢潨潬潽潾澃澇澈澋澌澍澐澒澓澔澖澚澟澠澥澦澧澨澮澯澰澵澶澼濅濇濈濊"],["8fc9a1","濚濞濨濩濰濵濹濼濽瀀瀅瀆瀇瀍瀗瀠瀣瀯瀴瀷瀹瀼灃灄灈灉灊灋灔灕灝灞灎灤灥灬灮灵灶灾炁炅炆炔",4,"炛炤炫炰炱炴炷烊烑烓烔烕烖烘烜烤烺焃",4,"焋焌焏焞焠焫焭焯焰焱焸煁煅煆煇煊煋煐煒煗煚煜煞煠"],["8fcaa1","煨煹熀熅熇熌熒熚熛熠熢熯熰熲熳熺熿燀燁燄燋燌燓燖燙燚燜燸燾爀爇爈爉爓爗爚爝爟爤爫爯爴爸爹牁牂牃牅牎牏牐牓牕牖牚牜牞牠牣牨牫牮牯牱牷牸牻牼牿犄犉犍犎犓犛犨犭犮犱犴犾狁狇狉狌狕狖狘狟狥狳狴狺狻"],["8fcba1","狾猂猄猅猇猋猍猒猓猘猙猞猢猤猧猨猬猱猲猵猺猻猽獃獍獐獒獖獘獝獞獟獠獦獧獩獫獬獮獯獱獷獹獼玀玁玃玅玆玎玐玓玕玗玘玜玞玟玠玢玥玦玪玫玭玵玷玹玼玽玿珅珆珉珋珌珏珒珓珖珙珝珡珣珦珧珩珴珵珷珹珺珻珽"],["8fcca1","珿琀琁琄琇琊琑琚琛琤琦琨",9,"琹瑀瑃瑄瑆瑇瑋瑍瑑瑒瑗瑝瑢瑦瑧瑨瑫瑭瑮瑱瑲璀璁璅璆璇璉璏璐璑璒璘璙璚璜璟璠璡璣璦璨璩璪璫璮璯璱璲璵璹璻璿瓈瓉瓌瓐瓓瓘瓚瓛瓞瓟瓤瓨瓪瓫瓯瓴瓺瓻瓼瓿甆"],["8fcda1","甒甖甗甠甡甤甧甩甪甯甶甹甽甾甿畀畃畇畈畎畐畒畗畞畟畡畯畱畹",5,"疁疅疐疒疓疕疙疜疢疤疴疺疿痀痁痄痆痌痎痏痗痜痟痠痡痤痧痬痮痯痱痹瘀瘂瘃瘄瘇瘈瘊瘌瘏瘒瘓瘕瘖瘙瘛瘜瘝瘞瘣瘥瘦瘩瘭瘲瘳瘵瘸瘹"],["8fcea1","瘺瘼癊癀癁癃癄癅癉癋癕癙癟癤癥癭癮癯癱癴皁皅皌皍皕皛皜皝皟皠皢",6,"皪皭皽盁盅盉盋盌盎盔盙盠盦盨盬盰盱盶盹盼眀眆眊眎眒眔眕眗眙眚眜眢眨眭眮眯眴眵眶眹眽眾睂睅睆睊睍睎睏睒睖睗睜睞睟睠睢"],["8fcfa1","睤睧睪睬睰睲睳睴睺睽瞀瞄瞌瞍瞔瞕瞖瞚瞟瞢瞧瞪瞮瞯瞱瞵瞾矃矉矑矒矕矙矞矟矠矤矦矪矬矰矱矴矸矻砅砆砉砍砎砑砝砡砢砣砭砮砰砵砷硃硄硇硈硌硎硒硜硞硠硡硣硤硨硪确硺硾碊碏碔碘碡碝碞碟碤碨碬碭碰碱碲碳"],["8fd0a1","碻碽碿磇磈磉磌磎磒磓磕磖磤磛磟磠磡磦磪磲磳礀磶磷磺磻磿礆礌礐礚礜礞礟礠礥礧礩礭礱礴礵礻礽礿祄祅祆祊祋祏祑祔祘祛祜祧祩祫祲祹祻祼祾禋禌禑禓禔禕禖禘禛禜禡禨禩禫禯禱禴禸离秂秄秇秈秊秏秔秖秚秝秞"],["8fd1a1","秠秢秥秪秫秭秱秸秼稂稃稇稉稊稌稑稕稛稞稡稧稫稭稯稰稴稵稸稹稺穄穅穇穈穌穕穖穙穜穝穟穠穥穧穪穭穵穸穾窀窂窅窆窊窋窐窑窔窞窠窣窬窳窵窹窻窼竆竉竌竎竑竛竨竩竫竬竱竴竻竽竾笇笔笟笣笧笩笪笫笭笮笯笰"],["8fd2a1","笱笴笽笿筀筁筇筎筕筠筤筦筩筪筭筯筲筳筷箄箉箎箐箑箖箛箞箠箥箬箯箰箲箵箶箺箻箼箽篂篅篈篊篔篖篗篙篚篛篨篪篲篴篵篸篹篺篼篾簁簂簃簄簆簉簋簌簎簏簙簛簠簥簦簨簬簱簳簴簶簹簺籆籊籕籑籒籓籙",5],["8fd3a1","籡籣籧籩籭籮籰籲籹籼籽粆粇粏粔粞粠粦粰粶粷粺粻粼粿糄糇糈糉糍糏糓糔糕糗糙糚糝糦糩糫糵紃紇紈紉紏紑紒紓紖紝紞紣紦紪紭紱紼紽紾絀絁絇絈絍絑絓絗絙絚絜絝絥絧絪絰絸絺絻絿綁綂綃綅綆綈綋綌綍綑綖綗綝"],["8fd4a1","綞綦綧綪綳綶綷綹緂",4,"緌緍緎緗緙縀緢緥緦緪緫緭緱緵緶緹緺縈縐縑縕縗縜縝縠縧縨縬縭縯縳縶縿繄繅繇繎繐繒繘繟繡繢繥繫繮繯繳繸繾纁纆纇纊纍纑纕纘纚纝纞缼缻缽缾缿罃罄罇罏罒罓罛罜罝罡罣罤罥罦罭"],["8fd5a1","罱罽罾罿羀羋羍羏羐羑羖羗羜羡羢羦羪羭羴羼羿翀翃翈翎翏翛翟翣翥翨翬翮翯翲翺翽翾翿耇耈耊耍耎耏耑耓耔耖耝耞耟耠耤耦耬耮耰耴耵耷耹耺耼耾聀聄聠聤聦聭聱聵肁肈肎肜肞肦肧肫肸肹胈胍胏胒胔胕胗胘胠胭胮"],["8fd6a1","胰胲胳胶胹胺胾脃脋脖脗脘脜脞脠脤脧脬脰脵脺脼腅腇腊腌腒腗腠腡腧腨腩腭腯腷膁膐膄膅膆膋膎膖膘膛膞膢膮膲膴膻臋臃臅臊臎臏臕臗臛臝臞臡臤臫臬臰臱臲臵臶臸臹臽臿舀舃舏舓舔舙舚舝舡舢舨舲舴舺艃艄艅艆"],["8fd7a1","艋艎艏艑艖艜艠艣艧艭艴艻艽艿芀芁芃芄芇芉芊芎芑芔芖芘芚芛芠芡芣芤芧芨芩芪芮芰芲芴芷芺芼芾芿苆苐苕苚苠苢苤苨苪苭苯苶苷苽苾茀茁茇茈茊茋荔茛茝茞茟茡茢茬茭茮茰茳茷茺茼茽荂荃荄荇荍荎荑荕荖荗荰荸"],["8fd8a1","荽荿莀莂莄莆莍莒莔莕莘莙莛莜莝莦莧莩莬莾莿菀菇菉菏菐菑菔菝荓菨菪菶菸菹菼萁萆萊萏萑萕萙莭萯萹葅葇葈葊葍葏葑葒葖葘葙葚葜葠葤葥葧葪葰葳葴葶葸葼葽蒁蒅蒒蒓蒕蒞蒦蒨蒩蒪蒯蒱蒴蒺蒽蒾蓀蓂蓇蓈蓌蓏蓓"],["8fd9a1","蓜蓧蓪蓯蓰蓱蓲蓷蔲蓺蓻蓽蔂蔃蔇蔌蔎蔐蔜蔞蔢蔣蔤蔥蔧蔪蔫蔯蔳蔴蔶蔿蕆蕏",4,"蕖蕙蕜",6,"蕤蕫蕯蕹蕺蕻蕽蕿薁薅薆薉薋薌薏薓薘薝薟薠薢薥薧薴薶薷薸薼薽薾薿藂藇藊藋藎薭藘藚藟藠藦藨藭藳藶藼"],["8fdaa1","藿蘀蘄蘅蘍蘎蘐蘑蘒蘘蘙蘛蘞蘡蘧蘩蘶蘸蘺蘼蘽虀虂虆虒虓虖虗虘虙虝虠",4,"虩虬虯虵虶虷虺蚍蚑蚖蚘蚚蚜蚡蚦蚧蚨蚭蚱蚳蚴蚵蚷蚸蚹蚿蛀蛁蛃蛅蛑蛒蛕蛗蛚蛜蛠蛣蛥蛧蚈蛺蛼蛽蜄蜅蜇蜋蜎蜏蜐蜓蜔蜙蜞蜟蜡蜣"],["8fdba1","蜨蜮蜯蜱蜲蜹蜺蜼蜽蜾蝀蝃蝅蝍蝘蝝蝡蝤蝥蝯蝱蝲蝻螃",6,"螋螌螐螓螕螗螘螙螞螠螣螧螬螭螮螱螵螾螿蟁蟈蟉蟊蟎蟕蟖蟙蟚蟜蟟蟢蟣蟤蟪蟫蟭蟱蟳蟸蟺蟿蠁蠃蠆蠉蠊蠋蠐蠙蠒蠓蠔蠘蠚蠛蠜蠞蠟蠨蠭蠮蠰蠲蠵"],["8fdca1","蠺蠼衁衃衅衈衉衊衋衎衑衕衖衘衚衜衟衠衤衩衱衹衻袀袘袚袛袜袟袠袨袪袺袽袾裀裊",4,"裑裒裓裛裞裧裯裰裱裵裷褁褆褍褎褏褕褖褘褙褚褜褠褦褧褨褰褱褲褵褹褺褾襀襂襅襆襉襏襒襗襚襛襜襡襢襣襫襮襰襳襵襺"],["8fdda1","襻襼襽覉覍覐覔覕覛覜覟覠覥覰覴覵覶覷覼觔",4,"觥觩觫觭觱觳觶觹觽觿訄訅訇訏訑訒訔訕訞訠訢訤訦訫訬訯訵訷訽訾詀詃詅詇詉詍詎詓詖詗詘詜詝詡詥詧詵詶詷詹詺詻詾詿誀誃誆誋誏誐誒誖誗誙誟誧誩誮誯誳"],["8fdea1","誶誷誻誾諃諆諈諉諊諑諓諔諕諗諝諟諬諰諴諵諶諼諿謅謆謋謑謜謞謟謊謭謰謷謼譂",4,"譈譒譓譔譙譍譞譣譭譶譸譹譼譾讁讄讅讋讍讏讔讕讜讞讟谸谹谽谾豅豇豉豋豏豑豓豔豗豘豛豝豙豣豤豦豨豩豭豳豵豶豻豾貆"],["8fdfa1","貇貋貐貒貓貙貛貜貤貹貺賅賆賉賋賏賖賕賙賝賡賨賬賯賰賲賵賷賸賾賿贁贃贉贒贗贛赥赩赬赮赿趂趄趈趍趐趑趕趞趟趠趦趫趬趯趲趵趷趹趻跀跅跆跇跈跊跎跑跔跕跗跙跤跥跧跬跰趼跱跲跴跽踁踄踅踆踋踑踔踖踠踡踢"],["8fe0a1","踣踦踧踱踳踶踷踸踹踽蹀蹁蹋蹍蹎蹏蹔蹛蹜蹝蹞蹡蹢蹩蹬蹭蹯蹰蹱蹹蹺蹻躂躃躉躐躒躕躚躛躝躞躢躧躩躭躮躳躵躺躻軀軁軃軄軇軏軑軔軜軨軮軰軱軷軹軺軭輀輂輇輈輏輐輖輗輘輞輠輡輣輥輧輨輬輭輮輴輵輶輷輺轀轁"],["8fe1a1","轃轇轏轑",4,"轘轝轞轥辝辠辡辤辥辦辵辶辸达迀迁迆迊迋迍运迒迓迕迠迣迤迨迮迱迵迶迻迾适逄逈逌逘逛逨逩逯逪逬逭逳逴逷逿遃遄遌遛遝遢遦遧遬遰遴遹邅邈邋邌邎邐邕邗邘邙邛邠邡邢邥邰邲邳邴邶邽郌邾郃"],["8fe2a1","郄郅郇郈郕郗郘郙郜郝郟郥郒郶郫郯郰郴郾郿鄀鄄鄅鄆鄈鄍鄐鄔鄖鄗鄘鄚鄜鄞鄠鄥鄢鄣鄧鄩鄮鄯鄱鄴鄶鄷鄹鄺鄼鄽酃酇酈酏酓酗酙酚酛酡酤酧酭酴酹酺酻醁醃醅醆醊醎醑醓醔醕醘醞醡醦醨醬醭醮醰醱醲醳醶醻醼醽醿"],["8fe3a1","釂釃釅釓釔釗釙釚釞釤釥釩釪釬",5,"釷釹釻釽鈀鈁鈄鈅鈆鈇鈉鈊鈌鈐鈒鈓鈖鈘鈜鈝鈣鈤鈥鈦鈨鈮鈯鈰鈳鈵鈶鈸鈹鈺鈼鈾鉀鉂鉃鉆鉇鉊鉍鉎鉏鉑鉘鉙鉜鉝鉠鉡鉥鉧鉨鉩鉮鉯鉰鉵",4,"鉻鉼鉽鉿銈銉銊銍銎銒銗"],["8fe4a1","銙銟銠銤銥銧銨銫銯銲銶銸銺銻銼銽銿",4,"鋅鋆鋇鋈鋋鋌鋍鋎鋐鋓鋕鋗鋘鋙鋜鋝鋟鋠鋡鋣鋥鋧鋨鋬鋮鋰鋹鋻鋿錀錂錈錍錑錔錕錜錝錞錟錡錤錥錧錩錪錳錴錶錷鍇鍈鍉鍐鍑鍒鍕鍗鍘鍚鍞鍤鍥鍧鍩鍪鍭鍯鍰鍱鍳鍴鍶"],["8fe5a1","鍺鍽鍿鎀鎁鎂鎈鎊鎋鎍鎏鎒鎕鎘鎛鎞鎡鎣鎤鎦鎨鎫鎴鎵鎶鎺鎩鏁鏄鏅鏆鏇鏉",4,"鏓鏙鏜鏞鏟鏢鏦鏧鏹鏷鏸鏺鏻鏽鐁鐂鐄鐈鐉鐍鐎鐏鐕鐖鐗鐟鐮鐯鐱鐲鐳鐴鐻鐿鐽鑃鑅鑈鑊鑌鑕鑙鑜鑟鑡鑣鑨鑫鑭鑮鑯鑱鑲钄钃镸镹"],["8fe6a1","镾閄閈閌閍閎閝閞閟閡閦閩閫閬閴閶閺閽閿闆闈闉闋闐闑闒闓闙闚闝闞闟闠闤闦阝阞阢阤阥阦阬阱阳阷阸阹阺阼阽陁陒陔陖陗陘陡陮陴陻陼陾陿隁隂隃隄隉隑隖隚隝隟隤隥隦隩隮隯隳隺雊雒嶲雘雚雝雞雟雩雯雱雺霂"],["8fe7a1","霃霅霉霚霛霝霡霢霣霨霱霳靁靃靊靎靏靕靗靘靚靛靣靧靪靮靳靶靷靸靻靽靿鞀鞉鞕鞖鞗鞙鞚鞞鞟鞢鞬鞮鞱鞲鞵鞶鞸鞹鞺鞼鞾鞿韁韄韅韇韉韊韌韍韎韐韑韔韗韘韙韝韞韠韛韡韤韯韱韴韷韸韺頇頊頙頍頎頔頖頜頞頠頣頦"],["8fe8a1","頫頮頯頰頲頳頵頥頾顄顇顊顑顒顓顖顗顙顚顢顣顥顦顪顬颫颭颮颰颴颷颸颺颻颿飂飅飈飌飡飣飥飦飧飪飳飶餂餇餈餑餕餖餗餚餛餜餟餢餦餧餫餱",4,"餹餺餻餼饀饁饆饇饈饍饎饔饘饙饛饜饞饟饠馛馝馟馦馰馱馲馵"],["8fe9a1","馹馺馽馿駃駉駓駔駙駚駜駞駧駪駫駬駰駴駵駹駽駾騂騃騄騋騌騐騑騖騞騠騢騣騤騧騭騮騳騵騶騸驇驁驄驊驋驌驎驑驔驖驝骪骬骮骯骲骴骵骶骹骻骾骿髁髃髆髈髎髐髒髕髖髗髛髜髠髤髥髧髩髬髲髳髵髹髺髽髿",4],["8feaa1","鬄鬅鬈鬉鬋鬌鬍鬎鬐鬒鬖鬙鬛鬜鬠鬦鬫鬭鬳鬴鬵鬷鬹鬺鬽魈魋魌魕魖魗魛魞魡魣魥魦魨魪",4,"魳魵魷魸魹魿鮀鮄鮅鮆鮇鮉鮊鮋鮍鮏鮐鮔鮚鮝鮞鮦鮧鮩鮬鮰鮱鮲鮷鮸鮻鮼鮾鮿鯁鯇鯈鯎鯐鯗鯘鯝鯟鯥鯧鯪鯫鯯鯳鯷鯸"],["8feba1","鯹鯺鯽鯿鰀鰂鰋鰏鰑鰖鰘鰙鰚鰜鰞鰢鰣鰦",4,"鰱鰵鰶鰷鰽鱁鱃鱄鱅鱉鱊鱎鱏鱐鱓鱔鱖鱘鱛鱝鱞鱟鱣鱩鱪鱜鱫鱨鱮鱰鱲鱵鱷鱻鳦鳲鳷鳹鴋鴂鴑鴗鴘鴜鴝鴞鴯鴰鴲鴳鴴鴺鴼鵅鴽鵂鵃鵇鵊鵓鵔鵟鵣鵢鵥鵩鵪鵫鵰鵶鵷鵻"],["8feca1","鵼鵾鶃鶄鶆鶊鶍鶎鶒鶓鶕鶖鶗鶘鶡鶪鶬鶮鶱鶵鶹鶼鶿鷃鷇鷉鷊鷔鷕鷖鷗鷚鷞鷟鷠鷥鷧鷩鷫鷮鷰鷳鷴鷾鸊鸂鸇鸎鸐鸑鸒鸕鸖鸙鸜鸝鹺鹻鹼麀麂麃麄麅麇麎麏麖麘麛麞麤麨麬麮麯麰麳麴麵黆黈黋黕黟黤黧黬黭黮黰黱黲黵"],["8feda1","黸黿鼂鼃鼉鼏鼐鼑鼒鼔鼖鼗鼙鼚鼛鼟鼢鼦鼪鼫鼯鼱鼲鼴鼷鼹鼺鼼鼽鼿齁齃",4,"齓齕齖齗齘齚齝齞齨齩齭",4,"齳齵齺齽龏龐龑龒龔龖龗龞龡龢龣龥"]]')},6258:function(A){"use strict";A.exports=JSON.parse('{"uChars":[128,165,169,178,184,216,226,235,238,244,248,251,253,258,276,284,300,325,329,334,364,463,465,467,469,471,473,475,477,506,594,610,712,716,730,930,938,962,970,1026,1104,1106,8209,8215,8218,8222,8231,8241,8244,8246,8252,8365,8452,8454,8458,8471,8482,8556,8570,8596,8602,8713,8720,8722,8726,8731,8737,8740,8742,8748,8751,8760,8766,8777,8781,8787,8802,8808,8816,8854,8858,8870,8896,8979,9322,9372,9548,9588,9616,9622,9634,9652,9662,9672,9676,9680,9702,9735,9738,9793,9795,11906,11909,11913,11917,11928,11944,11947,11951,11956,11960,11964,11979,12284,12292,12312,12319,12330,12351,12436,12447,12535,12543,12586,12842,12850,12964,13200,13215,13218,13253,13263,13267,13270,13384,13428,13727,13839,13851,14617,14703,14801,14816,14964,15183,15471,15585,16471,16736,17208,17325,17330,17374,17623,17997,18018,18212,18218,18301,18318,18760,18811,18814,18820,18823,18844,18848,18872,19576,19620,19738,19887,40870,59244,59336,59367,59413,59417,59423,59431,59437,59443,59452,59460,59478,59493,63789,63866,63894,63976,63986,64016,64018,64021,64025,64034,64037,64042,65074,65093,65107,65112,65127,65132,65375,65510,65536],"gbChars":[0,36,38,45,50,81,89,95,96,100,103,104,105,109,126,133,148,172,175,179,208,306,307,308,309,310,311,312,313,341,428,443,544,545,558,741,742,749,750,805,819,820,7922,7924,7925,7927,7934,7943,7944,7945,7950,8062,8148,8149,8152,8164,8174,8236,8240,8262,8264,8374,8380,8381,8384,8388,8390,8392,8393,8394,8396,8401,8406,8416,8419,8424,8437,8439,8445,8482,8485,8496,8521,8603,8936,8946,9046,9050,9063,9066,9076,9092,9100,9108,9111,9113,9131,9162,9164,9218,9219,11329,11331,11334,11336,11346,11361,11363,11366,11370,11372,11375,11389,11682,11686,11687,11692,11694,11714,11716,11723,11725,11730,11736,11982,11989,12102,12336,12348,12350,12384,12393,12395,12397,12510,12553,12851,12962,12973,13738,13823,13919,13933,14080,14298,14585,14698,15583,15847,16318,16434,16438,16481,16729,17102,17122,17315,17320,17402,17418,17859,17909,17911,17915,17916,17936,17939,17961,18664,18703,18814,18962,19043,33469,33470,33471,33484,33485,33490,33497,33501,33505,33513,33520,33536,33550,37845,37921,37948,38029,38038,38064,38065,38066,38069,38075,38076,38078,39108,39109,39113,39114,39115,39116,39265,39394,189000]}')},4346:function(A){"use strict";A.exports=JSON.parse('[["a140","",62],["a180","",32],["a240","",62],["a280","",32],["a2ab","",5],["a2e3","€"],["a2ef",""],["a2fd",""],["a340","",62],["a380","",31,"　"],["a440","",62],["a480","",32],["a4f4","",10],["a540","",62],["a580","",32],["a5f7","",7],["a640","",62],["a680","",32],["a6b9","",7],["a6d9","",6],["a6ec",""],["a6f3",""],["a6f6","",8],["a740","",62],["a780","",32],["a7c2","",14],["a7f2","",12],["a896","",10],["a8bc","ḿ"],["a8bf","ǹ"],["a8c1",""],["a8ea","",20],["a958",""],["a95b",""],["a95d",""],["a989","〾⿰",11],["a997","",12],["a9f0","",14],["aaa1","",93],["aba1","",93],["aca1","",93],["ada1","",93],["aea1","",93],["afa1","",93],["d7fa","",4],["f8a1","",93],["f9a1","",93],["faa1","",93],["fba1","",93],["fca1","",93],["fda1","",93],["fe50","⺁⺄㑳㑇⺈⺋㖞㘚㘎⺌⺗㥮㤘㧏㧟㩳㧐㭎㱮㳠⺧⺪䁖䅟⺮䌷⺳⺶⺷䎱䎬⺻䏝䓖䙡䙌"],["fe80","䜣䜩䝼䞍⻊䥇䥺䥽䦂䦃䦅䦆䦟䦛䦷䦶䲣䲟䲠䲡䱷䲢䴓",6,"䶮",93],["8135f437",""]]')},7014:function(A){"use strict";A.exports=JSON.parse('[["0","\\u0000",128],["a1","｡",62],["8140","　、。，．・：；？！゛゜´｀¨＾￣＿ヽヾゝゞ〃仝々〆〇ー―‐／＼～∥｜…‥‘’“”（）〔〕［］｛｝〈",9,"＋－±×"],["8180","÷＝≠＜＞≦≧∞∴♂♀°′″℃￥＄￠￡％＃＆＊＠§☆★○●◎◇◆□■△▲▽▼※〒→←↑↓〓"],["81b8","∈∋⊆⊇⊂⊃∪∩"],["81c8","∧∨￢⇒⇔∀∃"],["81da","∠⊥⌒∂∇≡≒≪≫√∽∝∵∫∬"],["81f0","Å‰♯♭♪†‡¶"],["81fc","◯"],["824f","０",9],["8260","Ａ",25],["8281","ａ",25],["829f","ぁ",82],["8340","ァ",62],["8380","ム",22],["839f","Α",16,"Σ",6],["83bf","α",16,"σ",6],["8440","А",5,"ЁЖ",25],["8470","а",5,"ёж",7],["8480","о",17],["849f","─│┌┐┘└├┬┤┴┼━┃┏┓┛┗┣┳┫┻╋┠┯┨┷┿┝┰┥┸╂"],["8740","①",19,"Ⅰ",9],["875f","㍉㌔㌢㍍㌘㌧㌃㌶㍑㍗㌍㌦㌣㌫㍊㌻㎜㎝㎞㎎㎏㏄㎡"],["877e","㍻"],["8780","〝〟№㏍℡㊤",4,"㈱㈲㈹㍾㍽㍼≒≡∫∮∑√⊥∠∟⊿∵∩∪"],["889f","亜唖娃阿哀愛挨姶逢葵茜穐悪握渥旭葦芦鯵梓圧斡扱宛姐虻飴絢綾鮎或粟袷安庵按暗案闇鞍杏以伊位依偉囲夷委威尉惟意慰易椅為畏異移維緯胃萎衣謂違遺医井亥域育郁磯一壱溢逸稲茨芋鰯允印咽員因姻引飲淫胤蔭"],["8940","院陰隠韻吋右宇烏羽迂雨卯鵜窺丑碓臼渦嘘唄欝蔚鰻姥厩浦瓜閏噂云運雲荏餌叡営嬰影映曳栄永泳洩瑛盈穎頴英衛詠鋭液疫益駅悦謁越閲榎厭円"],["8980","園堰奄宴延怨掩援沿演炎焔煙燕猿縁艶苑薗遠鉛鴛塩於汚甥凹央奥往応押旺横欧殴王翁襖鴬鴎黄岡沖荻億屋憶臆桶牡乙俺卸恩温穏音下化仮何伽価佳加可嘉夏嫁家寡科暇果架歌河火珂禍禾稼箇花苛茄荷華菓蝦課嘩貨迦過霞蚊俄峨我牙画臥芽蛾賀雅餓駕介会解回塊壊廻快怪悔恢懐戒拐改"],["8a40","魁晦械海灰界皆絵芥蟹開階貝凱劾外咳害崖慨概涯碍蓋街該鎧骸浬馨蛙垣柿蛎鈎劃嚇各廓拡撹格核殻獲確穫覚角赫較郭閣隔革学岳楽額顎掛笠樫"],["8a80","橿梶鰍潟割喝恰括活渇滑葛褐轄且鰹叶椛樺鞄株兜竃蒲釜鎌噛鴨栢茅萱粥刈苅瓦乾侃冠寒刊勘勧巻喚堪姦完官寛干幹患感慣憾換敢柑桓棺款歓汗漢澗潅環甘監看竿管簡緩缶翰肝艦莞観諌貫還鑑間閑関陥韓館舘丸含岸巌玩癌眼岩翫贋雁頑顔願企伎危喜器基奇嬉寄岐希幾忌揮机旗既期棋棄"],["8b40","機帰毅気汽畿祈季稀紀徽規記貴起軌輝飢騎鬼亀偽儀妓宜戯技擬欺犠疑祇義蟻誼議掬菊鞠吉吃喫桔橘詰砧杵黍却客脚虐逆丘久仇休及吸宮弓急救"],["8b80","朽求汲泣灸球究窮笈級糾給旧牛去居巨拒拠挙渠虚許距鋸漁禦魚亨享京供侠僑兇競共凶協匡卿叫喬境峡強彊怯恐恭挟教橋況狂狭矯胸脅興蕎郷鏡響饗驚仰凝尭暁業局曲極玉桐粁僅勤均巾錦斤欣欽琴禁禽筋緊芹菌衿襟謹近金吟銀九倶句区狗玖矩苦躯駆駈駒具愚虞喰空偶寓遇隅串櫛釧屑屈"],["8c40","掘窟沓靴轡窪熊隈粂栗繰桑鍬勲君薫訓群軍郡卦袈祁係傾刑兄啓圭珪型契形径恵慶慧憩掲携敬景桂渓畦稽系経継繋罫茎荊蛍計詣警軽頚鶏芸迎鯨"],["8c80","劇戟撃激隙桁傑欠決潔穴結血訣月件倹倦健兼券剣喧圏堅嫌建憲懸拳捲検権牽犬献研硯絹県肩見謙賢軒遣鍵険顕験鹸元原厳幻弦減源玄現絃舷言諺限乎個古呼固姑孤己庫弧戸故枯湖狐糊袴股胡菰虎誇跨鈷雇顧鼓五互伍午呉吾娯後御悟梧檎瑚碁語誤護醐乞鯉交佼侯候倖光公功効勾厚口向"],["8d40","后喉坑垢好孔孝宏工巧巷幸広庚康弘恒慌抗拘控攻昂晃更杭校梗構江洪浩港溝甲皇硬稿糠紅紘絞綱耕考肯肱腔膏航荒行衡講貢購郊酵鉱砿鋼閤降"],["8d80","項香高鴻剛劫号合壕拷濠豪轟麹克刻告国穀酷鵠黒獄漉腰甑忽惚骨狛込此頃今困坤墾婚恨懇昏昆根梱混痕紺艮魂些佐叉唆嵯左差査沙瑳砂詐鎖裟坐座挫債催再最哉塞妻宰彩才採栽歳済災采犀砕砦祭斎細菜裁載際剤在材罪財冴坂阪堺榊肴咲崎埼碕鷺作削咋搾昨朔柵窄策索錯桜鮭笹匙冊刷"],["8e40","察拶撮擦札殺薩雑皐鯖捌錆鮫皿晒三傘参山惨撒散桟燦珊産算纂蚕讃賛酸餐斬暫残仕仔伺使刺司史嗣四士始姉姿子屍市師志思指支孜斯施旨枝止"],["8e80","死氏獅祉私糸紙紫肢脂至視詞詩試誌諮資賜雌飼歯事似侍児字寺慈持時次滋治爾璽痔磁示而耳自蒔辞汐鹿式識鴫竺軸宍雫七叱執失嫉室悉湿漆疾質実蔀篠偲柴芝屡蕊縞舎写射捨赦斜煮社紗者謝車遮蛇邪借勺尺杓灼爵酌釈錫若寂弱惹主取守手朱殊狩珠種腫趣酒首儒受呪寿授樹綬需囚収周"],["8f40","宗就州修愁拾洲秀秋終繍習臭舟蒐衆襲讐蹴輯週酋酬集醜什住充十従戎柔汁渋獣縦重銃叔夙宿淑祝縮粛塾熟出術述俊峻春瞬竣舜駿准循旬楯殉淳"],["8f80","準潤盾純巡遵醇順処初所暑曙渚庶緒署書薯藷諸助叙女序徐恕鋤除傷償勝匠升召哨商唱嘗奨妾娼宵将小少尚庄床廠彰承抄招掌捷昇昌昭晶松梢樟樵沼消渉湘焼焦照症省硝礁祥称章笑粧紹肖菖蒋蕉衝裳訟証詔詳象賞醤鉦鍾鐘障鞘上丈丞乗冗剰城場壌嬢常情擾条杖浄状畳穣蒸譲醸錠嘱埴飾"],["9040","拭植殖燭織職色触食蝕辱尻伸信侵唇娠寝審心慎振新晋森榛浸深申疹真神秦紳臣芯薪親診身辛進針震人仁刃塵壬尋甚尽腎訊迅陣靭笥諏須酢図厨"],["9080","逗吹垂帥推水炊睡粋翠衰遂酔錐錘随瑞髄崇嵩数枢趨雛据杉椙菅頗雀裾澄摺寸世瀬畝是凄制勢姓征性成政整星晴棲栖正清牲生盛精聖声製西誠誓請逝醒青静斉税脆隻席惜戚斥昔析石積籍績脊責赤跡蹟碩切拙接摂折設窃節説雪絶舌蝉仙先千占宣専尖川戦扇撰栓栴泉浅洗染潜煎煽旋穿箭線"],["9140","繊羨腺舛船薦詮賎践選遷銭銑閃鮮前善漸然全禅繕膳糎噌塑岨措曾曽楚狙疏疎礎祖租粗素組蘇訴阻遡鼠僧創双叢倉喪壮奏爽宋層匝惣想捜掃挿掻"],["9180","操早曹巣槍槽漕燥争痩相窓糟総綜聡草荘葬蒼藻装走送遭鎗霜騒像増憎臓蔵贈造促側則即息捉束測足速俗属賊族続卒袖其揃存孫尊損村遜他多太汰詑唾堕妥惰打柁舵楕陀駄騨体堆対耐岱帯待怠態戴替泰滞胎腿苔袋貸退逮隊黛鯛代台大第醍題鷹滝瀧卓啄宅托択拓沢濯琢託鐸濁諾茸凧蛸只"],["9240","叩但達辰奪脱巽竪辿棚谷狸鱈樽誰丹単嘆坦担探旦歎淡湛炭短端箪綻耽胆蛋誕鍛団壇弾断暖檀段男談値知地弛恥智池痴稚置致蜘遅馳築畜竹筑蓄"],["9280","逐秩窒茶嫡着中仲宙忠抽昼柱注虫衷註酎鋳駐樗瀦猪苧著貯丁兆凋喋寵帖帳庁弔張彫徴懲挑暢朝潮牒町眺聴脹腸蝶調諜超跳銚長頂鳥勅捗直朕沈珍賃鎮陳津墜椎槌追鎚痛通塚栂掴槻佃漬柘辻蔦綴鍔椿潰坪壷嬬紬爪吊釣鶴亭低停偵剃貞呈堤定帝底庭廷弟悌抵挺提梯汀碇禎程締艇訂諦蹄逓"],["9340","邸鄭釘鼎泥摘擢敵滴的笛適鏑溺哲徹撤轍迭鉄典填天展店添纏甜貼転顛点伝殿澱田電兎吐堵塗妬屠徒斗杜渡登菟賭途都鍍砥砺努度土奴怒倒党冬"],["9380","凍刀唐塔塘套宕島嶋悼投搭東桃梼棟盗淘湯涛灯燈当痘祷等答筒糖統到董蕩藤討謄豆踏逃透鐙陶頭騰闘働動同堂導憧撞洞瞳童胴萄道銅峠鴇匿得徳涜特督禿篤毒独読栃橡凸突椴届鳶苫寅酉瀞噸屯惇敦沌豚遁頓呑曇鈍奈那内乍凪薙謎灘捺鍋楢馴縄畷南楠軟難汝二尼弐迩匂賑肉虹廿日乳入"],["9440","如尿韮任妊忍認濡禰祢寧葱猫熱年念捻撚燃粘乃廼之埜嚢悩濃納能脳膿農覗蚤巴把播覇杷波派琶破婆罵芭馬俳廃拝排敗杯盃牌背肺輩配倍培媒梅"],["9480","楳煤狽買売賠陪這蝿秤矧萩伯剥博拍柏泊白箔粕舶薄迫曝漠爆縛莫駁麦函箱硲箸肇筈櫨幡肌畑畠八鉢溌発醗髪伐罰抜筏閥鳩噺塙蛤隼伴判半反叛帆搬斑板氾汎版犯班畔繁般藩販範釆煩頒飯挽晩番盤磐蕃蛮匪卑否妃庇彼悲扉批披斐比泌疲皮碑秘緋罷肥被誹費避非飛樋簸備尾微枇毘琵眉美"],["9540","鼻柊稗匹疋髭彦膝菱肘弼必畢筆逼桧姫媛紐百謬俵彪標氷漂瓢票表評豹廟描病秒苗錨鋲蒜蛭鰭品彬斌浜瀕貧賓頻敏瓶不付埠夫婦富冨布府怖扶敷"],["9580","斧普浮父符腐膚芙譜負賦赴阜附侮撫武舞葡蕪部封楓風葺蕗伏副復幅服福腹複覆淵弗払沸仏物鮒分吻噴墳憤扮焚奮粉糞紛雰文聞丙併兵塀幣平弊柄並蔽閉陛米頁僻壁癖碧別瞥蔑箆偏変片篇編辺返遍便勉娩弁鞭保舗鋪圃捕歩甫補輔穂募墓慕戊暮母簿菩倣俸包呆報奉宝峰峯崩庖抱捧放方朋"],["9640","法泡烹砲縫胞芳萌蓬蜂褒訪豊邦鋒飽鳳鵬乏亡傍剖坊妨帽忘忙房暴望某棒冒紡肪膨謀貌貿鉾防吠頬北僕卜墨撲朴牧睦穆釦勃没殆堀幌奔本翻凡盆"],["9680","摩磨魔麻埋妹昧枚毎哩槙幕膜枕鮪柾鱒桝亦俣又抹末沫迄侭繭麿万慢満漫蔓味未魅巳箕岬密蜜湊蓑稔脈妙粍民眠務夢無牟矛霧鵡椋婿娘冥名命明盟迷銘鳴姪牝滅免棉綿緬面麺摸模茂妄孟毛猛盲網耗蒙儲木黙目杢勿餅尤戻籾貰問悶紋門匁也冶夜爺耶野弥矢厄役約薬訳躍靖柳薮鑓愉愈油癒"],["9740","諭輸唯佑優勇友宥幽悠憂揖有柚湧涌猶猷由祐裕誘遊邑郵雄融夕予余与誉輿預傭幼妖容庸揚揺擁曜楊様洋溶熔用窯羊耀葉蓉要謡踊遥陽養慾抑欲"],["9780","沃浴翌翼淀羅螺裸来莱頼雷洛絡落酪乱卵嵐欄濫藍蘭覧利吏履李梨理璃痢裏裡里離陸律率立葎掠略劉流溜琉留硫粒隆竜龍侶慮旅虜了亮僚両凌寮料梁涼猟療瞭稜糧良諒遼量陵領力緑倫厘林淋燐琳臨輪隣鱗麟瑠塁涙累類令伶例冷励嶺怜玲礼苓鈴隷零霊麗齢暦歴列劣烈裂廉恋憐漣煉簾練聯"],["9840","蓮連錬呂魯櫓炉賂路露労婁廊弄朗楼榔浪漏牢狼篭老聾蝋郎六麓禄肋録論倭和話歪賄脇惑枠鷲亙亘鰐詫藁蕨椀湾碗腕"],["989f","弌丐丕个丱丶丼丿乂乖乘亂亅豫亊舒弍于亞亟亠亢亰亳亶从仍仄仆仂仗仞仭仟价伉佚估佛佝佗佇佶侈侏侘佻佩佰侑佯來侖儘俔俟俎俘俛俑俚俐俤俥倚倨倔倪倥倅伜俶倡倩倬俾俯們倆偃假會偕偐偈做偖偬偸傀傚傅傴傲"],["9940","僉僊傳僂僖僞僥僭僣僮價僵儉儁儂儖儕儔儚儡儺儷儼儻儿兀兒兌兔兢竸兩兪兮冀冂囘册冉冏冑冓冕冖冤冦冢冩冪冫决冱冲冰况冽凅凉凛几處凩凭"],["9980","凰凵凾刄刋刔刎刧刪刮刳刹剏剄剋剌剞剔剪剴剩剳剿剽劍劔劒剱劈劑辨辧劬劭劼劵勁勍勗勞勣勦飭勠勳勵勸勹匆匈甸匍匐匏匕匚匣匯匱匳匸區卆卅丗卉卍凖卞卩卮夘卻卷厂厖厠厦厥厮厰厶參簒雙叟曼燮叮叨叭叺吁吽呀听吭吼吮吶吩吝呎咏呵咎呟呱呷呰咒呻咀呶咄咐咆哇咢咸咥咬哄哈咨"],["9a40","咫哂咤咾咼哘哥哦唏唔哽哮哭哺哢唹啀啣啌售啜啅啖啗唸唳啝喙喀咯喊喟啻啾喘喞單啼喃喩喇喨嗚嗅嗟嗄嗜嗤嗔嘔嗷嘖嗾嗽嘛嗹噎噐營嘴嘶嘲嘸"],["9a80","噫噤嘯噬噪嚆嚀嚊嚠嚔嚏嚥嚮嚶嚴囂嚼囁囃囀囈囎囑囓囗囮囹圀囿圄圉圈國圍圓團圖嗇圜圦圷圸坎圻址坏坩埀垈坡坿垉垓垠垳垤垪垰埃埆埔埒埓堊埖埣堋堙堝塲堡塢塋塰毀塒堽塹墅墹墟墫墺壞墻墸墮壅壓壑壗壙壘壥壜壤壟壯壺壹壻壼壽夂夊夐夛梦夥夬夭夲夸夾竒奕奐奎奚奘奢奠奧奬奩"],["9b40","奸妁妝佞侫妣妲姆姨姜妍姙姚娥娟娑娜娉娚婀婬婉娵娶婢婪媚媼媾嫋嫂媽嫣嫗嫦嫩嫖嫺嫻嬌嬋嬖嬲嫐嬪嬶嬾孃孅孀孑孕孚孛孥孩孰孳孵學斈孺宀"],["9b80","它宦宸寃寇寉寔寐寤實寢寞寥寫寰寶寳尅將專對尓尠尢尨尸尹屁屆屎屓屐屏孱屬屮乢屶屹岌岑岔妛岫岻岶岼岷峅岾峇峙峩峽峺峭嶌峪崋崕崗嵜崟崛崑崔崢崚崙崘嵌嵒嵎嵋嵬嵳嵶嶇嶄嶂嶢嶝嶬嶮嶽嶐嶷嶼巉巍巓巒巖巛巫已巵帋帚帙帑帛帶帷幄幃幀幎幗幔幟幢幤幇幵并幺麼广庠廁廂廈廐廏"],["9c40","廖廣廝廚廛廢廡廨廩廬廱廳廰廴廸廾弃弉彝彜弋弑弖弩弭弸彁彈彌彎弯彑彖彗彙彡彭彳彷徃徂彿徊很徑徇從徙徘徠徨徭徼忖忻忤忸忱忝悳忿怡恠"],["9c80","怙怐怩怎怱怛怕怫怦怏怺恚恁恪恷恟恊恆恍恣恃恤恂恬恫恙悁悍惧悃悚悄悛悖悗悒悧悋惡悸惠惓悴忰悽惆悵惘慍愕愆惶惷愀惴惺愃愡惻惱愍愎慇愾愨愧慊愿愼愬愴愽慂慄慳慷慘慙慚慫慴慯慥慱慟慝慓慵憙憖憇憬憔憚憊憑憫憮懌懊應懷懈懃懆憺懋罹懍懦懣懶懺懴懿懽懼懾戀戈戉戍戌戔戛"],["9d40","戞戡截戮戰戲戳扁扎扞扣扛扠扨扼抂抉找抒抓抖拔抃抔拗拑抻拏拿拆擔拈拜拌拊拂拇抛拉挌拮拱挧挂挈拯拵捐挾捍搜捏掖掎掀掫捶掣掏掉掟掵捫"],["9d80","捩掾揩揀揆揣揉插揶揄搖搴搆搓搦搶攝搗搨搏摧摯摶摎攪撕撓撥撩撈撼據擒擅擇撻擘擂擱擧舉擠擡抬擣擯攬擶擴擲擺攀擽攘攜攅攤攣攫攴攵攷收攸畋效敖敕敍敘敞敝敲數斂斃變斛斟斫斷旃旆旁旄旌旒旛旙无旡旱杲昊昃旻杳昵昶昴昜晏晄晉晁晞晝晤晧晨晟晢晰暃暈暎暉暄暘暝曁暹曉暾暼"],["9e40","曄暸曖曚曠昿曦曩曰曵曷朏朖朞朦朧霸朮朿朶杁朸朷杆杞杠杙杣杤枉杰枩杼杪枌枋枦枡枅枷柯枴柬枳柩枸柤柞柝柢柮枹柎柆柧檜栞框栩桀桍栲桎"],["9e80","梳栫桙档桷桿梟梏梭梔條梛梃檮梹桴梵梠梺椏梍桾椁棊椈棘椢椦棡椌棍棔棧棕椶椒椄棗棣椥棹棠棯椨椪椚椣椡棆楹楷楜楸楫楔楾楮椹楴椽楙椰楡楞楝榁楪榲榮槐榿槁槓榾槎寨槊槝榻槃榧樮榑榠榜榕榴槞槨樂樛槿權槹槲槧樅榱樞槭樔槫樊樒櫁樣樓橄樌橲樶橸橇橢橙橦橈樸樢檐檍檠檄檢檣"],["9f40","檗蘗檻櫃櫂檸檳檬櫞櫑櫟檪櫚櫪櫻欅蘖櫺欒欖鬱欟欸欷盜欹飮歇歃歉歐歙歔歛歟歡歸歹歿殀殄殃殍殘殕殞殤殪殫殯殲殱殳殷殼毆毋毓毟毬毫毳毯"],["9f80","麾氈氓气氛氤氣汞汕汢汪沂沍沚沁沛汾汨汳沒沐泄泱泓沽泗泅泝沮沱沾沺泛泯泙泪洟衍洶洫洽洸洙洵洳洒洌浣涓浤浚浹浙涎涕濤涅淹渕渊涵淇淦涸淆淬淞淌淨淒淅淺淙淤淕淪淮渭湮渮渙湲湟渾渣湫渫湶湍渟湃渺湎渤滿渝游溂溪溘滉溷滓溽溯滄溲滔滕溏溥滂溟潁漑灌滬滸滾漿滲漱滯漲滌"],["e040","漾漓滷澆潺潸澁澀潯潛濳潭澂潼潘澎澑濂潦澳澣澡澤澹濆澪濟濕濬濔濘濱濮濛瀉瀋濺瀑瀁瀏濾瀛瀚潴瀝瀘瀟瀰瀾瀲灑灣炙炒炯烱炬炸炳炮烟烋烝"],["e080","烙焉烽焜焙煥煕熈煦煢煌煖煬熏燻熄熕熨熬燗熹熾燒燉燔燎燠燬燧燵燼燹燿爍爐爛爨爭爬爰爲爻爼爿牀牆牋牘牴牾犂犁犇犒犖犢犧犹犲狃狆狄狎狒狢狠狡狹狷倏猗猊猜猖猝猴猯猩猥猾獎獏默獗獪獨獰獸獵獻獺珈玳珎玻珀珥珮珞璢琅瑯琥珸琲琺瑕琿瑟瑙瑁瑜瑩瑰瑣瑪瑶瑾璋璞璧瓊瓏瓔珱"],["e140","瓠瓣瓧瓩瓮瓲瓰瓱瓸瓷甄甃甅甌甎甍甕甓甞甦甬甼畄畍畊畉畛畆畚畩畤畧畫畭畸當疆疇畴疊疉疂疔疚疝疥疣痂疳痃疵疽疸疼疱痍痊痒痙痣痞痾痿"],["e180","痼瘁痰痺痲痳瘋瘍瘉瘟瘧瘠瘡瘢瘤瘴瘰瘻癇癈癆癜癘癡癢癨癩癪癧癬癰癲癶癸發皀皃皈皋皎皖皓皙皚皰皴皸皹皺盂盍盖盒盞盡盥盧盪蘯盻眈眇眄眩眤眞眥眦眛眷眸睇睚睨睫睛睥睿睾睹瞎瞋瞑瞠瞞瞰瞶瞹瞿瞼瞽瞻矇矍矗矚矜矣矮矼砌砒礦砠礪硅碎硴碆硼碚碌碣碵碪碯磑磆磋磔碾碼磅磊磬"],["e240","磧磚磽磴礇礒礑礙礬礫祀祠祗祟祚祕祓祺祿禊禝禧齋禪禮禳禹禺秉秕秧秬秡秣稈稍稘稙稠稟禀稱稻稾稷穃穗穉穡穢穩龝穰穹穽窈窗窕窘窖窩竈窰"],["e280","窶竅竄窿邃竇竊竍竏竕竓站竚竝竡竢竦竭竰笂笏笊笆笳笘笙笞笵笨笶筐筺笄筍笋筌筅筵筥筴筧筰筱筬筮箝箘箟箍箜箚箋箒箏筝箙篋篁篌篏箴篆篝篩簑簔篦篥籠簀簇簓篳篷簗簍篶簣簧簪簟簷簫簽籌籃籔籏籀籐籘籟籤籖籥籬籵粃粐粤粭粢粫粡粨粳粲粱粮粹粽糀糅糂糘糒糜糢鬻糯糲糴糶糺紆"],["e340","紂紜紕紊絅絋紮紲紿紵絆絳絖絎絲絨絮絏絣經綉絛綏絽綛綺綮綣綵緇綽綫總綢綯緜綸綟綰緘緝緤緞緻緲緡縅縊縣縡縒縱縟縉縋縢繆繦縻縵縹繃縷"],["e380","縲縺繧繝繖繞繙繚繹繪繩繼繻纃緕繽辮繿纈纉續纒纐纓纔纖纎纛纜缸缺罅罌罍罎罐网罕罔罘罟罠罨罩罧罸羂羆羃羈羇羌羔羞羝羚羣羯羲羹羮羶羸譱翅翆翊翕翔翡翦翩翳翹飜耆耄耋耒耘耙耜耡耨耿耻聊聆聒聘聚聟聢聨聳聲聰聶聹聽聿肄肆肅肛肓肚肭冐肬胛胥胙胝胄胚胖脉胯胱脛脩脣脯腋"],["e440","隋腆脾腓腑胼腱腮腥腦腴膃膈膊膀膂膠膕膤膣腟膓膩膰膵膾膸膽臀臂膺臉臍臑臙臘臈臚臟臠臧臺臻臾舁舂舅與舊舍舐舖舩舫舸舳艀艙艘艝艚艟艤"],["e480","艢艨艪艫舮艱艷艸艾芍芒芫芟芻芬苡苣苟苒苴苳苺莓范苻苹苞茆苜茉苙茵茴茖茲茱荀茹荐荅茯茫茗茘莅莚莪莟莢莖茣莎莇莊荼莵荳荵莠莉莨菴萓菫菎菽萃菘萋菁菷萇菠菲萍萢萠莽萸蔆菻葭萪萼蕚蒄葷葫蒭葮蒂葩葆萬葯葹萵蓊葢蒹蒿蒟蓙蓍蒻蓚蓐蓁蓆蓖蒡蔡蓿蓴蔗蔘蔬蔟蔕蔔蓼蕀蕣蕘蕈"],["e540","蕁蘂蕋蕕薀薤薈薑薊薨蕭薔薛藪薇薜蕷蕾薐藉薺藏薹藐藕藝藥藜藹蘊蘓蘋藾藺蘆蘢蘚蘰蘿虍乕虔號虧虱蚓蚣蚩蚪蚋蚌蚶蚯蛄蛆蚰蛉蠣蚫蛔蛞蛩蛬"],["e580","蛟蛛蛯蜒蜆蜈蜀蜃蛻蜑蜉蜍蛹蜊蜴蜿蜷蜻蜥蜩蜚蝠蝟蝸蝌蝎蝴蝗蝨蝮蝙蝓蝣蝪蠅螢螟螂螯蟋螽蟀蟐雖螫蟄螳蟇蟆螻蟯蟲蟠蠏蠍蟾蟶蟷蠎蟒蠑蠖蠕蠢蠡蠱蠶蠹蠧蠻衄衂衒衙衞衢衫袁衾袞衵衽袵衲袂袗袒袮袙袢袍袤袰袿袱裃裄裔裘裙裝裹褂裼裴裨裲褄褌褊褓襃褞褥褪褫襁襄褻褶褸襌褝襠襞"],["e640","襦襤襭襪襯襴襷襾覃覈覊覓覘覡覩覦覬覯覲覺覽覿觀觚觜觝觧觴觸訃訖訐訌訛訝訥訶詁詛詒詆詈詼詭詬詢誅誂誄誨誡誑誥誦誚誣諄諍諂諚諫諳諧"],["e680","諤諱謔諠諢諷諞諛謌謇謚諡謖謐謗謠謳鞫謦謫謾謨譁譌譏譎證譖譛譚譫譟譬譯譴譽讀讌讎讒讓讖讙讚谺豁谿豈豌豎豐豕豢豬豸豺貂貉貅貊貍貎貔豼貘戝貭貪貽貲貳貮貶賈賁賤賣賚賽賺賻贄贅贊贇贏贍贐齎贓賍贔贖赧赭赱赳趁趙跂趾趺跏跚跖跌跛跋跪跫跟跣跼踈踉跿踝踞踐踟蹂踵踰踴蹊"],["e740","蹇蹉蹌蹐蹈蹙蹤蹠踪蹣蹕蹶蹲蹼躁躇躅躄躋躊躓躑躔躙躪躡躬躰軆躱躾軅軈軋軛軣軼軻軫軾輊輅輕輒輙輓輜輟輛輌輦輳輻輹轅轂輾轌轉轆轎轗轜"],["e780","轢轣轤辜辟辣辭辯辷迚迥迢迪迯邇迴逅迹迺逑逕逡逍逞逖逋逧逶逵逹迸遏遐遑遒逎遉逾遖遘遞遨遯遶隨遲邂遽邁邀邊邉邏邨邯邱邵郢郤扈郛鄂鄒鄙鄲鄰酊酖酘酣酥酩酳酲醋醉醂醢醫醯醪醵醴醺釀釁釉釋釐釖釟釡釛釼釵釶鈞釿鈔鈬鈕鈑鉞鉗鉅鉉鉤鉈銕鈿鉋鉐銜銖銓銛鉚鋏銹銷鋩錏鋺鍄錮"],["e840","錙錢錚錣錺錵錻鍜鍠鍼鍮鍖鎰鎬鎭鎔鎹鏖鏗鏨鏥鏘鏃鏝鏐鏈鏤鐚鐔鐓鐃鐇鐐鐶鐫鐵鐡鐺鑁鑒鑄鑛鑠鑢鑞鑪鈩鑰鑵鑷鑽鑚鑼鑾钁鑿閂閇閊閔閖閘閙"],["e880","閠閨閧閭閼閻閹閾闊濶闃闍闌闕闔闖關闡闥闢阡阨阮阯陂陌陏陋陷陜陞陝陟陦陲陬隍隘隕隗險隧隱隲隰隴隶隸隹雎雋雉雍襍雜霍雕雹霄霆霈霓霎霑霏霖霙霤霪霰霹霽霾靄靆靈靂靉靜靠靤靦靨勒靫靱靹鞅靼鞁靺鞆鞋鞏鞐鞜鞨鞦鞣鞳鞴韃韆韈韋韜韭齏韲竟韶韵頏頌頸頤頡頷頽顆顏顋顫顯顰"],["e940","顱顴顳颪颯颱颶飄飃飆飩飫餃餉餒餔餘餡餝餞餤餠餬餮餽餾饂饉饅饐饋饑饒饌饕馗馘馥馭馮馼駟駛駝駘駑駭駮駱駲駻駸騁騏騅駢騙騫騷驅驂驀驃"],["e980","騾驕驍驛驗驟驢驥驤驩驫驪骭骰骼髀髏髑髓體髞髟髢髣髦髯髫髮髴髱髷髻鬆鬘鬚鬟鬢鬣鬥鬧鬨鬩鬪鬮鬯鬲魄魃魏魍魎魑魘魴鮓鮃鮑鮖鮗鮟鮠鮨鮴鯀鯊鮹鯆鯏鯑鯒鯣鯢鯤鯔鯡鰺鯲鯱鯰鰕鰔鰉鰓鰌鰆鰈鰒鰊鰄鰮鰛鰥鰤鰡鰰鱇鰲鱆鰾鱚鱠鱧鱶鱸鳧鳬鳰鴉鴈鳫鴃鴆鴪鴦鶯鴣鴟鵄鴕鴒鵁鴿鴾鵆鵈"],["ea40","鵝鵞鵤鵑鵐鵙鵲鶉鶇鶫鵯鵺鶚鶤鶩鶲鷄鷁鶻鶸鶺鷆鷏鷂鷙鷓鷸鷦鷭鷯鷽鸚鸛鸞鹵鹹鹽麁麈麋麌麒麕麑麝麥麩麸麪麭靡黌黎黏黐黔黜點黝黠黥黨黯"],["ea80","黴黶黷黹黻黼黽鼇鼈皷鼕鼡鼬鼾齊齒齔齣齟齠齡齦齧齬齪齷齲齶龕龜龠堯槇遙瑤凜熙"],["ed40","纊褜鍈銈蓜俉炻昱棈鋹曻彅丨仡仼伀伃伹佖侒侊侚侔俍偀倢俿倞偆偰偂傔僴僘兊兤冝冾凬刕劜劦勀勛匀匇匤卲厓厲叝﨎咜咊咩哿喆坙坥垬埈埇﨏"],["ed80","塚增墲夋奓奛奝奣妤妺孖寀甯寘寬尞岦岺峵崧嵓﨑嵂嵭嶸嶹巐弡弴彧德忞恝悅悊惞惕愠惲愑愷愰憘戓抦揵摠撝擎敎昀昕昻昉昮昞昤晥晗晙晴晳暙暠暲暿曺朎朗杦枻桒柀栁桄棏﨓楨﨔榘槢樰橫橆橳橾櫢櫤毖氿汜沆汯泚洄涇浯涖涬淏淸淲淼渹湜渧渼溿澈澵濵瀅瀇瀨炅炫焏焄煜煆煇凞燁燾犱"],["ee40","犾猤猪獷玽珉珖珣珒琇珵琦琪琩琮瑢璉璟甁畯皂皜皞皛皦益睆劯砡硎硤硺礰礼神祥禔福禛竑竧靖竫箞精絈絜綷綠緖繒罇羡羽茁荢荿菇菶葈蒴蕓蕙"],["ee80","蕫﨟薰蘒﨡蠇裵訒訷詹誧誾諟諸諶譓譿賰賴贒赶﨣軏﨤逸遧郞都鄕鄧釚釗釞釭釮釤釥鈆鈐鈊鈺鉀鈼鉎鉙鉑鈹鉧銧鉷鉸鋧鋗鋙鋐﨧鋕鋠鋓錥錡鋻﨨錞鋿錝錂鍰鍗鎤鏆鏞鏸鐱鑅鑈閒隆﨩隝隯霳霻靃靍靏靑靕顗顥飯飼餧館馞驎髙髜魵魲鮏鮱鮻鰀鵰鵫鶴鸙黑"],["eeef","ⅰ",9,"￢￤＇＂"],["f040","",62],["f080","",124],["f140","",62],["f180","",124],["f240","",62],["f280","",124],["f340","",62],["f380","",124],["f440","",62],["f480","",124],["f540","",62],["f580","",124],["f640","",62],["f680","",124],["f740","",62],["f780","",124],["f840","",62],["f880","",124],["f940",""],["fa40","ⅰ",9,"Ⅰ",9,"￢￤＇＂㈱№℡∵纊褜鍈銈蓜俉炻昱棈鋹曻彅丨仡仼伀伃伹佖侒侊侚侔俍偀倢俿倞偆偰偂傔僴僘兊"],["fa80","兤冝冾凬刕劜劦勀勛匀匇匤卲厓厲叝﨎咜咊咩哿喆坙坥垬埈埇﨏塚增墲夋奓奛奝奣妤妺孖寀甯寘寬尞岦岺峵崧嵓﨑嵂嵭嶸嶹巐弡弴彧德忞恝悅悊惞惕愠惲愑愷愰憘戓抦揵摠撝擎敎昀昕昻昉昮昞昤晥晗晙晴晳暙暠暲暿曺朎朗杦枻桒柀栁桄棏﨓楨﨔榘槢樰橫橆橳橾櫢櫤毖氿汜沆汯泚洄涇浯"],["fb40","涖涬淏淸淲淼渹湜渧渼溿澈澵濵瀅瀇瀨炅炫焏焄煜煆煇凞燁燾犱犾猤猪獷玽珉珖珣珒琇珵琦琪琩琮瑢璉璟甁畯皂皜皞皛皦益睆劯砡硎硤硺礰礼神"],["fb80","祥禔福禛竑竧靖竫箞精絈絜綷綠緖繒罇羡羽茁荢荿菇菶葈蒴蕓蕙蕫﨟薰蘒﨡蠇裵訒訷詹誧誾諟諸諶譓譿賰賴贒赶﨣軏﨤逸遧郞都鄕鄧釚釗釞釭釮釤釥鈆鈐鈊鈺鉀鈼鉎鉙鉑鈹鉧銧鉷鉸鋧鋗鋙鋐﨧鋕鋠鋓錥錡鋻﨨錞鋿錝錂鍰鍗鎤鏆鏞鏸鐱鑅鑈閒隆﨩隝隯霳霻靃靍靏靑靕顗顥飯飼餧館馞驎髙"],["fc40","髜魵魲鮏鮱鮻鰀鵰鵫鶴鸙黑"]]')}},t={};function e(n){var r=t[n];if(void 0!==r)return r.exports;var i=t[n]={id:n,loaded:!1,exports:{}};return A[n].call(i.exports,i,i.exports,e),i.loaded=!0,i.exports}return e.g=function(){if("object"==typeof globalThis)return globalThis;try{return this||new Function("return this")()}catch(A){if("object"==typeof window)return window}}(),e.nmd=function(A){return A.paths=[],A.children||(A.children=[]),A},e(2536)}()})),this.pdfMake=this.pdfMake||{},this.pdfMake.vfs={"Roboto-Italic.ttf":" ","Roboto-Medium.ttf":" ","Roboto-MediumItalic.ttf":" ","Roboto-Regular.ttf":" "},function(A){var t,e;"function"==typeof define&&define.amd?define(["jquery","datatables.net"],(function(t){return A(t,window,document)})):"object"==typeof exports?(t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net")(A,t)},"undefined"==typeof window?module.exports=function(n,r){return n=n||window,r=r||t(n),e(n,r),A(r,n,n.document)}:(e(window,t),module.exports=A(t,window,window.document))):A(jQuery,window,document)}((function(A,t,e,n){"use strict";var r=A.fn.dataTable,i=0,o=0,s=r.ext.buttons,a=null;function c(t,e,n){A.fn.animate?t.stop().fadeIn(e,n):(t.css("display","block"),n&&n.call(t))}function B(t,e,n){A.fn.animate?t.stop().fadeOut(e,n):(t.css("display","none"),n&&n.call(t))}function g(t,e){if(!(this instanceof g))return function(A){return new g(A,t).container()};!0===(e=void 0===e?{}:e)&&(e={}),Array.isArray(e)&&(e={buttons:e}),this.c=A.extend(!0,{},g.defaults,e),e.buttons&&(this.c.buttons=e.buttons),this.s={dt:new r.Api(t),buttons:[],listenKeys:"",namespace:"dtb"+i++},this.dom={container:A("<"+this.c.dom.container.tag+"/>").addClass(this.c.dom.container.className)},this._constructor()}A.extend(g.prototype,{action:function(A,t){return A=this._nodeToButton(A),t===n?A.conf.action:(A.conf.action=t,this)},active:function(t,e){t=this._nodeToButton(t);var r=this.c.dom.button.active,i=A(t.node);return t.inCollection&&this.c.dom.collection.button&&this.c.dom.collection.button.active!==n&&(r=this.c.dom.collection.button.active),e===n?i.hasClass(r):(i.toggleClass(r,e===n||e),this)},add:function(A,t,e){var r=this.s.buttons;if("string"==typeof t){for(var i=t.split("-"),o=this.s,s=0,a=i.length-1;s<a;s++)o=o.buttons[+i[s]];r=o.buttons,t=+i[i.length-1]}return this._expandButton(r,A,A!==n?A.split:n,(A===n||A.split===n||0===A.split.length)&&o!==n,!1,t),e!==n&&!0!==e||this._draw(),this},collectionRebuild:function(A,t){var e=this._nodeToButton(A);if(t!==n){for(var r=e.buttons.length-1;0<=r;r--)this.remove(e.buttons[r].node);for(e.conf.prefixButtons&&t.unshift.apply(t,e.conf.prefixButtons),e.conf.postfixButtons&&t.push.apply(t,e.conf.postfixButtons),r=0;r<t.length;r++){var i=t[r];this._expandButton(e.buttons,i,i!==n&&i.config!==n&&i.config.split!==n,!0,i.parentConf!==n&&i.parentConf.split!==n,null,i.parentConf)}}this._draw(e.collection,e.buttons)},container:function(){return this.dom.container},disable:function(t){return t=this._nodeToButton(t),A(t.node).addClass(this.c.dom.button.disabled).prop("disabled",!0),this},destroy:function(){A("body").off("keyup."+this.s.namespace);for(var t=this.s.buttons.slice(),e=0,n=t.length;e<n;e++)this.remove(t[e].node);this.dom.container.remove();var r=this.s.dt.settings()[0];for(e=0,n=r.length;e<n;e++)if(r.inst===this){r.splice(e,1);break}return this},enable:function(t,e){return!1===e?this.disable(t):(e=this._nodeToButton(t),A(e.node).removeClass(this.c.dom.button.disabled).prop("disabled",!1),this)},index:function(A,t,e){t||(t="",e=this.s.buttons);for(var n=0,r=e.length;n<r;n++){var i=e[n].buttons;if(e[n].node===A)return t+n;if(i&&i.length&&null!==(i=this.index(A,n+"-",i)))return i}return null},name:function(){return this.c.name},node:function(t){return t?(t=this._nodeToButton(t),A(t.node)):this.dom.container},processing:function(t,e){var r=this.s.dt,i=this._nodeToButton(t);return e===n?A(i.node).hasClass("processing"):(A(i.node).toggleClass("processing",e),A(r.table().node()).triggerHandler("buttons-processing.dt",[e,r.button(t),r,A(t),i.conf]),this)},remove:function(t){var e=this._nodeToButton(t),n=this._nodeToHost(t),r=this.s.dt;if(e.buttons.length)for(var i=e.buttons.length-1;0<=i;i--)this.remove(e.buttons[i].node);return e.conf.destroying=!0,e.conf.destroy&&e.conf.destroy.call(r.button(t),r,A(t),e.conf),this._removeKey(e.conf),A(e.node).remove(),r=A.inArray(e,n),n.splice(r,1),this},text:function(t,e){function r(A){return"function"==typeof A?A(o,s,i.conf):A}var i=this._nodeToButton(t),o=(t=i.textNode,this.s.dt),s=A(i.node);return e===n?r(i.conf.text):(i.conf.text=e,t.html(r(e)),this)},_constructor:function(){var t=this,n=this.s.dt,r=n.settings()[0],i=this.c.buttons;r._buttons||(r._buttons=[]),r._buttons.push({inst:this,name:this.c.name});for(var o=0,s=i.length;o<s;o++)this.add(i[o]);n.on("destroy",(function(A,e){e===r&&t.destroy()})),A("body").on("keyup."+this.s.namespace,(function(A){var n;e.activeElement&&e.activeElement!==e.body||(n=String.fromCharCode(A.keyCode).toLowerCase(),-1!==t.s.listenKeys.toLowerCase().indexOf(n)&&t._keypress(n,A))}))},_addKey:function(t){t.key&&(this.s.listenKeys+=(A.isPlainObject(t.key)?t.key:t).key)},_draw:function(A,t){A||(A=this.dom.container,t=this.s.buttons),A.children().detach();for(var e=0,n=t.length;e<n;e++)A.append(t[e].inserter),A.append(" "),t[e].buttons&&t[e].buttons.length&&this._draw(t[e].collection,t[e].buttons)},_expandButton:function(t,e,r,i,o,s,a){for(var c,B=this.s.dt,g=this.c.dom.collection,l=Array.isArray(e)?e:[e],u=0,w=(l=e===n?Array.isArray(r)?r:[r]:l).length;u<w;u++){var h=this._resolveExtends(l[u]);if(h)if(c=!(!h.config||!h.config.split),Array.isArray(h))this._expandButton(t,h,E!==n&&E.conf!==n?E.conf.split:n,i,a!==n&&a.split!==n,s,a);else{var E=this._buildButton(h,i,h.split!==n||h.config!==n&&h.config.split!==n,o);if(E){if(s!==n&&null!==s?(t.splice(s,0,E),s++):t.push(E),E.conf.buttons&&(E.collection=A("<"+g.container.content.tag+"/>"),E.conf._collection=E.collection,A(E.node).append(g.action.dropHtml),this._expandButton(E.buttons,E.conf.buttons,E.conf.split,!c,c,s,E.conf)),E.conf.split){E.collection=A("<"+g.container.tag+"/>"),E.conf._collection=E.collection;for(var f=0;f<E.conf.split.length;f++){var Q=E.conf.split[f];"object"==typeof Q&&(Q.parent=a,Q.collectionLayout===n&&(Q.collectionLayout=E.conf.collectionLayout),Q.dropup===n&&(Q.dropup=E.conf.dropup),Q.fade===n&&(Q.fade=E.conf.fade))}this._expandButton(E.buttons,E.conf.buttons,E.conf.split,!c,c,s,E.conf)}E.conf.parent=a,h.init&&h.init.call(B.button(E.node),B,A(E.node),h)}}}},_buildButton:function(t,e,r,i){function a(A){return"function"==typeof A?A(w,l,t):A}var c,B,g,l,u=this.c.dom,w=this.s.dt,h=A.extend(!0,{},u.button);if(e&&r&&u.collection.split?A.extend(!0,h,u.collection.split.action):i||e?A.extend(!0,h,u.collection.button):r&&A.extend(!0,h,u.split.button),t.spacer)return u=A("<"+h.spacer.tag+"/>").addClass("dt-button-spacer "+t.style+" "+h.spacer.className).html(a(t.text)),{conf:t,node:u,inserter:u,buttons:[],inCollection:e,isSplit:r,collection:null,textNode:u};if(t.available&&!t.available(w,t)&&!t.hasOwnProperty("html"))return!1;t.hasOwnProperty("html")?l=A(t.html):(B=function(t,e,n,r){r.action.call(e.button(n),t,e,n,r),A(e.table().node()).triggerHandler("buttons-action.dt",[e.button(n),e,n,r])},u=t.tag||h.tag,g=t.clickBlurs===n||t.clickBlurs,l=A("<"+u+"/>").addClass(h.className).attr("tabindex",this.s.dt.settings()[0].iTabIndex).attr("aria-controls",this.s.dt.table().node().id).on("click.dtb",(function(A){A.preventDefault(),!l.hasClass(h.disabled)&&t.action&&B(A,w,l,t),g&&l.trigger("blur")})).on("keypress.dtb",(function(A){13===A.keyCode&&(A.preventDefault(),!l.hasClass(h.disabled)&&t.action&&B(A,w,l,t))})),"a"===u.toLowerCase()&&l.attr("href","#"),"button"===u.toLowerCase()&&l.attr("type","button"),c=h.liner.tag?(u=A("<"+h.liner.tag+"/>").html(a(t.text)).addClass(h.liner.className),"a"===h.liner.tag.toLowerCase()&&u.attr("href","#"),l.append(u),u):(l.html(a(t.text)),l),!1===t.enabled&&l.addClass(h.disabled),t.className&&l.addClass(t.className),t.titleAttr&&l.attr("title",a(t.titleAttr)),t.attr&&l.attr(t.attr),t.namespace||(t.namespace=".dt-button-"+o++),t.config!==n&&t.config.split&&(t.split=t.config.split));var E,f,Q,d,C,M;u=(u=this.c.dom.buttonContainer)&&u.tag?A("<"+u.tag+"/>").addClass(u.className).append(l):l;return this._addKey(t),this.c.buttonCreated&&(u=this.c.buttonCreated(t,u)),r&&(f=(E=e?A.extend(!0,this.c.dom.split,this.c.dom.collection.split):this.c.dom.split).wrapper,Q=A("<"+f.tag+"/>").addClass(f.className).append(l),d=A.extend(t,{align:E.dropdown.align,attr:{"aria-haspopup":"dialog","aria-expanded":!1},className:E.dropdown.className,closeButton:!1,splitAlignClass:E.dropdown.splitAlignClass,text:E.dropdown.text}),this._addKey(d),C=function(t,e,n,r){s.split.action.call(e.button(Q),t,e,n,r),A(e.table().node()).triggerHandler("buttons-action.dt",[e.button(n),e,n,r]),n.attr("aria-expanded",!0)},M=A('<button class="'+E.dropdown.className+' dt-button"></button>').html(E.dropdown.dropHtml).on("click.dtb",(function(A){A.preventDefault(),A.stopPropagation(),M.hasClass(h.disabled)||C(A,w,M,d),g&&M.trigger("blur")})).on("keypress.dtb",(function(A){13===A.keyCode&&(A.preventDefault(),M.hasClass(h.disabled)||C(A,w,M,d))})),0===t.split.length&&M.addClass("dtb-hide-drop"),Q.append(M).attr(d.attr)),{conf:t,node:(r?Q:l).get(0),inserter:r?Q:u,buttons:[],inCollection:e,isSplit:r,inSplit:i,collection:null,textNode:c}},_nodeToButton:function(A,t){for(var e=0,n=(t=t||this.s.buttons).length;e<n;e++){if(t[e].node===A)return t[e];if(t[e].buttons.length){var r=this._nodeToButton(A,t[e].buttons);if(r)return r}}},_nodeToHost:function(A,t){for(var e=0,n=(t=t||this.s.buttons).length;e<n;e++){if(t[e].node===A)return t;if(t[e].buttons.length){var r=this._nodeToHost(A,t[e].buttons);if(r)return r}}},_keypress:function(t,e){var n;e._buttonsHandled||(n=function(r){for(var i,o,s=0,a=r.length;s<a;s++)i=r[s].conf,o=r[s].node,!i.key||i.key!==t&&(!A.isPlainObject(i.key)||i.key.key!==t||i.key.shiftKey&&!e.shiftKey||i.key.altKey&&!e.altKey||i.key.ctrlKey&&!e.ctrlKey||i.key.metaKey&&!e.metaKey)||(e._buttonsHandled=!0,A(o).click()),r[s].buttons.length&&n(r[s].buttons)})(this.s.buttons)},_removeKey:function(t){var e;t.key&&(t=(A.isPlainObject(t.key)?t.key:t).key,e=this.s.listenKeys.split(""),t=A.inArray(t,e),e.splice(t,1),this.s.listenKeys=e.join(""))},_resolveExtends:function(t){function e(e){for(var r=0;!A.isPlainObject(e)&&!Array.isArray(e);){if(e===n)return;if("function"==typeof e){if(!(e=e.call(o,a,t)))return!1}else if("string"==typeof e){if(!s[e])return{html:e};e=s[e]}if(30<++r)throw"Buttons: Too many iterations"}return Array.isArray(e)?e:A.extend({},e)}var r,i,o=this,a=this.s.dt;for(t=e(t);t&&t.extend;){if(!s[t.extend])throw"Cannot extend unknown button type: "+t.extend;var c=e(s[t.extend]);if(Array.isArray(c))return c;if(!c)return!1;var B=c.className;t.config!==n&&c.config!==n&&(t.config=A.extend({},c.config,t.config)),t=A.extend({},c,t),B&&t.className!==B&&(t.className=B+" "+t.className),t.extend=c.extend}var g=t.postfixButtons;if(g)for(t.buttons||(t.buttons=[]),r=0,i=g.length;r<i;r++)t.buttons.push(g[r]);var l=t.prefixButtons;if(l)for(t.buttons||(t.buttons=[]),r=0,i=l.length;r<i;r++)t.buttons.splice(r,0,l[r]);return t},_popover:function(n,r,i,o){function s(){C=!0,B(A(I),M.fade,(function(){A(this).detach()})),A(Q.buttons('[aria-haspopup="dialog"][aria-expanded="true"]').nodes()).attr("aria-expanded","false"),A("div.dt-button-background").off("click.dtb-collection"),g.background(!1,M.backgroundClassName,M.fade,p),A(t).off("resize.resize.dtb-collection"),A("body").off(".dtb-collection"),Q.off("buttons-action.b-internal"),Q.off("destroy")}var a,l,u,w,h,E,f,Q=r,d=this.c,C=!1,M=A.extend({align:"button-left",autoClose:!1,background:!0,backgroundClassName:"dt-button-background",closeButton:!0,containerClassName:d.dom.collection.container.className,contentClassName:d.dom.collection.container.content.className,collectionLayout:"",collectionTitle:"",dropup:!1,fade:400,popoverTitle:"",rightAlignClassName:"dt-button-right",tag:d.dom.collection.container.tag},i),I=M.tag+"."+M.containerClassName.replace(/ /g,"."),p=r.node();!1===n?s():((d=A(Q.buttons('[aria-haspopup="dialog"][aria-expanded="true"]').nodes())).length&&(p.closest(I).length&&(p=d.eq(0)),s()),d="",3===(i=A(".dt-button",n).length)?d="dtb-b3":2===i?d="dtb-b2":1===i&&(d="dtb-b1"),a=A("<"+M.tag+"/>").addClass(M.containerClassName).addClass(M.collectionLayout).addClass(M.splitAlignClass).addClass(d).css("display","none").attr({"aria-modal":!0,role:"dialog"}),n=A(n).addClass(M.contentClassName).attr("role","menu").appendTo(a),p.attr("aria-expanded","true"),p.parents("body")[0]!==e.body&&(p=e.body.lastChild),M.popoverTitle?a.prepend('<div class="dt-button-collection-title">'+M.popoverTitle+"</div>"):M.collectionTitle&&a.prepend('<div class="dt-button-collection-title">'+M.collectionTitle+"</div>"),M.closeButton&&a.prepend('<div class="dtb-popover-close">&times;</div>').addClass("dtb-collection-closeable"),c(a.insertAfter(p),M.fade),i=A(r.table().container()),f=a.css("position"),"container"!==M.span&&"dt-container"!==M.align||(p=p.parent(),a.css("width",i.width())),"absolute"===f?(d=A(p[0].offsetParent),r=p.position(),i=p.offset(),l=d.offset(),u=d.position(),w=t.getComputedStyle(d[0]),l.height=d.outerHeight(),l.width=d.width()+parseFloat(w.paddingLeft),l.right=l.left+l.width,l.bottom=l.top+l.height,d=r.top+p.outerHeight(),h=r.left,a.css({top:d,left:h}),w=t.getComputedStyle(a[0]),(E=a.offset()).height=a.outerHeight(),E.width=a.outerWidth(),E.right=E.left+E.width,E.bottom=E.top+E.height,E.marginTop=parseFloat(w.marginTop),E.marginBottom=parseFloat(w.marginBottom),M.dropup&&(d=r.top-E.height-E.marginTop-E.marginBottom),"button-right"!==M.align&&!a.hasClass(M.rightAlignClassName)||(h=r.left-E.width+p.outerWidth()),"dt-container"!==M.align&&"container"!==M.align||(h=h<r.left?-r.left:h)+E.width>l.width&&(h=l.width-E.width),u.left+h+E.width>A(t).width()&&(h=A(t).width()-E.width-u.left),i.left+h<0&&(h=-i.left),u.top+d+E.height>A(t).height()+A(t).scrollTop()&&(d=r.top-E.height-E.marginTop-E.marginBottom),u.top+d<A(t).scrollTop()&&(d=r.top+p.outerHeight()),a.css({top:d,left:h})):((f=function(){var e=A(t).height()/2,n=a.height()/2;a.css("marginTop",-1*(n=e<n?e:n))})(),A(t).on("resize.dtb-collection",(function(){f()}))),M.background&&g.background(!0,M.backgroundClassName,M.fade,M.backgroundHost||p),A("div.dt-button-background").on("click.dtb-collection",(function(){})),M.autoClose&&setTimeout((function(){Q.on("buttons-action.b-internal",(function(A,t,e,n){n[0]!==p[0]&&s()}))}),0),A(a).trigger("buttons-popover.dt"),Q.on("destroy",s),setTimeout((function(){C=!1,A("body").on("click.dtb-collection",(function(t){var e,r;C||(e=A.fn.addBack?"addBack":"andSelf",r=A(t.target).parent()[0],(A(t.target).parents()[e]().filter(n).length||A(r).hasClass("dt-buttons"))&&!A(t.target).hasClass("dt-button-background")||s())})).on("keyup.dtb-collection",(function(A){27===A.keyCode&&s()})).on("keydown.dtb-collection",(function(t){var r=A("a, button",n),i=e.activeElement;9===t.keyCode&&(-1===r.index(i)?(r.first().focus(),t.preventDefault()):t.shiftKey?i===r[0]&&(r.last().focus(),t.preventDefault()):i===r.last()[0]&&(r.first().focus(),t.preventDefault()))}))}),0))}}),g.background=function(t,r,i,o){i===n&&(i=400),o=o||e.body,t?c(A("<div/>").addClass(r).css("display","none").insertAfter(o),i):B(A("div."+r),i,(function(){A(this).removeClass(r).remove()}))},g.instanceSelector=function(t,e){var r,i,o;return t===n||null===t?A.map(e,(function(A){return A.inst})):(r=[],i=A.map(e,(function(A){return A.name})),(o=function(t){var n;if(Array.isArray(t))for(var s=0,a=t.length;s<a;s++)o(t[s]);else"string"==typeof t?-1!==t.indexOf(",")?o(t.split(",")):-1!==(n=A.inArray(t.trim(),i))&&r.push(e[n].inst):"number"==typeof t?r.push(e[t].inst):"object"==typeof t&&r.push(t)})(t),r)},g.buttonSelector=function(t,e){for(var r=[],i=function(A,t,e){for(var r,o,s=0,a=t.length;s<a;s++)(r=t[s])&&(A.push({node:r.node,name:r.conf.name,idx:o=e!==n?e+s:s+""}),r.buttons&&i(A,r.buttons,o+"-"))},o=function(t,e){var s=[],a=(i(s,e.s.buttons),A.map(s,(function(A){return A.node})));if(Array.isArray(t)||t instanceof A)for(B=0,g=t.length;B<g;B++)o(t[B],e);else if(null===t||t===n||"*"===t)for(B=0,g=s.length;B<g;B++)r.push({inst:e,node:s[B].node});else if("number"==typeof t)e.s.buttons[t]&&r.push({inst:e,node:e.s.buttons[t].node});else if("string"==typeof t)if(-1!==t.indexOf(","))for(var c=t.split(","),B=0,g=c.length;B<g;B++)o(c[B].trim(),e);else if(t.match(/^\d+(\-\d+)*$/)){var l=A.map(s,(function(A){return A.idx}));r.push({inst:e,node:s[A.inArray(t,l)].node})}else if(-1!==t.indexOf(":name")){var u=t.replace(":name","");for(B=0,g=s.length;B<g;B++)s[B].name===u&&r.push({inst:e,node:s[B].node})}else A(a).filter(t).each((function(){r.push({inst:e,node:this})}));else"object"!=typeof t||!t.nodeName||-1!==(l=A.inArray(t,a))&&r.push({inst:e,node:a[l]})},s=0,a=t.length;s<a;s++){var c=t[s];o(e,c)}return r},g.stripData=function(A,t){return"string"==typeof A&&(A=(A=A.replace(/<script\b[^<]*(?:(?!<\/script>)<[^<]*)*<\/script>/gi,"")).replace(/<!\-\-.*?\-\->/g,""),t&&!t.stripHtml||(A=A.replace(/<[^>]*>/g,"")),t&&!t.trim||(A=A.replace(/^\s+|\s+$/g,"")),t&&!t.stripNewlines||(A=A.replace(/\n/g," ")),t&&!t.decodeEntities||(A=a?a(A):(f.innerHTML=A,f.value))),A},g.entityDecoder=function(A){a=A},g.defaults={buttons:["copy","excel","csv","pdf","print"],name:"main",tabIndex:0,dom:{container:{tag:"div",className:"dt-buttons"},collection:{action:{dropHtml:'<span class="dt-button-down-arrow">&#x25BC;</span>'},container:{className:"dt-button-collection",content:{className:"",tag:"div"},tag:"div"}},button:{tag:"button",className:"dt-button",active:"dt-button-active",disabled:"disabled",spacer:{className:"dt-button-spacer",tag:"span"},liner:{tag:"span",className:""}},split:{action:{className:"dt-button-split-drop-button dt-button",tag:"button"},dropdown:{align:"split-right",className:"dt-button-split-drop",dropHtml:'<span class="dt-button-down-arrow">&#x25BC;</span>',splitAlignClass:"dt-button-split-left",tag:"button"},wrapper:{className:"dt-button-split",tag:"div"}}}},A.extend(s,{collection:{text:function(A){return A.i18n("buttons.collection","Collection")},className:"buttons-collection",closeButton:!(g.version="2.4.2"),init:function(A,t,e){t.attr("aria-expanded",!1)},action:function(t,e,n,r){r._collection.parents("body").length?this.popover(!1,r):this.popover(r._collection,r),"keypress"===t.type&&A("a, button",r._collection).eq(0).focus()},attr:{"aria-haspopup":"dialog"}},split:{text:function(A){return A.i18n("buttons.split","Split")},className:"buttons-split",closeButton:!1,init:function(A,t,e){return t.attr("aria-expanded",!1)},action:function(A,t,e,n){this.popover(n._collection,n)},attr:{"aria-haspopup":"dialog"}},copy:function(A,t){if(s.copyHtml5)return"copyHtml5"},csv:function(A,t){if(s.csvHtml5&&s.csvHtml5.available(A,t))return"csvHtml5"},excel:function(A,t){if(s.excelHtml5&&s.excelHtml5.available(A,t))return"excelHtml5"},pdf:function(A,t){if(s.pdfHtml5&&s.pdfHtml5.available(A,t))return"pdfHtml5"},pageLength:function(t){var e=t.settings()[0].aLengthMenu,n=[],r=[];if(Array.isArray(e[0]))n=e[0],r=e[1];else for(var i=0;i<e.length;i++){var o=e[i];A.isPlainObject(o)?(n.push(o.value),r.push(o.label)):(n.push(o),r.push(o))}return{extend:"collection",text:function(A){return A.i18n("buttons.pageLength",{"-1":"Show all rows",_:"Show %d rows"},A.page.len())},className:"buttons-page-length",autoClose:!0,buttons:A.map(n,(function(A,t){return{text:r[t],className:"button-page-length",action:function(t,e){e.page.len(A).draw()},init:function(t,e,n){function r(){i.active(t.page.len()===A)}var i=this;t.on("length.dt"+n.namespace,r),r()},destroy:function(A,t,e){A.off("length.dt"+e.namespace)}}})),init:function(A,t,e){var n=this;A.on("length.dt"+e.namespace,(function(){n.text(e.text)}))},destroy:function(A,t,e){A.off("length.dt"+e.namespace)}}},spacer:{style:"empty",spacer:!0,text:function(A){return A.i18n("buttons.spacer","")}}}),r.Api.register("buttons()",(function(A,t){t===n&&(t=A,A=n),this.selector.buttonGroup=A;var e=this.iterator(!0,"table",(function(e){if(e._buttons)return g.buttonSelector(g.instanceSelector(A,e._buttons),t)}),!0);return e._groupSelector=A,e})),r.Api.register("button()",(function(A,t){return 1<(A=this.buttons(A,t)).length&&A.splice(1,A.length),A})),r.Api.registerPlural("buttons().active()","button().active()",(function(A){return A===n?this.map((function(A){return A.inst.active(A.node)})):this.each((function(t){t.inst.active(t.node,A)}))})),r.Api.registerPlural("buttons().action()","button().action()",(function(A){return A===n?this.map((function(A){return A.inst.action(A.node)})):this.each((function(t){t.inst.action(t.node,A)}))})),r.Api.registerPlural("buttons().collectionRebuild()","button().collectionRebuild()",(function(A){return this.each((function(t){for(var e=0;e<A.length;e++)"object"==typeof A[e]&&(A[e].parentConf=t);t.inst.collectionRebuild(t.node,A)}))})),r.Api.register(["buttons().enable()","button().enable()"],(function(A){return this.each((function(t){t.inst.enable(t.node,A)}))})),r.Api.register(["buttons().disable()","button().disable()"],(function(){return this.each((function(A){A.inst.disable(A.node)}))})),r.Api.register("button().index()",(function(){var A=null;return this.each((function(t){null!==(t=t.inst.index(t.node))&&(A=t)})),A})),r.Api.registerPlural("buttons().nodes()","button().node()",(function(){var t=A();return A(this.each((function(A){t=t.add(A.inst.node(A.node))}))),t})),r.Api.registerPlural("buttons().processing()","button().processing()",(function(A){return A===n?this.map((function(A){return A.inst.processing(A.node)})):this.each((function(t){t.inst.processing(t.node,A)}))})),r.Api.registerPlural("buttons().text()","button().text()",(function(A){return A===n?this.map((function(A){return A.inst.text(A.node)})):this.each((function(t){t.inst.text(t.node,A)}))})),r.Api.registerPlural("buttons().trigger()","button().trigger()",(function(){return this.each((function(A){A.inst.node(A.node).trigger("click")}))})),r.Api.register("button().popover()",(function(A,t){return this.map((function(e){return e.inst._popover(A,this.button(this[0].node),t)}))})),r.Api.register("buttons().containers()",(function(){var t=A(),e=this._groupSelector;return this.iterator(!0,"table",(function(A){if(A._buttons)for(var n=g.instanceSelector(e,A._buttons),r=0,i=n.length;r<i;r++)t=t.add(n[r].container())})),t})),r.Api.register("buttons().container()",(function(){return this.containers().eq(0)})),r.Api.register("button().add()",(function(A,t,e){var n=this.context;return n.length&&(n=g.instanceSelector(this._groupSelector,n[0]._buttons)).length&&n[0].add(t,A,e),this.button(this._groupSelector,A)})),r.Api.register("buttons().destroy()",(function(){return this.pluck("inst").unique().each((function(A){A.destroy()})),this})),r.Api.registerPlural("buttons().remove()","buttons().remove()",(function(){return this.each((function(A){A.inst.remove(A.node)})),this})),r.Api.register("buttons.info()",(function(t,e,r){var i=this;return!1===t?(this.off("destroy.btn-info"),B(A("#datatables_buttons_info"),400,(function(){A(this).remove()})),clearTimeout(l),l=null):(l&&clearTimeout(l),A("#datatables_buttons_info").length&&A("#datatables_buttons_info").remove(),t=t?"<h2>"+t+"</h2>":"",c(A('<div id="datatables_buttons_info" class="dt-button-info"/>').html(t).append(A("<div/>")["string"==typeof e?"html":"append"](e)).css("display","none").appendTo("body")),r!==n&&0!==r&&(l=setTimeout((function(){i.buttons.info(!1)}),r)),this.on("destroy.btn-info",(function(){i.buttons.info(!1)}))),this})),r.Api.register("buttons.exportData()",(function(A){if(this.context.length)return Q(new r.Api(this.context[0]),A)})),r.Api.register("buttons.exportInfo()",(function(A){return{filename:u(A=A||{}),title:h(A),messageTop:E(this,A.message||A.messageTop,"top"),messageBottom:E(this,A.messageBottom,"bottom")}}));var l,u=function(t){var e;return(e="function"==typeof(e="*"===t.filename&&"*"!==t.title&&t.title!==n&&null!==t.title&&""!==t.title?t.title:t.filename)?e():e)===n||null===e?null:(e=(e=-1!==e.indexOf("*")?e.replace("*",A("head > title").text()).trim():e).replace(/[^a-zA-Z0-9_\u00A1-\uFFFF\.,\-_ !\(\)]/g,""))+(w(t.extension)||"")},w=function(A){return null===A||A===n?null:"function"==typeof A?A():A},h=function(t){return null===(t=w(t.title))?null:-1!==t.indexOf("*")?t.replace("*",A("head > title").text()||"Exported data"):t},E=function(t,e,n){return null===(e=w(e))?null:(t=A("caption",t.table().container()).eq(0),"*"===e?t.css("caption-side")!==n?null:t.length?t.text():"":e)},f=A("<textarea/>")[0],Q=function(t,e){for(var r=A.extend(!0,{},{rows:null,columns:"",modifier:{search:"applied",order:"applied"},orthogonal:"display",stripHtml:!0,stripNewlines:!0,decodeEntities:!0,trim:!0,format:{header:function(A){return g.stripData(A,r)},footer:function(A){return g.stripData(A,r)},body:function(A){return g.stripData(A,r)}},customizeData:null},e),i=(e=t.columns(r.columns).indexes().map((function(A){var e=t.column(A).header();return r.format.header(e.innerHTML,A,e)})).toArray(),t.table().footer()?t.columns(r.columns).indexes().map((function(A){var e=t.column(A).footer();return r.format.footer(e?e.innerHTML:"",A,e)})).toArray():null),o=A.extend({},r.modifier),s=(o=(t.select&&"function"==typeof t.select.info&&o.selected===n&&t.rows(r.rows,A.extend({selected:!0},o)).any()&&A.extend(o,{selected:!0}),t.rows(r.rows,o).indexes().toArray()),(o=t.cells(o,r.columns)).render(r.orthogonal).toArray()),a=o.nodes().toArray(),c=e.length,B=[],l=0,u=0,w=0<c?s.length/c:0;u<w;u++){for(var h=[c],E=0;E<c;E++)h[E]=r.format.body(s[l],u,E,a[l]),l++;B[u]=h}return o={header:e,footer:i,body:B},r.customizeData&&r.customizeData(o),o};function d(A,t){return A=new r.Api(A),t=t||A.init().buttons||r.defaults.buttons,new g(A,t).container()}return A.fn.dataTable.Buttons=g,A.fn.DataTable.Buttons=g,A(e).on("init.dt plugin-init.dt",(function(A,t){"dt"===A.namespace&&(A=t.oInit.buttons||r.defaults.buttons)&&!t._buttons&&new g(t,A).container()})),r.ext.feature.push({fnInit:d,cFeature:"B"}),r.ext.features&&r.ext.features.register("buttons",d),r})),function(A){var t,e;"function"==typeof define&&define.amd?define(["jquery","datatables.net-bs5","datatables.net-buttons"],(function(t){return A(t,window,document)})):"object"==typeof exports?(t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net-bs5")(A,t),t.fn.dataTable.Buttons||require("datatables.net-buttons")(A,t)},"undefined"==typeof window?module.exports=function(n,r){return n=n||window,r=r||t(n),e(n,r),A(r,0,n.document)}:(e(window,t),module.exports=A(t,window,window.document))):A(jQuery,window,document)}((function(A,t,e,n){"use strict";var r=A.fn.dataTable;return A.extend(!0,r.Buttons.defaults,{dom:{container:{className:"dt-buttons btn-group flex-wrap"},button:{className:"btn btn-secondary",active:"active"},collection:{action:{dropHtml:""},container:{tag:"div",className:"dropdown-menu dt-button-collection"},closeButton:!1,button:{tag:"a",className:"dt-button dropdown-item",active:"dt-button-active",disabled:"disabled",spacer:{className:"dropdown-divider",tag:"hr"}}},split:{action:{tag:"a",className:"btn btn-secondary dt-button-split-drop-button",closeButton:!1},dropdown:{tag:"button",dropHtml:"",className:"btn btn-secondary dt-button-split-drop dropdown-toggle dropdown-toggle-split",closeButton:!1,align:"split-left",splitAlignClass:"dt-button-split-left"},wrapper:{tag:"div",className:"dt-button-split btn-group",closeButton:!1}}},buttonCreated:function(t,e){return t.buttons?A('<div class="btn-group"/>').append(e):e}}),r.ext.buttons.collection.className+=" dropdown-toggle",r.ext.buttons.collection.rightAlignClassName="dropdown-menu-right",r})),
/*!
 * Column visibility buttons for Buttons and DataTables.
 * © SpryMedia Ltd - datatables.net/license
 */
function(A){if("function"==typeof define&&define.amd)define(["jquery","datatables.net","datatables.net-buttons"],(function(t){return A(t,window,document)}));else if("object"==typeof exports){var t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net")(A,t),t.fn.dataTable.Buttons||require("datatables.net-buttons")(A,t)};"undefined"==typeof window?module.exports=function(n,r){return n||(n=window),r||(r=t(n)),e(n,r),A(r,n,n.document)}:(e(window,t),module.exports=A(t,window,window.document))}else A(jQuery,window,document)}((function(A,t,e,n){"use strict";var r=A.fn.dataTable;return A.extend(r.ext.buttons,{colvis:function(A,t){var e=null,n={extend:"collection",init:function(A,t){e=t},text:function(A){return A.i18n("buttons.colvis","Column visibility")},className:"buttons-colvis",closeButton:!1,buttons:[{extend:"columnsToggle",columns:t.columns,columnText:t.columnText}]};return A.on("column-reorder.dt"+t.namespace,(function(n,r,i){A.button(null,A.button(null,e).node()).collectionRebuild([{extend:"columnsToggle",columns:t.columns,columnText:t.columnText}])})),n},columnsToggle:function(A,t){return A.columns(t.columns).indexes().map((function(A){return{extend:"columnToggle",columns:A,columnText:t.columnText}})).toArray()},columnToggle:function(A,t){return{extend:"columnVisibility",columns:t.columns,columnText:t.columnText}},columnsVisibility:function(A,t){return A.columns(t.columns).indexes().map((function(A){return{extend:"columnVisibility",columns:A,visibility:t.visibility,columnText:t.columnText}})).toArray()},columnVisibility:{columns:n,text:function(A,t,e){return e._columnText(A,e)},className:"buttons-columnVisibility",action:function(A,t,e,r){var i=t.columns(r.columns),o=i.visible();i.visible(r.visibility!==n?r.visibility:!(o.length&&o[0]))},init:function(A,t,e){var n=this;t.attr("data-cv-idx",e.columns),A.on("column-visibility.dt"+e.namespace,(function(t,r){r.bDestroying||r.nTable!=A.settings()[0].nTable||n.active(A.column(e.columns).visible())})).on("column-reorder.dt"+e.namespace,(function(t,r,i){e.destroying||1===A.columns(e.columns).count()&&(n.text(e._columnText(A,e)),n.active(A.column(e.columns).visible()))})),this.active(A.column(e.columns).visible())},destroy:function(A,t,e){A.off("column-visibility.dt"+e.namespace).off("column-reorder.dt"+e.namespace)},_columnText:function(A,t){var e=A.column(t.columns).index(),n=A.settings()[0].aoColumns[e].sTitle;return n||(n=A.column(e).header().innerHTML),n=n.replace(/\n/g," ").replace(/<br\s*\/?>/gi," ").replace(/<select(.*?)<\/select>/g,"").replace(/<!\-\-.*?\-\->/g,"").replace(/<.*?>/g,"").replace(/^\s+|\s+$/g,""),t.columnText?t.columnText(A,e,n):n}},colvisRestore:{className:"buttons-colvisRestore",text:function(A){return A.i18n("buttons.colvisRestore","Restore visibility")},init:function(A,t,e){e._visOriginal=A.columns().indexes().map((function(t){return A.column(t).visible()})).toArray()},action:function(A,t,e,n){t.columns().every((function(A){var e=t.colReorder&&t.colReorder.transpose?t.colReorder.transpose(A,"toOriginal"):A;this.visible(n._visOriginal[e])}))}},colvisGroup:{className:"buttons-colvisGroup",action:function(A,t,e,n){t.columns(n.show).visible(!0,!1),t.columns(n.hide).visible(!1,!1),t.columns.adjust()},show:[],hide:[]}}),r})),
/*!
 * Flash export buttons for Buttons and DataTables.
 * 2015 SpryMedia Ltd - datatables.net/license
 *
 * ZeroClipbaord - MIT license
 * Copyright (c) 2012 Joseph Huckaby
 */
function(A){"function"==typeof define&&define.amd?define(["jquery","datatables.net","datatables.net-buttons"],(function(t){return A(t,window,document)})):"object"==typeof exports?module.exports=function(t,e){return t||(t=window),e&&e.fn.dataTable||(e=require("datatables.net")(t,e).$),e.fn.dataTable.Buttons||require("datatables.net-buttons")(t,e),A(e,t,t.document)}:A(jQuery,window,document)}((function(A,t,e,n){"use strict";var r=A.fn.dataTable,i={version:"1.0.4-TableTools2",clients:{},moviePath:"",nextId:1,$:function(A){return"string"==typeof A&&(A=e.getElementById(A)),A.addClass||(A.hide=function(){this.style.display="none"},A.show=function(){this.style.display=""},A.addClass=function(A){this.removeClass(A),this.className+=" "+A},A.removeClass=function(A){this.className=this.className.replace(new RegExp("\\s*"+A+"\\s*")," ").replace(/^\s+/,"").replace(/\s+$/,"")},A.hasClass=function(A){return!!this.className.match(new RegExp("\\s*"+A+"\\s*"))}),A},setMoviePath:function(A){this.moviePath=A},dispatch:function(A,t,e){var n=this.clients[A];n&&n.receiveEvent(t,e)},log:function(A){console.log("Flash: "+A)},register:function(A,t){this.clients[A]=t},getDOMObjectPosition:function(A){var t={left:0,top:0,width:A.width?A.width:A.offsetWidth,height:A.height?A.height:A.offsetHeight};for(""!==A.style.width&&(t.width=A.style.width.replace("px","")),""!==A.style.height&&(t.height=A.style.height.replace("px",""));A;)t.left+=A.offsetLeft,t.top+=A.offsetTop,A=A.offsetParent;return t},Client:function(A){this.handlers={},this.id=i.nextId++,this.movieId="ZeroClipboard_TableToolsMovie_"+this.id,i.register(this.id,this),A&&this.glue(A)}};i.Client.prototype={id:0,ready:!1,movie:null,clipText:"",fileName:"",action:"copy",handCursorEnabled:!0,cssEffects:!0,handlers:null,sized:!1,sheetName:"",glue:function(A,t){this.domElement=i.$(A);var n=99;this.domElement.style.zIndex&&(n=parseInt(this.domElement.style.zIndex,10)+1);var r=i.getDOMObjectPosition(this.domElement);this.div=e.createElement("div");var o=this.div.style;o.position="absolute",o.left="0px",o.top="0px",o.width=r.width+"px",o.height=r.height+"px",o.zIndex=n,void 0!==t&&""!==t&&(this.div.title=t),0!==r.width&&0!==r.height&&(this.sized=!0),this.domElement&&(this.domElement.appendChild(this.div),this.div.innerHTML=this.getHTML(r.width,r.height).replace(/&/g,"&amp;"))},positionElement:function(){var A=i.getDOMObjectPosition(this.domElement),t=this.div.style;if(t.position="absolute",t.width=A.width+"px",t.height=A.height+"px",0!==A.width&&0!==A.height){this.sized=!0;var e=this.div.childNodes[0];e.width=A.width,e.height=A.height}},getHTML:function(A,t){var e="",n="id="+this.id+"&width="+A+"&height="+t;navigator.userAgent.match(/MSIE/)?e+='<object classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000" codebase="'+(location.href.match(/^https/i)?"https://":"http://")+'download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=10,0,0,0" width="'+A+'" height="'+t+'" id="'+this.movieId+'" align="middle"><param name="allowScriptAccess" value="always" /><param name="allowFullScreen" value="false" /><param name="movie" value="'+i.moviePath+'" /><param name="loop" value="false" /><param name="menu" value="false" /><param name="quality" value="best" /><param name="bgcolor" value="#ffffff" /><param name="flashvars" value="'+n+'"/><param name="wmode" value="transparent"/></object>':e+='<embed id="'+this.movieId+'" src="'+i.moviePath+'" loop="false" menu="false" quality="best" bgcolor="#ffffff" width="'+A+'" height="'+t+'" name="'+this.movieId+'" align="middle" allowScriptAccess="always" allowFullScreen="false" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" flashvars="'+n+'" wmode="transparent" />';return e},hide:function(){this.div&&(this.div.style.left="-2000px")},show:function(){this.reposition()},destroy:function(){var t=this;this.domElement&&this.div&&(A(this.div).remove(),this.domElement=null,this.div=null,A.each(i.clients,(function(A,e){e===t&&delete i.clients[A]})))},reposition:function(A){if(A&&(this.domElement=i.$(A),this.domElement||this.hide()),this.domElement&&this.div){var t=i.getDOMObjectPosition(this.domElement),e=this.div.style;e.left=t.left+"px",e.top=t.top+"px"}},clearText:function(){this.clipText="",this.ready&&this.movie.clearText()},appendText:function(A){this.clipText+=A,this.ready&&this.movie.appendText(A)},setText:function(A){this.clipText=A,this.ready&&this.movie.setText(A)},setFileName:function(A){this.fileName=A,this.ready&&this.movie.setFileName(A)},setSheetData:function(A){this.ready&&this.movie.setSheetData(JSON.stringify(A))},setAction:function(A){this.action=A,this.ready&&this.movie.setAction(A)},addEventListener:function(A,t){A=A.toString().toLowerCase().replace(/^on/,""),this.handlers[A]||(this.handlers[A]=[]),this.handlers[A].push(t)},setHandCursor:function(A){this.handCursorEnabled=A,this.ready&&this.movie.setHandCursor(A)},setCSSEffects:function(A){this.cssEffects=!!A},receiveEvent:function(A,n){var r;switch(A=A.toString().toLowerCase().replace(/^on/,"")){case"load":if(this.movie=e.getElementById(this.movieId),!this.movie)return r=this,void setTimeout((function(){r.receiveEvent("load",null)}),1);if(!this.ready&&navigator.userAgent.match(/Firefox/)&&navigator.userAgent.match(/Windows/))return r=this,setTimeout((function(){r.receiveEvent("load",null)}),100),void(this.ready=!0);this.ready=!0,this.movie.clearText(),this.movie.appendText(this.clipText),this.movie.setFileName(this.fileName),this.movie.setAction(this.action),this.movie.setHandCursor(this.handCursorEnabled);break;case"mouseover":this.domElement&&this.cssEffects&&this.recoverActive&&this.domElement.addClass("active");break;case"mouseout":this.domElement&&this.cssEffects&&(this.recoverActive=!1,this.domElement.hasClass("active")&&(this.domElement.removeClass("active"),this.recoverActive=!0));break;case"mousedown":this.domElement&&this.cssEffects&&this.domElement.addClass("active");break;case"mouseup":this.domElement&&this.cssEffects&&(this.domElement.removeClass("active"),this.recoverActive=!1)}if(this.handlers[A])for(var i=0,o=this.handlers[A].length;i<o;i++){var s=this.handlers[A][i];"function"==typeof s?s(this,n):"object"==typeof s&&2==s.length?s[0][s[1]](this,n):"string"==typeof s&&t[s](this,n)}}},i.hasFlash=function(){try{if(new ActiveXObject("ShockwaveFlash.ShockwaveFlash"))return!0}catch(A){if(navigator.mimeTypes&&navigator.mimeTypes["application/x-shockwave-flash"]!==n&&navigator.mimeTypes["application/x-shockwave-flash"].enabledPlugin)return!0}return!1},t.ZeroClipboard_TableTools=i;var o=function(A,t){t.attr("id");t.parents("html").length?A.glue(t[0],""):setTimeout((function(){o(A,t)}),500)},s=function(t,e){var r="*"===t.filename&&"*"!==t.title&&t.title!==n?t.title:t.filename;return"function"==typeof r&&(r=r()),-1!==r.indexOf("*")&&(r=A.trim(r.replace("*",A("title").text()))),r=r.replace(/[^a-zA-Z0-9_\u00A1-\uFFFF\.,\-_ !\(\)]/g,""),e===n||!0===e?r+t.extension:r},a=function(A,t){var e=t.match(/[\s\S]{1,8192}/g)||[];A.clearText();for(var n=0,r=e.length;n<r;n++)A.appendText(e[n])},c=function(A,t){for(var e=function(A){return A.newline?A.newline:navigator.userAgent.match(/Windows/)?"\r\n":"\n"}(t),r=A.buttons.exportData(t.exportOptions),i=t.fieldBoundary,o=t.fieldSeparator,s=new RegExp(i,"g"),a=t.escapeChar!==n?t.escapeChar:"\\",c=function(A){for(var t="",e=0,n=A.length;e<n;e++)e>0&&(t+=o),t+=i?i+(""+A[e]).replace(s,a+i)+i:A[e];return t},B=t.header?c(r.header)+e:"",g=t.footer&&r.footer?e+c(r.footer):"",l=[],u=0,w=r.body.length;u<w;u++)l.push(c(r.body[u]));return{str:B+l.join(e)+g,rows:l.length}},B={available:function(){return i.hasFlash()},init:function(A,t,e){i.moviePath=r.Buttons.swfPath;var n=new i.Client;n.setHandCursor(!0),n.addEventListener("mouseDown",(function(n){e._fromFlash=!0,A.button(t[0]).trigger(),e._fromFlash=!1})),o(n,t),e._flash=n},destroy:function(A,t,e){e._flash.destroy()},fieldSeparator:",",fieldBoundary:'"',exportOptions:{},title:"*",filename:"*",extension:".csv",header:!0,footer:!1};function g(A){for(var t="A".charCodeAt(0),e="Z".charCodeAt(0)-t+1,n="";A>=0;)n=String.fromCharCode(A%e+t)+n,A=Math.floor(A/e)-1;return n}function l(t,e,n){var r=t.createElement(e);return n&&(n.attr&&A(r).attr(n.attr),n.children&&A.each(n.children,(function(A,t){r.appendChild(t)})),n.text&&r.appendChild(t.createTextNode(n.text))),r}function u(A,t){var e,r,i,o=A.header[t].length;A.footer&&A.footer[t].length>o&&(o=A.footer[t].length);for(var s=0,a=A.body.length;s<a;s++){var c=A.body[s][t];if(-1!==(i=null!==c&&c!==n?c.toString():"").indexOf("\n")?((r=i.split("\n")).sort((function(A,t){return t.length-A.length})),e=r[0].length):e=i.length,e>o&&(o=e),o>40)return 52}return(o*=1.3)>6?o:6}var w,h="";function E(t){w===n&&(w=-1===h.serializeToString(A.parseXML(f["xl/worksheets/sheet1.xml"])).indexOf("xmlns:r")),A.each(t,(function(e,n){if(A.isPlainObject(n))E(n);else{if(w){var r,i,o=n.childNodes[0],s=[];for(r=o.attributes.length-1;r>=0;r--){var a=o.attributes[r].nodeName,c=o.attributes[r].nodeValue;-1!==a.indexOf(":")&&(s.push({name:a,value:c}),o.removeAttribute(a))}for(r=0,i=s.length;r<i;r++){var B=n.createAttribute(s[r].name.replace(":","_dt_b_namespace_token_"));B.value=s[r].value,o.setAttributeNode(B)}}var g=h.serializeToString(n);w&&(-1===g.indexOf("<?xml")&&(g='<?xml version="1.0" encoding="UTF-8" standalone="yes"?>'+g),g=g.replace(/_dt_b_namespace_token_/g,":")),g=g.replace(/<([^<>]*?) xmlns=""([^<>]*?)>/g,"<$1 $2>"),t[e]=g}}))}h=void 0===t.XMLSerializer?new function(){this.serializeToString=function(A){return A.xml}}:new XMLSerializer;var f={"_rels/.rels":'<?xml version="1.0" encoding="UTF-8" standalone="yes"?><Relationships xmlns="http://schemas.openxmlformats.org/package/2006/relationships"><Relationship Id="rId1" Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument" Target="xl/workbook.xml"/></Relationships>',"xl/_rels/workbook.xml.rels":'<?xml version="1.0" encoding="UTF-8" standalone="yes"?><Relationships xmlns="http://schemas.openxmlformats.org/package/2006/relationships"><Relationship Id="rId1" Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/worksheet" Target="worksheets/sheet1.xml"/><Relationship Id="rId2" Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/styles" Target="styles.xml"/></Relationships>',"[Content_Types].xml":'<?xml version="1.0" encoding="UTF-8" standalone="yes"?><Types xmlns="http://schemas.openxmlformats.org/package/2006/content-types"><Default Extension="xml" ContentType="application/xml" /><Default Extension="rels" ContentType="application/vnd.openxmlformats-package.relationships+xml" /><Default Extension="jpeg" ContentType="image/jpeg" /><Override PartName="/xl/workbook.xml" ContentType="application/vnd.openxmlformats-officedocument.spreadsheetml.sheet.main+xml" /><Override PartName="/xl/worksheets/sheet1.xml" ContentType="application/vnd.openxmlformats-officedocument.spreadsheetml.worksheet+xml" /><Override PartName="/xl/styles.xml" ContentType="application/vnd.openxmlformats-officedocument.spreadsheetml.styles+xml" /></Types>',"xl/workbook.xml":'<?xml version="1.0" encoding="UTF-8" standalone="yes"?><workbook xmlns="http://schemas.openxmlformats.org/spreadsheetml/2006/main" xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships"><fileVersion appName="xl" lastEdited="5" lowestEdited="5" rupBuild="24816"/><workbookPr showInkAnnotation="0" autoCompressPictures="0"/><bookViews><workbookView xWindow="0" yWindow="0" windowWidth="25600" windowHeight="19020" tabRatio="500"/></bookViews><sheets><sheet name="" sheetId="1" r:id="rId1"/></sheets></workbook>',"xl/worksheets/sheet1.xml":'<?xml version="1.0" encoding="UTF-8" standalone="yes"?><worksheet xmlns="http://schemas.openxmlformats.org/spreadsheetml/2006/main" xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships" xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006" mc:Ignorable="x14ac" xmlns:x14ac="http://schemas.microsoft.com/office/spreadsheetml/2009/9/ac"><sheetData/></worksheet>',"xl/styles.xml":'<?xml version="1.0" encoding="UTF-8"?><styleSheet xmlns="http://schemas.openxmlformats.org/spreadsheetml/2006/main" xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006" mc:Ignorable="x14ac" xmlns:x14ac="http://schemas.microsoft.com/office/spreadsheetml/2009/9/ac"><numFmts count="6"><numFmt numFmtId="164" formatCode="#,##0.00_- [$$-45C]"/><numFmt numFmtId="165" formatCode="&quot;£&quot;#,##0.00"/><numFmt numFmtId="166" formatCode="[$€-2] #,##0.00"/><numFmt numFmtId="167" formatCode="0.0%"/><numFmt numFmtId="168" formatCode="#,##0;(#,##0)"/><numFmt numFmtId="169" formatCode="#,##0.00;(#,##0.00)"/></numFmts><fonts count="5" x14ac:knownFonts="1"><font><sz val="11" /><name val="Calibri" /></font><font><sz val="11" /><name val="Calibri" /><color rgb="FFFFFFFF" /></font><font><sz val="11" /><name val="Calibri" /><b /></font><font><sz val="11" /><name val="Calibri" /><i /></font><font><sz val="11" /><name val="Calibri" /><u /></font></fonts><fills count="6"><fill><patternFill patternType="none" /></fill><fill/><fill><patternFill patternType="solid"><fgColor rgb="FFD9D9D9" /><bgColor indexed="64" /></patternFill></fill><fill><patternFill patternType="solid"><fgColor rgb="FFD99795" /><bgColor indexed="64" /></patternFill></fill><fill><patternFill patternType="solid"><fgColor rgb="ffc6efce" /><bgColor indexed="64" /></patternFill></fill><fill><patternFill patternType="solid"><fgColor rgb="ffc6cfef" /><bgColor indexed="64" /></patternFill></fill></fills><borders count="2"><border><left /><right /><top /><bottom /><diagonal /></border><border diagonalUp="false" diagonalDown="false"><left style="thin"><color auto="1" /></left><right style="thin"><color auto="1" /></right><top style="thin"><color auto="1" /></top><bottom style="thin"><color auto="1" /></bottom><diagonal /></border></borders><cellStyleXfs count="1"><xf numFmtId="0" fontId="0" fillId="0" borderId="0" /></cellStyleXfs><cellXfs count="61"><xf numFmtId="0" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="1" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="2" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="3" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="4" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="0" fillId="2" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="1" fillId="2" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="2" fillId="2" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="3" fillId="2" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="4" fillId="2" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="0" fillId="3" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="1" fillId="3" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="2" fillId="3" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="3" fillId="3" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="4" fillId="3" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="0" fillId="4" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="1" fillId="4" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="2" fillId="4" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="3" fillId="4" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="4" fillId="4" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="0" fillId="5" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="1" fillId="5" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="2" fillId="5" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="3" fillId="5" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="4" fillId="5" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="0" fillId="0" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="1" fillId="0" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="2" fillId="0" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="3" fillId="0" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="4" fillId="0" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="0" fillId="2" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="1" fillId="2" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="2" fillId="2" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="3" fillId="2" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="4" fillId="2" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="0" fillId="3" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="1" fillId="3" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="2" fillId="3" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="3" fillId="3" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="4" fillId="3" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="0" fillId="4" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="1" fillId="4" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="2" fillId="4" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="3" fillId="4" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="4" fillId="4" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="0" fillId="5" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="1" fillId="5" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="2" fillId="5" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="3" fillId="5" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="4" fillId="5" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyAlignment="1"><alignment horizontal="left"/></xf><xf numFmtId="0" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyAlignment="1"><alignment horizontal="center"/></xf><xf numFmtId="0" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyAlignment="1"><alignment horizontal="right"/></xf><xf numFmtId="0" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyAlignment="1"><alignment horizontal="fill"/></xf><xf numFmtId="0" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyAlignment="1"><alignment textRotation="90"/></xf><xf numFmtId="0" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyAlignment="1"><alignment wrapText="1"/></xf><xf numFmtId="9"   fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/><xf numFmtId="164" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/><xf numFmtId="165" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/><xf numFmtId="166" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/><xf numFmtId="167" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/><xf numFmtId="168" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/><xf numFmtId="169" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/><xf numFmtId="3" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/><xf numFmtId="4" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/></cellXfs><cellStyles count="1"><cellStyle name="Normal" xfId="0" builtinId="0" /></cellStyles><dxfs count="0" /><tableStyles count="0" defaultTableStyle="TableStyleMedium9" defaultPivotStyle="PivotStyleMedium4" /></styleSheet>'},Q=[{match:/^\-?\d+\.\d%$/,style:60,fmt:function(A){return A/100}},{match:/^\-?\d+\.?\d*%$/,style:56,fmt:function(A){return A/100}},{match:/^\-?\$[\d,]+.?\d*$/,style:57},{match:/^\-?£[\d,]+.?\d*$/,style:58},{match:/^\-?€[\d,]+.?\d*$/,style:59},{match:/^\([\d,]+\)$/,style:61,fmt:function(A){return-1*A.replace(/[\(\)]/g,"")}},{match:/^\([\d,]+\.\d{2}\)$/,style:62,fmt:function(A){return-1*A.replace(/[\(\)]/g,"")}},{match:/^[\d,]+$/,style:63},{match:/^[\d,]+\.\d{2}$/,style:64}];return r.Buttons.swfPath="//cdn.datatables.net/buttons/1.2.4/swf/flashExport.swf",r.Api.register("buttons.resize()",(function(){A.each(i.clients,(function(A,t){t.domElement!==n&&t.domElement.parentNode&&t.positionElement()}))})),r.ext.buttons.copyFlash=A.extend({},B,{className:"buttons-copy buttons-flash",text:function(A){return A.i18n("buttons.copy","Copy")},action:function(A,t,e,n){if(n._fromFlash){this.processing(!0);var r=n._flash,i=c(t,n),o=n.customize?n.customize(i.str,n):i.str;r.setAction("copy"),a(r,o),this.processing(!1),t.buttons.info(t.i18n("buttons.copyTitle","Copy to clipboard"),t.i18n("buttons.copySuccess",{_:"Copied %d rows to clipboard",1:"Copied 1 row to clipboard"},i.rows),3e3)}},fieldSeparator:"\t",fieldBoundary:""}),r.ext.buttons.csvFlash=A.extend({},B,{className:"buttons-csv buttons-flash",text:function(A){return A.i18n("buttons.csv","CSV")},action:function(A,t,e,n){var r=n._flash,i=c(t,n),o=n.customize?n.customize(i.str,n):i.str;r.setAction("csv"),r.setFileName(s(n)),a(r,o)},escapeChar:'"'}),r.ext.buttons.excelFlash=A.extend({},B,{className:"buttons-excel buttons-flash",text:function(A){return A.i18n("buttons.excel","Excel")},action:function(t,e,r,i){this.processing(!0);var o,c,B=i._flash,w=0,h=A.parseXML(f["xl/worksheets/sheet1.xml"]),d=h.getElementsByTagName("sheetData")[0],C={_rels:{".rels":A.parseXML(f["_rels/.rels"])},xl:{_rels:{"workbook.xml.rels":A.parseXML(f["xl/_rels/workbook.xml.rels"])},"workbook.xml":A.parseXML(f["xl/workbook.xml"]),"styles.xml":A.parseXML(f["xl/styles.xml"]),worksheets:{"sheet1.xml":h}},"[Content_Types].xml":A.parseXML(f["[Content_Types].xml"])},M=e.buttons.exportData(i.exportOptions),I=function(t){c=l(h,"row",{attr:{r:o=w+1}});for(var e=0,r=t.length;e<r;e++){var i=g(e)+""+o,s=null;if(null!==t[e]&&t[e]!==n&&""!==t[e]){t[e]=A.trim(t[e]);for(var a=0,B=Q.length;a<B;a++){var u=Q[a];if(t[e].match&&!t[e].match(/^0\d+/)&&t[e].match(u.match)){var E=t[e].replace(/[^\d\.\-]/g,"");u.fmt&&(E=u.fmt(E)),s=l(h,"c",{attr:{r:i,s:u.style},children:[l(h,"v",{text:E})]});break}}if(!s)if("number"==typeof t[e]||t[e].match&&t[e].match(/^-?\d+(\.\d+)?$/)&&!t[e].match(/^0\d+/))s=l(h,"c",{attr:{t:"n",r:i},children:[l(h,"v",{text:t[e]})]});else{var f=t[e].replace?t[e].replace(/[\x00-\x09\x0B\x0C\x0E-\x1F\x7F-\x9F]/g,""):t[e];s=l(h,"c",{attr:{t:"inlineStr",r:i},children:{row:l(h,"is",{children:{row:l(h,"t",{text:f})}})}})}c.appendChild(s)}}d.appendChild(c),w++};A("sheets sheet",C.xl["workbook.xml"]).attr("name",function(A){var t="Sheet1";return A.sheetName&&(t=A.sheetName.replace(/[\[\]\*\/\\\?\:]/g,"")),t}(i)),i.customizeData&&i.customizeData(M),i.header&&(I(M.header),A("row c",h).attr("s","2"));for(var p=0,D=M.body.length;p<D;p++)I(M.body[p]);i.footer&&M.footer&&(I(M.footer),A("row:last c",h).attr("s","2"));var y=l(h,"cols");A("worksheet",h).prepend(y);for(var v=0,m=M.header.length;v<m;v++)y.appendChild(l(h,"col",{attr:{min:v+1,max:v+1,width:u(M,v),customWidth:1}}));i.customize&&i.customize(C),E(C),B.setAction("excel"),B.setFileName(s(i)),B.setSheetData(C),a(B,""),this.processing(!1)},extension:".xlsx"}),r.ext.buttons.pdfFlash=A.extend({},B,{className:"buttons-pdf buttons-flash",text:function(A){return A.i18n("buttons.pdf","PDF")},action:function(A,t,e,n){this.processing(!0);var r=n._flash,i=t.buttons.exportData(n.exportOptions),o=t.table().node().offsetWidth,c=t.columns(n.columns).indexes().map((function(A){return t.column(A).header().offsetWidth/o}));r.setAction("pdf"),r.setFileName(s(n)),a(r,JSON.stringify({title:s(n,!1),message:"function"==typeof n.message?n.message(t,e,n):n.message,colWidth:c.toArray(),orientation:n.orientation,size:n.pageSize,header:n.header?i.header:null,footer:n.footer?i.footer:null,body:i.body})),this.processing(!1)},extension:".pdf",orientation:"portrait",pageSize:"A4",message:"",newline:"\n"}),r.Buttons})),
/*!
 * HTML5 export buttons for Buttons and DataTables.
 * © SpryMedia Ltd - datatables.net/license
 *
 * FileSaver.js (1.3.3) - MIT license
 * Copyright © 2016 Eli Grey - http://eligrey.com
 */
function(A){if("function"==typeof define&&define.amd)define(["jquery","datatables.net","datatables.net-buttons"],(function(t){return A(t,window,document)}));else if("object"==typeof exports){var t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net")(A,t),t.fn.dataTable.Buttons||require("datatables.net-buttons")(A,t)};"undefined"==typeof window?module.exports=function(n,r,i,o){return n||(n=window),r||(r=t(n)),e(n,r),A(r,n,n.document,i,o)}:(e(window,t),module.exports=A(t,window,window.document))}else A(jQuery,window,document)}((function(A,t,e,n,r,i){"use strict";var o,s,a=A.fn.dataTable;function c(){return o||t.JSZip}function B(){return s||t.pdfMake}a.Buttons.pdfMake=function(A){if(!A)return B();s=A},a.Buttons.jszip=function(A){if(!A)return c();o=A};var g=function(A){if(!(void 0===A||"undefined"!=typeof navigator&&/MSIE [1-9]\./.test(navigator.userAgent))){var t=A.document,e=function(){return A.URL||A.webkitURL||A},n=t.createElementNS("http://www.w3.org/1999/xhtml","a"),r="download"in n,o=/constructor/i.test(A.HTMLElement)||A.safari,s=/CriOS\/[\d]+/.test(navigator.userAgent),a=function(t){(A.setImmediate||A.setTimeout)((function(){throw t}),0)},c=function(A){setTimeout((function(){"string"==typeof A?e().revokeObjectURL(A):A.remove()}),4e4)},B=function(A){return/^\s*(?:text\/\S*|application\/xml|\S*\/\S*\+xml)\s*;.*charset\s*=\s*utf-8/i.test(A.type)?new Blob([String.fromCharCode(65279),A],{type:A.type}):A},g=function(t,g,l){l||(t=B(t));var u,w=this,h="application/octet-stream"===t.type,E=function(){!function(A,t,e){for(var n=(t=[].concat(t)).length;n--;){var r=A["on"+t[n]];if("function"==typeof r)try{r.call(A,e||A)}catch(A){a(A)}}}(w,"writestart progress write writeend".split(" "))};if(w.readyState=w.INIT,r)return u=e().createObjectURL(t),void setTimeout((function(){var A,t;n.href=u,n.download=g,A=n,t=new MouseEvent("click"),A.dispatchEvent(t),E(),c(u),w.readyState=w.DONE}));!function(){if((s||h&&o)&&A.FileReader){var n=new FileReader;return n.onloadend=function(){var t=s?n.result:n.result.replace(/^data:[^;]*;/,"data:attachment/file;");A.open(t,"_blank")||(A.location.href=t),t=i,w.readyState=w.DONE,E()},n.readAsDataURL(t),void(w.readyState=w.INIT)}(u||(u=e().createObjectURL(t)),h)?A.location.href=u:A.open(u,"_blank")||(A.location.href=u);w.readyState=w.DONE,E(),c(u)}()},l=g.prototype;return"undefined"!=typeof navigator&&navigator.msSaveOrOpenBlob?function(A,t,e){return t=t||A.name||"download",e||(A=B(A)),navigator.msSaveOrOpenBlob(A,t)}:(l.abort=function(){},l.readyState=l.INIT=0,l.WRITING=1,l.DONE=2,l.error=l.onwritestart=l.onprogress=l.onwrite=l.onabort=l.onerror=l.onwriteend=null,function(A,t,e){return new g(A,t||A.name||"download",e)})}}("undefined"!=typeof self&&self||void 0!==t&&t||this.content);a.fileSave=g;var l=function(A){var t="Sheet1";return A.sheetName&&(t=A.sheetName.replace(/[\[\]\*\/\\\?\:]/g,"")),t},u=function(A){return A.newline?A.newline:navigator.userAgent.match(/Windows/)?"\r\n":"\n"},w=function(A,t){for(var e=u(t),n=A.buttons.exportData(t.exportOptions),r=t.fieldBoundary,o=t.fieldSeparator,s=new RegExp(r,"g"),a=t.escapeChar!==i?t.escapeChar:"\\",c=function(A){for(var t="",e=0,n=A.length;e<n;e++)e>0&&(t+=o),t+=r?r+(""+A[e]).replace(s,a+r)+r:A[e];return t},B=t.header?c(n.header)+e:"",g=t.footer&&n.footer?e+c(n.footer):"",l=[],w=0,h=n.body.length;w<h;w++)l.push(c(n.body[w]));return{str:B+l.join(e)+g,rows:l.length}},h=function(){if(!(-1!==navigator.userAgent.indexOf("Safari")&&-1===navigator.userAgent.indexOf("Chrome")&&-1===navigator.userAgent.indexOf("Opera")))return!1;var A=navigator.userAgent.match(/AppleWebKit\/(\d+\.\d+)/);return!!(A&&A.length>1&&1*A[1]<603.1)};function E(A){for(var t="A".charCodeAt(0),e="Z".charCodeAt(0)-t+1,n="";A>=0;)n=String.fromCharCode(A%e+t)+n,A=Math.floor(A/e)-1;return n}try{var f,Q=new XMLSerializer}catch(A){}function d(e,n){f===i&&(f=-1===Q.serializeToString((new t.DOMParser).parseFromString(I["xl/worksheets/sheet1.xml"],"text/xml")).indexOf("xmlns:r")),A.each(n,(function(t,n){if(A.isPlainObject(n)){d(e.folder(t),n)}else{if(f){var r,i,o=n.childNodes[0],s=[];for(r=o.attributes.length-1;r>=0;r--){var a=o.attributes[r].nodeName,c=o.attributes[r].nodeValue;-1!==a.indexOf(":")&&(s.push({name:a,value:c}),o.removeAttribute(a))}for(r=0,i=s.length;r<i;r++){var B=n.createAttribute(s[r].name.replace(":","_dt_b_namespace_token_"));B.value=s[r].value,o.setAttributeNode(B)}}var g=Q.serializeToString(n);f&&(-1===g.indexOf("<?xml")&&(g='<?xml version="1.0" encoding="UTF-8" standalone="yes"?>'+g),g=(g=g.replace(/_dt_b_namespace_token_/g,":")).replace(/xmlns:NS[\d]+="" NS[\d]+:/g,"")),g=g.replace(/<([^<>]*?) xmlns=""([^<>]*?)>/g,"<$1 $2>"),e.file(t,g)}}))}function C(t,e,n){var r=t.createElement(e);return n&&(n.attr&&A(r).attr(n.attr),n.children&&A.each(n.children,(function(A,t){r.appendChild(t)})),null!==n.text&&n.text!==i&&r.appendChild(t.createTextNode(n.text))),r}function M(A,t){var e,n,r,o=A.header[t].length;A.footer&&A.footer[t].length>o&&(o=A.footer[t].length);for(var s=0,a=A.body.length;s<a;s++){var c=A.body[s][t];if(-1!==(r=null!==c&&c!==i?c.toString():"").indexOf("\n")?((n=r.split("\n")).sort((function(A,t){return t.length-A.length})),e=n[0].length):e=r.length,e>o&&(o=e),o>40)return 54}return(o*=1.35)>6?o:6}var I={"_rels/.rels":'<?xml version="1.0" encoding="UTF-8" standalone="yes"?><Relationships xmlns="http://schemas.openxmlformats.org/package/2006/relationships"><Relationship Id="rId1" Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument" Target="xl/workbook.xml"/></Relationships>',"xl/_rels/workbook.xml.rels":'<?xml version="1.0" encoding="UTF-8" standalone="yes"?><Relationships xmlns="http://schemas.openxmlformats.org/package/2006/relationships"><Relationship Id="rId1" Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/worksheet" Target="worksheets/sheet1.xml"/><Relationship Id="rId2" Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/styles" Target="styles.xml"/></Relationships>',"[Content_Types].xml":'<?xml version="1.0" encoding="UTF-8" standalone="yes"?><Types xmlns="http://schemas.openxmlformats.org/package/2006/content-types"><Default Extension="xml" ContentType="application/xml" /><Default Extension="rels" ContentType="application/vnd.openxmlformats-package.relationships+xml" /><Default Extension="jpeg" ContentType="image/jpeg" /><Override PartName="/xl/workbook.xml" ContentType="application/vnd.openxmlformats-officedocument.spreadsheetml.sheet.main+xml" /><Override PartName="/xl/worksheets/sheet1.xml" ContentType="application/vnd.openxmlformats-officedocument.spreadsheetml.worksheet+xml" /><Override PartName="/xl/styles.xml" ContentType="application/vnd.openxmlformats-officedocument.spreadsheetml.styles+xml" /></Types>',"xl/workbook.xml":'<?xml version="1.0" encoding="UTF-8" standalone="yes"?><workbook xmlns="http://schemas.openxmlformats.org/spreadsheetml/2006/main" xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships"><fileVersion appName="xl" lastEdited="5" lowestEdited="5" rupBuild="24816"/><workbookPr showInkAnnotation="0" autoCompressPictures="0"/><bookViews><workbookView xWindow="0" yWindow="0" windowWidth="25600" windowHeight="19020" tabRatio="500"/></bookViews><sheets><sheet name="Sheet1" sheetId="1" r:id="rId1"/></sheets><definedNames/></workbook>',"xl/worksheets/sheet1.xml":'<?xml version="1.0" encoding="UTF-8" standalone="yes"?><worksheet xmlns="http://schemas.openxmlformats.org/spreadsheetml/2006/main" xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships" xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006" mc:Ignorable="x14ac" xmlns:x14ac="http://schemas.microsoft.com/office/spreadsheetml/2009/9/ac"><sheetData/><mergeCells count="0"/></worksheet>',"xl/styles.xml":'<?xml version="1.0" encoding="UTF-8"?><styleSheet xmlns="http://schemas.openxmlformats.org/spreadsheetml/2006/main" xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006" mc:Ignorable="x14ac" xmlns:x14ac="http://schemas.microsoft.com/office/spreadsheetml/2009/9/ac"><numFmts count="6"><numFmt numFmtId="164" formatCode="#,##0.00_- [$$-45C]"/><numFmt numFmtId="165" formatCode="&quot;£&quot;#,##0.00"/><numFmt numFmtId="166" formatCode="[$€-2] #,##0.00"/><numFmt numFmtId="167" formatCode="0.0%"/><numFmt numFmtId="168" formatCode="#,##0;(#,##0)"/><numFmt numFmtId="169" formatCode="#,##0.00;(#,##0.00)"/></numFmts><fonts count="5" x14ac:knownFonts="1"><font><sz val="11" /><name val="Calibri" /></font><font><sz val="11" /><name val="Calibri" /><color rgb="FFFFFFFF" /></font><font><sz val="11" /><name val="Calibri" /><b /></font><font><sz val="11" /><name val="Calibri" /><i /></font><font><sz val="11" /><name val="Calibri" /><u /></font></fonts><fills count="6"><fill><patternFill patternType="none" /></fill><fill><patternFill patternType="none" /></fill><fill><patternFill patternType="solid"><fgColor rgb="FFD9D9D9" /><bgColor indexed="64" /></patternFill></fill><fill><patternFill patternType="solid"><fgColor rgb="FFD99795" /><bgColor indexed="64" /></patternFill></fill><fill><patternFill patternType="solid"><fgColor rgb="ffc6efce" /><bgColor indexed="64" /></patternFill></fill><fill><patternFill patternType="solid"><fgColor rgb="ffc6cfef" /><bgColor indexed="64" /></patternFill></fill></fills><borders count="2"><border><left /><right /><top /><bottom /><diagonal /></border><border diagonalUp="false" diagonalDown="false"><left style="thin"><color auto="1" /></left><right style="thin"><color auto="1" /></right><top style="thin"><color auto="1" /></top><bottom style="thin"><color auto="1" /></bottom><diagonal /></border></borders><cellStyleXfs count="1"><xf numFmtId="0" fontId="0" fillId="0" borderId="0" /></cellStyleXfs><cellXfs count="68"><xf numFmtId="0" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="1" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="2" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="3" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="4" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="0" fillId="2" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="1" fillId="2" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="2" fillId="2" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="3" fillId="2" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="4" fillId="2" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="0" fillId="3" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="1" fillId="3" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="2" fillId="3" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="3" fillId="3" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="4" fillId="3" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="0" fillId="4" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="1" fillId="4" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="2" fillId="4" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="3" fillId="4" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="4" fillId="4" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="0" fillId="5" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="1" fillId="5" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="2" fillId="5" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="3" fillId="5" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="4" fillId="5" borderId="0" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="0" fillId="0" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="1" fillId="0" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="2" fillId="0" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="3" fillId="0" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="4" fillId="0" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="0" fillId="2" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="1" fillId="2" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="2" fillId="2" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="3" fillId="2" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="4" fillId="2" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="0" fillId="3" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="1" fillId="3" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="2" fillId="3" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="3" fillId="3" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="4" fillId="3" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="0" fillId="4" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="1" fillId="4" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="2" fillId="4" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="3" fillId="4" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="4" fillId="4" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="0" fillId="5" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="1" fillId="5" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="2" fillId="5" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="3" fillId="5" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="4" fillId="5" borderId="1" applyFont="1" applyFill="1" applyBorder="1"/><xf numFmtId="0" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyAlignment="1"><alignment horizontal="left"/></xf><xf numFmtId="0" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyAlignment="1"><alignment horizontal="center"/></xf><xf numFmtId="0" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyAlignment="1"><alignment horizontal="right"/></xf><xf numFmtId="0" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyAlignment="1"><alignment horizontal="fill"/></xf><xf numFmtId="0" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyAlignment="1"><alignment textRotation="90"/></xf><xf numFmtId="0" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyAlignment="1"><alignment wrapText="1"/></xf><xf numFmtId="9"   fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/><xf numFmtId="164" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/><xf numFmtId="165" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/><xf numFmtId="166" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/><xf numFmtId="167" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/><xf numFmtId="168" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/><xf numFmtId="169" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/><xf numFmtId="3" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/><xf numFmtId="4" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/><xf numFmtId="1" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/><xf numFmtId="2" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/><xf numFmtId="14" fontId="0" fillId="0" borderId="0" applyFont="1" applyFill="1" applyBorder="1" xfId="0" applyNumberFormat="1"/></cellXfs><cellStyles count="1"><cellStyle name="Normal" xfId="0" builtinId="0" /></cellStyles><dxfs count="0" /><tableStyles count="0" defaultTableStyle="TableStyleMedium9" defaultPivotStyle="PivotStyleMedium4" /></styleSheet>'},p=[{match:/^\-?\d+\.\d%$/,style:60,fmt:function(A){return A/100}},{match:/^\-?\d+\.?\d*%$/,style:56,fmt:function(A){return A/100}},{match:/^\-?\$[\d,]+.?\d*$/,style:57},{match:/^\-?£[\d,]+.?\d*$/,style:58},{match:/^\-?€[\d,]+.?\d*$/,style:59},{match:/^\-?\d+$/,style:65},{match:/^\-?\d+\.\d{2}$/,style:66},{match:/^\([\d,]+\)$/,style:61,fmt:function(A){return-1*A.replace(/[\(\)]/g,"")}},{match:/^\([\d,]+\.\d{2}\)$/,style:62,fmt:function(A){return-1*A.replace(/[\(\)]/g,"")}},{match:/^\-?[\d,]+$/,style:63},{match:/^\-?[\d,]+\.\d{2}$/,style:64},{match:/^[\d]{4}\-[01][\d]\-[0123][\d]$/,style:67,fmt:function(A){return Math.round(25569+Date.parse(A)/864e5)}}];return a.ext.buttons.copyHtml5={className:"buttons-copy buttons-html5",text:function(A){return A.i18n("buttons.copy","Copy")},action:function(t,n,r,i){this.processing(!0);var o=this,s=w(n,i),a=n.buttons.exportInfo(i),c=u(i),B=s.str,g=A("<div/>").css({height:1,width:1,overflow:"hidden",position:"fixed",top:0,left:0});a.title&&(B=a.title+c+c+B),a.messageTop&&(B=a.messageTop+c+c+B),a.messageBottom&&(B=B+c+c+a.messageBottom),i.customize&&(B=i.customize(B,i,n));var l=A("<textarea readonly/>").val(B).appendTo(g);if(e.queryCommandSupported("copy")){g.appendTo(n.table().container()),l[0].focus(),l[0].select();try{var h=e.execCommand("copy");if(g.remove(),h)return n.buttons.info(n.i18n("buttons.copyTitle","Copy to clipboard"),n.i18n("buttons.copySuccess",{1:"Copied one row to clipboard",_:"Copied %d rows to clipboard"},s.rows),2e3),void this.processing(!1)}catch(A){}}var E=A("<span>"+n.i18n("buttons.copyKeys","Press <i>ctrl</i> or <i>⌘</i> + <i>C</i> to copy the table data<br>to your system clipboard.<br><br>To cancel, click this message or press escape.")+"</span>").append(g);n.buttons.info(n.i18n("buttons.copyTitle","Copy to clipboard"),E,0),l[0].focus(),l[0].select();var f=A(E).closest(".dt-button-info"),Q=function(){f.off("click.buttons-copy"),A(e).off(".buttons-copy"),n.buttons.info(!1)};f.on("click.buttons-copy",Q),A(e).on("keydown.buttons-copy",(function(A){27===A.keyCode&&(Q(),o.processing(!1))})).on("copy.buttons-copy cut.buttons-copy",(function(){Q(),o.processing(!1)}))},exportOptions:{},fieldSeparator:"\t",fieldBoundary:"",header:!0,footer:!1,title:"*",messageTop:"*",messageBottom:"*"},a.ext.buttons.csvHtml5={bom:!1,className:"buttons-csv buttons-html5",available:function(){return t.FileReader!==i&&t.Blob},text:function(A){return A.i18n("buttons.csv","CSV")},action:function(A,t,n,r){this.processing(!0);var i=w(t,r).str,o=t.buttons.exportInfo(r),s=r.charset;r.customize&&(i=r.customize(i,r,t)),!1!==s?(s||(s=e.characterSet||e.charset),s&&(s=";charset="+s)):s="",r.bom&&(i=String.fromCharCode(65279)+i),g(new Blob([i],{type:"text/csv"+s}),o.filename,!0),this.processing(!1)},filename:"*",extension:".csv",exportOptions:{},fieldSeparator:",",fieldBoundary:'"',escapeChar:'"',charset:null,header:!0,footer:!1},a.ext.buttons.excelHtml5={className:"buttons-excel buttons-html5",available:function(){return t.FileReader!==i&&c()!==i&&!h()&&Q},text:function(A){return A.i18n("buttons.excel","Excel")},action:function(t,e,n,r){this.processing(!0);var o,s,a,B,u=this,w=0,h=function(t){var e=I[t];return A.parseXML(e)},f=h("xl/worksheets/sheet1.xml"),Q=f.getElementsByTagName("sheetData")[0],D={_rels:{".rels":h("_rels/.rels")},xl:{_rels:{"workbook.xml.rels":h("xl/_rels/workbook.xml.rels")},"workbook.xml":h("xl/workbook.xml"),"styles.xml":h("xl/styles.xml"),worksheets:{"sheet1.xml":f}},"[Content_Types].xml":h("[Content_Types].xml")},y=e.buttons.exportData(r.exportOptions),v=function(A){B=C(f,"row",{attr:{r:a=w+1}});for(var t=0,e=A.length;t<e;t++){var n=E(t)+""+a,o=null;if(null===A[t]||A[t]===i||""===A[t]){if(!0!==r.createEmptyCells)continue;A[t]=""}var s=A[t];A[t]="function"==typeof A[t].trim?A[t].trim():A[t];for(var c=0,g=p.length;c<g;c++){var l=p[c];if(A[t].match&&!A[t].match(/^0\d+/)&&A[t].match(l.match)){var u=A[t].replace(/[^\d\.\-]/g,"");l.fmt&&(u=l.fmt(u)),o=C(f,"c",{attr:{r:n,s:l.style},children:[C(f,"v",{text:u})]});break}}if(!o)if("number"==typeof A[t]||A[t].match&&A[t].match(/^-?\d+(\.\d+)?([eE]\-?\d+)?$/)&&!A[t].match(/^0\d+/))o=C(f,"c",{attr:{t:"n",r:n},children:[C(f,"v",{text:A[t]})]});else{var h=s.replace?s.replace(/[\x00-\x09\x0B\x0C\x0E-\x1F\x7F-\x9F]/g,""):s;o=C(f,"c",{attr:{t:"inlineStr",r:n},children:{row:C(f,"is",{children:{row:C(f,"t",{text:h,attr:{"xml:space":"preserve"}})}})}})}B.appendChild(o)}Q.appendChild(B),w++};r.customizeData&&r.customizeData(y);var m=function(t,e){var n=A("mergeCells",f);n[0].appendChild(C(f,"mergeCell",{attr:{ref:"A"+t+":"+E(e)+t}})),n.attr("count",parseFloat(n.attr("count"))+1),A("row:eq("+(t-1)+") c",f).attr("s","51")},F=e.buttons.exportInfo(r);F.title&&(v([F.title]),m(w,y.header.length-1)),F.messageTop&&(v([F.messageTop]),m(w,y.header.length-1)),r.header&&(v(y.header),A("row:last c",f).attr("s","2")),o=w;for(var Y=0,b=y.body.length;Y<b;Y++)v(y.body[Y]);s=w,r.footer&&y.footer&&(v(y.footer),A("row:last c",f).attr("s","2")),F.messageBottom&&(v([F.messageBottom]),m(w,y.header.length-1));var z=C(f,"cols");A("worksheet",f).prepend(z);for(var U=0,S=y.header.length;U<S;U++)z.appendChild(C(f,"col",{attr:{min:U+1,max:U+1,width:M(y,U),customWidth:1}}));var x=D.xl["workbook.xml"];A("sheets sheet",x).attr("name",l(r)),r.autoFilter&&(A("mergeCells",f).before(C(f,"autoFilter",{attr:{ref:"A"+o+":"+E(y.header.length-1)+s}})),A("definedNames",x).append(C(x,"definedName",{attr:{name:"_xlnm._FilterDatabase",localSheetId:"0",hidden:1},text:l(r)+"!$A$"+o+":"+E(y.header.length-1)+s}))),r.customize&&r.customize(D,r,e),0===A("mergeCells",f).children().length&&A("mergeCells",f).remove();var T=new(c()),P={compression:"DEFLATE",type:"blob",mimeType:"application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"};d(T,D);var N=F.filename;N>175&&(N=N.substr(0,175)),T.generateAsync?T.generateAsync(P).then((function(A){g(A,N),u.processing(!1)})):(g(T.generate(P),N),this.processing(!1))},filename:"*",extension:".xlsx",exportOptions:{},header:!0,footer:!1,title:"*",messageTop:"*",messageBottom:"*",createEmptyCells:!1,autoFilter:!1,sheetName:""},a.ext.buttons.pdfHtml5={className:"buttons-pdf buttons-html5",available:function(){return t.FileReader!==i&&B()},text:function(A){return A.i18n("buttons.pdf","PDF")},action:function(t,e,n,r){this.processing(!0);var o=e.buttons.exportData(r.exportOptions),s=e.buttons.exportInfo(r),a=[];r.header&&a.push(A.map(o.header,(function(A){return{text:"string"==typeof A?A:A+"",style:"tableHeader"}})));for(var c=0,g=o.body.length;c<g;c++)a.push(A.map(o.body[c],(function(A){return null!==A&&A!==i||(A=""),{text:"string"==typeof A?A:A+"",style:c%2?"tableBodyEven":"tableBodyOdd"}})));r.footer&&o.footer&&a.push(A.map(o.footer,(function(A){return{text:"string"==typeof A?A:A+"",style:"tableFooter"}})));var l={pageSize:r.pageSize,pageOrientation:r.orientation,content:[{table:{headerRows:1,body:a},layout:"noBorders"}],styles:{tableHeader:{bold:!0,fontSize:11,color:"white",fillColor:"#2d4154",alignment:"center"},tableBodyEven:{},tableBodyOdd:{fillColor:"#f3f3f3"},tableFooter:{bold:!0,fontSize:11,color:"white",fillColor:"#2d4154"},title:{alignment:"center",fontSize:15},message:{}},defaultStyle:{fontSize:10}};s.messageTop&&l.content.unshift({text:s.messageTop,style:"message",margin:[0,0,0,12]}),s.messageBottom&&l.content.push({text:s.messageBottom,style:"message",margin:[0,0,0,12]}),s.title&&l.content.unshift({text:s.title,style:"title",margin:[0,0,0,12]}),r.customize&&r.customize(l,r,e);var u=B().createPdf(l);"open"!==r.download||h()?u.download(s.filename):u.open(),this.processing(!1)},title:"*",filename:"*",extension:".pdf",exportOptions:{},orientation:"portrait",pageSize:"A4",header:!0,footer:!1,messageTop:"*",messageBottom:"*",customize:null,download:"download"},a})),
/*!
 * Print button for Buttons and DataTables.
 * © SpryMedia Ltd - datatables.net/license
 */
function(A){if("function"==typeof define&&define.amd)define(["jquery","datatables.net","datatables.net-buttons"],(function(t){return A(t,window,document)}));else if("object"==typeof exports){var t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net")(A,t),t.fn.dataTable.Buttons||require("datatables.net-buttons")(A,t)};"undefined"==typeof window?module.exports=function(n,r){return n||(n=window),r||(r=t(n)),e(n,r),A(r,n,n.document)}:(e(window,t),module.exports=A(t,window,window.document))}else A(jQuery,window,document)}((function(A,t,e,n){"use strict";var r=A.fn.dataTable,i=e.createElement("a"),o=function(A){i.href=A;var t=i.host;return-1===t.indexOf("/")&&0!==i.pathname.indexOf("/")&&(t+="/"),i.protocol+"//"+t+i.pathname+i.search};return r.ext.buttons.print={className:"buttons-print",text:function(A){return A.i18n("buttons.print","Print")},action:function(e,r,i,s){var a=r.buttons.exportData(A.extend({decodeEntities:!1},s.exportOptions)),c=r.buttons.exportInfo(s),B=r.columns(s.exportOptions.columns).flatten().map((function(A){return r.settings()[0].aoColumns[r.column(A).index()].sClass})).toArray(),g=function(A,t){for(var e="<tr>",r=0,i=A.length;r<i;r++){var o=null===A[r]||A[r]===n?"":A[r];e+="<"+t+" "+(B[r]?'class="'+B[r]+'"':"")+">"+o+"</"+t+">"}return e+"</tr>"},l='<table class="'+r.table().node().className+'">';s.header&&(l+="<thead>"+g(a.header,"th")+"</thead>"),l+="<tbody>";for(var u=0,w=a.body.length;u<w;u++)l+=g(a.body[u],"td");l+="</tbody>",s.footer&&a.footer&&(l+="<tfoot>"+g(a.footer,"th")+"</tfoot>"),l+="</table>";var h=t.open("","");if(h){h.document.close();var E="<title>"+c.title+"</title>";A("style, link").each((function(){var t;E+=("link"===(t=A(this).clone()[0]).nodeName.toLowerCase()&&(t.href=o(t.href)),t.outerHTML)}));try{h.document.head.innerHTML=E}catch(e){A(h.document.head).html(E)}h.document.body.innerHTML="<h1>"+c.title+"</h1><div>"+(c.messageTop||"")+"</div>"+l+"<div>"+(c.messageBottom||"")+"</div>",A(h.document.body).addClass("dt-print-view"),A("img",h.document.body).each((function(A,t){t.setAttribute("src",o(t.getAttribute("src")))})),s.customize&&s.customize(h,s,r);var f=function(){s.autoPrint&&(h.print(),h.close())};navigator.userAgent.match(/Trident\/\d.\d/)?f():h.setTimeout(f,1e3)}else r.buttons.info(r.i18n("buttons.printErrorTitle","Unable to open print view"),r.i18n("buttons.printErrorMsg","Please allow popups in your browser for this site to be able to view the print view."),5e3)},title:"*",messageTop:"*",messageBottom:"*",exportOptions:{},header:!0,footer:!1,autoPrint:!0,customize:null},r})),function(A){var t,e;"function"==typeof define&&define.amd?define(["jquery","datatables.net"],(function(t){return A(t,window,document)})):"object"==typeof exports?(t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net")(A,t)},"undefined"==typeof window?module.exports=function(n,r){return n=n||window,r=r||t(n),e(n,r),A(r,0,n.document)}:(e(window,t),module.exports=A(t,window,window.document))):A(jQuery,window,document)}((function(A,t,e,n){"use strict";var r=A.fn.dataTable;function i(A){for(var t=[],e=0,n=A.length;e<n;e++)t[A[e]]=e;return t}function o(A,t,e){t=A.splice(t,1)[0],A.splice(e,0,t)}function s(A,t,e){for(var n=[],r=0,i=A.childNodes.length;r<i;r++)1==A.childNodes[r].nodeType&&n.push(A.childNodes[r]);t=n[t],null!==e?A.insertBefore(t,n[e]):A.appendChild(t)}function a(t,e){if((t=new A.fn.dataTable.Api(t).settings()[0])._colReorder)return t._colReorder;!0===e&&(e={});var n=A.fn.dataTable.camelToHungarian;return n&&(n(a.defaults,a.defaults,!0),n(a.defaults,e||{})),this.s={dt:null,enable:null,init:A.extend(!0,{},a.defaults,e),fixed:0,fixedRight:0,reorderCallback:null,mouse:{startX:-1,startY:-1,offsetX:-1,offsetY:-1,target:-1,targetIndex:-1,fromIndex:-1},aoTargets:[]},this.dom={drag:null,pointer:null},this.s.enable=this.s.init.bEnable,this.s.dt=t,(this.s.dt._colReorder=this)._fnConstruct(),this}return A.fn.dataTableExt.oApi.fnColReorder=function(t,e,r,a,c){function B(A,t,e){var n,r;A[t]&&"function"!=typeof A[t]&&(r=(n=A[t].split(".")).shift(),isNaN(+r)||(A[t]=e[+r]+"."+n.join(".")))}var g,l,u,w,h,E,f=t.aoColumns.length;if(e!=r)if(e<0||f<=e)this.oApi._fnLog(t,1,"ColReorder 'from' index is out of bounds: "+e);else if(r<0||f<=r)this.oApi._fnLog(t,1,"ColReorder 'to' index is out of bounds: "+r);else{var Q=[];for(I=0,g=f;I<g;I++)Q[I]=I;o(Q,e,r);var d=i(Q);for(I=0,g=t.aaSorting.length;I<g;I++)t.aaSorting[I][0]=d[t.aaSorting[I][0]];if(null!==t.aaSortingFixed)for(I=0,g=t.aaSortingFixed.length;I<g;I++)t.aaSortingFixed[I][0]=d[t.aaSortingFixed[I][0]];for(I=0,g=f;I<g;I++){for(l=0,u=(E=t.aoColumns[I]).aDataSort.length;l<u;l++)E.aDataSort[l]=d[E.aDataSort[l]];E.idx=d[E.idx]}for(A.each(t.aLastSort,(function(A,e){t.aLastSort[A].src=d[e.src]})),I=0,g=f;I<g;I++)"number"==typeof(E=t.aoColumns[I]).mData?E.mData=d[E.mData]:A.isPlainObject(E.mData)&&(B(E.mData,"_",d),B(E.mData,"filter",d),B(E.mData,"sort",d),B(E.mData,"type",d));if(t.aoColumns[e].bVisible){for(var C=this.oApi._fnColumnIndexToVisible(t,e),M=null,I=r<e?r:r+1;null===M&&I<f;)M=this.oApi._fnColumnIndexToVisible(t,I),I++;for(I=0,g=(h=t.nTHead.getElementsByTagName("tr")).length;I<g;I++)s(h[I],C,M);if(null!==t.nTFoot)for(I=0,g=(h=t.nTFoot.getElementsByTagName("tr")).length;I<g;I++)s(h[I],C,M);for(I=0,g=t.aoData.length;I<g;I++)null!==t.aoData[I].nTr&&s(t.aoData[I].nTr,C,M)}for(o(t.aoColumns,e,r),I=0,g=f;I<g;I++)t.oApi._fnColumnOptions(t,I,{});for(o(t.aoPreSearchCols,e,r),I=0,g=t.aoData.length;I<g;I++){var p=t.aoData[I],D=p.anCells;if(D)for(o(D,e,r),l=0,w=D.length;l<w;l++)D[l]&&D[l]._DT_CellIndex&&(D[l]._DT_CellIndex.column=l);Array.isArray(p._aData)&&o(p._aData,e,r)}for(I=0,g=t.aoHeader.length;I<g;I++)o(t.aoHeader[I],e,r);if(null!==t.aoFooter)for(I=0,g=t.aoFooter.length;I<g;I++)o(t.aoFooter[I],e,r);for(!c&&c!==n||A.fn.dataTable.Api(t).rows().invalidate("data"),I=0,g=f;I<g;I++)A(t.aoColumns[I].nTh).off(".DT"),this.oApi._fnSortAttachListener(t,t.aoColumns[I].nTh,I);A(t.oInstance).trigger("column-reorder.dt",[t,{from:e,to:r,mapping:d,drop:a,iFrom:e,iTo:r,aiInvertMapping:d}])}},A.extend(a.prototype,{fnEnable:function(A){if(!1===A)return this.fnDisable();this.s.enable=!0},fnDisable:function(){this.s.enable=!1},fnReset:function(){return this._fnOrderColumns(this.fnOrder()),this},fnGetCurrentOrder:function(){return this.fnOrder()},fnOrder:function(t,e){var r=[],o=this.s.dt.aoColumns;if(t===n){for(a=0,c=o.length;a<c;a++)r.push(o[a]._ColReorder_iOrigCol);return r}if(e){for(var s=this.fnOrder(),a=0,c=t.length;a<c;a++)r.push(A.inArray(t[a],s));t=r}return this._fnOrderColumns(i(t)),this},fnTranspose:function(t,e){e=e||"toCurrent";var n=this.fnOrder(),r=this.s.dt.aoColumns;return"toCurrent"===e?Array.isArray(t)?A.map(t,(function(t){return A.inArray(t,n)})):A.inArray(t,n):Array.isArray(t)?A.map(t,(function(A){return r[A]._ColReorder_iOrigCol})):r[t]._ColReorder_iOrigCol},_fnConstruct:function(){var t,e=this,n=this.s.dt.aoColumns.length,r=this.s.dt.nTable;for(this.s.init.iFixedColumns&&(this.s.fixed=this.s.init.iFixedColumns),this.s.init.iFixedColumnsLeft&&(this.s.fixed=this.s.init.iFixedColumnsLeft),this.s.fixedRight=this.s.init.iFixedColumnsRight||0,this.s.init.fnReorderCallback&&(this.s.reorderCallback=this.s.init.fnReorderCallback),t=0;t<n;t++)t>this.s.fixed-1&&t<n-this.s.fixedRight&&this._fnMouseListener(t,this.s.dt.aoColumns[t].nTh),this.s.dt.aoColumns[t]._ColReorder_iOrigCol=t;this.s.dt.oApi._fnCallbackReg(this.s.dt,"aoStateSaveParams",(function(A,t){e._fnStateSave.call(e,t)}),"ColReorder_State"),this.s.dt.oApi._fnCallbackReg(this.s.dt,"aoStateLoadParams",(function(A,t){e.s.dt._colReorder.fnOrder(t.ColReorder,!0)}));var o,s,a=null;this.s.init.aiOrder&&(a=this.s.init.aiOrder.slice()),(a=this.s.dt.oLoadedState&&void 0!==this.s.dt.oLoadedState.ColReorder&&this.s.dt.oLoadedState.ColReorder.length==this.s.dt.aoColumns.length?this.s.dt.oLoadedState.ColReorder:a)?e.s.dt._bInitComplete?(o=i(a),e._fnOrderColumns.call(e,o)):(s=!1,A(r).on("draw.dt.colReorder",(function(){var A;e.s.dt._bInitComplete||s||(s=!0,A=i(a),e._fnOrderColumns.call(e,A))}))):this._fnSetColumnIndexes(),A(r).on("destroy.dt.colReorder",(function(){e.fnReset(),A(r).off("destroy.dt.colReorder draw.dt.colReorder"),A.each(e.s.dt.aoColumns,(function(t,e){A(e.nTh).off(".ColReorder"),A(e.nTh).removeAttr("data-column-index")})),e.s.dt._colReorder=null,e.s=null}))},_fnOrderColumns:function(t){var e=!1;if(t.length!=this.s.dt.aoColumns.length)this.s.dt.oInstance.oApi._fnLog(this.s.dt,1,"ColReorder - array reorder does not match known number of columns. Skipping.");else{for(var n=0,r=t.length;n<r;n++){var i=A.inArray(n,t);n!=i&&(o(t,i,n),this.s.dt.oInstance.fnColReorder(i,n,!0,!1),e=!0)}this._fnSetColumnIndexes(),e&&(A.fn.dataTable.Api(this.s.dt).rows().invalidate("data"),""===this.s.dt.oScroll.sX&&""===this.s.dt.oScroll.sY||this.s.dt.oInstance.fnAdjustColumnSizing(!1),this.s.dt.oInstance.oApi._fnSaveState(this.s.dt),null!==this.s.reorderCallback&&this.s.reorderCallback.call(this))}},_fnStateSave:function(t){if(null!==this.s){var e,n=this.s.dt.aoColumns;if(t.ColReorder=[],t.aaSorting){for(i=0;i<t.aaSorting.length;i++)t.aaSorting[i][0]=n[t.aaSorting[i][0]]._ColReorder_iOrigCol;for(var r=A.extend(!0,[],t.aoSearchCols),i=0,o=n.length;i<o;i++)e=n[i]._ColReorder_iOrigCol,t.aoSearchCols[e]=r[i],t.abVisCols[e]=n[i].bVisible,t.ColReorder.push(e)}else if(t.order){for(i=0;i<t.order.length;i++)t.order[i][0]=n[t.order[i][0]]._ColReorder_iOrigCol;var s=A.extend(!0,[],t.columns);for(i=0,o=n.length;i<o;i++)e=n[i]._ColReorder_iOrigCol,t.columns[e]=s[i],t.ColReorder.push(e)}}},_fnMouseListener:function(t,e){var n=this;A(e).on("mousedown.ColReorder",(function(A){n.s.enable&&1===A.which&&n._fnMouseDown.call(n,A,e)})).on("touchstart.ColReorder",(function(A){n.s.enable&&n._fnMouseDown.call(n,A,e)}))},_fnMouseDown:function(t,r){var i=this,o=A(t.target).closest("th, td").offset();(r=parseInt(A(r).attr("data-column-index"),10))!==n&&(this.s.mouse.startX=this._fnCursorPosition(t,"pageX"),this.s.mouse.startY=this._fnCursorPosition(t,"pageY"),this.s.mouse.offsetX=this._fnCursorPosition(t,"pageX")-o.left,this.s.mouse.offsetY=this._fnCursorPosition(t,"pageY")-o.top,this.s.mouse.target=this.s.dt.aoColumns[r].nTh,this.s.mouse.targetIndex=r,this.s.mouse.fromIndex=r,this._fnRegions(),A(e).on("mousemove.ColReorder touchmove.ColReorder",(function(A){i._fnMouseMove.call(i,A)})).on("mouseup.ColReorder touchend.ColReorder",(function(A){i._fnMouseUp.call(i,A)})))},_fnMouseMove:function(A){var t,e=this;if(null===this.dom.drag){if(Math.pow(Math.pow(this._fnCursorPosition(A,"pageX")-this.s.mouse.startX,2)+Math.pow(this._fnCursorPosition(A,"pageY")-this.s.mouse.startY,2),.5)<5)return;this._fnCreateDragNode()}this.dom.drag.css({left:this._fnCursorPosition(A,"pageX")-this.s.mouse.offsetX,top:this._fnCursorPosition(A,"pageY")-this.s.mouse.offsetY});for(var n=this.s.mouse.toIndex,r=this._fnCursorPosition(A,"pageX"),i=(A=function(){for(var A=e.s.aoTargets.length-1;0<A;A--)if(e.s.aoTargets[A].x!==e.s.aoTargets[A-1].x)return e.s.aoTargets[A]},1);i<this.s.aoTargets.length;i++){var o=function(A){for(;0<=A;){if(--A<=0)return null;if(e.s.aoTargets[A+1].x!==e.s.aoTargets[A].x)return e.s.aoTargets[A]}}(i),s=(o=o||function(){for(var A=0;A<e.s.aoTargets.length-1;A++)if(e.s.aoTargets[A].x!==e.s.aoTargets[A+1].x)return e.s.aoTargets[A]}()).x+(this.s.aoTargets[i].x-o.x)/2;if(this._fnIsLtr()){if(r<s){t=o;break}}else if(s<r){t=o;break}}t?(this.dom.pointer.css("left",t.x),this.s.mouse.toIndex=t.to):(this.dom.pointer.css("left",A().x),this.s.mouse.toIndex=A().to),this.s.init.bRealtime&&n!==this.s.mouse.toIndex&&(this.s.dt.oInstance.fnColReorder(this.s.mouse.fromIndex,this.s.mouse.toIndex),this.s.mouse.fromIndex=this.s.mouse.toIndex,""===this.s.dt.oScroll.sX&&""===this.s.dt.oScroll.sY||this.s.dt.oInstance.fnAdjustColumnSizing(!1),this._fnRegions())},_fnMouseUp:function(t){A(e).off(".ColReorder"),null!==this.dom.drag&&(this.dom.drag.remove(),this.dom.pointer.remove(),this.dom.drag=null,this.dom.pointer=null,this.s.dt.oInstance.fnColReorder(this.s.mouse.fromIndex,this.s.mouse.toIndex,!0),this._fnSetColumnIndexes(),""===this.s.dt.oScroll.sX&&""===this.s.dt.oScroll.sY||this.s.dt.oInstance.fnAdjustColumnSizing(!1),this.s.dt.oInstance.oApi._fnSaveState(this.s.dt),null!==this.s.reorderCallback&&this.s.reorderCallback.call(this))},_fnRegions:function(){var t=this.s.dt.aoColumns,e=this._fnIsLtr(),n=(this.s.aoTargets.splice(0,this.s.aoTargets.length),A(this.s.dt.nTable).offset().left),r=[],i=(A.each(t,(function(t,i){var o;i.bVisible&&"none"!==i.nTh.style.display?(o=(i=A(i.nTh)).offset().left,e&&(o+=i.outerWidth()),r.push({index:t,bound:o}),n=o):r.push({index:t,bound:n})})),r[0]);t=A(t[i.index].nTh).outerWidth();this.s.aoTargets.push({to:0,x:i.bound-t});for(var o=0;o<r.length;o++){var s=r[o],a=s.index;s.index<this.s.mouse.fromIndex&&a++,this.s.aoTargets.push({to:a,x:s.bound})}0!==this.s.fixedRight&&this.s.aoTargets.splice(this.s.aoTargets.length-this.s.fixedRight),0!==this.s.fixed&&this.s.aoTargets.splice(0,this.s.fixed)},_fnCreateDragNode:function(){var t=""!==this.s.dt.oScroll.sX||""!==this.s.dt.oScroll.sY,e=this.s.dt.aoColumns[this.s.mouse.targetIndex].nTh,n=e.parentNode,r=n.parentNode,i=r.parentNode,o=A(e).clone();this.dom.drag=A(i.cloneNode(!1)).addClass("DTCR_clonedTable").append(A(r.cloneNode(!1)).append(A(n.cloneNode(!1)).append(o[0]))).css({position:"absolute",top:0,left:0,width:A(e).outerWidth(),height:A(e).outerHeight()}).appendTo("body"),this.dom.pointer=A("<div></div>").addClass("DTCR_pointer").css({position:"absolute",top:A(t?A(this.s.dt.nScrollBody).parent():this.s.dt.nTable).offset().top,height:A(t?A(this.s.dt.nScrollBody).parent():this.s.dt.nTable).height()}).appendTo("body")},_fnSetColumnIndexes:function(){A.each(this.s.dt.aoColumns,(function(t,e){A(e.nTh).attr("data-column-index",t)}))},_fnCursorPosition:function(A,t){return(-1!==A.type.indexOf("touch")?A.originalEvent.touches[0]:A)[t]},_fnIsLtr:function(){return"rtl"!==A(this.s.dt.nTable).css("direction")}}),a.defaults={aiOrder:null,bEnable:!0,bRealtime:!0,iFixedColumnsLeft:0,iFixedColumnsRight:0,fnReorderCallback:null},a.version="1.7.0",A.fn.dataTable.ColReorder=a,A.fn.DataTable.ColReorder=a,"function"==typeof A.fn.dataTable&&"function"==typeof A.fn.dataTableExt.fnVersionCheck&&A.fn.dataTableExt.fnVersionCheck("1.10.8")?A.fn.dataTableExt.aoFeatures.push({fnInit:function(A){var t=A.oInstance;return A._colReorder?t.oApi._fnLog(A,1,"ColReorder attempted to initialise twice. Ignoring second"):new a(A,t=(t=A.oInit).colReorder||t.oColReorder||{}),null},cFeature:"R",sFeature:"ColReorder"}):alert("Warning: ColReorder requires DataTables 1.10.8 or greater - www.datatables.net/download"),A(e).on("preInit.dt.colReorder",(function(t,e){var n;"dt"===t.namespace&&(t=e.oInit.colReorder,n=r.defaults.colReorder,(t||n)&&(n=A.extend({},t,n),!1!==t&&new a(e,n)))})),A.fn.dataTable.Api.register("colReorder.reset()",(function(){return this.iterator("table",(function(A){A._colReorder.fnReset()}))})),A.fn.dataTable.Api.register("colReorder.order()",(function(A,t){return A?this.iterator("table",(function(e){e._colReorder.fnOrder(A,t)})):this.context.length?this.context[0]._colReorder.fnOrder():null})),A.fn.dataTable.Api.register("colReorder.transpose()",(function(A,t){return this.context.length&&this.context[0]._colReorder?this.context[0]._colReorder.fnTranspose(A,t):A})),A.fn.dataTable.Api.register("colReorder.move()",(function(A,t,e,n){return this.context.length&&(this.context[0]._colReorder.s.dt.oInstance.fnColReorder(A,t,e,n),this.context[0]._colReorder._fnSetColumnIndexes()),this})),A.fn.dataTable.Api.register("colReorder.enable()",(function(A){return this.iterator("table",(function(t){t._colReorder&&t._colReorder.fnEnable(A)}))})),A.fn.dataTable.Api.register("colReorder.disable()",(function(){return this.iterator("table",(function(A){A._colReorder&&A._colReorder.fnDisable()}))})),r})),
/*! Bootstrap 5 styling wrapper for ColReorder
 * © SpryMedia Ltd - datatables.net/license
 */
function(A){if("function"==typeof define&&define.amd)define(["jquery","datatables.net-bs5","datatables.net-colreorder"],(function(t){return A(t,window,document)}));else if("object"==typeof exports){var t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net-bs5")(A,t),t.fn.dataTable.ColReorder||require("datatables.net-colreorder")(A,t)};"undefined"==typeof window?module.exports=function(n,r){return n||(n=window),r||(r=t(n)),e(n,r),A(r,n,n.document)}:(e(window,t),module.exports=A(t,window,window.document))}else A(jQuery,window,document)}((function(A,t,e,n){"use strict";return A.fn.dataTable})),function(A){var t,e;"function"==typeof define&&define.amd?define(["jquery","datatables.net"],(function(t){return A(t,window,document)})):"object"==typeof exports?(t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net")(A,t)},"undefined"==typeof window?module.exports=function(n,r){return n=n||window,r=r||t(n),e(n,r),A(r,0,n.document)}:(e(window,t),module.exports=A(t,window,window.document))):A(jQuery,window,document)}((function(A,t,e,n){"use strict";var r,i,o,s,a=A.fn.dataTable;function c(A,t){var e=this;if(i&&i.versionCheck&&i.versionCheck("1.10.0"))return A=new i.Api(A),this.classes=r.extend(!0,{},c.classes),this.c=r.extend(!0,{},c.defaults,t),t&&t.left!==n||this.c.leftColumns===n||(this.c.left=this.c.leftColumns),t&&t.right!==n||this.c.rightColumns===n||(this.c.right=this.c.rightColumns),this.s={barWidth:0,dt:A,rtl:"rtl"===r("body").css("direction")},t={bottom:"0px",display:"block",position:"absolute",width:this.s.barWidth+1+"px"},this.dom={leftBottomBlocker:r("<div>").css(t).css("left",0).addClass(this.classes.leftBottomBlocker),leftTopBlocker:r("<div>").css(t).css({left:0,top:0}).addClass(this.classes.leftTopBlocker),rightBottomBlocker:r("<div>").css(t).css("right",0).addClass(this.classes.rightBottomBlocker),rightTopBlocker:r("<div>").css(t).css({right:0,top:0}).addClass(this.classes.rightTopBlocker)},this.s.dt.settings()[0]._bInitComplete?(this._addStyles(),this._setKeyTableListener()):A.one("init.dt.dtfc",(function(){e._addStyles(),e._setKeyTableListener()})),A.on("column-sizing.dt.dtfc",(function(){return e._addStyles()})),A.settings()[0]._fixedColumns=this,A.on("destroy",(function(){return e._destroy()})),this;throw new Error("FixedColumns requires DataTables 1.10 or newer")}function B(A,t){void 0===t&&(t=null),A=new a.Api(A),t=t||A.init().fixedColumns||a.defaults.fixedColumns,new o(A,t)}return c.prototype.left=function(A){return A!==n?(0<=A&&A<=this.s.dt.columns().count()&&(this.c.left=A,this._addStyles()),this):this.c.left},c.prototype.right=function(A){return A!==n?(0<=A&&A<=this.s.dt.columns().count()&&(this.c.right=A,this._addStyles()),this):this.c.right},c.prototype._addStyles=function(){this.s.dt.settings()[0].oScroll.sY&&(t=r(this.s.dt.table().node()).closest("div.dataTables_scrollBody")[0],e=this.s.dt.settings()[0].oBrowser.barWidth,t.offsetWidth-t.clientWidth>=e?this.s.barWidth=e:this.s.barWidth=0,this.dom.rightTopBlocker.css("width",this.s.barWidth+1),this.dom.leftTopBlocker.css("width",this.s.barWidth+1),this.dom.rightBottomBlocker.css("width",this.s.barWidth+1),this.dom.leftBottomBlocker.css("width",this.s.barWidth+1));for(var A=null,t=this.s.dt.column(0).header(),e=null,i=(null!==t&&(e=(t=r(t)).outerHeight()+1,A=r(t.closest("div.dataTables_scroll")).css("position","relative")),this.s.dt.column(0).footer()),o=null,s=(null!==i&&(o=(i=r(i)).outerHeight(),null===A&&(A=r(i.closest("div.dataTables_scroll")).css("position","relative"))),this.s.dt.columns().data().toArray().length),a=0,c=0,B=r(this.s.dt.table().node()).children("tbody").children("tr"),g=0,l=new Map,u=0;u<s;u++){var w=this.s.dt.column(u);if(0<u&&l.set(u-1,g),w.visible()){var h=r(w.header()),E=r(w.footer());if(u-g<this.c.left){if(r(this.s.dt.table().node()).addClass(this.classes.tableFixedLeft),A.addClass(this.classes.tableFixedLeft),0<u-g)for(var f=u;f+1<s;){if((m=this.s.dt.column(f-1,{page:"current"})).visible()){a+=r(m.nodes()[0]).outerWidth(),c+=m.header()||m.footer()?r(m.header()).outerWidth():0;break}f--}for(var Q=0,d=B;Q<d.length;Q++){var C=d[Q];r(r(C).children()[u-g]).css(this._getCellCSS(!1,a,"left")).addClass(this.classes.fixedLeft)}h.css(this._getCellCSS(!0,c,"left")).addClass(this.classes.fixedLeft),E.css(this._getCellCSS(!0,c,"left")).addClass(this.classes.fixedLeft)}else{for(var M=0,I=B;M<I.length;M++)C=I[M],(U=r(r(C).children()[u-g])).hasClass(this.classes.fixedLeft)&&U.css(this._clearCellCSS("left")).removeClass(this.classes.fixedLeft);h.hasClass(this.classes.fixedLeft)&&h.css(this._clearCellCSS("left")).removeClass(this.classes.fixedLeft),E.hasClass(this.classes.fixedLeft)&&E.css(this._clearCellCSS("left")).removeClass(this.classes.fixedLeft)}}else g++}var p=0,D=0,y=0;for(u=s-1;0<=u;u--)if((w=this.s.dt.column(u)).visible()){h=r(w.header()),E=r(w.footer());var v=l.get(u);if(v===n&&(v=g),u+y>=s-this.c.right){if(r(this.s.dt.table().node()).addClass(this.classes.tableFixedRight),A.addClass(this.classes.tableFixedRight),u+1+y<s){var m;for(f=u;f+1<s;){if((m=this.s.dt.column(f+1,{page:"current"})).visible()){p+=r(m.nodes()[0]).outerWidth(),D+=m.header()||m.footer()?r(m.header()).outerWidth():0;break}f++}}for(var F=0,Y=B;F<Y.length;F++)C=Y[F],r(r(C).children()[u-v]).css(this._getCellCSS(!1,p,"right")).addClass(this.classes.fixedRight);h.css(this._getCellCSS(!0,D,"right")).addClass(this.classes.fixedRight),E.css(this._getCellCSS(!0,D,"right")).addClass(this.classes.fixedRight)}else{for(var b=0,z=B;b<z.length;b++){var U;C=z[b];(U=r(r(C).children()[u-v])).hasClass(this.classes.fixedRight)&&U.css(this._clearCellCSS("right")).removeClass(this.classes.fixedRight)}h.hasClass(this.classes.fixedRight)&&h.css(this._clearCellCSS("right")).removeClass(this.classes.fixedRight),E.hasClass(this.classes.fixedRight)&&E.css(this._clearCellCSS("right")).removeClass(this.classes.fixedRight)}}else y++;t&&(this.s.rtl?(this.dom.leftTopBlocker.outerHeight(e),A.append(this.dom.leftTopBlocker)):(this.dom.rightTopBlocker.outerHeight(e),A.append(this.dom.rightTopBlocker))),i&&(this.s.rtl?(this.dom.leftBottomBlocker.outerHeight(o),A.append(this.dom.leftBottomBlocker)):(this.dom.rightBottomBlocker.outerHeight(o),A.append(this.dom.rightBottomBlocker)))},c.prototype._destroy=function(){this.s.dt.off(".dtfc"),this.dom.leftBottomBlocker.remove(),this.dom.leftTopBlocker.remove(),this.dom.rightBottomBlocker.remove(),this.dom.rightTopBlocker.remove()},c.prototype._getCellCSS=function(A,t,e){return"left"===e?this.s.rtl?{position:"sticky",right:t+"px"}:{left:t+"px",position:"sticky"}:this.s.rtl?{left:t+(A?this.s.barWidth:0)+"px",position:"sticky"}:{position:"sticky",right:t+(A?this.s.barWidth:0)+"px"}},c.prototype._clearCellCSS=function(A){return"left"===A?this.s.rtl?{position:"",right:""}:{left:"",position:""}:this.s.rtl?{left:"",position:""}:{position:"",right:""}},c.prototype._setKeyTableListener=function(){var A=this;this.s.dt.on("key-focus.dt.dtfc",(function(t,e,n){var i,o,s,a=r(n.node()).offset(),c=r(r(A.s.dt.table().node()).closest("div.dataTables_scrollBody"));0<A.c.left&&(i=(o=r(A.s.dt.column(A.c.left-1).header())).offset(),o=o.outerWidth(),a.left<i.left+o&&(s=c.scrollLeft(),c.scrollLeft(s-(i.left+o-a.left)))),0<A.c.right&&(i=A.s.dt.columns().data().toArray().length,o=r(n.node()).outerWidth(),n=r(A.s.dt.column(i-A.c.right).header()).offset(),a.left+o>n.left&&(s=c.scrollLeft(),c.scrollLeft(s-(n.left-(a.left+o)))))})),this.s.dt.on("draw.dt.dtfc",(function(){A._addStyles()})),this.s.dt.on("column-reorder.dt.dtfc",(function(){A._addStyles()})),this.s.dt.on("column-visibility.dt.dtfc",(function(t,e,n,r,i){i&&!e.bDestroying&&setTimeout((function(){A._addStyles()}),50)}))},c.version="4.3.0",c.classes={fixedLeft:"dtfc-fixed-left",fixedRight:"dtfc-fixed-right",leftBottomBlocker:"dtfc-left-bottom-blocker",leftTopBlocker:"dtfc-left-top-blocker",rightBottomBlocker:"dtfc-right-bottom-blocker",rightTopBlocker:"dtfc-right-top-blocker",tableFixedLeft:"dtfc-has-left",tableFixedRight:"dtfc-has-right"},c.defaults={i18n:{button:"FixedColumns"},left:1,right:0},o=c,i=(r=A).fn.dataTable,A.fn.dataTable.FixedColumns=o,A.fn.DataTable.FixedColumns=o,(s=a.Api.register)("fixedColumns()",(function(){return this})),s("fixedColumns().left()",(function(A){var t=this.context[0];return A!==n?(t._fixedColumns.left(A),this):t._fixedColumns.left()})),s("fixedColumns().right()",(function(A){var t=this.context[0];return A!==n?(t._fixedColumns.right(A),this):t._fixedColumns.right()})),a.ext.buttons.fixedColumns={action:function(t,e,n,r){A(n).attr("active")?(A(n).removeAttr("active").removeClass("active"),e.fixedColumns().left(0),e.fixedColumns().right(0)):(A(n).attr("active","true").addClass("active"),e.fixedColumns().left(r.config.left),e.fixedColumns().right(r.config.right))},config:{left:1,right:0},init:function(t,e,r){t.settings()[0]._fixedColumns===n&&B(t.settings(),r),A(e).attr("active","true").addClass("active"),t.button(e).text(r.text||t.i18n("buttons.fixedColumns",t.settings()[0]._fixedColumns.c.i18n.button))},text:null},A(e).on("plugin-init.dt",(function(A,t){"dt"!==A.namespace||!t.oInit.fixedColumns&&!a.defaults.fixedColumns||t._fixedColumns||B(t,null)})),a})),
/*! Bootstrap 5 integration for DataTables' FixedColumns
 * © SpryMedia Ltd - datatables.net/license
 */
function(A){if("function"==typeof define&&define.amd)define(["jquery","datatables.net-bs5","datatables.net-fixedcolumns"],(function(t){return A(t,window,document)}));else if("object"==typeof exports){var t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net-bs5")(A,t),t.fn.dataTable.FixedColumns||require("datatables.net-fixedcolumns")(A,t)};"undefined"==typeof window?module.exports=function(n,r){return n||(n=window),r||(r=t(n)),e(n,r),A(r,n,n.document)}:(e(window,t),module.exports=A(t,window,window.document))}else A(jQuery,window,document)}((function(A,t,e,n){"use strict";return A.fn.dataTable})),function(A){var t,e;"function"==typeof define&&define.amd?define(["jquery","datatables.net"],(function(t){return A(t,window,document)})):"object"==typeof exports?(t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net")(A,t)},"undefined"==typeof window?module.exports=function(n,r){return n=n||window,r=r||t(n),e(n,r),A(r,n,n.document)}:(e(window,t),module.exports=A(t,window,window.document))):A(jQuery,window,document)}((function(A,t,e,n){"use strict";function r(e,n){if(!(this instanceof r))throw"FixedHeader must be initialised with the 'new' keyword.";if(!0===n&&(n={}),e=new i.Api(e),this.c=A.extend(!0,{},r.defaults,n),this.s={dt:e,position:{theadTop:0,tbodyTop:0,tfootTop:0,tfootBottom:0,width:0,left:0,tfootHeight:0,theadHeight:0,windowHeight:A(t).height(),visible:!0},headerMode:null,footerMode:null,autoWidth:e.settings()[0].oFeatures.bAutoWidth,namespace:".dtfc"+o++,scrollLeft:{header:-1,footer:-1},enable:!0,autoDisable:!1},this.dom={floatingHeader:null,thead:A(e.table().header()),tbody:A(e.table().body()),tfoot:A(e.table().footer()),header:{host:null,floating:null,floatingParent:A('<div class="dtfh-floatingparent">'),placeholder:null},footer:{host:null,floating:null,floatingParent:A('<div class="dtfh-floatingparent">'),placeholder:null}},this.dom.header.host=this.dom.thead.parent(),this.dom.footer.host=this.dom.tfoot.parent(),(n=e.settings()[0])._fixedHeader)throw"FixedHeader already initialised on table "+n.nTable.id;(n._fixedHeader=this)._constructor()}var i=A.fn.dataTable,o=0;return A.extend(r.prototype,{destroy:function(){var e=this.dom;this.s.dt.off(".dtfc"),A(t).off(this.s.namespace),e.header.rightBlocker&&e.header.rightBlocker.remove(),e.header.leftBlocker&&e.header.leftBlocker.remove(),e.footer.rightBlocker&&e.footer.rightBlocker.remove(),e.footer.leftBlocker&&e.footer.leftBlocker.remove(),this.c.header&&this._modeChange("in-place","header",!0),this.c.footer&&e.tfoot.length&&this._modeChange("in-place","footer",!0)},enable:function(A,t,e){this.s.enable=A,this.s.enableType=e,!t&&t!==n||(this._positions(),this._scroll(!0))},enabled:function(){return this.s.enable},headerOffset:function(A){return A!==n&&(this.c.headerOffset=A,this.update()),this.c.headerOffset},footerOffset:function(A){return A!==n&&(this.c.footerOffset=A,this.update()),this.c.footerOffset},update:function(t){var e=this.s.dt.table().node();(this.s.enable||this.s.autoDisable)&&(A(e).is(":visible")?(this.s.autoDisable=!1,this.enable(!0,!1)):(this.s.autoDisable=!0,this.enable(!1,!1)),0!==A(e).children("thead").length&&(this._positions(),this._scroll(t===n||t)))},_constructor:function(){var e=this,n=this.s.dt,r=(A(t).on("scroll"+this.s.namespace,(function(){e._scroll()})).on("resize"+this.s.namespace,i.util.throttle((function(){e.s.position.windowHeight=A(t).height(),e.update()}),50)),A(".fh-fixedHeader"));!this.c.headerOffset&&r.length&&(this.c.headerOffset=r.outerHeight()),r=A(".fh-fixedFooter");!this.c.footerOffset&&r.length&&(this.c.footerOffset=r.outerHeight()),n.on("column-reorder.dt.dtfc column-visibility.dt.dtfc column-sizing.dt.dtfc responsive-display.dt.dtfc",(function(A,t){e.update()})).on("draw.dt.dtfc",(function(A,t){e.update(t!==n.settings()[0])})),n.on("destroy.dtfc",(function(){e.destroy()})),this._positions(),this._scroll()},_clone:function(t,e){var n,r,i=this,o=this.s.dt,s=this.dom[t],a="header"===t?this.dom.thead:this.dom.tfoot;"footer"===t&&this._scrollEnabled()||(!e&&s.floating?s.floating.removeClass("fixedHeader-floating fixedHeader-locked"):(s.floating&&(null!==s.placeholder&&s.placeholder.remove(),this._unsize(t),s.floating.children().detach(),s.floating.remove()),e=A(o.table().node()),n=A(e.parent()),r=this._scrollEnabled(),s.floating=A(o.table().node().cloneNode(!1)).attr("aria-hidden","true").css({"table-layout":"fixed",top:0,left:0}).removeAttr("id").append(a),s.floatingParent.css({width:n.width(),overflow:"hidden",height:"fit-content",position:"fixed",left:r?e.offset().left+n.scrollLeft():0}).css("header"===t?{top:this.c.headerOffset,bottom:""}:{top:"",bottom:this.c.footerOffset}).addClass("footer"===t?"dtfh-floatingparentfoot":"dtfh-floatingparenthead").append(s.floating).appendTo("body"),this._stickyPosition(s.floating,"-"),(o=function(){var A=n.scrollLeft();i.s.scrollLeft={footer:A,header:A},s.floatingParent.scrollLeft(i.s.scrollLeft.header)})(),n.off("scroll.dtfh").on("scroll.dtfh",o),s.placeholder=a.clone(!1),s.placeholder.find("*[id]").removeAttr("id"),s.host.prepend(s.placeholder),this._matchWidths(s.placeholder,s.floating)))},_stickyPosition:function(t,e){var n,r;this._scrollEnabled()&&(r="rtl"===A((n=this).s.dt.table().node()).css("direction"),t.find("th").each((function(){var t,i,o;"sticky"===A(this).css("position")&&(t=A(this).css("right"),i=A(this).css("left"),"auto"===t||r?"auto"!==i&&r&&(o=+i.replace(/px/g,"")+("-"===e?-1:1)*n.s.dt.settings()[0].oBrowser.barWidth,A(this).css("left",0<o?o:0)):(o=+t.replace(/px/g,"")+("-"===e?-1:1)*n.s.dt.settings()[0].oBrowser.barWidth,A(this).css("right",0<o?o:0)))})))},_matchWidths:function(t,e){function n(e){return A(e,t).map((function(){return+A(this).css("width").replace(/[^\d\.]/g,"")})).toArray()}function r(t,n){A(t,e).each((function(t){A(this).css({width:n[t],minWidth:n[t]})}))}var i=n("th"),o=n("td");r("th",i),r("td",o)},_unsize:function(t){var e=this.dom[t].floating;e&&("footer"===t||"header"===t&&!this.s.autoWidth)?A("th, td",e).css({width:"",minWidth:""}):e&&"header"===t&&A("th, td",e).css("min-width","")},_horizontal:function(t,e){var n,r=this.dom[t],i=(this.s.position,this.s.scrollLeft);r.floating&&i[t]!==e&&(this._scrollEnabled()&&(n=A(A(this.s.dt.table().node()).parent()).scrollLeft(),r.floating.scrollLeft(n),r.floatingParent.scrollLeft(n)),i[t]=e)},_modeChange:function(n,r,i){this.s.dt;var o,s,a,c,B,g,l,u=this.dom[r],w=this.s.position,h=this._scrollEnabled();"footer"===r&&h||(o=function(A){u.floating.attr("style",(function(t,e){return(e||"")+"width: "+A+"px !important;"})),h||u.floatingParent.attr("style",(function(t,e){return(e||"")+"width: "+A+"px !important;"}))},c=this.dom["footer"===r?"tfoot":"thead"],s=A.contains(c[0],e.activeElement)?e.activeElement:null,B=A(A(this.s.dt.table().node()).parent()),"in-place"===n?(u.placeholder&&(u.placeholder.remove(),u.placeholder=null),this._unsize(r),"header"===r?u.host.prepend(c):u.host.append(c),u.floating&&(u.floating.remove(),u.floating=null,this._stickyPosition(u.host,"+")),u.floatingParent&&u.floatingParent.remove(),A(A(u.host.parent()).parent()).scrollLeft(B.scrollLeft())):"in"===n?(this._clone(r,i),c=B.offset(),l=(a=A(e).scrollTop())+A(t).height(),g=h?c.top:w.tbodyTop,c=h?c.top+B.outerHeight():w.tfootTop,B="footer"===r?l<g?w.tfootHeight:g+w.tfootHeight-l:a+this.c.headerOffset+w.theadHeight-c,g="header"===r?"top":"bottom",l=this.c[r+"Offset"]-(0<B?B:0),u.floating.addClass("fixedHeader-floating"),u.floatingParent.css(g,l).css({left:w.left,height:"header"===r?w.theadHeight:w.tfootHeight,"z-index":2}).append(u.floating),o(w.width),"footer"===r&&u.floating.css("top","")):"below"===n?(this._clone(r,i),u.floating.addClass("fixedHeader-locked"),u.floatingParent.css({position:"absolute",top:w.tfootTop-w.theadHeight,left:w.left+"px"}),o(w.width)):"above"===n&&(this._clone(r,i),u.floating.addClass("fixedHeader-locked"),u.floatingParent.css({position:"absolute",top:w.tbodyTop,left:w.left+"px"}),o(w.width)),s&&s!==e.activeElement&&setTimeout((function(){s.focus()}),10),this.s.scrollLeft.header=-1,this.s.scrollLeft.footer=-1,this.s[r+"Mode"]=n)},_positions:function(){var t=(o=this.s.dt).table(),e=this.s.position,n=this.dom,r=(t=A(t.node()),this._scrollEnabled()),i=A(o.table().header()),o=A(o.table().footer()),s=(n=n.tbody,t.parent());e.visible=t.is(":visible"),e.width=t.outerWidth(),e.left=t.offset().left,e.theadTop=i.offset().top,e.tbodyTop=(r?s:n).offset().top,e.tbodyHeight=(r?s:n).outerHeight(),e.theadHeight=i.outerHeight(),e.theadBottom=e.theadTop+e.theadHeight,o.length?(e.tfootTop=e.tbodyTop+e.tbodyHeight,e.tfootBottom=e.tfootTop+o.outerHeight(),e.tfootHeight=o.outerHeight()):(e.tfootTop=e.tbodyTop+n.outerHeight(),e.tfootBottom=e.tfootTop,e.tfootHeight=e.tfootTop)},_scroll:function(r){var i,o,s,a,c,B,g,l,u,w,h,E,f,Q,d,C;this.s.dt.settings()[0].bDestroying||(i=this._scrollEnabled(),o=(w=A(this.s.dt.table().node()).parent()).offset(),E=w.outerHeight(),s=A(e).scrollLeft(),a=A(e).scrollTop(),(h=A(t).height())+a,f=this.s.position,C=i?o.top:f.tbodyTop,B=(i?o:f).left,E=i?o.top+E:f.tfootTop,g=i?w.outerWidth():f.tbodyWidth,l=a+h,this.c.header&&(!this.s.enable||!f.visible||a+this.c.headerOffset+f.theadHeight<=C?u="in-place":a+this.c.headerOffset+f.theadHeight>C&&a+this.c.headerOffset+f.theadHeight<E?(u="in",w=A(A(this.s.dt.table().node()).parent()),a+this.c.headerOffset+f.theadHeight>E||this.dom.header.floatingParent===n?r=!0:this.dom.header.floatingParent.css({top:this.c.headerOffset,position:"fixed"}).append(this.dom.header.floating)):u="below",!r&&u===this.s.headerMode||this._modeChange(u,"header",r),this._horizontal("header",s)),Q={offset:{top:0,left:0},height:0},d={offset:{top:0,left:0},height:0},this.c.footer&&this.dom.tfoot.length&&(!this.s.enable||!f.visible||f.tfootBottom+this.c.footerOffset<=l?c="in-place":E+f.tfootHeight+this.c.footerOffset>l&&C+this.c.footerOffset<l?(c="in",r=!0):c="above",!r&&c===this.s.footerMode||this._modeChange(c,"footer",r),this._horizontal("footer",s),h=function(A){return{offset:A.offset(),height:A.outerHeight()}},Q=this.dom.header.floating?h(this.dom.header.floating):h(this.dom.thead),d=this.dom.footer.floating?h(this.dom.footer.floating):h(this.dom.tfoot),i&&d.offset.top>a&&(f=l+((E=a-o.top)>-Q.height?E:0)-(Q.offset.top+(E<-Q.height?Q.height:0)+d.height),w.outerHeight(f=f<0?0:f),Math.round(w.outerHeight())>=Math.round(f)?A(this.dom.tfoot.parent()).addClass("fixedHeader-floating"):A(this.dom.tfoot.parent()).removeClass("fixedHeader-floating"))),this.dom.header.floating&&this.dom.header.floatingParent.css("left",B-s),this.dom.footer.floating&&this.dom.footer.floatingParent.css("left",B-s),this.s.dt.settings()[0]._fixedColumns!==n&&(this.dom.header.rightBlocker=(C=function(t,e,r){var i;return null!==(r=r===n?0===(i=A("div.dtfc-"+t+"-"+e+"-blocker")).length?null:i.clone().css("z-index",1):r)&&("in"===u||"below"===u?r.appendTo("body").css({top:("top"===e?Q:d).offset.top,left:"right"===t?B+g-r.width():B}):r.detach()),r})("right","top",this.dom.header.rightBlocker),this.dom.header.leftBlocker=C("left","top",this.dom.header.leftBlocker),this.dom.footer.rightBlocker=C("right","bottom",this.dom.footer.rightBlocker),this.dom.footer.leftBlocker=C("left","bottom",this.dom.footer.leftBlocker)))},_scrollEnabled:function(){var A=this.s.dt.settings()[0].oScroll;return""!==A.sY||""!==A.sX}}),r.version="3.4.0",r.defaults={header:!0,footer:!1,headerOffset:0,footerOffset:0},A.fn.dataTable.FixedHeader=r,A.fn.DataTable.FixedHeader=r,A(e).on("init.dt.dtfh",(function(t,e,n){var o;"dt"===t.namespace&&(t=e.oInit.fixedHeader,o=i.defaults.fixedHeader,!t&&!o||e._fixedHeader||(o=A.extend({},o,t),!1!==t&&new r(e,o)))})),i.Api.register("fixedHeader()",(function(){})),i.Api.register("fixedHeader.adjust()",(function(){return this.iterator("table",(function(A){(A=A._fixedHeader)&&A.update()}))})),i.Api.register("fixedHeader.enable()",(function(A){return this.iterator("table",(function(t){t=t._fixedHeader,A=A===n||A,t&&A!==t.enabled()&&t.enable(A)}))})),i.Api.register("fixedHeader.enabled()",(function(){if(this.context.length){var A=this.context[0]._fixedHeader;if(A)return A.enabled()}return!1})),i.Api.register("fixedHeader.disable()",(function(){return this.iterator("table",(function(A){(A=A._fixedHeader)&&A.enabled()&&A.enable(!1)}))})),A.each(["header","footer"],(function(A,t){i.Api.register("fixedHeader."+t+"Offset()",(function(A){var e=this.context;return A===n?e.length&&e[0]._fixedHeader?e[0]._fixedHeader[t+"Offset"]():n:this.iterator("table",(function(e){(e=e._fixedHeader)&&e[t+"Offset"](A)}))}))})),i})),
/*! Bootstrap 5 styling wrapper for FixedHeader
 * © SpryMedia Ltd - datatables.net/license
 */
function(A){if("function"==typeof define&&define.amd)define(["jquery","datatables.net-bs5","datatables.net-fixedheader"],(function(t){return A(t,window,document)}));else if("object"==typeof exports){var t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net-bs5")(A,t),t.fn.dataTable.FixedHeader||require("datatables.net-fixedheader")(A,t)};"undefined"==typeof window?module.exports=function(n,r){return n||(n=window),r||(r=t(n)),e(n,r),A(r,n,n.document)}:(e(window,t),module.exports=A(t,window,window.document))}else A(jQuery,window,document)}((function(A,t,e,n){"use strict";return A.fn.dataTable})),function(A){var t,e;"function"==typeof define&&define.amd?define(["jquery","datatables.net"],(function(t){return A(t,window,document)})):"object"==typeof exports?(t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net")(A,t)},"undefined"==typeof window?module.exports=function(n,r){return n=n||window,r=r||t(n),e(n,r),A(r,n,n.document)}:(e(window,t),module.exports=A(t,window,window.document))):A(jQuery,window,document)}((function(A,t,e,n){"use strict";function r(t,e){if(!i.versionCheck||!i.versionCheck("1.10.10"))throw"DataTables Responsive requires DataTables 1.10.10 or newer";this.s={childNodeStore:{},columns:[],current:[],dt:new i.Api(t)},this.s.dt.settings()[0].responsive||(e&&"string"==typeof e.details?e.details={type:e.details}:e&&!1===e.details?e.details={type:!1}:e&&!0===e.details&&(e.details={type:"inline"}),this.c=A.extend(!0,{},r.defaults,i.defaults.responsive,e),(t.responsive=this)._constructor())}var i=A.fn.dataTable,o=(A.extend(r.prototype,{_constructor:function(){var e=this,n=this.s.dt,r=n.settings()[0],o=A(t).innerWidth();!1!==(r=(n.settings()[0]._responsive=this,A(t).on("resize.dtr orientationchange.dtr",i.util.throttle((function(){var n=A(t).innerWidth();n!==o&&(e._resize(),o=n)}))),r.oApi._fnCallbackReg(r,"aoRowCreatedCallback",(function(t,r,i){-1!==A.inArray(!1,e.s.current)&&A(">td, >th",t).each((function(t){t=n.column.index("toData",t),!1===e.s.current[t]&&A(this).css("display","none")}))})),n.on("destroy.dtr",(function(){n.off(".dtr"),A(n.table().body()).off(".dtr"),A(t).off("resize.dtr orientationchange.dtr"),n.cells(".dtr-control").nodes().to$().removeClass("dtr-control"),A.each(e.s.current,(function(A,t){!1===t&&e._setColumnVis(A,!0)}))})),this.c.breakpoints.sort((function(A,t){return A.width<t.width?1:A.width>t.width?-1:0})),this._classLogic(),this._resizeAuto(),this.c.details)).type&&(e._detailsInit(),n.on("column-visibility.dtr",(function(){e._timer&&clearTimeout(e._timer),e._timer=setTimeout((function(){e._timer=null,e._classLogic(),e._resizeAuto(),e._resize(!0),e._redrawChildren()}),100)})),n.on("draw.dtr",(function(){e._redrawChildren()})),A(n.table().node()).addClass("dtr-"+r.type)),n.on("column-reorder.dtr",(function(A,t,n){e._classLogic(),e._resizeAuto(),e._resize(!0)})),n.on("column-sizing.dtr",(function(){e._resizeAuto(),e._resize()})),n.on("column-calc.dt",(function(A,t){for(var n=e.s.current,r=0;r<n.length;r++){var i=t.visible.indexOf(r);!1===n[r]&&0<=i&&t.visible.splice(i,1)}})),n.on("preXhr.dtr",(function(){var A=[];n.rows().every((function(){this.child.isShown()&&A.push(this.id(!0))})),n.one("draw.dtr",(function(){e._resizeAuto(),e._resize(),n.rows(A).every((function(){e._detailsDisplay(this,!1)}))}))})),n.on("draw.dtr",(function(){e._controlClass()})).on("init.dtr",(function(t,r,i){"dt"===t.namespace&&(e._resizeAuto(),e._resize(),A.inArray(!1,e.s.current)&&n.columns.adjust())})),this._resize()},_childNodes:function(A,t,e){var n=t+"-"+e;if(this.s.childNodeStore[n])return this.s.childNodeStore[n];for(var r=[],i=A.cell(t,e).node().childNodes,o=0,s=i.length;o<s;o++)r.push(i[o]);return this.s.childNodeStore[n]=r},_childNodesRestore:function(A,t,e){var r=t+"-"+e;if(this.s.childNodeStore[r]){for(var i=A.cell(t,e).node(),o=this.s.childNodeStore[r][0].parentNode.childNodes,s=[],a=0,c=o.length;a<c;a++)s.push(o[a]);for(var B=0,g=s.length;B<g;B++)i.appendChild(s[B]);this.s.childNodeStore[r]=n}},_columnsVisiblity:function(t){for(var e=this.s.dt,n=this.s.columns,r=n.map((function(A,t){return{columnIdx:t,priority:A.priority}})).sort((function(A,t){return A.priority!==t.priority?A.priority-t.priority:A.columnIdx-t.columnIdx})),i=A.map(n,(function(n,r){return!1===e.column(r).visible()?"not-visible":(!n.auto||null!==n.minWidth)&&(!0===n.auto?"-":-1!==A.inArray(t,n.includeIn))})),o=0,s=0,a=i.length;s<a;s++)!0===i[s]&&(o+=n[s].minWidth);var c=(c=e.settings()[0].oScroll).sY||c.sX?c.iBarWidth:0,B=e.table().container().offsetWidth-c-o;for(s=0,a=i.length;s<a;s++)n[s].control&&(B-=n[s].minWidth);var g=!1;for(s=0,a=r.length;s<a;s++){var l=r[s].columnIdx;"-"===i[l]&&!n[l].control&&n[l].minWidth&&(g||B-n[l].minWidth<0?i[l]=!(g=!0):i[l]=!0,B-=n[l].minWidth)}var u=!1;for(s=0,a=n.length;s<a;s++)if(!n[s].control&&!n[s].never&&!1===i[s]){u=!0;break}for(s=0,a=n.length;s<a;s++)n[s].control&&(i[s]=u),"not-visible"===i[s]&&(i[s]=!1);return-1===A.inArray(!0,i)&&(i[0]=!0),i},_classLogic:function(){function t(A,t,n,i){var a,c,B;if(n){if("max-"===n)for(a=e._find(t).width,c=0,B=r.length;c<B;c++)r[c].width<=a&&s(A,r[c].name);else if("min-"===n)for(a=e._find(t).width,c=0,B=r.length;c<B;c++)r[c].width>=a&&s(A,r[c].name);else if("not-"===n)for(c=0,B=r.length;c<B;c++)-1===r[c].name.indexOf(i)&&s(A,r[c].name)}else o[A].includeIn.push(t)}var e=this,r=this.c.breakpoints,i=this.s.dt,o=i.columns().eq(0).map((function(A){var t=(e=this.column(A)).header().className,e=(A=i.settings()[0].aoColumns[A].responsivePriority,e.header().getAttribute("data-priority"));return A===n&&(A=e===n||null===e?1e4:+e),{className:t,includeIn:[],auto:!1,control:!1,never:!!t.match(/\b(dtr\-)?never\b/),priority:A}})),s=function(t,e){t=o[t].includeIn,-1===A.inArray(e,t)&&t.push(e)};o.each((function(e,n){for(var i=e.className.split(" "),o=!1,s=0,a=i.length;s<a;s++){var c=i[s].trim();if("all"===c||"dtr-all"===c)return o=!0,void(e.includeIn=A.map(r,(function(A){return A.name})));if("none"===c||"dtr-none"===c||e.never)return void(o=!0);if("control"===c||"dtr-control"===c)return o=!0,void(e.control=!0);A.each(r,(function(A,e){var r=e.name.split("-"),i=new RegExp("(min\\-|max\\-|not\\-)?("+r[0]+")(\\-[_a-zA-Z0-9])?");(i=c.match(i))&&(o=!0,i[2]===r[0]&&i[3]==="-"+r[1]?t(n,e.name,i[1],i[2]+i[3]):i[2]!==r[0]||i[3]||t(n,e.name,i[1],i[2]))}))}o||(e.auto=!0)})),this.s.columns=o},_controlClass:function(){var t,e,n;"inline"===this.c.details.type&&(t=this.s.dt,e=this.s.current,n=A.inArray(!0,e),t.cells(null,(function(A){return A!==n}),{page:"current"}).nodes().to$().filter(".dtr-control").removeClass("dtr-control"),t.cells(null,n,{page:"current"}).nodes().to$().addClass("dtr-control"))},_detailsDisplay:function(t,e){function n(n){A(t.node()).toggleClass("parent",!1!==n),A(s.table().node()).triggerHandler("responsive-display.dt",[s,t,n,e])}var i,o=this,s=this.s.dt,a=this.c.details;a&&!1!==a.type&&(i="string"==typeof a.renderer?r.renderer[a.renderer]():a.renderer,"boolean"==typeof(a=a.display(t,e,(function(){return i.call(o,s,t[0],o._detailsObj(t[0]))}),(function(){n(!1)})))&&n(a))},_detailsInit:function(){var t=this,e=this.s.dt,r=("inline"===(i=this.c.details).type&&(i.target="td.dtr-control, th.dtr-control"),e.on("draw.dtr",(function(){t._tabIndexes()})),t._tabIndexes(),A(e.table().body()).on("keyup.dtr","td, th",(function(t){13===t.keyCode&&A(this).data("dtr-keyboard")&&A(this).click()})),i.target),i="string"==typeof r?r:"td, th";r===n&&null===r||A(e.table().body()).on("click.dtr mousedown.dtr mouseup.dtr",i,(function(n){if(A(e.table().node()).hasClass("collapsed")&&-1!==A.inArray(A(this).closest("tr").get(0),e.rows().nodes().toArray())){if("number"==typeof r){var i=r<0?e.columns().eq(0).length+r:r;if(e.cell(this).index().column!==i)return}i=e.row(A(this).closest("tr")),"click"===n.type?t._detailsDisplay(i,!1):"mousedown"===n.type?A(this).css("outline","none"):"mouseup"===n.type&&A(this).trigger("blur").css("outline","")}}))},_detailsObj:function(t){var e=this,n=this.s.dt;return A.map(this.s.columns,(function(r,i){if(!r.never&&!r.control)return{className:(r=n.settings()[0].aoColumns[i]).sClass,columnIndex:i,data:n.cell(t,i).render(e.c.orthogonal),hidden:n.column(i).visible()&&!e.s.current[i],rowIndex:t,title:null!==r.sTitle?r.sTitle:A(n.column(i).header()).text()}}))},_find:function(A){for(var t=this.c.breakpoints,e=0,n=t.length;e<n;e++)if(t[e].name===A)return t[e]},_redrawChildren:function(){var A=this,t=this.s.dt;t.rows({page:"current"}).iterator("row",(function(e,n){A._detailsDisplay(t.row(n),!0)}))},_resize:function(e){for(var n,r=this,i=this.s.dt,o=A(t).innerWidth(),s=this.c.breakpoints,a=s[0].name,c=this.s.columns,B=this.s.current.slice(),g=s.length-1;0<=g;g--)if(o<=s[g].width){a=s[g].name;break}var l=this._columnsVisiblity(a),u=(this.s.current=l,!1);for(g=0,n=c.length;g<n;g++)if(!1===l[g]&&!c[g].never&&!c[g].control&&0==!i.column(g).visible()){u=!0;break}A(i.table().node()).toggleClass("collapsed",u);var w=!1,h=0;i.columns().eq(0).each((function(A,t){!0===l[t]&&h++,!e&&l[t]===B[t]||(w=!0,r._setColumnVis(A,l[t]))})),this._redrawChildren(),w&&(A(i.table().node()).trigger("responsive-resize.dt",[i,this.s.current]),0===i.page.info().recordsDisplay&&A("td",i.table().body()).eq(0).attr("colspan",h)),r._controlClass()},_resizeAuto:function(){var t,e,n,r,i,o=this.s.dt,s=this.s.columns,a=this;this.c.auto&&-1!==A.inArray(!0,A.map(s,(function(A){return A.auto})))&&(A.isEmptyObject(this.s.childNodeStore)||A.each(this.s.childNodeStore,(function(A){A=A.split("-"),a._childNodesRestore(o,+A[0],+A[1])})),o.table().node().offsetWidth,o.columns,t=o.table().node().cloneNode(!1),e=A(o.table().header().cloneNode(!1)).appendTo(t),r=A(o.table().body()).clone(!1,!1).empty().appendTo(t),t.style.width="auto",n=o.columns().header().filter((function(A){return o.column(A).visible()})).to$().clone(!1).css("display","table-cell").css("width","auto").css("min-width",0),A(r).append(A(o.rows({page:"current"}).nodes()).clone(!1)).find("th, td").css("display",""),(r=o.table().footer())&&(r=A(r.cloneNode(!1)).appendTo(t),i=o.columns().footer().filter((function(A){return o.column(A).visible()})).to$().clone(!1).css("display","table-cell"),A("<tr/>").append(i).appendTo(r)),A("<tr/>").append(n).appendTo(e),"inline"===this.c.details.type&&A(t).addClass("dtr-inline collapsed"),A(t).find("[name]").removeAttr("name"),A(t).css("position","relative"),(i=A("<div/>").css({width:1,height:1,overflow:"hidden",clear:"both"}).append(t)).insertBefore(o.table().node()),n.each((function(A){A=o.column.index("fromVisible",A),s[A].minWidth=this.offsetWidth||0})),i.remove())},_responsiveOnlyHidden:function(){var t=this.s.dt;return A.map(this.s.current,(function(A,e){return!1===t.column(e).visible()||A}))},_setColumnVis:function(t,e){var n=this,r=this.s.dt,i=e?"":"none";A(r.column(t).header()).css("display",i).toggleClass("dtr-hidden",!e),A(r.column(t).footer()).css("display",i).toggleClass("dtr-hidden",!e),r.column(t).nodes().to$().css("display",i).toggleClass("dtr-hidden",!e),A.isEmptyObject(this.s.childNodeStore)||r.cells(null,t).indexes().each((function(A){n._childNodesRestore(r,A.row,A.column)}))},_tabIndexes:function(){var t=this.s.dt,e=t.cells({page:"current"}).nodes().to$(),n=t.settings()[0],r=this.c.details.target;e.filter("[data-dtr-keyboard]").removeData("[data-dtr-keyboard]"),("number"==typeof r?t.cells(null,r,{page:"current"}).nodes().to$():A(r="td:first-child, th:first-child"===r?">td:first-child, >th:first-child":r,t.rows({page:"current"}).nodes())).attr("tabIndex",n.iTabIndex).data("dtr-keyboard",1)}}),r.defaults={breakpoints:r.breakpoints=[{name:"desktop",width:1/0},{name:"tablet-l",width:1024},{name:"tablet-p",width:768},{name:"mobile-l",width:480},{name:"mobile-p",width:320}],auto:!0,details:{display:(r.display={childRow:function(t,e,n){return e?A(t.node()).hasClass("parent")?(t.child(n(),"child").show(),!0):void 0:t.child.isShown()?(t.child(!1),!1):(t.child(n(),"child").show(),!0)},childRowImmediate:function(A,t,e){return!t&&A.child.isShown()||!A.responsive.hasHidden()?(A.child(!1),!1):(A.child(e(),"child").show(),!0)},modal:function(t){return function(n,r,i,o){if(r){if(!(a=A("div.dtr-modal-content")).length||n.index()!==a.data("dtr-row-idx"))return null;a.empty().append(i())}else{var s=function(){a.remove(),A(e).off("keypress.dtr"),A(n.node()).removeClass("parent"),o()},a=A('<div class="dtr-modal"/>').append(A('<div class="dtr-modal-display"/>').append(A('<div class="dtr-modal-content"/>').data("dtr-row-idx",n.index()).append(i())).append(A('<div class="dtr-modal-close">&times;</div>').click((function(){s()})))).append(A('<div class="dtr-modal-background"/>').click((function(){s()}))).appendTo("body");A(n.node()).addClass("parent"),A(e).on("keyup.dtr",(function(A){27===A.keyCode&&(A.stopPropagation(),s())}))}return t&&t.header&&A("div.dtr-modal-content").prepend("<h2>"+t.header(n)+"</h2>"),!0}}}).childRow,renderer:(r.renderer={listHiddenNodes:function(){return function(t,e,n){var r=this,i=A('<ul data-dtr-index="'+e+'" class="dtr-details"/>'),o=!1;return A.each(n,(function(e,n){var s;n.hidden&&(s=n.className?'class="'+n.className+'"':"",A("<li "+s+' data-dtr-index="'+n.columnIndex+'" data-dt-row="'+n.rowIndex+'" data-dt-column="'+n.columnIndex+'"><span class="dtr-title">'+n.title+"</span> </li>").append(A('<span class="dtr-data"/>').append(r._childNodes(t,n.rowIndex,n.columnIndex))).appendTo(i),o=!0)})),!!o&&i}},listHidden:function(){return function(t,e,n){return n=A.map(n,(function(A){var t=A.className?'class="'+A.className+'"':"";return A.hidden?"<li "+t+' data-dtr-index="'+A.columnIndex+'" data-dt-row="'+A.rowIndex+'" data-dt-column="'+A.columnIndex+'"><span class="dtr-title">'+A.title+'</span> <span class="dtr-data">'+A.data+"</span></li>":""})).join(""),!!n&&A('<ul data-dtr-index="'+e+'" class="dtr-details"/>').append(n)}},tableAll:function(t){return t=A.extend({tableClass:""},t),function(e,n,r){return r=A.map(r,(function(A){return"<tr "+(A.className?'class="'+A.className+'"':"")+' data-dt-row="'+A.rowIndex+'" data-dt-column="'+A.columnIndex+'"><td>'+A.title+":</td> <td>"+A.data+"</td></tr>"})).join(""),A('<table class="'+t.tableClass+' dtr-details" width="100%"/>').append(r)}}}).listHidden(),target:0,type:"inline"},orthogonal:"display"},A.fn.dataTable.Api);return o.register("responsive()",(function(){return this})),o.register("responsive.index()",(function(t){return{column:(t=A(t)).data("dtr-index"),row:t.parent().data("dtr-index")}})),o.register("responsive.rebuild()",(function(){return this.iterator("table",(function(A){A._responsive&&A._responsive._classLogic()}))})),o.register("responsive.recalc()",(function(){return this.iterator("table",(function(A){A._responsive&&(A._responsive._resizeAuto(),A._responsive._resize())}))})),o.register("responsive.hasHidden()",(function(){var t=this.context[0];return!!t._responsive&&-1!==A.inArray(!1,t._responsive._responsiveOnlyHidden())})),o.registerPlural("columns().responsiveHidden()","column().responsiveHidden()",(function(){return this.iterator("column",(function(A,t){return!!A._responsive&&A._responsive._responsiveOnlyHidden()[t]}),1)})),r.version="2.5.0",A.fn.dataTable.Responsive=r,A.fn.DataTable.Responsive=r,A(e).on("preInit.dt.dtr",(function(t,e,n){"dt"===t.namespace&&(A(e.nTable).hasClass("responsive")||A(e.nTable).hasClass("dt-responsive")||e.oInit.responsive||i.defaults.responsive)&&!1!==(t=e.oInit.responsive)&&new r(e,A.isPlainObject(t)?t:{})})),i})),function(A){var t,e;"function"==typeof define&&define.amd?define(["jquery","datatables.net-bs5","datatables.net-responsive"],(function(t){return A(t,window,document)})):"object"==typeof exports?(t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net-bs5")(A,t),t.fn.dataTable.Responsive||require("datatables.net-responsive")(A,t)},"undefined"==typeof window?module.exports=function(n,r){return n=n||window,r=r||t(n),e(n,r),A(r,n,n.document)}:(e(window,t),module.exports=A(t,window,window.document))):A(jQuery,window,document)}((function(A,t,e,n){"use strict";var r,i=A.fn.dataTable,o=i.Responsive.display,s=o.modal,a=A('<div class="modal fade dtr-bs-modal" role="dialog"><div class="modal-dialog" role="document"><div class="modal-content"><div class="modal-header"><button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button></div><div class="modal-body"/></div></div></div>'),c=t.bootstrap;return i.Responsive.bootstrap=function(A){c=A},o.modal=function(t){return r=r||new c.Modal(a[0]),function(n,i,o,c){if(A.fn.modal){if(i){if(!A.contains(e,a[0])||n.index()!==a.data("dtr-row-idx"))return null;a.find("div.modal-body").empty().append(o())}else{var B,g;t&&t.header&&(g=(B=a.find("div.modal-header")).find("button").detach(),B.empty().append('<h4 class="modal-title">'+t.header(n)+"</h4>").append(g)),a.find("div.modal-body").empty().append(o()),a.data("dtr-row-idx",n.index()).one("hidden.bs.modal",c).appendTo("body").modal(),r.show()}return!0}return s(n,i,o,c)}},i})),function(A){var t,e;"function"==typeof define&&define.amd?define(["jquery","datatables.net"],(function(t){return A(t,window,document)})):"object"==typeof exports?(t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net")(A,t)},"undefined"==typeof window?module.exports=function(n,r){return n=n||window,r=r||t(n),e(n,r),A(r,0,n.document)}:(e(window,t),module.exports=A(t,window,window.document))):A(jQuery,window,document)}((function(A,t,e,n){"use strict";function r(t,e){if(!i.versionCheck||!i.versionCheck("1.10.8"))throw"RowGroup requires DataTables 1.10.8 or newer";if(this.c=A.extend(!0,{},i.defaults.rowGroup,r.defaults,e),this.s={dt:new i.Api(t)},this.dom={},t=(e=this.s.dt.settings()[0]).rowGroup)return t;(e.rowGroup=this)._constructor()}var i=A.fn.dataTable;return A.extend(r.prototype,{dataSrc:function(t){var e;return t===n?this.c.dataSrc:(e=this.s.dt,this.c.dataSrc=t,A(e.table().node()).triggerHandler("rowgroup-datasrc.dt",[e,t]),this)},disable:function(){return this.c.enable=!1,this},enable:function(A){return!1===A?this.disable():(this.c.enable=!0,this)},enabled:function(){return this.c.enable},_constructor:function(){var A=this,t=this.s.dt,e=t.settings()[0];t.on("draw.dtrg",(function(t,n){A.c.enable&&e===n&&A._draw()})),t.on("column-visibility.dt.dtrg responsive-resize.dt.dtrg",(function(){A._adjustColspan()})),t.on("destroy",(function(){t.off(".dtrg")}))},_adjustColspan:function(){A("tr."+this.c.className,this.s.dt.table().body()).find("th:visible, td:visible").attr("colspan",this._colspan())},_colspan:function(){return this.s.dt.columns().visible().reduce((function(A,t){return A+t}),0)},_draw:function(){var A=this.s.dt;A=this._group(0,A.rows({page:"current"}).indexes());this._groupDisplay(0,A)},_group:function(A,t){for(var e,r=Array.isArray(this.c.dataSrc)?this.c.dataSrc:[this.c.dataSrc],o=i.ext.oApi._fnGetObjectDataFn(r[A]),s=this.s.dt,a=[],c=0,B=t.length;c<B;c++){var g,l=t[c];null!==(g=o(s.row(l).data()))&&g!==n||(g=this.c.emptyDataGroup),e!==n&&g===e||(a.push({dataPoint:g,rows:[]}),e=g),a[a.length-1].rows.push(l)}if(r[A+1]!==n)for(c=0,B=a.length;c<B;c++)a[c].children=this._group(A+1,a[c].rows);return a},_groupDisplay:function(A,t){for(var e,n=this.s.dt,r=0,i=t.length;r<i;r++){var o,s=t[r],a=s.dataPoint,c=s.rows;this.c.startRender&&(e=this.c.startRender.call(this,n.rows(c),a,A),(o=this._rowWrap(e,this.c.startClassName,A))&&o.insertBefore(n.row(c[0]).node())),this.c.endRender&&(e=this.c.endRender.call(this,n.rows(c),a,A),(o=this._rowWrap(e,this.c.endClassName,A))&&o.insertAfter(n.row(c[c.length-1]).node())),s.children&&this._groupDisplay(A+1,s.children)}},_rowWrap:function(t,e,r){return(t=null!==t&&""!==t?t:this.c.emptyDataGroup)===n||null===t?null:("object"==typeof t&&t.nodeName&&"tr"===t.nodeName.toLowerCase()?A(t):t instanceof A&&t.length&&"tr"===t[0].nodeName.toLowerCase()?t:A("<tr/>").append(A("<th/>").attr("colspan",this._colspan()).attr("scope","row").append(t))).addClass(this.c.className).addClass(e).addClass("dtrg-level-"+r)}}),r.defaults={className:"dtrg-group",dataSrc:0,emptyDataGroup:"No group",enable:!0,endClassName:"dtrg-end",endRender:null,startClassName:"dtrg-start",startRender:function(A,t){return t}},r.version="1.4.1",A.fn.dataTable.RowGroup=r,A.fn.DataTable.RowGroup=r,i.Api.register("rowGroup()",(function(){return this})),i.Api.register("rowGroup().disable()",(function(){return this.iterator("table",(function(A){A.rowGroup&&A.rowGroup.enable(!1)}))})),i.Api.register("rowGroup().enable()",(function(A){return this.iterator("table",(function(t){t.rowGroup&&t.rowGroup.enable(A===n||A)}))})),i.Api.register("rowGroup().enabled()",(function(){var A=this.context;return!(!A.length||!A[0].rowGroup)&&A[0].rowGroup.enabled()})),i.Api.register("rowGroup().dataSrc()",(function(A){return A===n?this.context[0].rowGroup.dataSrc():this.iterator("table",(function(t){t.rowGroup&&t.rowGroup.dataSrc(A)}))})),A(e).on("preInit.dt.dtrg",(function(t,e,n){var o;"dt"===t.namespace&&(t=e.oInit.rowGroup,o=i.defaults.rowGroup,(t||o)&&(o=A.extend({},o,t),!1!==t&&new r(e,o)))})),i})),
/*! Bootstrap 5 styling wrapper for RowGroup
 * © SpryMedia Ltd - datatables.net/license
 */
function(A){if("function"==typeof define&&define.amd)define(["jquery","datatables.net-bs5","datatables.net-rowgroup"],(function(t){return A(t,window,document)}));else if("object"==typeof exports){var t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net-bs5")(A,t),t.fn.dataTable.RowGroup||require("datatables.net-rowgroup")(A,t)};"undefined"==typeof window?module.exports=function(n,r){return n||(n=window),r||(r=t(n)),e(n,r),A(r,n,n.document)}:(e(window,t),module.exports=A(t,window,window.document))}else A(jQuery,window,document)}((function(A,t,e,n){"use strict";return A.fn.dataTable})),function(A){var t,e;"function"==typeof define&&define.amd?define(["jquery","datatables.net"],(function(t){return A(t,window,document)})):"object"==typeof exports?(t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net")(A,t)},"undefined"==typeof window?module.exports=function(n,r){return n=n||window,r=r||t(n),e(n,r),A(r,n,n.document)}:(e(window,t),module.exports=A(t,window,window.document))):A(jQuery,window,document)}((function(A,t,e,n){"use strict";function r(t,e){if(!i.versionCheck||!i.versionCheck("1.10.8"))throw"DataTables RowReorder requires DataTables 1.10.8 or newer";if(this.c=A.extend(!0,{},i.defaults.rowReorder,r.defaults,e),this.s={bodyTop:null,dt:new i.Api(t),getDataFn:i.ext.oApi._fnGetObjectDataFn(this.c.dataSrc),middles:null,scroll:{},scrollInterval:null,setDataFn:i.ext.oApi._fnSetObjectDataFn(this.c.dataSrc),start:{top:0,left:0,offsetTop:0,offsetLeft:0,nodes:[],rowIndex:0},windowHeight:0,documentOuterHeight:0,domCloneOuterHeight:0,dropAllowed:!0},this.dom={clone:null,cloneParent:null,dtScroll:A("div.dataTables_scrollBody",this.s.dt.table().container())},t=(e=this.s.dt.settings()[0]).rowreorder)return t;this.dom.dtScroll.length||(this.dom.dtScroll=A(this.s.dt.table().container(),"tbody")),(e.rowreorder=this)._constructor()}var i=A.fn.dataTable,o=(A.extend(r.prototype,{_constructor:function(){var t=this,e=this.s.dt,n=A(e.table().node());"static"===n.css("position")&&n.css("position","relative"),A(e.table().container()).on("mousedown.rowReorder touchstart.rowReorder",this.c.selector,(function(n){var r,i;if(t.c.enable)return!!A(n.target).is(t.c.excludedChildren)||(r=A(this).closest("tr"),(i=e.row(r)).any()?(t._emitEvent("pre-row-reorder",{node:i.node(),index:i.index()}),t._mouseDown(n,r),!1):void 0)})),e.on("destroy.rowReorder",(function(){A(e.table().container()).off(".rowReorder"),e.off(".rowReorder")})),this._keyup=this._keyup.bind(this)},_cachePositions:function(){var n=this.s.dt,r=A(n.table().node()).find("thead").outerHeight(),i=A.unique(n.rows({page:"current"}).nodes().toArray());i=A.map(i,(function(t,e){var n=A(t).position().top-r;return(n+n+A(t).outerHeight())/2}));this.s.middles=i,this.s.bodyTop=A(n.table().body()).offset().top,this.s.windowHeight=A(t).height(),this.s.documentOuterHeight=A(e).outerHeight(),this.s.bodyArea=this._calcBodyArea()},_clone:function(t){var e=this.s.dt,n=(e=A(e.table().node().cloneNode(!1)).addClass("dt-rowReorder-float").append("<tbody/>").append(t.clone(!1)),t.outerWidth()),r=t.outerHeight(),i=(o=A(A(this.s.dt.table().node()).parent())).width(),o=o.scrollLeft(),s=t.children().map((function(){return A(this).width()}));e.width(n).height(r).find("tr").children().each((function(A){this.style.width=s[A]+"px"})),t=A("<div>").addClass("dt-rowReorder-float-parent").width(i).append(e).appendTo("body").scrollLeft(o);this.dom.clone=e,this.dom.cloneParent=t,this.s.domCloneOuterHeight=e.outerHeight()},_clonePosition:function(A){var t=this.s.start,e=this._eventToPage(A,"Y")-t.top,n=(A=this._eventToPage(A,"X")-t.left,this.c.snapX);e+=t.offsetTop,n=!0===n?t.offsetLeft:"number"==typeof n?t.offsetLeft+n:A+t.offsetLeft+this.dom.cloneParent.scrollLeft();e<0?e=0:e+this.s.domCloneOuterHeight>this.s.documentOuterHeight&&(e=this.s.documentOuterHeight-this.s.domCloneOuterHeight),this.dom.cloneParent.css({top:e,left:n})},_emitEvent:function(t,e){var r;return this.s.dt.iterator("table",(function(i,o){(i=A(i.nTable).triggerHandler(t+".dt",e))!==n&&(r=i)})),r},_eventToPage:function(A,t){return(-1!==A.type.indexOf("touch")?A.originalEvent.touches[0]:A)["page"+t]},_mouseDown:function(n,r){var i=this,o=this.s.dt,s=this.s.start,a=this.c.cancelable,c=r.offset();s.top=this._eventToPage(n,"Y"),s.left=this._eventToPage(n,"X"),s.offsetTop=c.top,s.offsetLeft=c.left,s.nodes=A.unique(o.rows({page:"current"}).nodes().toArray()),this._cachePositions(),this._clone(r),this._clonePosition(n),c=this._eventToPage(n,"Y")-this.s.bodyTop,s.rowIndex=this._calcRowIndexByPos(c),(this.dom.target=r).addClass("dt-rowReorder-moving"),A(e).on("mouseup.rowReorder touchend.rowReorder",(function(A){i._mouseUp(A)})).on("mousemove.rowReorder touchmove.rowReorder",(function(A){i._mouseMove(A)})),A(t).width()===A(e).width()&&A(e.body).addClass("dt-rowReorder-noOverflow"),o=this.dom.dtScroll;this.s.scroll={windowHeight:A(t).height(),windowWidth:A(t).width(),dtTop:o.length?o.offset().top:null,dtLeft:o.length?o.offset().left:null,dtHeight:o.length?o.outerHeight():null,dtWidth:o.length?o.outerWidth():null},a&&A(e).on("keyup",this._keyup)},_mouseMove:function(t){this._clonePosition(t);for(var e,n,r=this.s.start,i=this.c.cancelable,o=(i&&(e=this.s.bodyArea,n=this._calcCloneParentArea(),this.s.dropAllowed=this._rectanglesIntersect(e,n),this.s.dropAllowed?A(this.dom.cloneParent).removeClass("drop-not-allowed"):A(this.dom.cloneParent).addClass("drop-not-allowed")),this._eventToPage(t,"Y")-this.s.bodyTop),s=this.s.middles,a=null,c=0,B=s.length;c<B;c++)if(o<s[c]){a=c;break}null===a&&(a=s.length),i&&(this.s.dropAllowed||(a=r.rowIndex>this.s.lastInsert?r.rowIndex+1:r.rowIndex),this.dom.target.toggleClass("dt-rowReorder-moving",this.s.dropAllowed)),this._moveTargetIntoPosition(a),this._shiftScroll(t)},_mouseUp:function(t){var e=this,n=this.s.dt,r=this.c.dataSrc;if(this.s.dropAllowed){for(var i,o,s,a=this.s.start.nodes,c=A.unique(n.rows({page:"current"}).nodes().toArray()),B={},g=[],l=[],u=this.s.getDataFn,w=this.s.setDataFn,h=0,E=a.length;h<E;h++)a[h]!==c[h]&&(i=n.row(c[h]).id(),o=n.row(c[h]).data(),s=n.row(a[h]).data(),i&&(B[i]=u(s)),g.push({node:c[h],oldData:u(o),newData:u(s),newPosition:h,oldPosition:A.inArray(c[h],a)}),l.push(c[h]));var f,Q=[g,{dataSrc:r,nodes:l,values:B,triggerRow:n.row(this.dom.target),originalEvent:t}];!1===this._emitEvent("row-reorder",Q)?e._cancel():(this._cleanupDragging(),f=function(){if(e.c.update){for(h=0,E=g.length;h<E;h++){var A=n.row(g[h].node).data();w(A,g[h].newData),n.columns().every((function(){this.dataSrc()===r&&n.cell(g[h].node,this.index()).invalidate("data")}))}e._emitEvent("row-reordered",Q),n.draw(!1)}},this.c.editor?(this.c.enable=!1,this.c.editor.edit(l,!1,A.extend({submit:"changed"},this.c.formOptions)).multiSet(r,B).one("preSubmitCancelled.rowReorder",(function(){e.c.enable=!0,e.c.editor.off(".rowReorder"),n.draw(!1)})).one("submitUnsuccessful.rowReorder",(function(){n.draw(!1)})).one("submitSuccess.rowReorder",(function(){f()})).one("submitComplete",(function(){e.c.enable=!0,e.c.editor.off(".rowReorder")})).submit()):f())}else e._cancel()},_moveTargetIntoPosition:function(t){var e,n,r=this.s.dt;null!==this.s.lastInsert&&this.s.lastInsert===t||(e=A.unique(r.rows({page:"current"}).nodes().toArray()),"",n=t>this.s.lastInsert?(this.dom.target.insertAfter(e[t-1]),"after"):(this.dom.target.insertBefore(e[t]),"before"),this._cachePositions(),this.s.lastInsert=t,this._emitEvent("row-reorder-changed",{insertPlacement:n,insertPoint:t,row:r.row(this.dom.target)}))},_cleanupDragging:function(){var t=this.c.cancelable;this.dom.clone.remove(),this.dom.cloneParent.remove(),this.dom.clone=null,this.dom.cloneParent=null,this.dom.target.removeClass("dt-rowReorder-moving"),A(e).off(".rowReorder"),A(e.body).removeClass("dt-rowReorder-noOverflow"),clearInterval(this.s.scrollInterval),this.s.scrollInterval=null,t&&A(e).off("keyup",this._keyup)},_shiftScroll:function(n){var r,i,o=this,s=(this.s.dt,this.s.scroll),a=!1,c=n.pageY-e.body.scrollTop;c<A(t).scrollTop()+65?r=-5:c>s.windowHeight+A(t).scrollTop()-65&&(r=5),null!==s.dtTop&&n.pageY<s.dtTop+65?i=-5:null!==s.dtTop&&n.pageY>s.dtTop+s.dtHeight-65&&(i=5),r||i?(s.windowVert=r,s.dtVert=i,a=!0):this.s.scrollInterval&&(clearInterval(this.s.scrollInterval),this.s.scrollInterval=null),!this.s.scrollInterval&&a&&(this.s.scrollInterval=setInterval((function(){var t;s.windowVert&&(t=A(e).scrollTop(),A(e).scrollTop(t+s.windowVert),t!==A(e).scrollTop()&&(t=parseFloat(o.dom.cloneParent.css("top")),o.dom.cloneParent.css("top",t+s.windowVert))),s.dtVert&&(t=o.dom.dtScroll[0],s.dtVert&&(t.scrollTop+=s.dtVert))}),20))},_calcBodyArea:function(t){var e=this.s.dt,n=A(e.table().body()).offset();return{left:n.left,top:n.top,right:n.left+A(e.table().body()).width(),bottom:n.top+A(e.table().body()).height()}},_calcCloneParentArea:function(t){this.s.dt;var e=A(this.dom.cloneParent).offset();return{left:e.left,top:e.top,right:e.left+A(this.dom.cloneParent).width(),bottom:e.top+A(this.dom.cloneParent).height()}},_rectanglesIntersect:function(A,t){return!(A.left>=t.right||t.left>=A.right||A.top>=t.bottom||t.top>=A.bottom)},_calcRowIndexByPos:function(t){var e=this.s.dt,n=A.unique(e.rows({page:"current"}).nodes().toArray()),r=-1,i=A(e.table().node()).find("thead").outerHeight();return A.each(n,(function(e,n){var o=A(n).position().top-i;n=o+A(n).outerHeight();o<=t&&t<=n&&(r=e)})),r},_keyup:function(A){this.c.cancelable&&27===A.which&&(A.preventDefault(),this._cancel())},_cancel:function(){var A=(A=this.s.start).rowIndex>this.s.lastInsert?A.rowIndex+1:A.rowIndex;this._moveTargetIntoPosition(A),this._cleanupDragging(),this._emitEvent("row-reorder-canceled",[this.s.start.rowIndex])}}),r.defaults={dataSrc:0,editor:null,enable:!0,formOptions:{},selector:"td:first-child",snapX:!1,update:!0,excludedChildren:"a",cancelable:!1},A.fn.dataTable.Api);return o.register("rowReorder()",(function(){return this})),o.register("rowReorder.enable()",(function(A){return A===n&&(A=!0),this.iterator("table",(function(t){t.rowreorder&&(t.rowreorder.c.enable=A)}))})),o.register("rowReorder.disable()",(function(){return this.iterator("table",(function(A){A.rowreorder&&(A.rowreorder.c.enable=!1)}))})),r.version="1.4.1",A.fn.dataTable.RowReorder=r,A.fn.DataTable.RowReorder=r,A(e).on("init.dt.dtr",(function(t,e,n){var o;"dt"===t.namespace&&(t=e.oInit.rowReorder,o=i.defaults.rowReorder,(t||o)&&(o=A.extend({},t,o),!1!==t&&new r(e,o)))})),i})),
/*! Bootstrap 5 styling wrapper for RowReorder
 * © SpryMedia Ltd - datatables.net/license
 */
function(A){if("function"==typeof define&&define.amd)define(["jquery","datatables.net-bs5","datatables.net-rowreorder"],(function(t){return A(t,window,document)}));else if("object"==typeof exports){var t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net-bs5")(A,t),t.fn.dataTable.RowReorder||require("datatables.net-rowreorder")(A,t)};"undefined"==typeof window?module.exports=function(n,r){return n||(n=window),r||(r=t(n)),e(n,r),A(r,n,n.document)}:(e(window,t),module.exports=A(t,window,window.document))}else A(jQuery,window,document)}((function(A,t,e,n){"use strict";return A.fn.dataTable})),function(A){var t,e;"function"==typeof define&&define.amd?define(["jquery","datatables.net"],(function(t){return A(t,window,document)})):"object"==typeof exports?(t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net")(A,t)},"undefined"==typeof window?module.exports=function(n,r){return n=n||window,r=r||t(n),e(n,r),A(r,n,n.document)}:(e(window,t),module.exports=A(t,window,window.document))):A(jQuery,window,document)}((function(A,t,e,n){"use strict";function r(t,i){this instanceof r?(i===n&&(i={}),t=A.fn.dataTable.Api(t),this.s={dt:t.settings()[0],dtApi:t,tableTop:0,tableBottom:0,redrawTop:0,redrawBottom:0,autoHeight:!0,viewportRows:0,stateTO:null,stateSaveThrottle:function(){},drawTO:null,heights:{jump:null,page:null,virtual:null,scroll:null,row:null,viewport:null,labelHeight:0,xbar:0},topRowFloat:0,scrollDrawDiff:null,loaderVisible:!1,forceReposition:!1,baseRowTop:0,baseScrollTop:0,mousedown:!1,lastScrollTop:0},this.s=A.extend(this.s,r.oDefaults,i),this.s.heights.row=this.s.rowHeight,this.dom={force:e.createElement("div"),label:A('<div class="dts_label">0</div>'),scroller:null,table:null,loader:null},this.s.dt.oScroller||(this.s.dt.oScroller=this).construct()):alert("Scroller warning: Scroller must be initialised with the 'new' keyword.")}var i=A.fn.dataTable,o=(A.extend(r.prototype,{measure:function(t){this.s.autoHeight&&this._calcRowHeight();var e=this.s.heights,r=(e.row&&(e.viewport=this._parseHeight(A(this.dom.scroller).css("max-height")),this.s.viewportRows=parseInt(e.viewport/e.row,10)+1,this.s.dt._iDisplayLength=this.s.viewportRows*this.s.displayBuffer),this.dom.label.outerHeight());e.xbar=this.dom.scroller.offsetHeight-this.dom.scroller.clientHeight,e.labelHeight=r,t!==n&&!t||this.s.dt.oInstance.fnDraw(!1)},pageInfo:function(){var A=this.s.dt,t=this.dom.scroller.scrollTop,e=(A=A.fnRecordsDisplay(),Math.ceil(this.pixelsToRow(t+this.s.heights.viewport,!1,this.s.ani)));return{start:Math.floor(this.pixelsToRow(t,!1,this.s.ani)),end:A<e?A-1:e-1}},pixelsToRow:function(A,t,e){return A-=this.s.baseScrollTop,e=e?(this._domain("physicalToVirtual",this.s.baseScrollTop)+A)/this.s.heights.row:A/this.s.heights.row+this.s.baseRowTop,t||t===n?parseInt(e,10):e},rowToPixels:function(A,t,e){return A-=this.s.baseRowTop,e=e?this._domain("virtualToPhysical",this.s.baseScrollTop):this.s.baseScrollTop,e+=A*this.s.heights.row,t||t===n?parseInt(e,10):e},scrollToRow:function(t,e){var r=this,i=!1,o=this.rowToPixels(t),s=t-(this.s.displayBuffer-1)/2*this.s.viewportRows;s<0&&(s=0),(o>this.s.redrawBottom||o<this.s.redrawTop)&&this.s.dt._iDisplayStart!==s&&(i=!0,o=this._domain("virtualToPhysical",t*this.s.heights.row),this.s.redrawTop<o&&o<this.s.redrawBottom&&(e=!(this.s.forceReposition=!0))),e===n||e?(this.s.ani=i,A(this.dom.scroller).animate({scrollTop:o},(function(){setTimeout((function(){r.s.ani=!1}),250)}))):A(this.dom.scroller).scrollTop(o)},construct:function(){var e=this,r=this.s.dtApi;if(!this.s.dt.oFeatures.bPaginate)throw new Error("Pagination must be enabled for Scroller to operate");this.dom.force.style.position="relative",this.dom.force.style.top="0px",this.dom.force.style.left="0px",this.dom.force.style.width="1px",this.dom.scroller=r.table().node().parentNode,this.dom.scroller.appendChild(this.dom.force),this.dom.scroller.style.position="relative",this.dom.table=A(">table",this.dom.scroller)[0],this.dom.table.style.position="absolute",this.dom.table.style.top="0px",this.dom.table.style.left="0px",A(r.table().container()).addClass("dts DTS"),this.dom.label.appendTo(this.dom.scroller),this.s.heights.row&&"auto"!=this.s.heights.row&&(this.s.autoHeight=!1),this.s.ingnoreScroll=!0,A(this.dom.scroller).on("scroll.dt-scroller",(function(A){e._scroll.call(e)})),A(this.dom.scroller).on("touchstart.dt-scroller",(function(){e._scroll.call(e)})),A(this.dom.scroller).on("mousedown.dt-scroller",(function(){e.s.mousedown=!0})).on("mouseup.dt-scroller",(function(){e.s.labelVisible=!1,e.s.mousedown=!1,e.dom.label.css("display","none")})),A(t).on("resize.dt-scroller",(function(){e.measure(!1),e._info()}));var o=!0,s=r.state.loaded();r.on("stateSaveParams.scroller",(function(A,t,n){o&&s?(n.scroller=s.scroller,o=!1,n.scroller&&(e.s.lastScrollTop=n.scroller.scrollTop)):n.scroller={topRow:e.s.topRowFloat,baseScrollTop:e.s.baseScrollTop,baseRowTop:e.s.baseRowTop,scrollTop:e.s.lastScrollTop}})),r.on("stateLoadParams.scroller",(function(A,t,r){r.scroller!==n&&e.scrollToRow(r.scroller.topRow)})),s&&s.scroller&&(this.s.topRowFloat=s.scroller.topRow,this.s.baseScrollTop=s.scroller.baseScrollTop,this.s.baseRowTop=s.scroller.baseRowTop),this.measure(!1),e.s.stateSaveThrottle=i.util.throttle((function(){e.s.dtApi.state.save()}),500),r.on("init.scroller",(function(){e.measure(!1),e.s.scrollType="jump",e._draw(),r.on("draw.scroller",(function(){e._draw()}))})),r.on("preDraw.dt.scroller",(function(){e._scrollForce()})),r.on("destroy.scroller",(function(){A(t).off("resize.dt-scroller"),A(e.dom.scroller).off(".dt-scroller"),A(e.s.dt.nTable).off(".scroller"),A(e.s.dt.nTableWrapper).removeClass("DTS"),A("div.DTS_Loading",e.dom.scroller.parentNode).remove(),e.dom.table.style.position="",e.dom.table.style.top="",e.dom.table.style.left=""}))},_calcRowHeight:function(){var t=(r=this.s.dt).nTable,e=t.cloneNode(!1),n=A("<tbody/>").appendTo(e),r=r.oClasses,o=(r=i.versionCheck("2")?{container:r.container,scroller:r.scrolling.container,body:r.scrolling.body}:{container:r.sWrapper,scroller:r.sScrollWrapper,body:r.sScrollBody},A('<div class="'+r.container+' DTS"><div class="'+r.scroller+'"><div class="'+r.body+'"></div></div></div>')),s=(A("tbody tr:lt(4)",t).clone().appendTo(n),A("tr",n).length);if(1===s)n.prepend("<tr><td>&#160;</td></tr>"),n.append("<tr><td>&#160;</td></tr>");else for(;s<3;s++)n.append("<tr><td>&#160;</td></tr>");A("div."+r.body,o).append(e),r=this.s.dt.nHolding||t.parentNode,A(r).is(":visible")||(r="body"),o.find("input").removeAttr("name"),o.appendTo(r),this.s.heights.row=A("tr",n).eq(1).outerHeight(),o.remove()},_draw:function(){var t=this,e=this.s.heights,n=this.dom.scroller.scrollTop,r=A(this.s.dt.nTable).height(),i=this.s.dt._iDisplayStart,o=this.s.dt._iDisplayLength,s=this.s.dt.fnRecordsDisplay(),a=n+e.viewport,c=(this.s.skip=!0,!this.s.dt.bSorted&&!this.s.dt.bFiltered||0!==i||this.s.dt._drawHold||(this.s.topRowFloat=0),n="jump"===this.s.scrollType?this._domain("virtualToPhysical",this.s.topRowFloat*e.row):n,this.s.baseScrollTop=n,this.s.baseRowTop=this.s.topRowFloat,n-(this.s.topRowFloat-i)*e.row);0===i?c=0:s<=i+o?c=e.scroll-r:c+r<a&&(this.s.baseScrollTop+=(s=a-r)-c+1,c=s),this.dom.table.style.top=c+"px",this.s.tableTop=c,this.s.tableBottom=r+this.s.tableTop,i=(n-this.s.tableTop)*this.s.boundaryScale;this.s.redrawTop=n-i,this.s.redrawBottom=n+i>e.scroll-e.viewport-e.row?e.scroll-e.viewport-e.row:n+i,this.s.skip=!1,t.s.ingnoreScroll&&(this.s.dt.oFeatures.bStateSave&&null!==this.s.dt.oLoadedState&&void 0!==this.s.dt.oLoadedState.scroller?((o=!(!this.s.dt.sAjaxSource&&!t.s.dt.ajax||this.s.dt.oFeatures.bServerSide))&&2<=this.s.dt.iDraw||!o&&1<=this.s.dt.iDraw)&&setTimeout((function(){A(t.dom.scroller).scrollTop(t.s.dt.oLoadedState.scroller.scrollTop),setTimeout((function(){t.s.ingnoreScroll=!1}),0)}),0):t.s.ingnoreScroll=!1),this.s.dt.oFeatures.bInfo&&setTimeout((function(){t._info.call(t)}),0),A(this.s.dt.nTable).triggerHandler("position.dts.dt",c)},_domain:function(A,t){var e,n=this.s.heights,r=1e4;return n.virtual===n.scroll||t<r?t:"virtualToPhysical"===A&&t>=n.virtual-r?(e=n.virtual-t,n.scroll-e):"physicalToVirtual"===A&&t>=n.scroll-r?(e=n.scroll-t,n.virtual-e):(n=r-(e=(n.virtual-r-r)/(n.scroll-r-r))*r,"virtualToPhysical"===A?(t-n)/e:e*t+n)},_info:function(){if(this.s.dt.oFeatures.bInfo){var t,e=this.s.dt,n=this.s.dtApi,r=e.oLanguage,i=(o=n.page.info()).recordsDisplay,o=o.recordsTotal,s=Math.floor(this.s.topRowFloat)+1,a=i<(a=s+Math.floor(this.s.heights.viewport/this.s.heights.row))?i:a,c=((r=(0===i&&i==o?t=r.sInfoEmpty+r.sInfoPostFix:0===i?t=r.sInfoEmpty+" "+r.sInfoFiltered+r.sInfoPostFix:i==o?t=r.sInfo+r.sInfoPostFix:(t=r.sInfo,r.sInfoFiltered,r.sInfoPostFix),t=this._macros(t,s,a,o,i),r.fnInfoCallback))&&(t=r.call(e.oInstance,e,s,a,o,i,t)),e.aanFeatures.i);if(void 0!==c){for(var B=0,g=c.length;B<g;B++)A(c[B]).html(t);A(e.nTable).triggerHandler("info.dt")}A("div.dt-info",n.table().container()).each((function(){A(this).html(t),n.trigger("info",[this,t])}))}},_macros:function(A,t,e,n,r){var i=this.s.dtApi,o=this.s.dt,s=o.fnFormatNumber;return A.replace(/_START_/g,s.call(o,t)).replace(/_END_/g,s.call(o,e)).replace(/_MAX_/g,s.call(o,n)).replace(/_TOTAL_/g,s.call(o,r)).replace(/_ENTRIES_/g,i.i18n("entries","")).replace(/_ENTRIES-MAX_/g,i.i18n("entries","",n)).replace(/_ENTRIES-TOTAL_/g,i.i18n("entries","",r))},_parseHeight:function(e){var n,r;return null!==(e=/^([+-]?(?:\d+(?:\.\d+)?|\.\d+))(px|em|rem|vh)$/.exec(e))&&(r=parseFloat(e[1]),"px"===(e=e[2])?n=r:"vh"===e?n=r/100*A(t).height():"rem"===e?n=r*parseFloat(A(":root").css("font-size")):"em"===e&&(n=r*parseFloat(A("body").css("font-size"))),n)||0},_scroll:function(){var t,e=this,n=this.s.heights,r=this.dom.scroller.scrollTop;this.s.skip||this.s.ingnoreScroll||r!==this.s.lastScrollTop&&(this.s.dt.bFiltered||this.s.dt.bSorted?this.s.lastScrollTop=0:(clearTimeout(this.s.stateTO),this.s.stateTO=setTimeout((function(){e.s.dtApi.state.save()}),250),this.s.scrollType=Math.abs(r-this.s.lastScrollTop)>n.viewport?"jump":"cont",this.s.topRowFloat="cont"===this.s.scrollType?this.pixelsToRow(r,!1,!1):this._domain("physicalToVirtual",r)/n.row,this.s.topRowFloat<0&&(this.s.topRowFloat=0),this.s.forceReposition||r<this.s.redrawTop||r>this.s.redrawBottom?(t=Math.ceil((this.s.displayBuffer-1)/2*this.s.viewportRows),t=parseInt(this.s.topRowFloat,10)-t,this.s.forceReposition=!1,t<=0?t=0:t+this.s.dt._iDisplayLength>this.s.dt.fnRecordsDisplay()?(t=this.s.dt.fnRecordsDisplay()-this.s.dt._iDisplayLength)<0&&(t=0):t%2!=0&&t++,(this.s.targetTop=t)!=this.s.dt._iDisplayStart&&(this.s.tableTop=A(this.s.dt.nTable).offset().top,this.s.tableBottom=A(this.s.dt.nTable).height()+this.s.tableTop,t=function(){e.s.dt._iDisplayStart=e.s.targetTop,e.s.dtApi.draw("page")},this.s.dt.oFeatures.bServerSide?(this.s.forceReposition=!0,A(this.s.dt.nTable).triggerHandler("scroller-will-draw.dt"),i.versionCheck("2")?e.s.dtApi.processing(!0):this.s.dt.oApi._fnProcessingDisplay(this.s.dt,!0),clearTimeout(this.s.drawTO),this.s.drawTO=setTimeout(t,this.s.serverWait)):t())):this.s.topRowFloat=this.pixelsToRow(r,!1,!0),this._info(),this.s.lastScrollTop=r,this.s.stateSaveThrottle(),"jump"===this.s.scrollType&&this.s.mousedown&&(this.s.labelVisible=!0),this.s.labelVisible&&(t=(n.viewport-n.labelHeight-n.xbar)/n.scroll,this.dom.label.html(this.s.dt.fnFormatNumber(parseInt(this.s.topRowFloat,10)+1)).css("top",r+r*t).css("display","block"))))},_scrollForce:function(){var A=this.s.heights;A.virtual=A.row*this.s.dt.fnRecordsDisplay(),A.scroll=A.virtual,1e6<A.scroll&&(A.scroll=1e6),this.dom.force.style.height=A.scroll>this.s.heights.row?A.scroll+"px":this.s.heights.row+"px"}}),r.oDefaults=r.defaults={boundaryScale:.5,displayBuffer:9,rowHeight:"auto",serverWait:200},r.version="2.3.0",A(e).on("preInit.dt.dtscroller",(function(t,e){var n;"dt"===t.namespace&&(t=e.oInit.scroller,n=i.defaults.scroller,(t||n)&&(n=A.extend({},t,n),!1!==t&&new r(e,n)))})),A.fn.dataTable.Scroller=r,A.fn.DataTable.Scroller=r,A.fn.dataTable.Api);return o.register("scroller()",(function(){return this})),o.register("scroller().rowToPixels()",(function(A,t,e){var n=this.context;if(n.length&&n[0].oScroller)return n[0].oScroller.rowToPixels(A,t,e)})),o.register("scroller().pixelsToRow()",(function(A,t,e){var n=this.context;if(n.length&&n[0].oScroller)return n[0].oScroller.pixelsToRow(A,t,e)})),o.register(["scroller().scrollToRow()","scroller.toPosition()"],(function(A,t){return this.iterator("table",(function(e){e.oScroller&&e.oScroller.scrollToRow(A,t)})),this})),o.register("row().scrollTo()",(function(A){var t=this;return this.iterator("row",(function(e,n){e.oScroller&&(n=t.rows({order:"applied",search:"applied"}).indexes().indexOf(n),e.oScroller.scrollToRow(n,A))})),this})),o.register("scroller.measure()",(function(A){return this.iterator("table",(function(t){t.oScroller&&t.oScroller.measure(A)})),this})),o.register("scroller.page()",(function(){var A=this.context;if(A.length&&A[0].oScroller)return A[0].oScroller.pageInfo()})),i})),function(A){var t,e;"function"==typeof define&&define.amd?define(["jquery","datatables.net"],(function(t){return A(t,window,document)})):"object"==typeof exports?(t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net")(A,t)},"undefined"==typeof window?module.exports=function(n,r){return n=n||window,r=r||t(n),e(n,r),A(r,n,n.document)}:(e(window,t),module.exports=A(t,window,window.document))):A(jQuery,window,document)}((function(A,t,e,n){"use strict";var r=A.fn.dataTable;function i(A,t,e){function n(t,e){e<t&&(n=e,e=t,t=n);var n,r=!1;return A.columns(":visible").indexes().filter((function(A){return A===t&&(r=!0),A===e?!(r=!1):r}))}function r(t,e){var n,r=A.rows({search:"applied"}).indexes(),i=(r.indexOf(t)>r.indexOf(e)&&(n=e,e=t,t=n),!1);return r.filter((function(A){return A===t&&(i=!0),A===e?!(i=!1):i}))}var i;e=A.cells({selected:!0}).any()||e?(i=n(e.column,t.column),r(e.row,t.row)):(i=n(0,t.column),r(0,t.row)),e=A.cells(e,i).flatten();A.cells(t,{selected:!0}).any()?A.cells(e).deselect():A.cells(e).select()}function o(t){var e=t.settings()[0]._select.selector;A(t.table().container()).off("mousedown.dtSelect",e).off("mouseup.dtSelect",e).off("click.dtSelect",e),A("body").off("click.dtSelect"+l(t.table().node()))}function s(e){var n,r=A(e.table().container()),i=e.settings()[0],o=i._select.selector;r.on("mousedown.dtSelect",o,(function(A){(A.shiftKey||A.metaKey||A.ctrlKey)&&r.css("-moz-user-select","none").one("selectstart.dtSelect",o,(function(){return!1})),t.getSelection&&(n=t.getSelection())})).on("mouseup.dtSelect",o,(function(){r.css("-moz-user-select","")})).on("click.dtSelect",o,(function(r){var i,o=e.select.items();if(n&&((!(c=t.getSelection()).anchorNode||A(c.anchorNode).closest("table")[0]===e.table().node())&&c!==n))return;var s,c=e.settings()[0],B=e.settings()[0].oClasses.sWrapper.trim().replace(/ +/g,".");A(r.target).closest("div."+B)[0]==e.table().container()&&(B=e.cell(A(r.target).closest("td, th"))).any()&&(s=A.Event("user-select.dt"),a(e,s,[o,B,r]),s.isDefaultPrevented()||(s=B.index(),"row"===o?(i=s.row,g(r,e,c,"row",i)):"column"===o?(i=B.index().column,g(r,e,c,"column",i)):"cell"===o&&(i=B.index(),g(r,e,c,"cell",i)),c._select_lastCell=s))})),A("body").on("click.dtSelect"+l(e.table().node()),(function(t){var n;!i._select.blurable||A(t.target).parents().filter(e.table().container()).length||0===A(t.target).parents("html").length||A(t.target).parents("div.DTE").length||(n=A.Event("select-blur.dt"),a(e,n,[t.target,t]),n.isDefaultPrevented()||B(i,!0))}))}function a(t,e,n,r){r&&!t.flatten().length||("string"==typeof e&&(e+=".dt"),n.unshift(t),A(t.table().node()).trigger(e,n))}function c(t,e,n,r){var i,o=t[e+"s"]({search:"applied"}).indexes(),s=(r=A.inArray(r,o),A.inArray(n,o));t[e+"s"]({selected:!0}).any()||-1!==r?(s<r&&(i=s,s=r,r=i),o.splice(s+1,o.length),o.splice(0,r)):o.splice(A.inArray(n,o)+1,o.length),t[e](n,{selected:!0}).any()?(o.splice(A.inArray(n,o),1),t[e+"s"](o).deselect()):t[e+"s"](o).select()}function B(A,t){!t&&"single"!==A._select.style||((t=new r.Api(A)).rows({selected:!0}).deselect(),t.columns({selected:!0}).deselect(),t.cells({selected:!0}).deselect())}function g(A,t,e,n,r){var o=t.select.style(),s=t.select.toggleable(),a=t[n](r,{selected:!0}).any();a&&!s||("os"===o?A.ctrlKey||A.metaKey?t[n](r).select(!a):A.shiftKey?"cell"===n?i(t,r,e._select_lastCell||null):c(t,n,r,e._select_lastCell?e._select_lastCell[n]:null):(s=t[n+"s"]({selected:!0}),a&&1===s.flatten().length?t[n](r).deselect():(s.deselect(),t[n](r).select())):"multi+shift"==o&&A.shiftKey?"cell"===n?i(t,r,e._select_lastCell||null):c(t,n,r,e._select_lastCell?e._select_lastCell[n]:null):t[n](r).select(!a))}function l(A){return A.id.replace(/[^a-zA-Z0-9\-\_]/g,"-")}r.select={},r.select.version="1.7.0",r.select.init=function(t){var e,i,o,s,a,c,B,g,l,u,w,h=t.settings()[0];h._select||(e=t.state.loaded(),i=function(A,e,r){if(null!==r&&r.select!==n){if(t.rows({selected:!0}).any()&&t.rows().deselect(),r.select.rows!==n&&t.rows(r.select.rows).select(),t.columns({selected:!0}).any()&&t.columns().deselect(),r.select.columns!==n&&t.columns(r.select.columns).select(),t.cells({selected:!0}).any()&&t.cells().deselect(),r.select.cells!==n)for(var i=0;i<r.select.cells.length;i++)t.cell(r.select.cells[i].row,r.select.cells[i].column).select();t.state.save()}},t.on("stateSaveParams",(function(A,e,n){n.select={},n.select.rows=t.rows({selected:!0}).ids(!0).toArray(),n.select.columns=t.columns({selected:!0})[0],n.select.cells=t.cells({selected:!0})[0].map((function(A){return{row:t.row(A.row).id(!0),column:A.column}}))})).on("stateLoadParams",i).one("init",(function(){i(0,0,e)})),s=h.oInit.select,o=r.defaults.select,o=s===n?o:s,s="row",g=B=!(c=!(a="api")),l="td, th",w=!(u="selected"),h._select={},!0===o?(a="os",w=!0):"string"==typeof o?(a=o,w=!0):A.isPlainObject(o)&&(o.blurable!==n&&(c=o.blurable),o.toggleable!==n&&(B=o.toggleable),o.info!==n&&(g=o.info),o.items!==n&&(s=o.items),a=o.style!==n?o.style:"os",w=!0,o.selector!==n&&(l=o.selector),o.className!==n&&(u=o.className)),t.select.selector(l),t.select.items(s),t.select.style(a),t.select.blurable(c),t.select.toggleable(B),t.select.info(g),h._select.className=u,A.fn.dataTable.ext.order["select-checkbox"]=function(t,e){return this.api().column(e,{order:"index"}).nodes().map((function(e){return"row"===t._select.items?A(e).parent().hasClass(t._select.className):"cell"===t._select.items&&A(e).hasClass(t._select.className)}))},!w&&A(t.table().node()).hasClass("selectable")&&t.select.style("os"))},A.each([{type:"row",prop:"aoData"},{type:"column",prop:"aoColumns"}],(function(A,t){r.ext.selector[t.type].push((function(A,e,n){var r,i=e.selected,o=[];if(!0!==i&&!1!==i)return n;for(var s=0,a=n.length;s<a;s++)r=A[t.prop][n[s]],(!0===i&&!0===r._select_selected||!1===i&&!r._select_selected)&&o.push(n[s]);return o}))})),r.ext.selector.cell.push((function(A,t,e){var r,i=t.selected,o=[];if(i===n)return e;for(var s=0,a=e.length;s<a;s++)r=A.aoData[e[s].row],(!0!==i||!r._selected_cells||!0!==r._selected_cells[e[s].column])&&(!1!==i||r._selected_cells&&r._selected_cells[e[s].column])||o.push(e[s]);return o}));var u=r.Api.register,w=r.Api.registerPlural;function h(A,t){return function(e){return e.i18n("buttons."+A,t)}}function E(A){return"draw.dt.DT"+(A=A._eventNamespace)+" select.dt.DT"+A+" deselect.dt.DT"+A}u("select()",(function(){return this.iterator("table",(function(A){r.select.init(new r.Api(A))}))})),u("select.blurable()",(function(A){return A===n?this.context[0]._select.blurable:this.iterator("table",(function(t){t._select.blurable=A}))})),u("select.toggleable()",(function(A){return A===n?this.context[0]._select.toggleable:this.iterator("table",(function(t){t._select.toggleable=A}))})),u("select.info()",(function(A){return A===n?this.context[0]._select.info:this.iterator("table",(function(t){t._select.info=A}))})),u("select.items()",(function(A){return A===n?this.context[0]._select.items:this.iterator("table",(function(t){t._select.items=A,a(new r.Api(t),"selectItems",[A])}))})),u("select.style()",(function(t){return t===n?this.context[0]._select.style:this.iterator("table",(function(e){e._select||r.select.init(new r.Api(e)),e._select_init||function(t){var e=new r.Api(t);t._select_init=!0,t.aoRowCreatedCallback.push({fn:function(e,n,r){var i,o,s=t.aoData[r];for(s._select_selected&&A(e).addClass(t._select.className),i=0,o=t.aoColumns.length;i<o;i++)(t.aoColumns[i]._select_selected||s._selected_cells&&s._selected_cells[i])&&A(s.anCells[i]).addClass(t._select.className)},sName:"select-deferRender"}),e.on("preXhr.dt.dtSelect",(function(A,t){var r,i;t===e.settings()[0]&&(r=e.rows({selected:!0}).ids(!0).filter((function(A){return A!==n})),i=e.cells({selected:!0}).eq(0).map((function(A){var t=e.row(A.row).id(!0);return t?{row:t,column:A.column}:n})).filter((function(A){return A!==n})),e.one("draw.dt.dtSelect",(function(){e.rows(r).select(),i.any()&&i.each((function(A){e.cells(A.row,A.column).select()}))})))})),e.on("draw.dtSelect.dt select.dtSelect.dt deselect.dtSelect.dt info.dt",(function(){var t,n,r,i,o,s;(s=(t=e).settings()[0])._select.info&&s.aanFeatures.i&&"api"!==t.select.style()&&(n=t.rows({selected:!0}).flatten().length,r=t.columns({selected:!0}).flatten().length,i=t.cells({selected:!0}).flatten().length,o=function(e,n,r){e.append(A('<span class="select-item"/>').append(t.i18n("select."+n+"s",{_:"%d "+n+"s selected",0:"",1:"1 "+n+" selected"},r)))},A.each(s.aanFeatures.i,(function(t,e){e=A(e);var s=A('<span class="select-info"/>'),a=(o(s,"row",n),o(s,"column",r),o(s,"cell",i),e.children("span.select-info"));a.length&&a.remove(),""!==s.text()&&e.append(s)}))),e.state.save()})),e.on("destroy.dtSelect",(function(){A(e.rows({selected:!0}).nodes()).removeClass(e.settings()[0]._select.className),o(e),e.off(".dtSelect"),A("body").off(".dtSelect"+l(e.table().node()))}))}(e),e._select.style=t;var i=new r.Api(e);o(i),"api"!==t&&s(i),a(new r.Api(e),"selectStyle",[t])}))})),u("select.selector()",(function(A){return A===n?this.context[0]._select.selector:this.iterator("table",(function(t){o(new r.Api(t)),t._select.selector=A,"api"!==t._select.style&&s(new r.Api(t))}))})),w("rows().select()","row().select()",(function(t){var e=this;return!1===t?this.deselect():(this.iterator("row",(function(t,e){B(t),t.aoData[e]._select_selected=!0,A(t.aoData[e].nTr).addClass(t._select.className)})),this.iterator("table",(function(A,t){a(e,"select",["row",e[t]],!0)})),this)})),u("row().selected()",(function(){var A=this.context[0];return!!(A&&this.length&&A.aoData[this[0]]&&A.aoData[this[0]]._select_selected)})),w("columns().select()","column().select()",(function(t){var e=this;return!1===t?this.deselect():(this.iterator("column",(function(t,e){B(t),t.aoColumns[e]._select_selected=!0,e=new r.Api(t).column(e),A(e.header()).addClass(t._select.className),A(e.footer()).addClass(t._select.className),e.nodes().to$().addClass(t._select.className)})),this.iterator("table",(function(A,t){a(e,"select",["column",e[t]],!0)})),this)})),u("column().selected()",(function(){var A=this.context[0];return!!(A&&this.length&&A.aoColumns[this[0]]&&A.aoColumns[this[0]]._select_selected)})),w("cells().select()","cell().select()",(function(t){var e=this;return!1===t?this.deselect():(this.iterator("cell",(function(t,e,r){B(t),(e=t.aoData[e])._selected_cells===n&&(e._selected_cells=[]),e._selected_cells[r]=!0,e.anCells&&A(e.anCells[r]).addClass(t._select.className)})),this.iterator("table",(function(A,t){a(e,"select",["cell",e.cells(e[t]).indexes().toArray()],!0)})),this)})),u("cell().selected()",(function(){var A=this.context[0];return!!(A&&this.length&&(A=A.aoData[this[0][0].row])&&A._selected_cells&&A._selected_cells[this[0][0].column])})),w("rows().deselect()","row().deselect()",(function(){var t=this;return this.iterator("row",(function(t,e){t.aoData[e]._select_selected=!1,t._select_lastCell=null,A(t.aoData[e].nTr).removeClass(t._select.className)})),this.iterator("table",(function(A,e){a(t,"deselect",["row",t[e]],!0)})),this})),w("columns().deselect()","column().deselect()",(function(){var t=this;return this.iterator("column",(function(t,e){t.aoColumns[e]._select_selected=!1;var n=new r.Api(t),i=n.column(e);A(i.header()).removeClass(t._select.className),A(i.footer()).removeClass(t._select.className),n.cells(null,e).indexes().each((function(e){var n=t.aoData[e.row],r=n._selected_cells;!n.anCells||r&&r[e.column]||A(n.anCells[e.column]).removeClass(t._select.className)}))})),this.iterator("table",(function(A,e){a(t,"deselect",["column",t[e]],!0)})),this})),w("cells().deselect()","cell().deselect()",(function(){var t=this;return this.iterator("cell",(function(t,e,r){(e=t.aoData[e])._selected_cells!==n&&(e._selected_cells[r]=!1),e.anCells&&!t.aoColumns[r]._select_selected&&A(e.anCells[r]).removeClass(t._select.className)})),this.iterator("table",(function(A,e){a(t,"deselect",["cell",t[e]],!0)})),this}));var f=0;return A.extend(r.ext.buttons,{selected:{text:h("selected","Selected"),className:"buttons-selected",limitTo:["rows","columns","cells"],init:function(t,e,n){var r=this;n._eventNamespace=".select"+f++,t.on(E(n),(function(){var e,i;r.enable((e=t,i=n,!(-1===A.inArray("rows",i.limitTo)||!e.rows({selected:!0}).any())||!(-1===A.inArray("columns",i.limitTo)||!e.columns({selected:!0}).any())||!(-1===A.inArray("cells",i.limitTo)||!e.cells({selected:!0}).any())))})),this.disable()},destroy:function(A,t,e){A.off(e._eventNamespace)}},selectedSingle:{text:h("selectedSingle","Selected single"),className:"buttons-selected-single",init:function(A,t,e){var n=this;e._eventNamespace=".select"+f++,A.on(E(e),(function(){var t=A.rows({selected:!0}).flatten().length+A.columns({selected:!0}).flatten().length+A.cells({selected:!0}).flatten().length;n.enable(1===t)})),this.disable()},destroy:function(A,t,e){A.off(e._eventNamespace)}},selectAll:{text:h("selectAll","Select all"),className:"buttons-select-all",action:function(A,t,e,n){var r=this.select.items(),i=n.selectorModifier;(i?("function"==typeof i&&(i=i.call(t,A,t,e,n)),this[r+"s"](i)):this[r+"s"]()).select()}},selectNone:{text:h("selectNone","Deselect all"),className:"buttons-select-none",action:function(){B(this.settings()[0],!0)},init:function(A,t,e){var n=this;e._eventNamespace=".select"+f++,A.on(E(e),(function(){var t=A.rows({selected:!0}).flatten().length+A.columns({selected:!0}).flatten().length+A.cells({selected:!0}).flatten().length;n.enable(0<t)})),this.disable()},destroy:function(A,t,e){A.off(e._eventNamespace)}},showSelected:{text:h("showSelected","Show only selected"),className:"buttons-show-selected",action:function(A,t,e,n){var i;n._filter?(-1!==(i=r.ext.search.indexOf(n._filter))&&(r.ext.search.splice(i,1),n._filter=null),this.active(!1)):(n._filter=i=function(A,e,n){return A!==t.settings()[0]||A.aoData[n]._select_selected},r.ext.search.push(i),this.active(!0)),t.draw()}}}),A.each(["Row","Column","Cell"],(function(A,t){var e=t.toLowerCase();r.ext.buttons["select"+t+"s"]={text:h("select"+t+"s","Select "+e+"s"),className:"buttons-select-"+e+"s",action:function(){this.select.items(e)},init:function(A){var t=this;A.on("selectItems.dt.DT",(function(A,n,r){t.active(r===e)}))}}})),A.fn.DataTable.select=r.select,A(e).on("preInit.dt.dtSelect",(function(A,t){"dt"===A.namespace&&r.select.init(new r.Api(t))})),r})),function(A){var t;"function"==typeof define&&define.amd?define(["jquery"],(function(t){return A(t,window,document)})):"object"==typeof exports?(t=require("jquery"),"undefined"==typeof window?module.exports=function(e,n){return e=e||window,n=n||t(e),A(n,e,e.document)}:module.exports=A(t,window,window.document)):A(jQuery,window,document)}((function(A,t,e,n){"use strict";function r(e,n){if(r.factory(e,n))return r;if(void 0===i&&(i=t.moment||t.dayjs||t.luxon||null),this.c=A.extend(!0,{},r.defaults,n),n=this.c.classPrefix,this.c.i18n,!i&&"YYYY-MM-DD"!==this.c.format)throw"DateTime: Without momentjs, dayjs or luxon only the format 'YYYY-MM-DD' can be used";"string"==typeof this.c.minDate&&(this.c.minDate=new Date(this.c.minDate)),"string"==typeof this.c.maxDate&&(this.c.maxDate=new Date(this.c.maxDate));var o=A('<div class="'+n+'"><div class="'+n+'-date"><div class="'+n+'-title"><div class="'+n+'-iconLeft"><button type="button"></button></div><div class="'+n+'-iconRight"><button type="button"></button></div><div class="'+n+'-label"><span></span><select class="'+n+'-month"></select></div><div class="'+n+'-label"><span></span><select class="'+n+'-year"></select></div></div><div class="'+n+'-buttons"><a class="'+n+'-clear"></a><a class="'+n+'-today"></a></div><div class="'+n+'-calendar"></div></div><div class="'+n+'-time"><div class="'+n+'-hours"></div><div class="'+n+'-minutes"></div><div class="'+n+'-seconds"></div></div><div class="'+n+'-error"></div></div>');this.dom={container:o,date:o.find("."+n+"-date"),title:o.find("."+n+"-title"),calendar:o.find("."+n+"-calendar"),time:o.find("."+n+"-time"),error:o.find("."+n+"-error"),buttons:o.find("."+n+"-buttons"),clear:o.find("."+n+"-clear"),today:o.find("."+n+"-today"),previous:o.find("."+n+"-iconLeft"),next:o.find("."+n+"-iconRight"),input:A(e)},this.s={d:null,display:null,minutesRange:null,secondsRange:null,namespace:"dateime-"+r._instance++,parts:{date:null!==this.c.format.match(/[YMD]|L(?!T)|l/),time:null!==this.c.format.match(/[Hhm]|LT|LTS/),seconds:-1!==this.c.format.indexOf("s"),hours12:null!==this.c.format.match(/[haA]/)}},this.dom.container.append(this.dom.date).append(this.dom.time).append(this.dom.error),this.dom.date.append(this.dom.title).append(this.dom.buttons).append(this.dom.calendar),this.dom.input.addClass("dt-datetime"),this._constructor()}var i;return A.extend(r.prototype,{destroy:function(){this._hide(!0),this.dom.container.off().empty(),this.dom.input.removeClass("dt-datetime").removeAttr("autocomplete").off(".datetime")},display:function(A,t){return A!==n&&this.s.display.setUTCFullYear(A),t!==n&&this.s.display.setUTCMonth(t-1),A!==n||t!==n?(this._setTitle(),this._setCalander(),this):{month:this.s.display.getUTCMonth()+1,year:this.s.display.getUTCFullYear()}},errorMsg:function(A){var t=this.dom.error;return A?t.html(A):t.empty(),this},hide:function(){return this._hide(),this},max:function(A){return this.c.maxDate="string"==typeof A?new Date(A):A,this._optionsTitle(),this._setCalander(),this},min:function(A){return this.c.minDate="string"==typeof A?new Date(A):A,this._optionsTitle(),this._setCalander(),this},owns:function(t){return 0<A(t).parents().filter(this.dom.container).length},val:function(A,t){return A===n?this.s.d:(A instanceof Date?this.s.d=this._dateToUtc(A):null===A||""===A?this.s.d=null:"--now"===A?this.s.d=this._dateToUtc(new Date):"string"==typeof A&&(this.s.d=this._dateToUtc(this._convert(A,this.c.format,null))),!t&&t!==n||(this.s.d?this._writeOutput():this.dom.input.val(A)),this.s.display=this.s.d?new Date(this.s.d.toString()):new Date,this.s.display.setUTCDate(1),this._setTitle(),this._setCalander(),this._setTime(),this)},valFormat:function(A,t){return t?(this.val(this._convert(t,A,null)),this):this._convert(this.val(),null,A)},_constructor:function(){function t(){var A=n.dom.input.val();A!==i&&(n.c.onChange.call(n,A,n.s.d,n.dom.input),i=A)}var n=this,r=this.c.classPrefix,i=this.dom.input.val();this.s.parts.date||this.dom.date.css("display","none"),this.s.parts.time||this.dom.time.css("display","none"),this.s.parts.seconds||(this.dom.time.children("div."+r+"-seconds").remove(),this.dom.time.children("span").eq(1).remove()),this.c.buttons.clear||this.dom.clear.css("display","none"),this.c.buttons.today||this.dom.today.css("display","none"),this._optionsTitle(),A(e).on("i18n.dt",(function(t,e){e.oLanguage.datetime&&(A.extend(!0,n.c.i18n,e.oLanguage.datetime),n._optionsTitle())})),"hidden"===this.dom.input.attr("type")&&(this.dom.container.addClass("inline"),this.c.attachTo="input",this.val(this.dom.input.val(),!1),this._show()),i&&this.val(i,!1),this.dom.input.attr("autocomplete","off").on("focus.datetime click.datetime",(function(){n.dom.container.is(":visible")||n.dom.input.is(":disabled")||(n.val(n.dom.input.val(),!1),n._show())})).on("keyup.datetime",(function(){n.dom.container.is(":visible")&&n.val(n.dom.input.val(),!1)})),this.dom.container.on("change","select",(function(){var e,i,o=A(this),s=o.val();o.hasClass(r+"-month")?(n._correctMonth(n.s.display,s),n._setTitle(),n._setCalander()):o.hasClass(r+"-year")?(n.s.display.setUTCFullYear(s),n._setTitle(),n._setCalander()):o.hasClass(r+"-hours")||o.hasClass(r+"-ampm")?(n.s.parts.hours12?(e=+A(n.dom.container).find("."+r+"-hours").val(),i="pm"===A(n.dom.container).find("."+r+"-ampm").val(),n.s.d.setUTCHours(12!=e||i?i&&12!=e?12+e:e:0)):n.s.d.setUTCHours(s),n._setTime(),n._writeOutput(!0),t()):o.hasClass(r+"-minutes")?(n.s.d.setUTCMinutes(s),n._setTime(),n._writeOutput(!0),t()):o.hasClass(r+"-seconds")&&(n.s.d.setSeconds(s),n._setTime(),n._writeOutput(!0),t()),n.dom.input.focus(),n._position()})).on("click",(function(e){var i=n.s.d,o=(s="span"===e.target.nodeName.toLowerCase()?e.target.parentNode:e.target).nodeName.toLowerCase();if("select"!==o)if(e.stopPropagation(),"a"===o&&(e.preventDefault(),A(s).hasClass(r+"-clear")?(n.s.d=null,n.dom.input.val(""),n._writeOutput(),n._setCalander(),n._setTime(),t()):A(s).hasClass(r+"-today")&&(n.s.display=new Date,n._setTitle(),n._setCalander())),"button"===o)if((o=(e=A(s)).parent()).hasClass("disabled")&&!o.hasClass("range"))e.blur();else if(o.hasClass(r+"-iconLeft"))n.s.display.setUTCMonth(n.s.display.getUTCMonth()-1),n._setTitle(),n._setCalander(),n.dom.input.focus();else if(o.hasClass(r+"-iconRight"))n._correctMonth(n.s.display,n.s.display.getUTCMonth()+1),n._setTitle(),n._setCalander(),n.dom.input.focus();else{if(e.parents("."+r+"-time").length){var s=e.data("value"),a=e.data("unit");i=n._needValue();if("minutes"===a){if(o.hasClass("disabled")&&o.hasClass("range"))return n.s.minutesRange=s,void n._setTime();n.s.minutesRange=null}if("seconds"===a){if(o.hasClass("disabled")&&o.hasClass("range"))return n.s.secondsRange=s,void n._setTime();n.s.secondsRange=null}if("am"===s){if(!(12<=i.getUTCHours()))return;s=i.getUTCHours()-12}else if("pm"===s){if(!(i.getUTCHours()<12))return;s=i.getUTCHours()+12}i["hours"===a?"setUTCHours":"minutes"===a?"setUTCMinutes":"setSeconds"](s),n._setCalander(),n._setTime(),n._writeOutput(!0)}else(i=n._needValue()).setUTCDate(1),i.setUTCFullYear(e.data("year")),i.setUTCMonth(e.data("month")),i.setUTCDate(e.data("day")),n._writeOutput(!0),n.s.parts.time?(n._setCalander(),n._setTime()):setTimeout((function(){n._hide()}),10);t()}else n.dom.input.focus()}))},_compareDates:function(A,t){return this._isLuxon()?i.DateTime.fromJSDate(A).toUTC().toISODate()===i.DateTime.fromJSDate(t).toUTC().toISODate():this._dateToUtcString(A)===this._dateToUtcString(t)},_convert:function(A,t,e){var r;return A&&(i?this._isLuxon()?(r=A instanceof Date?i.DateTime.fromJSDate(A).toUTC():i.DateTime.fromFormat(A,t)).isValid?e?r.toFormat(e):r.toJSDate():null:(r=A instanceof Date?i.utc(A,n,this.c.locale,this.c.strict):i(A,t,this.c.locale,this.c.strict)).isValid()?e?r.format(e):r.toDate():null:!t&&!e||t&&e?A:t?(r=A.match(/(\d{4})\-(\d{2})\-(\d{2})/))?new Date(r[1],r[2]-1,r[3]):null:A.getUTCFullYear()+"-"+this._pad(A.getUTCMonth()+1)+"-"+this._pad(A.getUTCDate()))},_correctMonth:function(A,t){var e=this._daysInMonth(A.getUTCFullYear(),t),n=A.getUTCDate()>e;A.setUTCMonth(t),n&&(A.setUTCDate(e),A.setUTCMonth(t))},_daysInMonth:function(A,t){return[31,A%4!=0||A%100==0&&A%400!=0?28:29,31,30,31,30,31,31,30,31,30,31][t]},_dateToUtc:function(A){return A&&new Date(Date.UTC(A.getFullYear(),A.getMonth(),A.getDate(),A.getHours(),A.getMinutes(),A.getSeconds()))},_dateToUtcString:function(A){return this._isLuxon()?i.DateTime.fromJSDate(A).toUTC().toISODate():A.getUTCFullYear()+"-"+this._pad(A.getUTCMonth()+1)+"-"+this._pad(A.getUTCDate())},_hide:function(n){!n&&"hidden"===this.dom.input.attr("type")||(n=this.s.namespace,this.dom.container.detach(),A(t).off("."+n),A(e).off("keydown."+n),A("div.dataTables_scrollBody").off("scroll."+n),A("div.DTE_Body_Content").off("scroll."+n),A("body").off("click."+n),A(this.dom.input[0].offsetParent).off("."+n))},_hours24To12:function(A){return 0===A?12:12<A?A-12:A},_htmlDay:function(A){var t,e;return A.empty?'<td class="empty"></td>':(t=["selectable"],e=this.c.classPrefix,A.disabled&&t.push("disabled"),A.today&&t.push("now"),A.selected&&t.push("selected"),'<td data-day="'+A.day+'" class="'+t.join(" ")+'"><button class="'+e+"-button "+e+'-day" type="button" data-year="'+A.year+'" data-month="'+A.month+'" data-day="'+A.day+'"><span>'+A.day+"</span></button></td>")},_htmlMonth:function(t,e){for(var n=this._dateToUtc(new Date),r=this._daysInMonth(t,e),i=new Date(Date.UTC(t,e,1)).getUTCDay(),o=[],s=[],a=(0<this.c.firstDay&&(i-=this.c.firstDay)<0&&(i+=7),r+i),c=a;7<c;)c-=7;a+=7-c;var B=this.c.minDate,g=this.c.maxDate;B&&(B.setUTCHours(0),B.setUTCMinutes(0),B.setSeconds(0)),g&&(g.setUTCHours(23),g.setUTCMinutes(59),g.setSeconds(59));for(var l=0,u=0;l<a;l++){var w=new Date(Date.UTC(t,e,l-i+1)),h=!!this.s.d&&this._compareDates(w,this.s.d),E=this._compareDates(w,n),f=l<i||r+i<=l,Q=B&&w<B||g&&g<w,d=this.c.disableDays;h={day:l-i+1,month:e,year:t,selected:h,today:E,disabled:Q=!!(Array.isArray(d)&&-1!==A.inArray(w.getUTCDay(),d)||"function"==typeof d&&!0===d(w))||Q,empty:f};s.push(this._htmlDay(h)),7==++u&&(this.c.showWeekNumber&&s.unshift(this._htmlWeekOfYear(l-i,e,t)),o.push("<tr>"+s.join("")+"</tr>"),s=[],u=0)}var C,M=this.c.classPrefix,I=M+"-table";return this.c.showWeekNumber&&(I+=" weekNumber"),B&&(C=B>=new Date(Date.UTC(t,e,1,0,0,0)),this.dom.title.find("div."+M+"-iconLeft").css("display",C?"none":"block")),g&&(C=g<new Date(Date.UTC(t,e+1,1,0,0,0)),this.dom.title.find("div."+M+"-iconRight").css("display",C?"none":"block")),'<table class="'+I+'"><thead>'+this._htmlMonthHead()+"</thead><tbody>"+o.join("")+"</tbody></table>"},_htmlMonthHead:function(){var A=[],t=this.c.firstDay,e=this.c.i18n;this.c.showWeekNumber&&A.push("<th></th>");for(var n=0;n<7;n++)A.push("<th>"+function(A){for(A+=t;7<=A;)A-=7;return e.weekdays[A]}(n)+"</th>");return A.join("")},_htmlWeekOfYear:function(A,t,e){return(t=new Date(e,t,A,0,0,0,0)).setDate(t.getDate()+4-(t.getDay()||7)),A=new Date(e,0,1),e=Math.ceil(((t-A)/864e5+1)/7),'<td class="'+this.c.classPrefix+'-week">'+e+"</td>"},_isLuxon:function(){return!!(i&&i.DateTime&&i.Duration&&i.Settings)},_needValue:function(){return this.s.d||(this.s.d=this._dateToUtc(new Date),this.s.parts.time)||(this.s.d.setUTCHours(0),this.s.d.setUTCMinutes(0),this.s.d.setSeconds(0),this.s.d.setMilliseconds(0)),this.s.d},_options:function(A,t,e){e=e||t;var n=this.dom.container.find("select."+this.c.classPrefix+"-"+A);n.empty();for(var r=0,i=t.length;r<i;r++)n.append('<option value="'+t[r]+'">'+e[r]+"</option>")},_optionSet:function(A,t){var e=(A=this.dom.container.find("select."+this.c.classPrefix+"-"+A)).parent().children("span");A.val(t),t=A.find("option:selected");e.html(0!==t.length?t.text():this.c.i18n.unknown)},_optionsTime:function(t,e,n,r,i){var o,s=this.c.classPrefix,a=this.dom.container.find("div."+s+"-"+t),c=12===e?function(A){return A}:this._pad,B=(s=this.c.classPrefix)+"-table",g=this.c.i18n;if(a.length){var l="",u=10,w=function(i,o,a){12===e&&"number"==typeof i&&(12<=n&&(i+=12),12==i?i=0:24==i&&(i=12));var c=n===i||"am"===i&&n<12||"pm"===i&&12<=n?"selected":"";return"number"==typeof i&&r&&-1===A.inArray(i,r)&&(c+=" disabled"),a&&(c+=" "+a),'<td class="selectable '+c+'"><button class="'+s+"-button "+s+'-day" type="button" data-unit="'+t+'" data-value="'+i+'"><span>'+o+"</span></button></td>"};if(12===e){for(l+="<tr>",o=1;o<=6;o++)l+=w(o,c(o));for(l=(l+=w("am",g.amPm[0]))+"</tr><tr>",o=7;o<=12;o++)l+=w(o,c(o));l=l+w("pm",g.amPm[1])+"</tr>",u=7}else{if(24===e)for(var h=0,E=0;E<4;E++){for(l+="<tr>",o=0;o<6;o++)l+=w(h,c(h)),h++;l+="</tr>"}else{for(l+="<tr>",E=0;E<60;E+=10)l+=w(E,c(E),"range");l=l+'</tr></tbody></thead><table class="'+B+" "+B+'-nospace"><tbody>';var f=null!==i?i:-1===n?0:10*Math.floor(n/10);for(l+="<tr>",E=f+1;E<f+10;E++)l+=w(E,c(E));l+="</tr>"}u=6}a.empty().append('<table class="'+B+'"><thead><tr><th colspan="'+u+'">'+g[t]+"</th></tr></thead><tbody>"+l+"</tbody></table>")}},_optionsTitle:function(){var A=this.c.i18n,t=this.c.minDate,e=this.c.maxDate;t=t?t.getFullYear():null,e=e?e.getFullYear():null,t=null!==t?t:(new Date).getFullYear()-this.c.yearRange,e=null!==e?e:(new Date).getFullYear()+this.c.yearRange;this._options("month",this._range(0,11),A.months),this._options("year",this._range(t,e)),this.dom.today.text(A.today).text(A.today),this.dom.clear.text(A.clear).text(A.clear),this.dom.previous.attr("title",A.previous).children("button").text(A.previous),this.dom.next.attr("title",A.next).children("button").text(A.next)},_pad:function(A){return A<10?"0"+A:A},_position:function(){var e,n,r,i="input"===this.c.attachTo?this.dom.input.position():this.dom.input.offset(),o=this.dom.container,s=this.dom.input.outerHeight();o.hasClass("inline")?o.insertAfter(this.dom.input):(this.s.parts.date&&this.s.parts.time&&550<A(t).width()?o.addClass("horizontal"):o.removeClass("horizontal"),"input"===this.c.attachTo?o.css({top:i.top+s,left:i.left}).insertAfter(this.dom.input):o.css({top:i.top+s,left:i.left}).appendTo("body"),e=o.outerHeight(),n=o.outerWidth(),r=A(t).scrollTop(),i.top+s+e-r>A(t).height()&&(s=i.top-e,o.css("top",s<0?0:s)),n+i.left>A(t).width()&&(r=A(t).width()-n,"input"===this.c.attachTo&&(r-=A(o).offsetParent().offset().left),o.css("left",r<0?0:r)))},_range:function(A,t,e){var n=[];e=e||1;for(var r=A;r<=t;r+=e)n.push(r);return n},_setCalander:function(){this.s.display&&this.dom.calendar.empty().append(this._htmlMonth(this.s.display.getUTCFullYear(),this.s.display.getUTCMonth()))},_setTitle:function(){this._optionSet("month",this.s.display.getUTCMonth()),this._optionSet("year",this.s.display.getUTCFullYear())},_setTime:function(){function A(A){return t.c[A+"Available"]||t._range(0,59,t.c[A+"Increment"])}var t=this,e=this.s.d,n=null,r=null!=(n=this._isLuxon()?i.DateTime.fromJSDate(e).toUTC():n)?n.hour:e?e.getUTCHours():-1;this._optionsTime("hours",this.s.parts.hours12?12:24,r,this.c.hoursAvailable),this._optionsTime("minutes",60,null!=n?n.minute:e?e.getUTCMinutes():-1,A("minutes"),this.s.minutesRange),this._optionsTime("seconds",60,null!=n?n.second:e?e.getSeconds():-1,A("seconds"),this.s.secondsRange)},_show:function(){var n=this,r=this.s.namespace,i=(this._position(),A(t).on("scroll."+r+" resize."+r,(function(){n._position()})),A("div.DTE_Body_Content").on("scroll."+r,(function(){n._position()})),A("div.dataTables_scrollBody").on("scroll."+r,(function(){n._position()})),this.dom.input[0].offsetParent);i!==e.body&&A(i).on("scroll."+r,(function(){n._position()})),A(e).on("keydown."+r,(function(A){9!==A.keyCode&&27!==A.keyCode&&13!==A.keyCode||n._hide()})),setTimeout((function(){A("body").on("click."+r,(function(t){A(t.target).parents().filter(n.dom.container).length||t.target===n.dom.input[0]||n._hide()}))}),10)},_writeOutput:function(A){var t=this.s.d,e="",n=this.dom.input;t&&(e=this._convert(t,null,this.c.format)),n.val(e),t=new Event("change",{bubbles:!0});n[0].dispatchEvent(t),"hidden"===n.attr("type")&&this.val(e,!1),A&&n.focus()}}),r.use=function(A){i=A},r._instance=0,r.type="DateTime",r.defaults={attachTo:"body",buttons:{clear:!1,today:!1},classPrefix:"dt-datetime",disableDays:null,firstDay:1,format:"YYYY-MM-DD",hoursAvailable:null,i18n:{clear:"Clear",previous:"Previous",next:"Next",months:["January","February","March","April","May","June","July","August","September","October","November","December"],weekdays:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],amPm:["am","pm"],hours:"Hour",minutes:"Minute",seconds:"Second",unknown:"-",today:"Today"},maxDate:null,minDate:null,minutesAvailable:null,minutesIncrement:1,strict:!0,locale:"en",onChange:function(){},secondsAvailable:null,secondsIncrement:1,showWeekNumber:!1,yearRange:25},r.version="1.5.0",r.factory=function(n,r){var i=!1;return n&&n.document&&(e=(t=n).document),r&&r.fn&&r.fn.jquery&&(A=r,i=!0),i},t.DateTime||(t.DateTime=r),t.DataTable&&(t.DataTable.DateTime=r),A.fn.dtDateTime=function(A){return this.each((function(){new r(this,A)}))},A.fn.dataTable&&(A.fn.dataTable.DateTime=r,A.fn.DataTable.DateTime=r,A.fn.dataTable.Editor)&&(A.fn.dataTable.Editor.DateTime=r),r})),
/*! © SpryMedia Ltd, Matthew Hasbach - datatables.net/license */
function(A){if("function"==typeof define&&define.amd)define(["jquery","datatables.net"],(function(t){return A(t,window,document)}));else if("object"==typeof exports){var t=require("jquery"),e=function(A,t){t.fn.dataTable||require("datatables.net")(A,t)};"undefined"==typeof window?module.exports=function(n,r){return n||(n=window),r||(r=t(n)),e(n,r),A(r,n,n.document)}:(e(window,t),module.exports=A(t,window,window.document))}else A(jQuery,window,document)}((function(A,t,e,n){"use strict";var r=A.fn.dataTable;
/**
 * @summary     ConditionalPaging
 * @description Hide paging controls when the amount of pages is <= 1
 * @version     1.0.0
 * @author      Matthew Hasbach (https://github.com/mjhasbach)
 * @copyright   Copyright 2015 Matthew Hasbach
 *
 * License      MIT - http://datatables.net/license/mit
 *
 * This feature plugin for DataTables hides paging controls when the amount
 * of pages is <= 1. The controls can either appear / disappear or fade in / out
 *
 * @example
 *    $('#myTable').DataTable({
 *        conditionalPaging: true
 *    });
 *
 * @example
 *    $('#myTable').DataTable({
 *        conditionalPaging: {
 *            style: 'fade',
 *            speed: 500 // optional
 *        }
 *    });
 */return A(e).on("init.dt",(function(t,e){if("dt"===t.namespace){var i=e.oInit.conditionalPaging||r.defaults.conditionalPaging;if(A.isPlainObject(i)||!0===i){var o=A.isPlainObject(i)?i:{},s=new r.Api(e),a=500,c=function(t){var e=A(s.table().container()).find("div.dataTables_paginate"),n=s.page.info().pages;t instanceof A.Event?n<=1?"fade"===o.style?e.stop().fadeTo(a,0):e.css("visibility","hidden"):"fade"===o.style?e.stop().fadeTo(a,1):e.css("visibility",""):n<=1&&("fade"===o.style?e.css("opacity",0):e.css("visibility","hidden"))};o.speed!==n&&(a=o.speed),c(null),s.on("draw.dt",c)}}})),r}));